#include "src/ast/ast.h"
#include "src/builtins/builtins-array-gen.h"
#include "src/builtins/builtins-bigint-gen.h"
#include "src/builtins/builtins-call-gen.h"
#include "src/builtins/builtins-collections-gen.h"
#include "src/builtins/builtins-constructor-gen.h"
#include "src/builtins/builtins-data-view-gen.h"
#include "src/builtins/builtins-iterator-gen.h"
#include "src/builtins/builtins-object-gen.h"
#include "src/builtins/builtins-promise-gen.h"
#include "src/builtins/builtins-promise.h"
#include "src/builtins/builtins-proxy-gen.h"
#include "src/builtins/builtins-regexp-gen.h"
#include "src/builtins/builtins-string-gen.h"
#include "src/builtins/builtins-typed-array-gen.h"
#include "src/builtins/builtins-utils-gen.h"
#include "src/builtins/builtins-wasm-gen.h"
#include "src/builtins/builtins.h"
#include "src/codegen/code-factory.h"
#include "src/debug/debug-wasm-objects.h"
#include "src/heap/factory-inl.h"
#include "src/ic/binary-op-assembler.h"
#include "src/ic/handler-configuration-inl.h"
#include "src/objects/arguments.h"
#include "src/objects/bigint.h"
#include "src/objects/call-site-info.h"
#include "src/objects/elements-kind.h"
#include "src/objects/free-space.h"
#include "src/objects/intl-objects.h"
#include "src/objects/js-atomics-synchronization.h"
#include "src/objects/js-break-iterator.h"
#include "src/objects/js-collator.h"
#include "src/objects/js-date-time-format.h"
#include "src/objects/js-display-names.h"
#include "src/objects/js-disposable-stack.h"
#include "src/objects/js-duration-format.h"
#include "src/objects/js-function.h"
#include "src/objects/js-generator.h"
#include "src/objects/js-iterator-helpers.h"
#include "src/objects/js-list-format.h"
#include "src/objects/js-locale.h"
#include "src/objects/js-number-format.h"
#include "src/objects/js-objects.h"
#include "src/objects/js-plural-rules.h"
#include "src/objects/js-promise.h"
#include "src/objects/js-raw-json.h"
#include "src/objects/js-regexp-string-iterator.h"
#include "src/objects/js-relative-time-format.h"
#include "src/objects/js-segment-iterator-inl.h"
#include "src/objects/js-segmenter.h"
#include "src/objects/js-segments.h"
#include "src/objects/js-shadow-realm.h"
#include "src/objects/js-shared-array.h"
#include "src/objects/js-struct.h"
#include "src/objects/js-temporal-objects.h"
#include "src/objects/js-weak-refs.h"
#include "src/objects/objects.h"
#include "src/objects/ordered-hash-table.h"
#include "src/objects/property-array.h"
#include "src/objects/property-descriptor-object.h"
#include "src/objects/source-text-module.h"
#include "src/objects/swiss-hash-table-helpers.h"
#include "src/objects/swiss-name-dictionary.h"
#include "src/objects/synthetic-module.h"
#include "src/objects/template-objects.h"
#include "src/objects/torque-defined-classes.h"
#include "src/objects/turbofan-types.h"
#include "src/objects/turboshaft-types.h"
#include "src/torque/runtime-support.h"
#include "src/wasm/value-type.h"
#include "src/wasm/wasm-linkage.h"
#include "src/wasm/wasm-module.h"
#include "src/codegen/code-stub-assembler-inl.h"
// Required Builtins:
#include "torque-generated/src/builtins/wasm-to-js-tq-csa.h"
#include "torque-generated/src/builtins/array-join-tq-csa.h"
#include "torque-generated/src/builtins/base-tq-csa.h"
#include "torque-generated/src/builtins/cast-tq-csa.h"
#include "torque-generated/src/builtins/convert-tq-csa.h"
#include "torque-generated/src/builtins/frames-tq-csa.h"
#include "torque-generated/src/builtins/torque-internal-tq-csa.h"
#include "torque-generated/src/objects/contexts-tq-csa.h"
#include "torque-generated/src/objects/fixed-array-tq-csa.h"
#include "torque-generated/src/builtins/js-to-js-tq-csa.h"
#include "torque-generated/src/builtins/js-to-wasm-tq-csa.h"
#include "torque-generated/src/builtins/wasm-tq-csa.h"
#include "torque-generated/src/builtins/wasm-to-js-tq-csa.h"
#include "torque-generated/src/wasm/wasm-objects-tq-csa.h"

namespace v8 {
namespace internal {

// https://source.chromium.org/chromium/chromium/src/+/main:v8/src/builtins/wasm-to-js.tq?l=28&c=1
void HandleF32Returns_0(compiler::CodeAssemblerState* state_, TNode<NativeContext> p_context, TorqueStructLocationAllocator_0 p_locationAllocator, TorqueStructReference_intptr_0 p_toRef, TNode<JSAny> p_retVal) {
  compiler::CodeAssembler ca_(state_);
  compiler::CodeAssembler::SourcePositionScope pos_scope(&ca_);
  compiler::CodeAssemblerParameterizedLabel<> block0(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block2(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block5(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block6(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block8(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block3(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block9(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block10(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block12(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block15(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block16(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block18(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block13(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block14(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block11(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block4(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block19(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
    ca_.Goto(&block0);

  if (block0.is_used()) {
    ca_.Bind(&block0);
    if ((wasm::kIsFpAlwaysDouble)) {
      ca_.Goto(&block2);
    } else {
      ca_.Goto(&block3);
    }
  }

  TNode<IntPtrT> tmp0;
  TNode<BoolT> tmp1;
  if (block2.is_used()) {
    ca_.Bind(&block2);
    tmp0 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp1 = CodeStubAssembler(state_).IntPtrGreaterThanOrEqual(TNode<IntPtrT>{p_locationAllocator.remainingFPRegs}, TNode<IntPtrT>{tmp0});
    ca_.Branch(tmp1, &block5, std::vector<compiler::Node*>{}, &block6, std::vector<compiler::Node*>{});
  }

  TNode<Union<HeapObject, TaggedIndex>> tmp2;
  TNode<IntPtrT> tmp3;
  TNode<Float64T> tmp4;
  TNode<Float64T> tmp5;
  if (block5.is_used()) {
    ca_.Bind(&block5);
    std::tie(tmp2, tmp3) = RefCast_float64_0(state_, TorqueStructReference_intptr_0{TNode<Union<HeapObject, TaggedIndex>>{p_toRef.object}, TNode<IntPtrT>{p_toRef.offset}, TorqueStructUnsafe_0{}}).Flatten();
    tmp4 = CodeStubAssembler(state_).ChangeTaggedToFloat64(TNode<Context>{p_context}, TNode<JSAny>{p_retVal});
    tmp5 = CodeStubAssembler(state_).Float64SilenceNaN(TNode<Float64T>{tmp4});
    CodeStubAssembler(state_).StoreReference<Float64T>(CodeStubAssembler::Reference{tmp2, tmp3}, tmp5);
    ca_.Goto(&block8);
  }

  TNode<Union<HeapObject, TaggedIndex>> tmp6;
  TNode<IntPtrT> tmp7;
  TNode<Float32T> tmp8;
  if (block6.is_used()) {
    ca_.Bind(&block6);
    std::tie(tmp6, tmp7) = RefCast_float32_0(state_, TorqueStructReference_intptr_0{TNode<Union<HeapObject, TaggedIndex>>{p_toRef.object}, TNode<IntPtrT>{p_toRef.offset}, TorqueStructUnsafe_0{}}).Flatten();
    tmp8 = ca_.CallBuiltin<Float32T>(Builtin::kWasmTaggedToFloat32, p_context, p_retVal);
    CodeStubAssembler(state_).StoreReference<Float32T>(CodeStubAssembler::Reference{tmp6, tmp7}, tmp8);
    ca_.Goto(&block8);
  }

  if (block8.is_used()) {
    ca_.Bind(&block8);
    ca_.Goto(&block4);
  }

  if (block3.is_used()) {
    ca_.Bind(&block3);
    if ((wasm::kIsBigEndian)) {
      ca_.Goto(&block9);
    } else {
      ca_.Goto(&block10);
    }
  }

  TNode<Float32T> tmp9;
  TNode<Uint32T> tmp10;
  TNode<IntPtrT> tmp11;
  TNode<IntPtrT> tmp12;
  TNode<IntPtrT> tmp13;
  if (block9.is_used()) {
    ca_.Bind(&block9);
    tmp9 = ca_.CallBuiltin<Float32T>(Builtin::kWasmTaggedToFloat32, p_context, p_retVal);
    tmp10 = Bitcast_WasmCodePointer_float32_0(state_, TNode<Float32T>{tmp9});
    tmp11 = Convert_intptr_WasmCodePointer_0(state_, TNode<Uint32T>{tmp10});
    tmp12 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x20ull));
    tmp13 = CodeStubAssembler(state_).WordShl(TNode<IntPtrT>{tmp11}, TNode<IntPtrT>{tmp12});
    CodeStubAssembler(state_).StoreReference<IntPtrT>(CodeStubAssembler::Reference{p_toRef.object, p_toRef.offset}, tmp13);
    ca_.Goto(&block11);
  }

  if (block10.is_used()) {
    ca_.Bind(&block10);
    if ((wasm::kIsBigEndianOnSim)) {
      ca_.Goto(&block12);
    } else {
      ca_.Goto(&block13);
    }
  }

  TNode<IntPtrT> tmp14;
  TNode<BoolT> tmp15;
  if (block12.is_used()) {
    ca_.Bind(&block12);
    tmp14 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp15 = CodeStubAssembler(state_).IntPtrGreaterThanOrEqual(TNode<IntPtrT>{p_locationAllocator.remainingFPRegs}, TNode<IntPtrT>{tmp14});
    ca_.Branch(tmp15, &block15, std::vector<compiler::Node*>{}, &block16, std::vector<compiler::Node*>{});
  }

  TNode<Float32T> tmp16;
  TNode<Uint32T> tmp17;
  TNode<IntPtrT> tmp18;
  TNode<IntPtrT> tmp19;
  TNode<IntPtrT> tmp20;
  if (block15.is_used()) {
    ca_.Bind(&block15);
    tmp16 = ca_.CallBuiltin<Float32T>(Builtin::kWasmTaggedToFloat32, p_context, p_retVal);
    tmp17 = Bitcast_WasmCodePointer_float32_0(state_, TNode<Float32T>{tmp16});
    tmp18 = Convert_intptr_WasmCodePointer_0(state_, TNode<Uint32T>{tmp17});
    tmp19 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x20ull));
    tmp20 = CodeStubAssembler(state_).WordShl(TNode<IntPtrT>{tmp18}, TNode<IntPtrT>{tmp19});
    CodeStubAssembler(state_).StoreReference<IntPtrT>(CodeStubAssembler::Reference{p_toRef.object, p_toRef.offset}, tmp20);
    ca_.Goto(&block18);
  }

  TNode<Float32T> tmp21;
  TNode<Uint32T> tmp22;
  TNode<IntPtrT> tmp23;
  if (block16.is_used()) {
    ca_.Bind(&block16);
    tmp21 = ca_.CallBuiltin<Float32T>(Builtin::kWasmTaggedToFloat32, p_context, p_retVal);
    tmp22 = Bitcast_WasmCodePointer_float32_0(state_, TNode<Float32T>{tmp21});
    tmp23 = Convert_intptr_WasmCodePointer_0(state_, TNode<Uint32T>{tmp22});
    CodeStubAssembler(state_).StoreReference<IntPtrT>(CodeStubAssembler::Reference{p_toRef.object, p_toRef.offset}, tmp23);
    ca_.Goto(&block18);
  }

  if (block18.is_used()) {
    ca_.Bind(&block18);
    ca_.Goto(&block14);
  }

  if (block13.is_used()) {
    ca_.Bind(&block13);
    ca_.Goto(&block14);
  }

  if (block14.is_used()) {
    ca_.Bind(&block14);
    ca_.Goto(&block11);
  }

  if (block11.is_used()) {
    ca_.Bind(&block11);
    ca_.Goto(&block4);
  }

  if (block4.is_used()) {
    ca_.Bind(&block4);
    ca_.Goto(&block19);
  }

    ca_.Bind(&block19);
}

// https://source.chromium.org/chromium/chromium/src/+/main:v8/src/builtins/wasm-to-js.tq?l=50&c=1
TorqueStructWasmToJSResult WasmToJSWrapper_0(compiler::CodeAssemblerState* state_, TNode<WasmImportData> p_data) {
  compiler::CodeAssembler ca_(state_);
  compiler::CodeAssembler::SourcePositionScope pos_scope(&ca_);
  compiler::CodeAssemblerParameterizedLabel<> block0(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block15(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block16(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block20(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block19(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block24(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block23(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block29(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block30(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block36(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block34(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block45(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block49(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block50(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block52(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block53(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block55(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block56(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block51(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block48(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block57(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block58(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, Int32T> block59(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT> block64(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT> block65(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block46(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block68(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block72(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block73(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block75(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block76(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block78(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block79(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block74(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block71(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block80(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block83(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block84(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, Float32T> block86(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block81(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block87(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block90(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block91(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, Float32T> block93(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block88(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, Float32T> block89(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, Float32T> block82(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT> block98(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT> block99(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block69(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block102(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block105(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block109(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block110(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block112(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block113(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block115(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block116(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block111(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block108(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT> block121(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT> block122(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block106(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block126(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block127(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block129(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block130(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block132(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block133(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block128(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block125(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block135(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block136(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block138(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block139(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block141(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block142(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, Union<HeapObject, TaggedIndex>, IntPtrT> block137(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, Union<HeapObject, TaggedIndex>, IntPtrT> block134(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, Union<HeapObject, TaggedIndex>, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT> block147(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, Union<HeapObject, TaggedIndex>, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT> block148(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block107(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block103(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block151(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block155(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block156(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block157(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block161(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block162(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block164(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block165(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block160(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block158(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block154(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT> block170(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT> block171(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block152(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block175(&ca_, compiler::CodeAssemblerLabel::kDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block174(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block153(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block104(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block70(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block47(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block35(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block176(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block179(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block180(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block184(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block182(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block193(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block196(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block197(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block199(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block200(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block202(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block203(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block198(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block195(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT> block208(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT> block209(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, BoolT> block194(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block183(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT> block177(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT> block212(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT> block213(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, FixedArray> block214(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, IntPtrT> block216(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, IntPtrT> block217(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT> block218(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, IntPtrT> block219(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block223(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block221(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block225(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block226(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT, IntPtrT, IntPtrT, IntPtrT, IntPtrT> block232(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT, IntPtrT, IntPtrT, IntPtrT, IntPtrT> block233(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT, JSAny> block227(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block243(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block247(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block248(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block250(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block251(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block253(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block254(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block249(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block246(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT, JSAny, JSAny> block258(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT, JSAny, JSAny> block257(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT, JSAny> block255(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block244(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block259(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block263(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block264(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block266(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block267(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block269(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block270(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block265(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block262(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block271(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block272(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block273(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block260(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block274(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block278(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block279(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block280(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block284(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block285(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block287(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block288(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block283(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block281(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block277(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block275(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block289(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block292(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block296(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block297(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block299(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block300(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block302(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block303(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block298(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block295(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block293(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block305(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block306(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block308(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block309(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block311(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block312(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block307(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block304(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block314(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block315(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block317(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block318(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block320(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block321(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT, Union<HeapObject, TaggedIndex>, IntPtrT> block316(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT, Union<HeapObject, TaggedIndex>, IntPtrT> block313(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block294(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block290(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block323(&ca_, compiler::CodeAssemblerLabel::kDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block322(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block324(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block328(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block329(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block331(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block332(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block334(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block335(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block330(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny, Union<HeapObject, TaggedIndex>, IntPtrT> block327(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block325(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, JSAny, IntPtrT, IntPtrT, IntPtrT, IntPtrT> block340(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, JSAny, IntPtrT, IntPtrT, IntPtrT, IntPtrT> block341(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block326(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block291(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block276(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block261(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, JSAny> block245(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block222(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block344(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block347(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block348(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block352(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block350(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT> block361(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT> block364(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT> block365(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT> block367(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT> block368(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT> block370(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT> block371(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block366(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT> block363(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT> block376(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT, Union<HeapObject, TaggedIndex>, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT> block377(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, BoolT> block362(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, IntPtrT, BoolT> block351(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT, IntPtrT, IntPtrT, BoolT> block345(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block380(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
    ca_.Goto(&block0);

  TNode<RawPtrT> tmp0;
  TNode<RawPtrT> tmp1;
  TNode<IntPtrT> tmp2;
  TNode<RawPtrT> tmp3;
  TNode<IntPtrT> tmp4;
  TNode<Union<HeapObject, TaggedIndex>> tmp5;
  TNode<IntPtrT> tmp6;
  TNode<IntPtrT> tmp7;
  TNode<RawPtrT> tmp8;
  TNode<IntPtrT> tmp9;
  TNode<IntPtrT> tmp10;
  TNode<IntPtrT> tmp11;
  TNode<Int32T> tmp12;
  TNode<IntPtrT> tmp13;
  TNode<IntPtrT> tmp14;
  TNode<Smi> tmp15;
  TNode<Smi> tmp16;
  TNode<Smi> tmp17;
  TNode<IntPtrT> tmp18;
  TNode<Smi> tmp19;
  TNode<Smi> tmp20;
  TNode<BoolT> tmp21;
  if (block0.is_used()) {
    ca_.Bind(&block0);
    tmp0 = CodeStubAssembler(state_).SwitchToTheCentralStackIfNeeded();
    tmp1 = CodeStubAssembler(state_).LoadFramePointer();
    tmp2 = FromConstexpr_intptr_constexpr_intptr_0(state_, WasmToJSWrapperConstants::kSignatureOffset);
    tmp3 = CodeStubAssembler(state_).RawPtrAdd(TNode<RawPtrT>{tmp1}, TNode<IntPtrT>{tmp2});
    tmp4 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    std::tie(tmp5, tmp6) = GetRefAt_RawPtr_RawPtr_0(state_, TNode<RawPtrT>{tmp3}, TNode<IntPtrT>{tmp4}).Flatten();
    tmp7 = FromConstexpr_intptr_constexpr_int31_0(state_, 48);
    tmp8 = CodeStubAssembler(state_).LoadReference<RawPtrT>(CodeStubAssembler::Reference{p_data, tmp7});
    CodeStubAssembler(state_).StoreReference<RawPtrT>(CodeStubAssembler::Reference{tmp5, tmp6}, tmp8);
    tmp9 = CodeStubAssembler(state_).StackAlignmentInBytes();
    tmp10 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp11 = CodeStubAssembler(state_).IntPtrDiv(TNode<IntPtrT>{tmp9}, TNode<IntPtrT>{tmp10});
    tmp12 = FromConstexpr_int32_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    ModifyThreadInWasmFlag_0(state_, TNode<Int32T>{tmp12});
    tmp13 = FromConstexpr_intptr_constexpr_int31_0(state_, 40);
    tmp14 = FromConstexpr_intptr_constexpr_int31_0(state_, 40);
    tmp15 = CodeStubAssembler(state_).LoadReference<Smi>(CodeStubAssembler::Reference{p_data, tmp14});
    tmp16 = FromConstexpr_Smi_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x1ull));
    tmp17 = CodeStubAssembler(state_).SmiSub(TNode<Smi>{tmp15}, TNode<Smi>{tmp16});
    CodeStubAssembler(state_).StoreReference<Smi>(CodeStubAssembler::Reference{p_data, tmp13}, tmp17);
    tmp18 = FromConstexpr_intptr_constexpr_int31_0(state_, 40);
    tmp19 = CodeStubAssembler(state_).LoadReference<Smi>(CodeStubAssembler::Reference{p_data, tmp18});
    tmp20 = FromConstexpr_Smi_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp21 = CodeStubAssembler(state_).SmiEqual(TNode<Smi>{tmp19}, TNode<Smi>{tmp20});
    ca_.Branch(tmp21, &block15, std::vector<compiler::Node*>{}, &block16, std::vector<compiler::Node*>{});
  }

  TNode<Smi> tmp22;
  TNode<JSAny> tmp23;
  if (block15.is_used()) {
    ca_.Bind(&block15);
    tmp22 = kNoContext_0(state_);
    tmp23 = TORQUE_CAST(CodeStubAssembler(state_).CallRuntime(Runtime::kTierUpWasmToJSWrapper, tmp22, p_data)); 
    ca_.Goto(&block16);
  }

  TNode<IntPtrT> tmp24;
  TNode<RawPtrT> tmp25;
  TNode<IntPtrT> tmp26;
  TNode<RawPtrT> tmp27;
  TNode<RawPtrT> tmp28;
  TNode<Union<HeapObject, TaggedIndex>> tmp29;
  TNode<IntPtrT> tmp30;
  TNode<IntPtrT> tmp31;
  TNode<IntPtrT> tmp32;
  TNode<RawPtrT> tmp33;
  TNode<IntPtrT> tmp34;
  TNode<RawPtrT> tmp35;
  TNode<RawPtrT> tmp36;
  TNode<Union<HeapObject, TaggedIndex>> tmp37;
  TNode<IntPtrT> tmp38;
  TNode<IntPtrT> tmp39;
  TNode<IntPtrT> tmp40;
  TNode<RawPtrT> tmp41;
  TNode<IntPtrT> tmp42;
  TNode<RawPtrT> tmp43;
  TNode<RawPtrT> tmp44;
  TNode<Union<HeapObject, TaggedIndex>> tmp45;
  TNode<IntPtrT> tmp46;
  TNode<RawPtrT> tmp47;
  TNode<IntPtrT> tmp48;
  TNode<Union<HeapObject, TaggedIndex>> tmp49;
  TNode<IntPtrT> tmp50;
  TNode<IntPtrT> tmp51;
  TNode<IntPtrT> tmp52;
  TNode<Union<HeapObject, TaggedIndex>> tmp53;
  TNode<IntPtrT> tmp54;
  TNode<IntPtrT> tmp55;
  if (block16.is_used()) {
    ca_.Bind(&block16);
    tmp24 = FromConstexpr_intptr_constexpr_int31_0(state_, 48);
    tmp25 = CodeStubAssembler(state_).LoadReference<RawPtrT>(CodeStubAssembler::Reference{p_data, tmp24});
    tmp26 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp27 = CodeStubAssembler(state_).RawPtrAdd(TNode<RawPtrT>{tmp25}, TNode<IntPtrT>{tmp26});
    tmp28 = (TNode<RawPtrT>{tmp27});
    std::tie(tmp29, tmp30) = NewOffHeapReference_intptr_0(state_, TNode<RawPtrT>{tmp28}).Flatten();
    tmp31 = CodeStubAssembler(state_).LoadReference<IntPtrT>(CodeStubAssembler::Reference{tmp29, tmp30});
    tmp32 = FromConstexpr_intptr_constexpr_int31_0(state_, 48);
    tmp33 = CodeStubAssembler(state_).LoadReference<RawPtrT>(CodeStubAssembler::Reference{p_data, tmp32});
    tmp34 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp35 = CodeStubAssembler(state_).RawPtrAdd(TNode<RawPtrT>{tmp33}, TNode<IntPtrT>{tmp34});
    tmp36 = (TNode<RawPtrT>{tmp35});
    std::tie(tmp37, tmp38) = NewOffHeapReference_intptr_0(state_, TNode<RawPtrT>{tmp36}).Flatten();
    tmp39 = CodeStubAssembler(state_).LoadReference<IntPtrT>(CodeStubAssembler::Reference{tmp37, tmp38});
    tmp40 = FromConstexpr_intptr_constexpr_int31_0(state_, 48);
    tmp41 = CodeStubAssembler(state_).LoadReference<RawPtrT>(CodeStubAssembler::Reference{p_data, tmp40});
    tmp42 = FromConstexpr_intptr_constexpr_int31_0(state_, (CodeStubAssembler(state_).ConstexprInt31Mul((FromConstexpr_constexpr_int31_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x2ull))), (SizeOf_intptr_0(state_)))));
    tmp43 = CodeStubAssembler(state_).RawPtrAdd(TNode<RawPtrT>{tmp41}, TNode<IntPtrT>{tmp42});
    tmp44 = (TNode<RawPtrT>{tmp43});
    std::tie(tmp45, tmp46) = NewOffHeapReference_RawPtr_WasmCodePointer_0(state_, TNode<RawPtrT>{tmp44}).Flatten();
    tmp47 = CodeStubAssembler(state_).LoadReference<RawPtrT>(CodeStubAssembler::Reference{tmp45, tmp46});
    tmp48 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp39}, TNode<IntPtrT>{tmp31});
    std::tie(tmp49, tmp50, tmp51) = NewOffHeapConstSlice_WasmCodePointer_0(state_, TNode<RawPtrT>{tmp47}, TNode<IntPtrT>{tmp48}).Flatten();
    tmp52 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    compiler::CodeAssemblerLabel label56(&ca_);
    std::tie(tmp53, tmp54, tmp55) = Subslice_WasmCodePointer_0(state_, TorqueStructSlice_WasmCodePointer_ConstReference_WasmCodePointer_0{TNode<Union<HeapObject, TaggedIndex>>{tmp49}, TNode<IntPtrT>{tmp50}, TNode<IntPtrT>{tmp51}, TorqueStructUnsafe_0{}}, TNode<IntPtrT>{tmp52}, TNode<IntPtrT>{tmp31}, &label56).Flatten();
    ca_.Goto(&block19);
    if (label56.is_used()) {
      ca_.Bind(&label56);
      ca_.Goto(&block20);
    }
  }

  if (block20.is_used()) {
    ca_.Bind(&block20);
    CodeStubAssembler(state_).Unreachable();
  }

  TNode<Union<HeapObject, TaggedIndex>> tmp57;
  TNode<IntPtrT> tmp58;
  TNode<IntPtrT> tmp59;
  if (block19.is_used()) {
    ca_.Bind(&block19);
    compiler::CodeAssemblerLabel label60(&ca_);
    std::tie(tmp57, tmp58, tmp59) = Subslice_WasmCodePointer_0(state_, TorqueStructSlice_WasmCodePointer_ConstReference_WasmCodePointer_0{TNode<Union<HeapObject, TaggedIndex>>{tmp49}, TNode<IntPtrT>{tmp50}, TNode<IntPtrT>{tmp51}, TorqueStructUnsafe_0{}}, TNode<IntPtrT>{tmp31}, TNode<IntPtrT>{tmp39}, &label60).Flatten();
    ca_.Goto(&block23);
    if (label60.is_used()) {
      ca_.Bind(&label60);
      ca_.Goto(&block24);
    }
  }

  if (block24.is_used()) {
    ca_.Bind(&block24);
    CodeStubAssembler(state_).Unreachable();
  }

  TNode<IntPtrT> tmp61;
  TNode<IntPtrT> tmp62;
  TNode<FixedArray> tmp63;
  TNode<IntPtrT> tmp64;
  TNode<Union<HeapObject, TaggedIndex>> tmp65;
  TNode<IntPtrT> tmp66;
  TNode<IntPtrT> tmp67;
  TNode<IntPtrT> tmp68;
  TNode<IntPtrT> tmp69;
  TNode<UintPtrT> tmp70;
  TNode<UintPtrT> tmp71;
  TNode<BoolT> tmp72;
  if (block23.is_used()) {
    ca_.Bind(&block23);
    tmp61 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x1ull));
    tmp62 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp39}, TNode<IntPtrT>{tmp61});
    tmp63 = ca_.CallBuiltin<FixedArray>(Builtin::kWasmAllocateZeroedFixedArray, TNode<Object>(), tmp62);
    tmp64 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    std::tie(tmp65, tmp66, tmp67) = FieldSliceFixedArrayObjects_0(state_, TNode<FixedArray>{tmp63}).Flatten();
    tmp68 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp69 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp64}, TNode<IntPtrT>{tmp68});
    tmp70 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{tmp64});
    tmp71 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{tmp67});
    tmp72 = CodeStubAssembler(state_).UintPtrLessThan(TNode<UintPtrT>{tmp70}, TNode<UintPtrT>{tmp71});
    ca_.Branch(tmp72, &block29, std::vector<compiler::Node*>{}, &block30, std::vector<compiler::Node*>{});
  }

  TNode<IntPtrT> tmp73;
  TNode<IntPtrT> tmp74;
  TNode<Union<HeapObject, TaggedIndex>> tmp75;
  TNode<IntPtrT> tmp76;
  TNode<Undefined> tmp77;
  TNode<RawPtrT> tmp78;
  TNode<IntPtrT> tmp79;
  TNode<IntPtrT> tmp80;
  TNode<IntPtrT> tmp81;
  TNode<IntPtrT> tmp82;
  TNode<RawPtrT> tmp83;
  TNode<RawPtrT> tmp84;
  TNode<Union<HeapObject, TaggedIndex>> tmp85;
  TNode<IntPtrT> tmp86;
  TNode<IntPtrT> tmp87;
  TNode<Union<HeapObject, TaggedIndex>> tmp88;
  TNode<IntPtrT> tmp89;
  TNode<IntPtrT> tmp90;
  TNode<IntPtrT> tmp91;
  TNode<IntPtrT> tmp92;
  TNode<IntPtrT> tmp93;
  TNode<IntPtrT> tmp94;
  TNode<IntPtrT> tmp95;
  TNode<IntPtrT> tmp96;
  TNode<BoolT> tmp97;
  TNode<IntPtrT> tmp98;
  TNode<IntPtrT> tmp99;
  TNode<BoolT> tmp100;
  if (block29.is_used()) {
    ca_.Bind(&block29);
    tmp73 = TimesSizeOf_Object_0(state_, TNode<IntPtrT>{tmp64});
    tmp74 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp66}, TNode<IntPtrT>{tmp73});
    std::tie(tmp75, tmp76) = NewReference_Object_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp65}, TNode<IntPtrT>{tmp74}).Flatten();
    tmp77 = Undefined_0(state_);
    CodeStubAssembler(state_).StoreReference<Object>(CodeStubAssembler::Reference{tmp75, tmp76}, tmp77);
    tmp78 = CodeStubAssembler(state_).LoadFramePointer();
    tmp79 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x2ull));
    tmp80 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp79}, TNode<IntPtrT>{tmp11});
    tmp81 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp82 = CodeStubAssembler(state_).IntPtrMul(TNode<IntPtrT>{tmp80}, TNode<IntPtrT>{tmp81});
    tmp83 = CodeStubAssembler(state_).RawPtrAdd(TNode<RawPtrT>{tmp78}, TNode<IntPtrT>{tmp82});
    tmp84 = (TNode<RawPtrT>{tmp83});
    std::tie(tmp85, tmp86) = NewOffHeapReference_intptr_0(state_, TNode<RawPtrT>{tmp84}).Flatten();
    tmp87 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    std::tie(tmp88, tmp89, tmp90, tmp91, tmp92, tmp93, tmp94, tmp95, tmp96, tmp97) = LocationAllocatorForParams_0(state_, TorqueStructReference_intptr_0{TNode<Union<HeapObject, TaggedIndex>>{tmp85}, TNode<IntPtrT>{tmp86}, TorqueStructUnsafe_0{}}, TNode<IntPtrT>{tmp87}).Flatten();
    tmp98 = TimesSizeOf_WasmCodePointer_0(state_, TNode<IntPtrT>{tmp59});
    tmp99 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp58}, TNode<IntPtrT>{tmp98});
    tmp100 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block36, tmp69, tmp89, tmp90, tmp91, tmp92, tmp93, tmp96, tmp97, tmp58, tmp100);
  }

  if (block30.is_used()) {
    ca_.Bind(&block30);
    CodeStubAssembler(state_).Unreachable();
  }

  TNode<IntPtrT> phi_bb36_19;
  TNode<IntPtrT> phi_bb36_24;
  TNode<IntPtrT> phi_bb36_25;
  TNode<IntPtrT> phi_bb36_26;
  TNode<IntPtrT> phi_bb36_27;
  TNode<IntPtrT> phi_bb36_28;
  TNode<IntPtrT> phi_bb36_31;
  TNode<BoolT> phi_bb36_32;
  TNode<IntPtrT> phi_bb36_34;
  TNode<BoolT> phi_bb36_36;
  TNode<BoolT> tmp101;
  TNode<BoolT> tmp102;
  if (block36.is_used()) {
    ca_.Bind(&block36, &phi_bb36_19, &phi_bb36_24, &phi_bb36_25, &phi_bb36_26, &phi_bb36_27, &phi_bb36_28, &phi_bb36_31, &phi_bb36_32, &phi_bb36_34, &phi_bb36_36);
    tmp101 = CodeStubAssembler(state_).WordEqual(TNode<IntPtrT>{phi_bb36_34}, TNode<IntPtrT>{tmp99});
    tmp102 = CodeStubAssembler(state_).Word32BinaryNot(TNode<BoolT>{tmp101});
    ca_.Branch(tmp102, &block34, std::vector<compiler::Node*>{phi_bb36_19, phi_bb36_24, phi_bb36_25, phi_bb36_26, phi_bb36_27, phi_bb36_28, phi_bb36_31, phi_bb36_32, phi_bb36_34, phi_bb36_36}, &block35, std::vector<compiler::Node*>{phi_bb36_19, phi_bb36_24, phi_bb36_25, phi_bb36_26, phi_bb36_27, phi_bb36_28, phi_bb36_31, phi_bb36_32, phi_bb36_34, phi_bb36_36});
  }

  TNode<IntPtrT> phi_bb34_19;
  TNode<IntPtrT> phi_bb34_24;
  TNode<IntPtrT> phi_bb34_25;
  TNode<IntPtrT> phi_bb34_26;
  TNode<IntPtrT> phi_bb34_27;
  TNode<IntPtrT> phi_bb34_28;
  TNode<IntPtrT> phi_bb34_31;
  TNode<BoolT> phi_bb34_32;
  TNode<IntPtrT> phi_bb34_34;
  TNode<BoolT> phi_bb34_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp103;
  TNode<IntPtrT> tmp104;
  TNode<IntPtrT> tmp105;
  TNode<IntPtrT> tmp106;
  TNode<Uint32T> tmp107;
  TNode<Uint32T> tmp108;
  TNode<BoolT> tmp109;
  if (block34.is_used()) {
    ca_.Bind(&block34, &phi_bb34_19, &phi_bb34_24, &phi_bb34_25, &phi_bb34_26, &phi_bb34_27, &phi_bb34_28, &phi_bb34_31, &phi_bb34_32, &phi_bb34_34, &phi_bb34_36);
    std::tie(tmp103, tmp104) = NewReference_WasmCodePointer_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp57}, TNode<IntPtrT>{phi_bb34_34}).Flatten();
    tmp105 = FromConstexpr_intptr_constexpr_int31_0(state_, kInt32Size);
    tmp106 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb34_34}, TNode<IntPtrT>{tmp105});
    tmp107 = CodeStubAssembler(state_).LoadReference<Uint32T>(CodeStubAssembler::Reference{tmp103, tmp104});
    tmp108 = FromConstexpr_WasmCodePointer_constexpr_WasmCodePointer_0(state_, wasm::kWasmI32.raw_bit_field());
    tmp109 = CodeStubAssembler(state_).Word32Equal(TNode<Uint32T>{tmp107}, TNode<Uint32T>{tmp108});
    ca_.Branch(tmp109, &block45, std::vector<compiler::Node*>{phi_bb34_19, phi_bb34_24, phi_bb34_25, phi_bb34_26, phi_bb34_27, phi_bb34_28, phi_bb34_31, phi_bb34_32, phi_bb34_36}, &block46, std::vector<compiler::Node*>{phi_bb34_19, phi_bb34_24, phi_bb34_25, phi_bb34_26, phi_bb34_27, phi_bb34_28, phi_bb34_31, phi_bb34_32, phi_bb34_36});
  }

  TNode<IntPtrT> phi_bb45_19;
  TNode<IntPtrT> phi_bb45_24;
  TNode<IntPtrT> phi_bb45_25;
  TNode<IntPtrT> phi_bb45_26;
  TNode<IntPtrT> phi_bb45_27;
  TNode<IntPtrT> phi_bb45_28;
  TNode<IntPtrT> phi_bb45_31;
  TNode<BoolT> phi_bb45_32;
  TNode<BoolT> phi_bb45_36;
  TNode<IntPtrT> tmp110;
  TNode<IntPtrT> tmp111;
  TNode<IntPtrT> tmp112;
  TNode<BoolT> tmp113;
  if (block45.is_used()) {
    ca_.Bind(&block45, &phi_bb45_19, &phi_bb45_24, &phi_bb45_25, &phi_bb45_26, &phi_bb45_27, &phi_bb45_28, &phi_bb45_31, &phi_bb45_32, &phi_bb45_36);
    tmp110 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp111 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{phi_bb45_24}, TNode<IntPtrT>{tmp110});
    tmp112 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp113 = CodeStubAssembler(state_).IntPtrGreaterThan(TNode<IntPtrT>{phi_bb45_24}, TNode<IntPtrT>{tmp112});
    ca_.Branch(tmp113, &block49, std::vector<compiler::Node*>{phi_bb45_19, phi_bb45_25, phi_bb45_26, phi_bb45_27, phi_bb45_28, phi_bb45_31, phi_bb45_32, phi_bb45_36}, &block50, std::vector<compiler::Node*>{phi_bb45_19, phi_bb45_25, phi_bb45_26, phi_bb45_27, phi_bb45_28, phi_bb45_31, phi_bb45_32, phi_bb45_36});
  }

  TNode<IntPtrT> phi_bb49_19;
  TNode<IntPtrT> phi_bb49_25;
  TNode<IntPtrT> phi_bb49_26;
  TNode<IntPtrT> phi_bb49_27;
  TNode<IntPtrT> phi_bb49_28;
  TNode<IntPtrT> phi_bb49_31;
  TNode<BoolT> phi_bb49_32;
  TNode<BoolT> phi_bb49_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp114;
  TNode<IntPtrT> tmp115;
  TNode<IntPtrT> tmp116;
  TNode<IntPtrT> tmp117;
  if (block49.is_used()) {
    ca_.Bind(&block49, &phi_bb49_19, &phi_bb49_25, &phi_bb49_26, &phi_bb49_27, &phi_bb49_28, &phi_bb49_31, &phi_bb49_32, &phi_bb49_36);
    std::tie(tmp114, tmp115) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb49_26}).Flatten();
    tmp116 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp117 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb49_26}, TNode<IntPtrT>{tmp116});
    ca_.Goto(&block48, phi_bb49_19, phi_bb49_25, tmp117, phi_bb49_27, phi_bb49_28, phi_bb49_31, phi_bb49_32, phi_bb49_36, tmp114, tmp115);
  }

  TNode<IntPtrT> phi_bb50_19;
  TNode<IntPtrT> phi_bb50_25;
  TNode<IntPtrT> phi_bb50_26;
  TNode<IntPtrT> phi_bb50_27;
  TNode<IntPtrT> phi_bb50_28;
  TNode<IntPtrT> phi_bb50_31;
  TNode<BoolT> phi_bb50_32;
  TNode<BoolT> phi_bb50_36;
  if (block50.is_used()) {
    ca_.Bind(&block50, &phi_bb50_19, &phi_bb50_25, &phi_bb50_26, &phi_bb50_27, &phi_bb50_28, &phi_bb50_31, &phi_bb50_32, &phi_bb50_36);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block52, phi_bb50_19, phi_bb50_25, phi_bb50_26, phi_bb50_27, phi_bb50_28, phi_bb50_31, phi_bb50_32, phi_bb50_36);
    } else {
      ca_.Goto(&block53, phi_bb50_19, phi_bb50_25, phi_bb50_26, phi_bb50_27, phi_bb50_28, phi_bb50_31, phi_bb50_32, phi_bb50_36);
    }
  }

  TNode<IntPtrT> phi_bb52_19;
  TNode<IntPtrT> phi_bb52_25;
  TNode<IntPtrT> phi_bb52_26;
  TNode<IntPtrT> phi_bb52_27;
  TNode<IntPtrT> phi_bb52_28;
  TNode<IntPtrT> phi_bb52_31;
  TNode<BoolT> phi_bb52_32;
  TNode<BoolT> phi_bb52_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp118;
  TNode<IntPtrT> tmp119;
  TNode<IntPtrT> tmp120;
  TNode<IntPtrT> tmp121;
  if (block52.is_used()) {
    ca_.Bind(&block52, &phi_bb52_19, &phi_bb52_25, &phi_bb52_26, &phi_bb52_27, &phi_bb52_28, &phi_bb52_31, &phi_bb52_32, &phi_bb52_36);
    std::tie(tmp118, tmp119) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb52_28}).Flatten();
    tmp120 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp121 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb52_28}, TNode<IntPtrT>{tmp120});
    ca_.Goto(&block51, phi_bb52_19, phi_bb52_25, phi_bb52_26, phi_bb52_27, tmp121, phi_bb52_31, phi_bb52_32, phi_bb52_36, tmp118, tmp119);
  }

  TNode<IntPtrT> phi_bb53_19;
  TNode<IntPtrT> phi_bb53_25;
  TNode<IntPtrT> phi_bb53_26;
  TNode<IntPtrT> phi_bb53_27;
  TNode<IntPtrT> phi_bb53_28;
  TNode<IntPtrT> phi_bb53_31;
  TNode<BoolT> phi_bb53_32;
  TNode<BoolT> phi_bb53_36;
  TNode<IntPtrT> tmp122;
  TNode<BoolT> tmp123;
  if (block53.is_used()) {
    ca_.Bind(&block53, &phi_bb53_19, &phi_bb53_25, &phi_bb53_26, &phi_bb53_27, &phi_bb53_28, &phi_bb53_31, &phi_bb53_32, &phi_bb53_36);
    tmp122 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp123 = CodeStubAssembler(state_).WordNotEqual(TNode<IntPtrT>{phi_bb53_31}, TNode<IntPtrT>{tmp122});
    ca_.Branch(tmp123, &block55, std::vector<compiler::Node*>{phi_bb53_19, phi_bb53_25, phi_bb53_26, phi_bb53_27, phi_bb53_28, phi_bb53_31, phi_bb53_32, phi_bb53_36}, &block56, std::vector<compiler::Node*>{phi_bb53_19, phi_bb53_25, phi_bb53_26, phi_bb53_27, phi_bb53_28, phi_bb53_31, phi_bb53_32, phi_bb53_36});
  }

  TNode<IntPtrT> phi_bb55_19;
  TNode<IntPtrT> phi_bb55_25;
  TNode<IntPtrT> phi_bb55_26;
  TNode<IntPtrT> phi_bb55_27;
  TNode<IntPtrT> phi_bb55_28;
  TNode<IntPtrT> phi_bb55_31;
  TNode<BoolT> phi_bb55_32;
  TNode<BoolT> phi_bb55_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp124;
  TNode<IntPtrT> tmp125;
  TNode<IntPtrT> tmp126;
  TNode<BoolT> tmp127;
  if (block55.is_used()) {
    ca_.Bind(&block55, &phi_bb55_19, &phi_bb55_25, &phi_bb55_26, &phi_bb55_27, &phi_bb55_28, &phi_bb55_31, &phi_bb55_32, &phi_bb55_36);
    std::tie(tmp124, tmp125) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb55_31}).Flatten();
    tmp126 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp127 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block51, phi_bb55_19, phi_bb55_25, phi_bb55_26, phi_bb55_27, phi_bb55_28, tmp126, tmp127, phi_bb55_36, tmp124, tmp125);
  }

  TNode<IntPtrT> phi_bb56_19;
  TNode<IntPtrT> phi_bb56_25;
  TNode<IntPtrT> phi_bb56_26;
  TNode<IntPtrT> phi_bb56_27;
  TNode<IntPtrT> phi_bb56_28;
  TNode<IntPtrT> phi_bb56_31;
  TNode<BoolT> phi_bb56_32;
  TNode<BoolT> phi_bb56_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp128;
  TNode<IntPtrT> tmp129;
  TNode<IntPtrT> tmp130;
  TNode<IntPtrT> tmp131;
  TNode<IntPtrT> tmp132;
  TNode<IntPtrT> tmp133;
  TNode<BoolT> tmp134;
  if (block56.is_used()) {
    ca_.Bind(&block56, &phi_bb56_19, &phi_bb56_25, &phi_bb56_26, &phi_bb56_27, &phi_bb56_28, &phi_bb56_31, &phi_bb56_32, &phi_bb56_36);
    std::tie(tmp128, tmp129) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb56_28}).Flatten();
    tmp130 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp131 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb56_28}, TNode<IntPtrT>{tmp130});
    tmp132 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp133 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp131}, TNode<IntPtrT>{tmp132});
    tmp134 = FromConstexpr_bool_constexpr_bool_0(state_, true);
    ca_.Goto(&block51, phi_bb56_19, phi_bb56_25, phi_bb56_26, phi_bb56_27, tmp133, tmp131, tmp134, phi_bb56_36, tmp128, tmp129);
  }

  TNode<IntPtrT> phi_bb51_19;
  TNode<IntPtrT> phi_bb51_25;
  TNode<IntPtrT> phi_bb51_26;
  TNode<IntPtrT> phi_bb51_27;
  TNode<IntPtrT> phi_bb51_28;
  TNode<IntPtrT> phi_bb51_31;
  TNode<BoolT> phi_bb51_32;
  TNode<BoolT> phi_bb51_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb51_38;
  TNode<IntPtrT> phi_bb51_39;
  if (block51.is_used()) {
    ca_.Bind(&block51, &phi_bb51_19, &phi_bb51_25, &phi_bb51_26, &phi_bb51_27, &phi_bb51_28, &phi_bb51_31, &phi_bb51_32, &phi_bb51_36, &phi_bb51_38, &phi_bb51_39);
    ca_.Goto(&block48, phi_bb51_19, phi_bb51_25, phi_bb51_26, phi_bb51_27, phi_bb51_28, phi_bb51_31, phi_bb51_32, phi_bb51_36, phi_bb51_38, phi_bb51_39);
  }

  TNode<IntPtrT> phi_bb48_19;
  TNode<IntPtrT> phi_bb48_25;
  TNode<IntPtrT> phi_bb48_26;
  TNode<IntPtrT> phi_bb48_27;
  TNode<IntPtrT> phi_bb48_28;
  TNode<IntPtrT> phi_bb48_31;
  TNode<BoolT> phi_bb48_32;
  TNode<BoolT> phi_bb48_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb48_38;
  TNode<IntPtrT> phi_bb48_39;
  if (block48.is_used()) {
    ca_.Bind(&block48, &phi_bb48_19, &phi_bb48_25, &phi_bb48_26, &phi_bb48_27, &phi_bb48_28, &phi_bb48_31, &phi_bb48_32, &phi_bb48_36, &phi_bb48_38, &phi_bb48_39);
    if ((wasm::kIsBigEndian)) {
      ca_.Goto(&block57, phi_bb48_19, phi_bb48_25, phi_bb48_26, phi_bb48_27, phi_bb48_28, phi_bb48_31, phi_bb48_32, phi_bb48_36, phi_bb48_38, phi_bb48_39);
    } else {
      ca_.Goto(&block58, phi_bb48_19, phi_bb48_25, phi_bb48_26, phi_bb48_27, phi_bb48_28, phi_bb48_31, phi_bb48_32, phi_bb48_36, phi_bb48_38, phi_bb48_39);
    }
  }

  TNode<IntPtrT> phi_bb57_19;
  TNode<IntPtrT> phi_bb57_25;
  TNode<IntPtrT> phi_bb57_26;
  TNode<IntPtrT> phi_bb57_27;
  TNode<IntPtrT> phi_bb57_28;
  TNode<IntPtrT> phi_bb57_31;
  TNode<BoolT> phi_bb57_32;
  TNode<BoolT> phi_bb57_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb57_38;
  TNode<IntPtrT> phi_bb57_39;
  TNode<Union<HeapObject, TaggedIndex>> tmp135;
  TNode<IntPtrT> tmp136;
  TNode<Int64T> tmp137;
  TNode<Int32T> tmp138;
  if (block57.is_used()) {
    ca_.Bind(&block57, &phi_bb57_19, &phi_bb57_25, &phi_bb57_26, &phi_bb57_27, &phi_bb57_28, &phi_bb57_31, &phi_bb57_32, &phi_bb57_36, &phi_bb57_38, &phi_bb57_39);
    std::tie(tmp135, tmp136) = RefCast_int64_0(state_, TorqueStructReference_intptr_0{TNode<Union<HeapObject, TaggedIndex>>{phi_bb57_38}, TNode<IntPtrT>{phi_bb57_39}, TorqueStructUnsafe_0{}}).Flatten();
    tmp137 = CodeStubAssembler(state_).LoadReference<Int64T>(CodeStubAssembler::Reference{tmp135, tmp136});
    tmp138 = CodeStubAssembler(state_).TruncateInt64ToInt32(TNode<Int64T>{tmp137});
    ca_.Goto(&block59, phi_bb57_19, phi_bb57_25, phi_bb57_26, phi_bb57_27, phi_bb57_28, phi_bb57_31, phi_bb57_32, phi_bb57_36, phi_bb57_38, phi_bb57_39, tmp138);
  }

  TNode<IntPtrT> phi_bb58_19;
  TNode<IntPtrT> phi_bb58_25;
  TNode<IntPtrT> phi_bb58_26;
  TNode<IntPtrT> phi_bb58_27;
  TNode<IntPtrT> phi_bb58_28;
  TNode<IntPtrT> phi_bb58_31;
  TNode<BoolT> phi_bb58_32;
  TNode<BoolT> phi_bb58_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb58_38;
  TNode<IntPtrT> phi_bb58_39;
  TNode<Union<HeapObject, TaggedIndex>> tmp139;
  TNode<IntPtrT> tmp140;
  TNode<Int32T> tmp141;
  if (block58.is_used()) {
    ca_.Bind(&block58, &phi_bb58_19, &phi_bb58_25, &phi_bb58_26, &phi_bb58_27, &phi_bb58_28, &phi_bb58_31, &phi_bb58_32, &phi_bb58_36, &phi_bb58_38, &phi_bb58_39);
    std::tie(tmp139, tmp140) = RefCast_int32_0(state_, TorqueStructReference_intptr_0{TNode<Union<HeapObject, TaggedIndex>>{phi_bb58_38}, TNode<IntPtrT>{phi_bb58_39}, TorqueStructUnsafe_0{}}).Flatten();
    tmp141 = CodeStubAssembler(state_).LoadReference<Int32T>(CodeStubAssembler::Reference{tmp139, tmp140});
    ca_.Goto(&block59, phi_bb58_19, phi_bb58_25, phi_bb58_26, phi_bb58_27, phi_bb58_28, phi_bb58_31, phi_bb58_32, phi_bb58_36, phi_bb58_38, phi_bb58_39, tmp141);
  }

  TNode<IntPtrT> phi_bb59_19;
  TNode<IntPtrT> phi_bb59_25;
  TNode<IntPtrT> phi_bb59_26;
  TNode<IntPtrT> phi_bb59_27;
  TNode<IntPtrT> phi_bb59_28;
  TNode<IntPtrT> phi_bb59_31;
  TNode<BoolT> phi_bb59_32;
  TNode<BoolT> phi_bb59_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb59_38;
  TNode<IntPtrT> phi_bb59_39;
  TNode<Int32T> phi_bb59_40;
  TNode<Union<HeapObject, TaggedIndex>> tmp142;
  TNode<IntPtrT> tmp143;
  TNode<IntPtrT> tmp144;
  TNode<IntPtrT> tmp145;
  TNode<IntPtrT> tmp146;
  TNode<UintPtrT> tmp147;
  TNode<UintPtrT> tmp148;
  TNode<BoolT> tmp149;
  if (block59.is_used()) {
    ca_.Bind(&block59, &phi_bb59_19, &phi_bb59_25, &phi_bb59_26, &phi_bb59_27, &phi_bb59_28, &phi_bb59_31, &phi_bb59_32, &phi_bb59_36, &phi_bb59_38, &phi_bb59_39, &phi_bb59_40);
    std::tie(tmp142, tmp143, tmp144) = FieldSliceFixedArrayObjects_0(state_, TNode<FixedArray>{tmp63}).Flatten();
    tmp145 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp146 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb59_19}, TNode<IntPtrT>{tmp145});
    tmp147 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{phi_bb59_19});
    tmp148 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{tmp144});
    tmp149 = CodeStubAssembler(state_).UintPtrLessThan(TNode<UintPtrT>{tmp147}, TNode<UintPtrT>{tmp148});
    ca_.Branch(tmp149, &block64, std::vector<compiler::Node*>{phi_bb59_25, phi_bb59_26, phi_bb59_27, phi_bb59_28, phi_bb59_31, phi_bb59_32, phi_bb59_36, phi_bb59_38, phi_bb59_39, phi_bb59_19, phi_bb59_19, phi_bb59_19, phi_bb59_19}, &block65, std::vector<compiler::Node*>{phi_bb59_25, phi_bb59_26, phi_bb59_27, phi_bb59_28, phi_bb59_31, phi_bb59_32, phi_bb59_36, phi_bb59_38, phi_bb59_39, phi_bb59_19, phi_bb59_19, phi_bb59_19, phi_bb59_19});
  }

  TNode<IntPtrT> phi_bb64_25;
  TNode<IntPtrT> phi_bb64_26;
  TNode<IntPtrT> phi_bb64_27;
  TNode<IntPtrT> phi_bb64_28;
  TNode<IntPtrT> phi_bb64_31;
  TNode<BoolT> phi_bb64_32;
  TNode<BoolT> phi_bb64_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb64_38;
  TNode<IntPtrT> phi_bb64_39;
  TNode<IntPtrT> phi_bb64_45;
  TNode<IntPtrT> phi_bb64_46;
  TNode<IntPtrT> phi_bb64_50;
  TNode<IntPtrT> phi_bb64_51;
  TNode<IntPtrT> tmp150;
  TNode<IntPtrT> tmp151;
  TNode<Union<HeapObject, TaggedIndex>> tmp152;
  TNode<IntPtrT> tmp153;
  TNode<Number> tmp154;
  if (block64.is_used()) {
    ca_.Bind(&block64, &phi_bb64_25, &phi_bb64_26, &phi_bb64_27, &phi_bb64_28, &phi_bb64_31, &phi_bb64_32, &phi_bb64_36, &phi_bb64_38, &phi_bb64_39, &phi_bb64_45, &phi_bb64_46, &phi_bb64_50, &phi_bb64_51);
    tmp150 = TimesSizeOf_Object_0(state_, TNode<IntPtrT>{phi_bb64_51});
    tmp151 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp143}, TNode<IntPtrT>{tmp150});
    std::tie(tmp152, tmp153) = NewReference_Object_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp142}, TNode<IntPtrT>{tmp151}).Flatten();
    tmp154 = Convert_Number_int32_0(state_, TNode<Int32T>{phi_bb59_40});
    CodeStubAssembler(state_).StoreReference<Object>(CodeStubAssembler::Reference{tmp152, tmp153}, tmp154);
    ca_.Goto(&block47, tmp146, tmp111, phi_bb64_25, phi_bb64_26, phi_bb64_27, phi_bb64_28, phi_bb64_31, phi_bb64_32, phi_bb64_36);
  }

  TNode<IntPtrT> phi_bb65_25;
  TNode<IntPtrT> phi_bb65_26;
  TNode<IntPtrT> phi_bb65_27;
  TNode<IntPtrT> phi_bb65_28;
  TNode<IntPtrT> phi_bb65_31;
  TNode<BoolT> phi_bb65_32;
  TNode<BoolT> phi_bb65_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb65_38;
  TNode<IntPtrT> phi_bb65_39;
  TNode<IntPtrT> phi_bb65_45;
  TNode<IntPtrT> phi_bb65_46;
  TNode<IntPtrT> phi_bb65_50;
  TNode<IntPtrT> phi_bb65_51;
  if (block65.is_used()) {
    ca_.Bind(&block65, &phi_bb65_25, &phi_bb65_26, &phi_bb65_27, &phi_bb65_28, &phi_bb65_31, &phi_bb65_32, &phi_bb65_36, &phi_bb65_38, &phi_bb65_39, &phi_bb65_45, &phi_bb65_46, &phi_bb65_50, &phi_bb65_51);
    CodeStubAssembler(state_).Unreachable();
  }

  TNode<IntPtrT> phi_bb46_19;
  TNode<IntPtrT> phi_bb46_24;
  TNode<IntPtrT> phi_bb46_25;
  TNode<IntPtrT> phi_bb46_26;
  TNode<IntPtrT> phi_bb46_27;
  TNode<IntPtrT> phi_bb46_28;
  TNode<IntPtrT> phi_bb46_31;
  TNode<BoolT> phi_bb46_32;
  TNode<BoolT> phi_bb46_36;
  TNode<Uint32T> tmp155;
  TNode<BoolT> tmp156;
  if (block46.is_used()) {
    ca_.Bind(&block46, &phi_bb46_19, &phi_bb46_24, &phi_bb46_25, &phi_bb46_26, &phi_bb46_27, &phi_bb46_28, &phi_bb46_31, &phi_bb46_32, &phi_bb46_36);
    tmp155 = FromConstexpr_WasmCodePointer_constexpr_WasmCodePointer_0(state_, wasm::kWasmF32.raw_bit_field());
    tmp156 = CodeStubAssembler(state_).Word32Equal(TNode<Uint32T>{tmp107}, TNode<Uint32T>{tmp155});
    ca_.Branch(tmp156, &block68, std::vector<compiler::Node*>{phi_bb46_19, phi_bb46_24, phi_bb46_25, phi_bb46_26, phi_bb46_27, phi_bb46_28, phi_bb46_31, phi_bb46_32, phi_bb46_36}, &block69, std::vector<compiler::Node*>{phi_bb46_19, phi_bb46_24, phi_bb46_25, phi_bb46_26, phi_bb46_27, phi_bb46_28, phi_bb46_31, phi_bb46_32, phi_bb46_36});
  }

  TNode<IntPtrT> phi_bb68_19;
  TNode<IntPtrT> phi_bb68_24;
  TNode<IntPtrT> phi_bb68_25;
  TNode<IntPtrT> phi_bb68_26;
  TNode<IntPtrT> phi_bb68_27;
  TNode<IntPtrT> phi_bb68_28;
  TNode<IntPtrT> phi_bb68_31;
  TNode<BoolT> phi_bb68_32;
  TNode<BoolT> phi_bb68_36;
  TNode<IntPtrT> tmp157;
  TNode<IntPtrT> tmp158;
  TNode<IntPtrT> tmp159;
  TNode<BoolT> tmp160;
  if (block68.is_used()) {
    ca_.Bind(&block68, &phi_bb68_19, &phi_bb68_24, &phi_bb68_25, &phi_bb68_26, &phi_bb68_27, &phi_bb68_28, &phi_bb68_31, &phi_bb68_32, &phi_bb68_36);
    tmp157 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp158 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{phi_bb68_25}, TNode<IntPtrT>{tmp157});
    tmp159 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp160 = CodeStubAssembler(state_).IntPtrGreaterThan(TNode<IntPtrT>{phi_bb68_25}, TNode<IntPtrT>{tmp159});
    ca_.Branch(tmp160, &block72, std::vector<compiler::Node*>{phi_bb68_19, phi_bb68_24, phi_bb68_26, phi_bb68_27, phi_bb68_28, phi_bb68_31, phi_bb68_32, phi_bb68_36}, &block73, std::vector<compiler::Node*>{phi_bb68_19, phi_bb68_24, phi_bb68_26, phi_bb68_27, phi_bb68_28, phi_bb68_31, phi_bb68_32, phi_bb68_36});
  }

  TNode<IntPtrT> phi_bb72_19;
  TNode<IntPtrT> phi_bb72_24;
  TNode<IntPtrT> phi_bb72_26;
  TNode<IntPtrT> phi_bb72_27;
  TNode<IntPtrT> phi_bb72_28;
  TNode<IntPtrT> phi_bb72_31;
  TNode<BoolT> phi_bb72_32;
  TNode<BoolT> phi_bb72_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp161;
  TNode<IntPtrT> tmp162;
  TNode<IntPtrT> tmp163;
  TNode<IntPtrT> tmp164;
  if (block72.is_used()) {
    ca_.Bind(&block72, &phi_bb72_19, &phi_bb72_24, &phi_bb72_26, &phi_bb72_27, &phi_bb72_28, &phi_bb72_31, &phi_bb72_32, &phi_bb72_36);
    std::tie(tmp161, tmp162) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb72_27}).Flatten();
    tmp163 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_float64_0(state_)));
    tmp164 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb72_27}, TNode<IntPtrT>{tmp163});
    ca_.Goto(&block71, phi_bb72_19, phi_bb72_24, phi_bb72_26, tmp164, phi_bb72_28, phi_bb72_31, phi_bb72_32, phi_bb72_36, tmp161, tmp162);
  }

  TNode<IntPtrT> phi_bb73_19;
  TNode<IntPtrT> phi_bb73_24;
  TNode<IntPtrT> phi_bb73_26;
  TNode<IntPtrT> phi_bb73_27;
  TNode<IntPtrT> phi_bb73_28;
  TNode<IntPtrT> phi_bb73_31;
  TNode<BoolT> phi_bb73_32;
  TNode<BoolT> phi_bb73_36;
  if (block73.is_used()) {
    ca_.Bind(&block73, &phi_bb73_19, &phi_bb73_24, &phi_bb73_26, &phi_bb73_27, &phi_bb73_28, &phi_bb73_31, &phi_bb73_32, &phi_bb73_36);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block75, phi_bb73_19, phi_bb73_24, phi_bb73_26, phi_bb73_27, phi_bb73_28, phi_bb73_31, phi_bb73_32, phi_bb73_36);
    } else {
      ca_.Goto(&block76, phi_bb73_19, phi_bb73_24, phi_bb73_26, phi_bb73_27, phi_bb73_28, phi_bb73_31, phi_bb73_32, phi_bb73_36);
    }
  }

  TNode<IntPtrT> phi_bb75_19;
  TNode<IntPtrT> phi_bb75_24;
  TNode<IntPtrT> phi_bb75_26;
  TNode<IntPtrT> phi_bb75_27;
  TNode<IntPtrT> phi_bb75_28;
  TNode<IntPtrT> phi_bb75_31;
  TNode<BoolT> phi_bb75_32;
  TNode<BoolT> phi_bb75_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp165;
  TNode<IntPtrT> tmp166;
  TNode<IntPtrT> tmp167;
  TNode<IntPtrT> tmp168;
  if (block75.is_used()) {
    ca_.Bind(&block75, &phi_bb75_19, &phi_bb75_24, &phi_bb75_26, &phi_bb75_27, &phi_bb75_28, &phi_bb75_31, &phi_bb75_32, &phi_bb75_36);
    std::tie(tmp165, tmp166) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb75_28}).Flatten();
    tmp167 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp168 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb75_28}, TNode<IntPtrT>{tmp167});
    ca_.Goto(&block74, phi_bb75_19, phi_bb75_24, phi_bb75_26, phi_bb75_27, tmp168, phi_bb75_31, phi_bb75_32, phi_bb75_36, tmp165, tmp166);
  }

  TNode<IntPtrT> phi_bb76_19;
  TNode<IntPtrT> phi_bb76_24;
  TNode<IntPtrT> phi_bb76_26;
  TNode<IntPtrT> phi_bb76_27;
  TNode<IntPtrT> phi_bb76_28;
  TNode<IntPtrT> phi_bb76_31;
  TNode<BoolT> phi_bb76_32;
  TNode<BoolT> phi_bb76_36;
  TNode<IntPtrT> tmp169;
  TNode<BoolT> tmp170;
  if (block76.is_used()) {
    ca_.Bind(&block76, &phi_bb76_19, &phi_bb76_24, &phi_bb76_26, &phi_bb76_27, &phi_bb76_28, &phi_bb76_31, &phi_bb76_32, &phi_bb76_36);
    tmp169 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp170 = CodeStubAssembler(state_).WordNotEqual(TNode<IntPtrT>{phi_bb76_31}, TNode<IntPtrT>{tmp169});
    ca_.Branch(tmp170, &block78, std::vector<compiler::Node*>{phi_bb76_19, phi_bb76_24, phi_bb76_26, phi_bb76_27, phi_bb76_28, phi_bb76_31, phi_bb76_32, phi_bb76_36}, &block79, std::vector<compiler::Node*>{phi_bb76_19, phi_bb76_24, phi_bb76_26, phi_bb76_27, phi_bb76_28, phi_bb76_31, phi_bb76_32, phi_bb76_36});
  }

  TNode<IntPtrT> phi_bb78_19;
  TNode<IntPtrT> phi_bb78_24;
  TNode<IntPtrT> phi_bb78_26;
  TNode<IntPtrT> phi_bb78_27;
  TNode<IntPtrT> phi_bb78_28;
  TNode<IntPtrT> phi_bb78_31;
  TNode<BoolT> phi_bb78_32;
  TNode<BoolT> phi_bb78_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp171;
  TNode<IntPtrT> tmp172;
  TNode<IntPtrT> tmp173;
  TNode<BoolT> tmp174;
  if (block78.is_used()) {
    ca_.Bind(&block78, &phi_bb78_19, &phi_bb78_24, &phi_bb78_26, &phi_bb78_27, &phi_bb78_28, &phi_bb78_31, &phi_bb78_32, &phi_bb78_36);
    std::tie(tmp171, tmp172) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb78_31}).Flatten();
    tmp173 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp174 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block74, phi_bb78_19, phi_bb78_24, phi_bb78_26, phi_bb78_27, phi_bb78_28, tmp173, tmp174, phi_bb78_36, tmp171, tmp172);
  }

  TNode<IntPtrT> phi_bb79_19;
  TNode<IntPtrT> phi_bb79_24;
  TNode<IntPtrT> phi_bb79_26;
  TNode<IntPtrT> phi_bb79_27;
  TNode<IntPtrT> phi_bb79_28;
  TNode<IntPtrT> phi_bb79_31;
  TNode<BoolT> phi_bb79_32;
  TNode<BoolT> phi_bb79_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp175;
  TNode<IntPtrT> tmp176;
  TNode<IntPtrT> tmp177;
  TNode<IntPtrT> tmp178;
  TNode<IntPtrT> tmp179;
  TNode<IntPtrT> tmp180;
  TNode<BoolT> tmp181;
  if (block79.is_used()) {
    ca_.Bind(&block79, &phi_bb79_19, &phi_bb79_24, &phi_bb79_26, &phi_bb79_27, &phi_bb79_28, &phi_bb79_31, &phi_bb79_32, &phi_bb79_36);
    std::tie(tmp175, tmp176) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb79_28}).Flatten();
    tmp177 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp178 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb79_28}, TNode<IntPtrT>{tmp177});
    tmp179 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp180 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp178}, TNode<IntPtrT>{tmp179});
    tmp181 = FromConstexpr_bool_constexpr_bool_0(state_, true);
    ca_.Goto(&block74, phi_bb79_19, phi_bb79_24, phi_bb79_26, phi_bb79_27, tmp180, tmp178, tmp181, phi_bb79_36, tmp175, tmp176);
  }

  TNode<IntPtrT> phi_bb74_19;
  TNode<IntPtrT> phi_bb74_24;
  TNode<IntPtrT> phi_bb74_26;
  TNode<IntPtrT> phi_bb74_27;
  TNode<IntPtrT> phi_bb74_28;
  TNode<IntPtrT> phi_bb74_31;
  TNode<BoolT> phi_bb74_32;
  TNode<BoolT> phi_bb74_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb74_38;
  TNode<IntPtrT> phi_bb74_39;
  if (block74.is_used()) {
    ca_.Bind(&block74, &phi_bb74_19, &phi_bb74_24, &phi_bb74_26, &phi_bb74_27, &phi_bb74_28, &phi_bb74_31, &phi_bb74_32, &phi_bb74_36, &phi_bb74_38, &phi_bb74_39);
    ca_.Goto(&block71, phi_bb74_19, phi_bb74_24, phi_bb74_26, phi_bb74_27, phi_bb74_28, phi_bb74_31, phi_bb74_32, phi_bb74_36, phi_bb74_38, phi_bb74_39);
  }

  TNode<IntPtrT> phi_bb71_19;
  TNode<IntPtrT> phi_bb71_24;
  TNode<IntPtrT> phi_bb71_26;
  TNode<IntPtrT> phi_bb71_27;
  TNode<IntPtrT> phi_bb71_28;
  TNode<IntPtrT> phi_bb71_31;
  TNode<BoolT> phi_bb71_32;
  TNode<BoolT> phi_bb71_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb71_38;
  TNode<IntPtrT> phi_bb71_39;
  if (block71.is_used()) {
    ca_.Bind(&block71, &phi_bb71_19, &phi_bb71_24, &phi_bb71_26, &phi_bb71_27, &phi_bb71_28, &phi_bb71_31, &phi_bb71_32, &phi_bb71_36, &phi_bb71_38, &phi_bb71_39);
    if ((wasm::kIsFpAlwaysDouble)) {
      ca_.Goto(&block80, phi_bb71_19, phi_bb71_24, phi_bb71_26, phi_bb71_27, phi_bb71_28, phi_bb71_31, phi_bb71_32, phi_bb71_36, phi_bb71_38, phi_bb71_39);
    } else {
      ca_.Goto(&block81, phi_bb71_19, phi_bb71_24, phi_bb71_26, phi_bb71_27, phi_bb71_28, phi_bb71_31, phi_bb71_32, phi_bb71_36, phi_bb71_38, phi_bb71_39);
    }
  }

  TNode<IntPtrT> phi_bb80_19;
  TNode<IntPtrT> phi_bb80_24;
  TNode<IntPtrT> phi_bb80_26;
  TNode<IntPtrT> phi_bb80_27;
  TNode<IntPtrT> phi_bb80_28;
  TNode<IntPtrT> phi_bb80_31;
  TNode<BoolT> phi_bb80_32;
  TNode<BoolT> phi_bb80_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb80_38;
  TNode<IntPtrT> phi_bb80_39;
  TNode<IntPtrT> tmp182;
  TNode<BoolT> tmp183;
  if (block80.is_used()) {
    ca_.Bind(&block80, &phi_bb80_19, &phi_bb80_24, &phi_bb80_26, &phi_bb80_27, &phi_bb80_28, &phi_bb80_31, &phi_bb80_32, &phi_bb80_36, &phi_bb80_38, &phi_bb80_39);
    tmp182 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp183 = CodeStubAssembler(state_).IntPtrGreaterThanOrEqual(TNode<IntPtrT>{tmp158}, TNode<IntPtrT>{tmp182});
    ca_.Branch(tmp183, &block83, std::vector<compiler::Node*>{phi_bb80_19, phi_bb80_24, phi_bb80_26, phi_bb80_27, phi_bb80_28, phi_bb80_31, phi_bb80_32, phi_bb80_36, phi_bb80_38, phi_bb80_39}, &block84, std::vector<compiler::Node*>{phi_bb80_19, phi_bb80_24, phi_bb80_26, phi_bb80_27, phi_bb80_28, phi_bb80_31, phi_bb80_32, phi_bb80_36, phi_bb80_38, phi_bb80_39});
  }

  TNode<IntPtrT> phi_bb83_19;
  TNode<IntPtrT> phi_bb83_24;
  TNode<IntPtrT> phi_bb83_26;
  TNode<IntPtrT> phi_bb83_27;
  TNode<IntPtrT> phi_bb83_28;
  TNode<IntPtrT> phi_bb83_31;
  TNode<BoolT> phi_bb83_32;
  TNode<BoolT> phi_bb83_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb83_38;
  TNode<IntPtrT> phi_bb83_39;
  TNode<Union<HeapObject, TaggedIndex>> tmp184;
  TNode<IntPtrT> tmp185;
  TNode<Float64T> tmp186;
  TNode<Float32T> tmp187;
  if (block83.is_used()) {
    ca_.Bind(&block83, &phi_bb83_19, &phi_bb83_24, &phi_bb83_26, &phi_bb83_27, &phi_bb83_28, &phi_bb83_31, &phi_bb83_32, &phi_bb83_36, &phi_bb83_38, &phi_bb83_39);
    std::tie(tmp184, tmp185) = RefCast_float64_0(state_, TorqueStructReference_intptr_0{TNode<Union<HeapObject, TaggedIndex>>{phi_bb83_38}, TNode<IntPtrT>{phi_bb83_39}, TorqueStructUnsafe_0{}}).Flatten();
    tmp186 = CodeStubAssembler(state_).LoadReference<Float64T>(CodeStubAssembler::Reference{tmp184, tmp185});
    tmp187 = CodeStubAssembler(state_).TruncateFloat64ToFloat32(TNode<Float64T>{tmp186});
    ca_.Goto(&block86, phi_bb83_19, phi_bb83_24, phi_bb83_26, phi_bb83_27, phi_bb83_28, phi_bb83_31, phi_bb83_32, phi_bb83_36, phi_bb83_38, phi_bb83_39, tmp187);
  }

  TNode<IntPtrT> phi_bb84_19;
  TNode<IntPtrT> phi_bb84_24;
  TNode<IntPtrT> phi_bb84_26;
  TNode<IntPtrT> phi_bb84_27;
  TNode<IntPtrT> phi_bb84_28;
  TNode<IntPtrT> phi_bb84_31;
  TNode<BoolT> phi_bb84_32;
  TNode<BoolT> phi_bb84_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb84_38;
  TNode<IntPtrT> phi_bb84_39;
  TNode<Union<HeapObject, TaggedIndex>> tmp188;
  TNode<IntPtrT> tmp189;
  TNode<Float32T> tmp190;
  if (block84.is_used()) {
    ca_.Bind(&block84, &phi_bb84_19, &phi_bb84_24, &phi_bb84_26, &phi_bb84_27, &phi_bb84_28, &phi_bb84_31, &phi_bb84_32, &phi_bb84_36, &phi_bb84_38, &phi_bb84_39);
    std::tie(tmp188, tmp189) = RefCast_float32_0(state_, TorqueStructReference_intptr_0{TNode<Union<HeapObject, TaggedIndex>>{phi_bb84_38}, TNode<IntPtrT>{phi_bb84_39}, TorqueStructUnsafe_0{}}).Flatten();
    tmp190 = CodeStubAssembler(state_).LoadReference<Float32T>(CodeStubAssembler::Reference{tmp188, tmp189});
    ca_.Goto(&block86, phi_bb84_19, phi_bb84_24, phi_bb84_26, phi_bb84_27, phi_bb84_28, phi_bb84_31, phi_bb84_32, phi_bb84_36, phi_bb84_38, phi_bb84_39, tmp190);
  }

  TNode<IntPtrT> phi_bb86_19;
  TNode<IntPtrT> phi_bb86_24;
  TNode<IntPtrT> phi_bb86_26;
  TNode<IntPtrT> phi_bb86_27;
  TNode<IntPtrT> phi_bb86_28;
  TNode<IntPtrT> phi_bb86_31;
  TNode<BoolT> phi_bb86_32;
  TNode<BoolT> phi_bb86_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb86_38;
  TNode<IntPtrT> phi_bb86_39;
  TNode<Float32T> phi_bb86_40;
  if (block86.is_used()) {
    ca_.Bind(&block86, &phi_bb86_19, &phi_bb86_24, &phi_bb86_26, &phi_bb86_27, &phi_bb86_28, &phi_bb86_31, &phi_bb86_32, &phi_bb86_36, &phi_bb86_38, &phi_bb86_39, &phi_bb86_40);
    ca_.Goto(&block82, phi_bb86_19, phi_bb86_24, phi_bb86_26, phi_bb86_27, phi_bb86_28, phi_bb86_31, phi_bb86_32, phi_bb86_36, phi_bb86_38, phi_bb86_39, phi_bb86_40);
  }

  TNode<IntPtrT> phi_bb81_19;
  TNode<IntPtrT> phi_bb81_24;
  TNode<IntPtrT> phi_bb81_26;
  TNode<IntPtrT> phi_bb81_27;
  TNode<IntPtrT> phi_bb81_28;
  TNode<IntPtrT> phi_bb81_31;
  TNode<BoolT> phi_bb81_32;
  TNode<BoolT> phi_bb81_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb81_38;
  TNode<IntPtrT> phi_bb81_39;
  if (block81.is_used()) {
    ca_.Bind(&block81, &phi_bb81_19, &phi_bb81_24, &phi_bb81_26, &phi_bb81_27, &phi_bb81_28, &phi_bb81_31, &phi_bb81_32, &phi_bb81_36, &phi_bb81_38, &phi_bb81_39);
    if ((wasm::kIsBigEndianOnSim)) {
      ca_.Goto(&block87, phi_bb81_19, phi_bb81_24, phi_bb81_26, phi_bb81_27, phi_bb81_28, phi_bb81_31, phi_bb81_32, phi_bb81_36, phi_bb81_38, phi_bb81_39);
    } else {
      ca_.Goto(&block88, phi_bb81_19, phi_bb81_24, phi_bb81_26, phi_bb81_27, phi_bb81_28, phi_bb81_31, phi_bb81_32, phi_bb81_36, phi_bb81_38, phi_bb81_39);
    }
  }

  TNode<IntPtrT> phi_bb87_19;
  TNode<IntPtrT> phi_bb87_24;
  TNode<IntPtrT> phi_bb87_26;
  TNode<IntPtrT> phi_bb87_27;
  TNode<IntPtrT> phi_bb87_28;
  TNode<IntPtrT> phi_bb87_31;
  TNode<BoolT> phi_bb87_32;
  TNode<BoolT> phi_bb87_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb87_38;
  TNode<IntPtrT> phi_bb87_39;
  TNode<IntPtrT> tmp191;
  TNode<BoolT> tmp192;
  if (block87.is_used()) {
    ca_.Bind(&block87, &phi_bb87_19, &phi_bb87_24, &phi_bb87_26, &phi_bb87_27, &phi_bb87_28, &phi_bb87_31, &phi_bb87_32, &phi_bb87_36, &phi_bb87_38, &phi_bb87_39);
    tmp191 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp192 = CodeStubAssembler(state_).IntPtrGreaterThanOrEqual(TNode<IntPtrT>{tmp158}, TNode<IntPtrT>{tmp191});
    ca_.Branch(tmp192, &block90, std::vector<compiler::Node*>{phi_bb87_19, phi_bb87_24, phi_bb87_26, phi_bb87_27, phi_bb87_28, phi_bb87_31, phi_bb87_32, phi_bb87_36, phi_bb87_38, phi_bb87_39}, &block91, std::vector<compiler::Node*>{phi_bb87_19, phi_bb87_24, phi_bb87_26, phi_bb87_27, phi_bb87_28, phi_bb87_31, phi_bb87_32, phi_bb87_36, phi_bb87_38, phi_bb87_39});
  }

  TNode<IntPtrT> phi_bb90_19;
  TNode<IntPtrT> phi_bb90_24;
  TNode<IntPtrT> phi_bb90_26;
  TNode<IntPtrT> phi_bb90_27;
  TNode<IntPtrT> phi_bb90_28;
  TNode<IntPtrT> phi_bb90_31;
  TNode<BoolT> phi_bb90_32;
  TNode<BoolT> phi_bb90_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb90_38;
  TNode<IntPtrT> phi_bb90_39;
  TNode<Union<HeapObject, TaggedIndex>> tmp193;
  TNode<IntPtrT> tmp194;
  TNode<Int64T> tmp195;
  TNode<Int64T> tmp196;
  TNode<Int64T> tmp197;
  TNode<Int32T> tmp198;
  TNode<Float32T> tmp199;
  if (block90.is_used()) {
    ca_.Bind(&block90, &phi_bb90_19, &phi_bb90_24, &phi_bb90_26, &phi_bb90_27, &phi_bb90_28, &phi_bb90_31, &phi_bb90_32, &phi_bb90_36, &phi_bb90_38, &phi_bb90_39);
    std::tie(tmp193, tmp194) = RefCast_int64_0(state_, TorqueStructReference_intptr_0{TNode<Union<HeapObject, TaggedIndex>>{phi_bb90_38}, TNode<IntPtrT>{phi_bb90_39}, TorqueStructUnsafe_0{}}).Flatten();
    tmp195 = CodeStubAssembler(state_).LoadReference<Int64T>(CodeStubAssembler::Reference{tmp193, tmp194});
    tmp196 = FromConstexpr_int64_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x20ull));
    tmp197 = CodeStubAssembler(state_).Word64Sar(TNode<Int64T>{tmp195}, TNode<Int64T>{tmp196});
    tmp198 = CodeStubAssembler(state_).TruncateInt64ToInt32(TNode<Int64T>{tmp197});
    tmp199 = CodeStubAssembler(state_).BitcastInt32ToFloat32(TNode<Int32T>{tmp198});
    ca_.Goto(&block93, phi_bb90_19, phi_bb90_24, phi_bb90_26, phi_bb90_27, phi_bb90_28, phi_bb90_31, phi_bb90_32, phi_bb90_36, phi_bb90_38, phi_bb90_39, tmp199);
  }

  TNode<IntPtrT> phi_bb91_19;
  TNode<IntPtrT> phi_bb91_24;
  TNode<IntPtrT> phi_bb91_26;
  TNode<IntPtrT> phi_bb91_27;
  TNode<IntPtrT> phi_bb91_28;
  TNode<IntPtrT> phi_bb91_31;
  TNode<BoolT> phi_bb91_32;
  TNode<BoolT> phi_bb91_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb91_38;
  TNode<IntPtrT> phi_bb91_39;
  TNode<Union<HeapObject, TaggedIndex>> tmp200;
  TNode<IntPtrT> tmp201;
  TNode<Float32T> tmp202;
  if (block91.is_used()) {
    ca_.Bind(&block91, &phi_bb91_19, &phi_bb91_24, &phi_bb91_26, &phi_bb91_27, &phi_bb91_28, &phi_bb91_31, &phi_bb91_32, &phi_bb91_36, &phi_bb91_38, &phi_bb91_39);
    std::tie(tmp200, tmp201) = RefCast_float32_0(state_, TorqueStructReference_intptr_0{TNode<Union<HeapObject, TaggedIndex>>{phi_bb91_38}, TNode<IntPtrT>{phi_bb91_39}, TorqueStructUnsafe_0{}}).Flatten();
    tmp202 = CodeStubAssembler(state_).LoadReference<Float32T>(CodeStubAssembler::Reference{tmp200, tmp201});
    ca_.Goto(&block93, phi_bb91_19, phi_bb91_24, phi_bb91_26, phi_bb91_27, phi_bb91_28, phi_bb91_31, phi_bb91_32, phi_bb91_36, phi_bb91_38, phi_bb91_39, tmp202);
  }

  TNode<IntPtrT> phi_bb93_19;
  TNode<IntPtrT> phi_bb93_24;
  TNode<IntPtrT> phi_bb93_26;
  TNode<IntPtrT> phi_bb93_27;
  TNode<IntPtrT> phi_bb93_28;
  TNode<IntPtrT> phi_bb93_31;
  TNode<BoolT> phi_bb93_32;
  TNode<BoolT> phi_bb93_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb93_38;
  TNode<IntPtrT> phi_bb93_39;
  TNode<Float32T> phi_bb93_40;
  if (block93.is_used()) {
    ca_.Bind(&block93, &phi_bb93_19, &phi_bb93_24, &phi_bb93_26, &phi_bb93_27, &phi_bb93_28, &phi_bb93_31, &phi_bb93_32, &phi_bb93_36, &phi_bb93_38, &phi_bb93_39, &phi_bb93_40);
    ca_.Goto(&block89, phi_bb93_19, phi_bb93_24, phi_bb93_26, phi_bb93_27, phi_bb93_28, phi_bb93_31, phi_bb93_32, phi_bb93_36, phi_bb93_38, phi_bb93_39, phi_bb93_40);
  }

  TNode<IntPtrT> phi_bb88_19;
  TNode<IntPtrT> phi_bb88_24;
  TNode<IntPtrT> phi_bb88_26;
  TNode<IntPtrT> phi_bb88_27;
  TNode<IntPtrT> phi_bb88_28;
  TNode<IntPtrT> phi_bb88_31;
  TNode<BoolT> phi_bb88_32;
  TNode<BoolT> phi_bb88_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb88_38;
  TNode<IntPtrT> phi_bb88_39;
  TNode<Union<HeapObject, TaggedIndex>> tmp203;
  TNode<IntPtrT> tmp204;
  TNode<Float32T> tmp205;
  if (block88.is_used()) {
    ca_.Bind(&block88, &phi_bb88_19, &phi_bb88_24, &phi_bb88_26, &phi_bb88_27, &phi_bb88_28, &phi_bb88_31, &phi_bb88_32, &phi_bb88_36, &phi_bb88_38, &phi_bb88_39);
    std::tie(tmp203, tmp204) = RefCast_float32_0(state_, TorqueStructReference_intptr_0{TNode<Union<HeapObject, TaggedIndex>>{phi_bb88_38}, TNode<IntPtrT>{phi_bb88_39}, TorqueStructUnsafe_0{}}).Flatten();
    tmp205 = CodeStubAssembler(state_).LoadReference<Float32T>(CodeStubAssembler::Reference{tmp203, tmp204});
    ca_.Goto(&block89, phi_bb88_19, phi_bb88_24, phi_bb88_26, phi_bb88_27, phi_bb88_28, phi_bb88_31, phi_bb88_32, phi_bb88_36, phi_bb88_38, phi_bb88_39, tmp205);
  }

  TNode<IntPtrT> phi_bb89_19;
  TNode<IntPtrT> phi_bb89_24;
  TNode<IntPtrT> phi_bb89_26;
  TNode<IntPtrT> phi_bb89_27;
  TNode<IntPtrT> phi_bb89_28;
  TNode<IntPtrT> phi_bb89_31;
  TNode<BoolT> phi_bb89_32;
  TNode<BoolT> phi_bb89_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb89_38;
  TNode<IntPtrT> phi_bb89_39;
  TNode<Float32T> phi_bb89_40;
  if (block89.is_used()) {
    ca_.Bind(&block89, &phi_bb89_19, &phi_bb89_24, &phi_bb89_26, &phi_bb89_27, &phi_bb89_28, &phi_bb89_31, &phi_bb89_32, &phi_bb89_36, &phi_bb89_38, &phi_bb89_39, &phi_bb89_40);
    ca_.Goto(&block82, phi_bb89_19, phi_bb89_24, phi_bb89_26, phi_bb89_27, phi_bb89_28, phi_bb89_31, phi_bb89_32, phi_bb89_36, phi_bb89_38, phi_bb89_39, phi_bb89_40);
  }

  TNode<IntPtrT> phi_bb82_19;
  TNode<IntPtrT> phi_bb82_24;
  TNode<IntPtrT> phi_bb82_26;
  TNode<IntPtrT> phi_bb82_27;
  TNode<IntPtrT> phi_bb82_28;
  TNode<IntPtrT> phi_bb82_31;
  TNode<BoolT> phi_bb82_32;
  TNode<BoolT> phi_bb82_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb82_38;
  TNode<IntPtrT> phi_bb82_39;
  TNode<Float32T> phi_bb82_40;
  TNode<Union<HeapObject, TaggedIndex>> tmp206;
  TNode<IntPtrT> tmp207;
  TNode<IntPtrT> tmp208;
  TNode<IntPtrT> tmp209;
  TNode<IntPtrT> tmp210;
  TNode<UintPtrT> tmp211;
  TNode<UintPtrT> tmp212;
  TNode<BoolT> tmp213;
  if (block82.is_used()) {
    ca_.Bind(&block82, &phi_bb82_19, &phi_bb82_24, &phi_bb82_26, &phi_bb82_27, &phi_bb82_28, &phi_bb82_31, &phi_bb82_32, &phi_bb82_36, &phi_bb82_38, &phi_bb82_39, &phi_bb82_40);
    std::tie(tmp206, tmp207, tmp208) = FieldSliceFixedArrayObjects_0(state_, TNode<FixedArray>{tmp63}).Flatten();
    tmp209 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp210 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb82_19}, TNode<IntPtrT>{tmp209});
    tmp211 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{phi_bb82_19});
    tmp212 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{tmp208});
    tmp213 = CodeStubAssembler(state_).UintPtrLessThan(TNode<UintPtrT>{tmp211}, TNode<UintPtrT>{tmp212});
    ca_.Branch(tmp213, &block98, std::vector<compiler::Node*>{phi_bb82_24, phi_bb82_26, phi_bb82_27, phi_bb82_28, phi_bb82_31, phi_bb82_32, phi_bb82_36, phi_bb82_38, phi_bb82_39, phi_bb82_19, phi_bb82_19, phi_bb82_19, phi_bb82_19}, &block99, std::vector<compiler::Node*>{phi_bb82_24, phi_bb82_26, phi_bb82_27, phi_bb82_28, phi_bb82_31, phi_bb82_32, phi_bb82_36, phi_bb82_38, phi_bb82_39, phi_bb82_19, phi_bb82_19, phi_bb82_19, phi_bb82_19});
  }

  TNode<IntPtrT> phi_bb98_24;
  TNode<IntPtrT> phi_bb98_26;
  TNode<IntPtrT> phi_bb98_27;
  TNode<IntPtrT> phi_bb98_28;
  TNode<IntPtrT> phi_bb98_31;
  TNode<BoolT> phi_bb98_32;
  TNode<BoolT> phi_bb98_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb98_38;
  TNode<IntPtrT> phi_bb98_39;
  TNode<IntPtrT> phi_bb98_45;
  TNode<IntPtrT> phi_bb98_46;
  TNode<IntPtrT> phi_bb98_50;
  TNode<IntPtrT> phi_bb98_51;
  TNode<IntPtrT> tmp214;
  TNode<IntPtrT> tmp215;
  TNode<Union<HeapObject, TaggedIndex>> tmp216;
  TNode<IntPtrT> tmp217;
  TNode<Number> tmp218;
  if (block98.is_used()) {
    ca_.Bind(&block98, &phi_bb98_24, &phi_bb98_26, &phi_bb98_27, &phi_bb98_28, &phi_bb98_31, &phi_bb98_32, &phi_bb98_36, &phi_bb98_38, &phi_bb98_39, &phi_bb98_45, &phi_bb98_46, &phi_bb98_50, &phi_bb98_51);
    tmp214 = TimesSizeOf_Object_0(state_, TNode<IntPtrT>{phi_bb98_51});
    tmp215 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp207}, TNode<IntPtrT>{tmp214});
    std::tie(tmp216, tmp217) = NewReference_Object_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp206}, TNode<IntPtrT>{tmp215}).Flatten();
    tmp218 = Convert_Number_float32_0(state_, TNode<Float32T>{phi_bb82_40});
    CodeStubAssembler(state_).StoreReference<Object>(CodeStubAssembler::Reference{tmp216, tmp217}, tmp218);
    ca_.Goto(&block70, tmp210, phi_bb98_24, tmp158, phi_bb98_26, phi_bb98_27, phi_bb98_28, phi_bb98_31, phi_bb98_32, phi_bb98_36);
  }

  TNode<IntPtrT> phi_bb99_24;
  TNode<IntPtrT> phi_bb99_26;
  TNode<IntPtrT> phi_bb99_27;
  TNode<IntPtrT> phi_bb99_28;
  TNode<IntPtrT> phi_bb99_31;
  TNode<BoolT> phi_bb99_32;
  TNode<BoolT> phi_bb99_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb99_38;
  TNode<IntPtrT> phi_bb99_39;
  TNode<IntPtrT> phi_bb99_45;
  TNode<IntPtrT> phi_bb99_46;
  TNode<IntPtrT> phi_bb99_50;
  TNode<IntPtrT> phi_bb99_51;
  if (block99.is_used()) {
    ca_.Bind(&block99, &phi_bb99_24, &phi_bb99_26, &phi_bb99_27, &phi_bb99_28, &phi_bb99_31, &phi_bb99_32, &phi_bb99_36, &phi_bb99_38, &phi_bb99_39, &phi_bb99_45, &phi_bb99_46, &phi_bb99_50, &phi_bb99_51);
    CodeStubAssembler(state_).Unreachable();
  }

  TNode<IntPtrT> phi_bb69_19;
  TNode<IntPtrT> phi_bb69_24;
  TNode<IntPtrT> phi_bb69_25;
  TNode<IntPtrT> phi_bb69_26;
  TNode<IntPtrT> phi_bb69_27;
  TNode<IntPtrT> phi_bb69_28;
  TNode<IntPtrT> phi_bb69_31;
  TNode<BoolT> phi_bb69_32;
  TNode<BoolT> phi_bb69_36;
  TNode<Uint32T> tmp219;
  TNode<BoolT> tmp220;
  if (block69.is_used()) {
    ca_.Bind(&block69, &phi_bb69_19, &phi_bb69_24, &phi_bb69_25, &phi_bb69_26, &phi_bb69_27, &phi_bb69_28, &phi_bb69_31, &phi_bb69_32, &phi_bb69_36);
    tmp219 = FromConstexpr_WasmCodePointer_constexpr_WasmCodePointer_0(state_, wasm::kWasmI64.raw_bit_field());
    tmp220 = CodeStubAssembler(state_).Word32Equal(TNode<Uint32T>{tmp107}, TNode<Uint32T>{tmp219});
    ca_.Branch(tmp220, &block102, std::vector<compiler::Node*>{phi_bb69_19, phi_bb69_24, phi_bb69_25, phi_bb69_26, phi_bb69_27, phi_bb69_28, phi_bb69_31, phi_bb69_32, phi_bb69_36}, &block103, std::vector<compiler::Node*>{phi_bb69_19, phi_bb69_24, phi_bb69_25, phi_bb69_26, phi_bb69_27, phi_bb69_28, phi_bb69_31, phi_bb69_32, phi_bb69_36});
  }

  TNode<IntPtrT> phi_bb102_19;
  TNode<IntPtrT> phi_bb102_24;
  TNode<IntPtrT> phi_bb102_25;
  TNode<IntPtrT> phi_bb102_26;
  TNode<IntPtrT> phi_bb102_27;
  TNode<IntPtrT> phi_bb102_28;
  TNode<IntPtrT> phi_bb102_31;
  TNode<BoolT> phi_bb102_32;
  TNode<BoolT> phi_bb102_36;
  if (block102.is_used()) {
    ca_.Bind(&block102, &phi_bb102_19, &phi_bb102_24, &phi_bb102_25, &phi_bb102_26, &phi_bb102_27, &phi_bb102_28, &phi_bb102_31, &phi_bb102_32, &phi_bb102_36);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block105, phi_bb102_19, phi_bb102_24, phi_bb102_25, phi_bb102_26, phi_bb102_27, phi_bb102_28, phi_bb102_31, phi_bb102_32, phi_bb102_36);
    } else {
      ca_.Goto(&block106, phi_bb102_19, phi_bb102_24, phi_bb102_25, phi_bb102_26, phi_bb102_27, phi_bb102_28, phi_bb102_31, phi_bb102_32, phi_bb102_36);
    }
  }

  TNode<IntPtrT> phi_bb105_19;
  TNode<IntPtrT> phi_bb105_24;
  TNode<IntPtrT> phi_bb105_25;
  TNode<IntPtrT> phi_bb105_26;
  TNode<IntPtrT> phi_bb105_27;
  TNode<IntPtrT> phi_bb105_28;
  TNode<IntPtrT> phi_bb105_31;
  TNode<BoolT> phi_bb105_32;
  TNode<BoolT> phi_bb105_36;
  TNode<IntPtrT> tmp221;
  TNode<IntPtrT> tmp222;
  TNode<IntPtrT> tmp223;
  TNode<BoolT> tmp224;
  if (block105.is_used()) {
    ca_.Bind(&block105, &phi_bb105_19, &phi_bb105_24, &phi_bb105_25, &phi_bb105_26, &phi_bb105_27, &phi_bb105_28, &phi_bb105_31, &phi_bb105_32, &phi_bb105_36);
    tmp221 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp222 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{phi_bb105_24}, TNode<IntPtrT>{tmp221});
    tmp223 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp224 = CodeStubAssembler(state_).IntPtrGreaterThan(TNode<IntPtrT>{phi_bb105_24}, TNode<IntPtrT>{tmp223});
    ca_.Branch(tmp224, &block109, std::vector<compiler::Node*>{phi_bb105_19, phi_bb105_25, phi_bb105_26, phi_bb105_27, phi_bb105_28, phi_bb105_31, phi_bb105_32, phi_bb105_36}, &block110, std::vector<compiler::Node*>{phi_bb105_19, phi_bb105_25, phi_bb105_26, phi_bb105_27, phi_bb105_28, phi_bb105_31, phi_bb105_32, phi_bb105_36});
  }

  TNode<IntPtrT> phi_bb109_19;
  TNode<IntPtrT> phi_bb109_25;
  TNode<IntPtrT> phi_bb109_26;
  TNode<IntPtrT> phi_bb109_27;
  TNode<IntPtrT> phi_bb109_28;
  TNode<IntPtrT> phi_bb109_31;
  TNode<BoolT> phi_bb109_32;
  TNode<BoolT> phi_bb109_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp225;
  TNode<IntPtrT> tmp226;
  TNode<IntPtrT> tmp227;
  TNode<IntPtrT> tmp228;
  if (block109.is_used()) {
    ca_.Bind(&block109, &phi_bb109_19, &phi_bb109_25, &phi_bb109_26, &phi_bb109_27, &phi_bb109_28, &phi_bb109_31, &phi_bb109_32, &phi_bb109_36);
    std::tie(tmp225, tmp226) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb109_26}).Flatten();
    tmp227 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp228 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb109_26}, TNode<IntPtrT>{tmp227});
    ca_.Goto(&block108, phi_bb109_19, phi_bb109_25, tmp228, phi_bb109_27, phi_bb109_28, phi_bb109_31, phi_bb109_32, phi_bb109_36, tmp225, tmp226);
  }

  TNode<IntPtrT> phi_bb110_19;
  TNode<IntPtrT> phi_bb110_25;
  TNode<IntPtrT> phi_bb110_26;
  TNode<IntPtrT> phi_bb110_27;
  TNode<IntPtrT> phi_bb110_28;
  TNode<IntPtrT> phi_bb110_31;
  TNode<BoolT> phi_bb110_32;
  TNode<BoolT> phi_bb110_36;
  if (block110.is_used()) {
    ca_.Bind(&block110, &phi_bb110_19, &phi_bb110_25, &phi_bb110_26, &phi_bb110_27, &phi_bb110_28, &phi_bb110_31, &phi_bb110_32, &phi_bb110_36);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block112, phi_bb110_19, phi_bb110_25, phi_bb110_26, phi_bb110_27, phi_bb110_28, phi_bb110_31, phi_bb110_32, phi_bb110_36);
    } else {
      ca_.Goto(&block113, phi_bb110_19, phi_bb110_25, phi_bb110_26, phi_bb110_27, phi_bb110_28, phi_bb110_31, phi_bb110_32, phi_bb110_36);
    }
  }

  TNode<IntPtrT> phi_bb112_19;
  TNode<IntPtrT> phi_bb112_25;
  TNode<IntPtrT> phi_bb112_26;
  TNode<IntPtrT> phi_bb112_27;
  TNode<IntPtrT> phi_bb112_28;
  TNode<IntPtrT> phi_bb112_31;
  TNode<BoolT> phi_bb112_32;
  TNode<BoolT> phi_bb112_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp229;
  TNode<IntPtrT> tmp230;
  TNode<IntPtrT> tmp231;
  TNode<IntPtrT> tmp232;
  if (block112.is_used()) {
    ca_.Bind(&block112, &phi_bb112_19, &phi_bb112_25, &phi_bb112_26, &phi_bb112_27, &phi_bb112_28, &phi_bb112_31, &phi_bb112_32, &phi_bb112_36);
    std::tie(tmp229, tmp230) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb112_28}).Flatten();
    tmp231 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp232 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb112_28}, TNode<IntPtrT>{tmp231});
    ca_.Goto(&block111, phi_bb112_19, phi_bb112_25, phi_bb112_26, phi_bb112_27, tmp232, phi_bb112_31, phi_bb112_32, phi_bb112_36, tmp229, tmp230);
  }

  TNode<IntPtrT> phi_bb113_19;
  TNode<IntPtrT> phi_bb113_25;
  TNode<IntPtrT> phi_bb113_26;
  TNode<IntPtrT> phi_bb113_27;
  TNode<IntPtrT> phi_bb113_28;
  TNode<IntPtrT> phi_bb113_31;
  TNode<BoolT> phi_bb113_32;
  TNode<BoolT> phi_bb113_36;
  TNode<IntPtrT> tmp233;
  TNode<BoolT> tmp234;
  if (block113.is_used()) {
    ca_.Bind(&block113, &phi_bb113_19, &phi_bb113_25, &phi_bb113_26, &phi_bb113_27, &phi_bb113_28, &phi_bb113_31, &phi_bb113_32, &phi_bb113_36);
    tmp233 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp234 = CodeStubAssembler(state_).WordNotEqual(TNode<IntPtrT>{phi_bb113_31}, TNode<IntPtrT>{tmp233});
    ca_.Branch(tmp234, &block115, std::vector<compiler::Node*>{phi_bb113_19, phi_bb113_25, phi_bb113_26, phi_bb113_27, phi_bb113_28, phi_bb113_31, phi_bb113_32, phi_bb113_36}, &block116, std::vector<compiler::Node*>{phi_bb113_19, phi_bb113_25, phi_bb113_26, phi_bb113_27, phi_bb113_28, phi_bb113_31, phi_bb113_32, phi_bb113_36});
  }

  TNode<IntPtrT> phi_bb115_19;
  TNode<IntPtrT> phi_bb115_25;
  TNode<IntPtrT> phi_bb115_26;
  TNode<IntPtrT> phi_bb115_27;
  TNode<IntPtrT> phi_bb115_28;
  TNode<IntPtrT> phi_bb115_31;
  TNode<BoolT> phi_bb115_32;
  TNode<BoolT> phi_bb115_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp235;
  TNode<IntPtrT> tmp236;
  TNode<IntPtrT> tmp237;
  TNode<BoolT> tmp238;
  if (block115.is_used()) {
    ca_.Bind(&block115, &phi_bb115_19, &phi_bb115_25, &phi_bb115_26, &phi_bb115_27, &phi_bb115_28, &phi_bb115_31, &phi_bb115_32, &phi_bb115_36);
    std::tie(tmp235, tmp236) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb115_31}).Flatten();
    tmp237 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp238 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block111, phi_bb115_19, phi_bb115_25, phi_bb115_26, phi_bb115_27, phi_bb115_28, tmp237, tmp238, phi_bb115_36, tmp235, tmp236);
  }

  TNode<IntPtrT> phi_bb116_19;
  TNode<IntPtrT> phi_bb116_25;
  TNode<IntPtrT> phi_bb116_26;
  TNode<IntPtrT> phi_bb116_27;
  TNode<IntPtrT> phi_bb116_28;
  TNode<IntPtrT> phi_bb116_31;
  TNode<BoolT> phi_bb116_32;
  TNode<BoolT> phi_bb116_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp239;
  TNode<IntPtrT> tmp240;
  TNode<IntPtrT> tmp241;
  TNode<IntPtrT> tmp242;
  TNode<IntPtrT> tmp243;
  TNode<IntPtrT> tmp244;
  TNode<BoolT> tmp245;
  if (block116.is_used()) {
    ca_.Bind(&block116, &phi_bb116_19, &phi_bb116_25, &phi_bb116_26, &phi_bb116_27, &phi_bb116_28, &phi_bb116_31, &phi_bb116_32, &phi_bb116_36);
    std::tie(tmp239, tmp240) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb116_28}).Flatten();
    tmp241 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp242 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb116_28}, TNode<IntPtrT>{tmp241});
    tmp243 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp244 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp242}, TNode<IntPtrT>{tmp243});
    tmp245 = FromConstexpr_bool_constexpr_bool_0(state_, true);
    ca_.Goto(&block111, phi_bb116_19, phi_bb116_25, phi_bb116_26, phi_bb116_27, tmp244, tmp242, tmp245, phi_bb116_36, tmp239, tmp240);
  }

  TNode<IntPtrT> phi_bb111_19;
  TNode<IntPtrT> phi_bb111_25;
  TNode<IntPtrT> phi_bb111_26;
  TNode<IntPtrT> phi_bb111_27;
  TNode<IntPtrT> phi_bb111_28;
  TNode<IntPtrT> phi_bb111_31;
  TNode<BoolT> phi_bb111_32;
  TNode<BoolT> phi_bb111_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb111_38;
  TNode<IntPtrT> phi_bb111_39;
  if (block111.is_used()) {
    ca_.Bind(&block111, &phi_bb111_19, &phi_bb111_25, &phi_bb111_26, &phi_bb111_27, &phi_bb111_28, &phi_bb111_31, &phi_bb111_32, &phi_bb111_36, &phi_bb111_38, &phi_bb111_39);
    ca_.Goto(&block108, phi_bb111_19, phi_bb111_25, phi_bb111_26, phi_bb111_27, phi_bb111_28, phi_bb111_31, phi_bb111_32, phi_bb111_36, phi_bb111_38, phi_bb111_39);
  }

  TNode<IntPtrT> phi_bb108_19;
  TNode<IntPtrT> phi_bb108_25;
  TNode<IntPtrT> phi_bb108_26;
  TNode<IntPtrT> phi_bb108_27;
  TNode<IntPtrT> phi_bb108_28;
  TNode<IntPtrT> phi_bb108_31;
  TNode<BoolT> phi_bb108_32;
  TNode<BoolT> phi_bb108_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb108_38;
  TNode<IntPtrT> phi_bb108_39;
  TNode<IntPtrT> tmp246;
  TNode<Union<HeapObject, TaggedIndex>> tmp247;
  TNode<IntPtrT> tmp248;
  TNode<IntPtrT> tmp249;
  TNode<IntPtrT> tmp250;
  TNode<IntPtrT> tmp251;
  TNode<UintPtrT> tmp252;
  TNode<UintPtrT> tmp253;
  TNode<BoolT> tmp254;
  if (block108.is_used()) {
    ca_.Bind(&block108, &phi_bb108_19, &phi_bb108_25, &phi_bb108_26, &phi_bb108_27, &phi_bb108_28, &phi_bb108_31, &phi_bb108_32, &phi_bb108_36, &phi_bb108_38, &phi_bb108_39);
    tmp246 = CodeStubAssembler(state_).LoadReference<IntPtrT>(CodeStubAssembler::Reference{phi_bb108_38, phi_bb108_39});
    std::tie(tmp247, tmp248, tmp249) = FieldSliceFixedArrayObjects_0(state_, TNode<FixedArray>{tmp63}).Flatten();
    tmp250 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp251 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb108_19}, TNode<IntPtrT>{tmp250});
    tmp252 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{phi_bb108_19});
    tmp253 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{tmp249});
    tmp254 = CodeStubAssembler(state_).UintPtrLessThan(TNode<UintPtrT>{tmp252}, TNode<UintPtrT>{tmp253});
    ca_.Branch(tmp254, &block121, std::vector<compiler::Node*>{phi_bb108_25, phi_bb108_26, phi_bb108_27, phi_bb108_28, phi_bb108_31, phi_bb108_32, phi_bb108_36, phi_bb108_38, phi_bb108_39, phi_bb108_19, phi_bb108_19, phi_bb108_19, phi_bb108_19}, &block122, std::vector<compiler::Node*>{phi_bb108_25, phi_bb108_26, phi_bb108_27, phi_bb108_28, phi_bb108_31, phi_bb108_32, phi_bb108_36, phi_bb108_38, phi_bb108_39, phi_bb108_19, phi_bb108_19, phi_bb108_19, phi_bb108_19});
  }

  TNode<IntPtrT> phi_bb121_25;
  TNode<IntPtrT> phi_bb121_26;
  TNode<IntPtrT> phi_bb121_27;
  TNode<IntPtrT> phi_bb121_28;
  TNode<IntPtrT> phi_bb121_31;
  TNode<BoolT> phi_bb121_32;
  TNode<BoolT> phi_bb121_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb121_38;
  TNode<IntPtrT> phi_bb121_39;
  TNode<IntPtrT> phi_bb121_45;
  TNode<IntPtrT> phi_bb121_46;
  TNode<IntPtrT> phi_bb121_50;
  TNode<IntPtrT> phi_bb121_51;
  TNode<IntPtrT> tmp255;
  TNode<IntPtrT> tmp256;
  TNode<Union<HeapObject, TaggedIndex>> tmp257;
  TNode<IntPtrT> tmp258;
  TNode<BigInt> tmp259;
  if (block121.is_used()) {
    ca_.Bind(&block121, &phi_bb121_25, &phi_bb121_26, &phi_bb121_27, &phi_bb121_28, &phi_bb121_31, &phi_bb121_32, &phi_bb121_36, &phi_bb121_38, &phi_bb121_39, &phi_bb121_45, &phi_bb121_46, &phi_bb121_50, &phi_bb121_51);
    tmp255 = TimesSizeOf_Object_0(state_, TNode<IntPtrT>{phi_bb121_51});
    tmp256 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp248}, TNode<IntPtrT>{tmp255});
    std::tie(tmp257, tmp258) = NewReference_Object_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp247}, TNode<IntPtrT>{tmp256}).Flatten();
    tmp259 = ca_.CallBuiltin<BigInt>(Builtin::kI64ToBigInt, TNode<Object>(), tmp246);
    CodeStubAssembler(state_).StoreReference<Object>(CodeStubAssembler::Reference{tmp257, tmp258}, tmp259);
    ca_.Goto(&block107, tmp251, tmp222, phi_bb121_25, phi_bb121_26, phi_bb121_27, phi_bb121_28, phi_bb121_31, phi_bb121_32, phi_bb121_36);
  }

  TNode<IntPtrT> phi_bb122_25;
  TNode<IntPtrT> phi_bb122_26;
  TNode<IntPtrT> phi_bb122_27;
  TNode<IntPtrT> phi_bb122_28;
  TNode<IntPtrT> phi_bb122_31;
  TNode<BoolT> phi_bb122_32;
  TNode<BoolT> phi_bb122_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb122_38;
  TNode<IntPtrT> phi_bb122_39;
  TNode<IntPtrT> phi_bb122_45;
  TNode<IntPtrT> phi_bb122_46;
  TNode<IntPtrT> phi_bb122_50;
  TNode<IntPtrT> phi_bb122_51;
  if (block122.is_used()) {
    ca_.Bind(&block122, &phi_bb122_25, &phi_bb122_26, &phi_bb122_27, &phi_bb122_28, &phi_bb122_31, &phi_bb122_32, &phi_bb122_36, &phi_bb122_38, &phi_bb122_39, &phi_bb122_45, &phi_bb122_46, &phi_bb122_50, &phi_bb122_51);
    CodeStubAssembler(state_).Unreachable();
  }

  TNode<IntPtrT> phi_bb106_19;
  TNode<IntPtrT> phi_bb106_24;
  TNode<IntPtrT> phi_bb106_25;
  TNode<IntPtrT> phi_bb106_26;
  TNode<IntPtrT> phi_bb106_27;
  TNode<IntPtrT> phi_bb106_28;
  TNode<IntPtrT> phi_bb106_31;
  TNode<BoolT> phi_bb106_32;
  TNode<BoolT> phi_bb106_36;
  TNode<IntPtrT> tmp260;
  TNode<IntPtrT> tmp261;
  TNode<IntPtrT> tmp262;
  TNode<BoolT> tmp263;
  if (block106.is_used()) {
    ca_.Bind(&block106, &phi_bb106_19, &phi_bb106_24, &phi_bb106_25, &phi_bb106_26, &phi_bb106_27, &phi_bb106_28, &phi_bb106_31, &phi_bb106_32, &phi_bb106_36);
    tmp260 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp261 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{phi_bb106_24}, TNode<IntPtrT>{tmp260});
    tmp262 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp263 = CodeStubAssembler(state_).IntPtrGreaterThan(TNode<IntPtrT>{phi_bb106_24}, TNode<IntPtrT>{tmp262});
    ca_.Branch(tmp263, &block126, std::vector<compiler::Node*>{phi_bb106_19, phi_bb106_25, phi_bb106_26, phi_bb106_27, phi_bb106_28, phi_bb106_31, phi_bb106_32, phi_bb106_36}, &block127, std::vector<compiler::Node*>{phi_bb106_19, phi_bb106_25, phi_bb106_26, phi_bb106_27, phi_bb106_28, phi_bb106_31, phi_bb106_32, phi_bb106_36});
  }

  TNode<IntPtrT> phi_bb126_19;
  TNode<IntPtrT> phi_bb126_25;
  TNode<IntPtrT> phi_bb126_26;
  TNode<IntPtrT> phi_bb126_27;
  TNode<IntPtrT> phi_bb126_28;
  TNode<IntPtrT> phi_bb126_31;
  TNode<BoolT> phi_bb126_32;
  TNode<BoolT> phi_bb126_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp264;
  TNode<IntPtrT> tmp265;
  TNode<IntPtrT> tmp266;
  TNode<IntPtrT> tmp267;
  if (block126.is_used()) {
    ca_.Bind(&block126, &phi_bb126_19, &phi_bb126_25, &phi_bb126_26, &phi_bb126_27, &phi_bb126_28, &phi_bb126_31, &phi_bb126_32, &phi_bb126_36);
    std::tie(tmp264, tmp265) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb126_26}).Flatten();
    tmp266 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp267 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb126_26}, TNode<IntPtrT>{tmp266});
    ca_.Goto(&block125, phi_bb126_19, phi_bb126_25, tmp267, phi_bb126_27, phi_bb126_28, phi_bb126_31, phi_bb126_32, phi_bb126_36, tmp264, tmp265);
  }

  TNode<IntPtrT> phi_bb127_19;
  TNode<IntPtrT> phi_bb127_25;
  TNode<IntPtrT> phi_bb127_26;
  TNode<IntPtrT> phi_bb127_27;
  TNode<IntPtrT> phi_bb127_28;
  TNode<IntPtrT> phi_bb127_31;
  TNode<BoolT> phi_bb127_32;
  TNode<BoolT> phi_bb127_36;
  if (block127.is_used()) {
    ca_.Bind(&block127, &phi_bb127_19, &phi_bb127_25, &phi_bb127_26, &phi_bb127_27, &phi_bb127_28, &phi_bb127_31, &phi_bb127_32, &phi_bb127_36);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block129, phi_bb127_19, phi_bb127_25, phi_bb127_26, phi_bb127_27, phi_bb127_28, phi_bb127_31, phi_bb127_32, phi_bb127_36);
    } else {
      ca_.Goto(&block130, phi_bb127_19, phi_bb127_25, phi_bb127_26, phi_bb127_27, phi_bb127_28, phi_bb127_31, phi_bb127_32, phi_bb127_36);
    }
  }

  TNode<IntPtrT> phi_bb129_19;
  TNode<IntPtrT> phi_bb129_25;
  TNode<IntPtrT> phi_bb129_26;
  TNode<IntPtrT> phi_bb129_27;
  TNode<IntPtrT> phi_bb129_28;
  TNode<IntPtrT> phi_bb129_31;
  TNode<BoolT> phi_bb129_32;
  TNode<BoolT> phi_bb129_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp268;
  TNode<IntPtrT> tmp269;
  TNode<IntPtrT> tmp270;
  TNode<IntPtrT> tmp271;
  if (block129.is_used()) {
    ca_.Bind(&block129, &phi_bb129_19, &phi_bb129_25, &phi_bb129_26, &phi_bb129_27, &phi_bb129_28, &phi_bb129_31, &phi_bb129_32, &phi_bb129_36);
    std::tie(tmp268, tmp269) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb129_28}).Flatten();
    tmp270 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp271 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb129_28}, TNode<IntPtrT>{tmp270});
    ca_.Goto(&block128, phi_bb129_19, phi_bb129_25, phi_bb129_26, phi_bb129_27, tmp271, phi_bb129_31, phi_bb129_32, phi_bb129_36, tmp268, tmp269);
  }

  TNode<IntPtrT> phi_bb130_19;
  TNode<IntPtrT> phi_bb130_25;
  TNode<IntPtrT> phi_bb130_26;
  TNode<IntPtrT> phi_bb130_27;
  TNode<IntPtrT> phi_bb130_28;
  TNode<IntPtrT> phi_bb130_31;
  TNode<BoolT> phi_bb130_32;
  TNode<BoolT> phi_bb130_36;
  TNode<IntPtrT> tmp272;
  TNode<BoolT> tmp273;
  if (block130.is_used()) {
    ca_.Bind(&block130, &phi_bb130_19, &phi_bb130_25, &phi_bb130_26, &phi_bb130_27, &phi_bb130_28, &phi_bb130_31, &phi_bb130_32, &phi_bb130_36);
    tmp272 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp273 = CodeStubAssembler(state_).WordNotEqual(TNode<IntPtrT>{phi_bb130_31}, TNode<IntPtrT>{tmp272});
    ca_.Branch(tmp273, &block132, std::vector<compiler::Node*>{phi_bb130_19, phi_bb130_25, phi_bb130_26, phi_bb130_27, phi_bb130_28, phi_bb130_31, phi_bb130_32, phi_bb130_36}, &block133, std::vector<compiler::Node*>{phi_bb130_19, phi_bb130_25, phi_bb130_26, phi_bb130_27, phi_bb130_28, phi_bb130_31, phi_bb130_32, phi_bb130_36});
  }

  TNode<IntPtrT> phi_bb132_19;
  TNode<IntPtrT> phi_bb132_25;
  TNode<IntPtrT> phi_bb132_26;
  TNode<IntPtrT> phi_bb132_27;
  TNode<IntPtrT> phi_bb132_28;
  TNode<IntPtrT> phi_bb132_31;
  TNode<BoolT> phi_bb132_32;
  TNode<BoolT> phi_bb132_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp274;
  TNode<IntPtrT> tmp275;
  TNode<IntPtrT> tmp276;
  TNode<BoolT> tmp277;
  if (block132.is_used()) {
    ca_.Bind(&block132, &phi_bb132_19, &phi_bb132_25, &phi_bb132_26, &phi_bb132_27, &phi_bb132_28, &phi_bb132_31, &phi_bb132_32, &phi_bb132_36);
    std::tie(tmp274, tmp275) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb132_31}).Flatten();
    tmp276 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp277 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block128, phi_bb132_19, phi_bb132_25, phi_bb132_26, phi_bb132_27, phi_bb132_28, tmp276, tmp277, phi_bb132_36, tmp274, tmp275);
  }

  TNode<IntPtrT> phi_bb133_19;
  TNode<IntPtrT> phi_bb133_25;
  TNode<IntPtrT> phi_bb133_26;
  TNode<IntPtrT> phi_bb133_27;
  TNode<IntPtrT> phi_bb133_28;
  TNode<IntPtrT> phi_bb133_31;
  TNode<BoolT> phi_bb133_32;
  TNode<BoolT> phi_bb133_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp278;
  TNode<IntPtrT> tmp279;
  TNode<IntPtrT> tmp280;
  TNode<IntPtrT> tmp281;
  TNode<IntPtrT> tmp282;
  TNode<IntPtrT> tmp283;
  TNode<BoolT> tmp284;
  if (block133.is_used()) {
    ca_.Bind(&block133, &phi_bb133_19, &phi_bb133_25, &phi_bb133_26, &phi_bb133_27, &phi_bb133_28, &phi_bb133_31, &phi_bb133_32, &phi_bb133_36);
    std::tie(tmp278, tmp279) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb133_28}).Flatten();
    tmp280 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp281 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb133_28}, TNode<IntPtrT>{tmp280});
    tmp282 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp283 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp281}, TNode<IntPtrT>{tmp282});
    tmp284 = FromConstexpr_bool_constexpr_bool_0(state_, true);
    ca_.Goto(&block128, phi_bb133_19, phi_bb133_25, phi_bb133_26, phi_bb133_27, tmp283, tmp281, tmp284, phi_bb133_36, tmp278, tmp279);
  }

  TNode<IntPtrT> phi_bb128_19;
  TNode<IntPtrT> phi_bb128_25;
  TNode<IntPtrT> phi_bb128_26;
  TNode<IntPtrT> phi_bb128_27;
  TNode<IntPtrT> phi_bb128_28;
  TNode<IntPtrT> phi_bb128_31;
  TNode<BoolT> phi_bb128_32;
  TNode<BoolT> phi_bb128_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb128_38;
  TNode<IntPtrT> phi_bb128_39;
  if (block128.is_used()) {
    ca_.Bind(&block128, &phi_bb128_19, &phi_bb128_25, &phi_bb128_26, &phi_bb128_27, &phi_bb128_28, &phi_bb128_31, &phi_bb128_32, &phi_bb128_36, &phi_bb128_38, &phi_bb128_39);
    ca_.Goto(&block125, phi_bb128_19, phi_bb128_25, phi_bb128_26, phi_bb128_27, phi_bb128_28, phi_bb128_31, phi_bb128_32, phi_bb128_36, phi_bb128_38, phi_bb128_39);
  }

  TNode<IntPtrT> phi_bb125_19;
  TNode<IntPtrT> phi_bb125_25;
  TNode<IntPtrT> phi_bb125_26;
  TNode<IntPtrT> phi_bb125_27;
  TNode<IntPtrT> phi_bb125_28;
  TNode<IntPtrT> phi_bb125_31;
  TNode<BoolT> phi_bb125_32;
  TNode<BoolT> phi_bb125_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb125_38;
  TNode<IntPtrT> phi_bb125_39;
  TNode<IntPtrT> tmp285;
  TNode<IntPtrT> tmp286;
  TNode<IntPtrT> tmp287;
  TNode<BoolT> tmp288;
  if (block125.is_used()) {
    ca_.Bind(&block125, &phi_bb125_19, &phi_bb125_25, &phi_bb125_26, &phi_bb125_27, &phi_bb125_28, &phi_bb125_31, &phi_bb125_32, &phi_bb125_36, &phi_bb125_38, &phi_bb125_39);
    tmp285 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp286 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{tmp261}, TNode<IntPtrT>{tmp285});
    tmp287 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp288 = CodeStubAssembler(state_).IntPtrGreaterThan(TNode<IntPtrT>{tmp261}, TNode<IntPtrT>{tmp287});
    ca_.Branch(tmp288, &block135, std::vector<compiler::Node*>{phi_bb125_19, phi_bb125_25, phi_bb125_26, phi_bb125_27, phi_bb125_28, phi_bb125_31, phi_bb125_32, phi_bb125_36, phi_bb125_38, phi_bb125_39}, &block136, std::vector<compiler::Node*>{phi_bb125_19, phi_bb125_25, phi_bb125_26, phi_bb125_27, phi_bb125_28, phi_bb125_31, phi_bb125_32, phi_bb125_36, phi_bb125_38, phi_bb125_39});
  }

  TNode<IntPtrT> phi_bb135_19;
  TNode<IntPtrT> phi_bb135_25;
  TNode<IntPtrT> phi_bb135_26;
  TNode<IntPtrT> phi_bb135_27;
  TNode<IntPtrT> phi_bb135_28;
  TNode<IntPtrT> phi_bb135_31;
  TNode<BoolT> phi_bb135_32;
  TNode<BoolT> phi_bb135_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb135_38;
  TNode<IntPtrT> phi_bb135_39;
  TNode<Union<HeapObject, TaggedIndex>> tmp289;
  TNode<IntPtrT> tmp290;
  TNode<IntPtrT> tmp291;
  TNode<IntPtrT> tmp292;
  if (block135.is_used()) {
    ca_.Bind(&block135, &phi_bb135_19, &phi_bb135_25, &phi_bb135_26, &phi_bb135_27, &phi_bb135_28, &phi_bb135_31, &phi_bb135_32, &phi_bb135_36, &phi_bb135_38, &phi_bb135_39);
    std::tie(tmp289, tmp290) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb135_26}).Flatten();
    tmp291 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp292 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb135_26}, TNode<IntPtrT>{tmp291});
    ca_.Goto(&block134, phi_bb135_19, phi_bb135_25, tmp292, phi_bb135_27, phi_bb135_28, phi_bb135_31, phi_bb135_32, phi_bb135_36, phi_bb135_38, phi_bb135_39, tmp289, tmp290);
  }

  TNode<IntPtrT> phi_bb136_19;
  TNode<IntPtrT> phi_bb136_25;
  TNode<IntPtrT> phi_bb136_26;
  TNode<IntPtrT> phi_bb136_27;
  TNode<IntPtrT> phi_bb136_28;
  TNode<IntPtrT> phi_bb136_31;
  TNode<BoolT> phi_bb136_32;
  TNode<BoolT> phi_bb136_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb136_38;
  TNode<IntPtrT> phi_bb136_39;
  if (block136.is_used()) {
    ca_.Bind(&block136, &phi_bb136_19, &phi_bb136_25, &phi_bb136_26, &phi_bb136_27, &phi_bb136_28, &phi_bb136_31, &phi_bb136_32, &phi_bb136_36, &phi_bb136_38, &phi_bb136_39);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block138, phi_bb136_19, phi_bb136_25, phi_bb136_26, phi_bb136_27, phi_bb136_28, phi_bb136_31, phi_bb136_32, phi_bb136_36, phi_bb136_38, phi_bb136_39);
    } else {
      ca_.Goto(&block139, phi_bb136_19, phi_bb136_25, phi_bb136_26, phi_bb136_27, phi_bb136_28, phi_bb136_31, phi_bb136_32, phi_bb136_36, phi_bb136_38, phi_bb136_39);
    }
  }

  TNode<IntPtrT> phi_bb138_19;
  TNode<IntPtrT> phi_bb138_25;
  TNode<IntPtrT> phi_bb138_26;
  TNode<IntPtrT> phi_bb138_27;
  TNode<IntPtrT> phi_bb138_28;
  TNode<IntPtrT> phi_bb138_31;
  TNode<BoolT> phi_bb138_32;
  TNode<BoolT> phi_bb138_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb138_38;
  TNode<IntPtrT> phi_bb138_39;
  TNode<Union<HeapObject, TaggedIndex>> tmp293;
  TNode<IntPtrT> tmp294;
  TNode<IntPtrT> tmp295;
  TNode<IntPtrT> tmp296;
  if (block138.is_used()) {
    ca_.Bind(&block138, &phi_bb138_19, &phi_bb138_25, &phi_bb138_26, &phi_bb138_27, &phi_bb138_28, &phi_bb138_31, &phi_bb138_32, &phi_bb138_36, &phi_bb138_38, &phi_bb138_39);
    std::tie(tmp293, tmp294) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb138_28}).Flatten();
    tmp295 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp296 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb138_28}, TNode<IntPtrT>{tmp295});
    ca_.Goto(&block137, phi_bb138_19, phi_bb138_25, phi_bb138_26, phi_bb138_27, tmp296, phi_bb138_31, phi_bb138_32, phi_bb138_36, phi_bb138_38, phi_bb138_39, tmp293, tmp294);
  }

  TNode<IntPtrT> phi_bb139_19;
  TNode<IntPtrT> phi_bb139_25;
  TNode<IntPtrT> phi_bb139_26;
  TNode<IntPtrT> phi_bb139_27;
  TNode<IntPtrT> phi_bb139_28;
  TNode<IntPtrT> phi_bb139_31;
  TNode<BoolT> phi_bb139_32;
  TNode<BoolT> phi_bb139_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb139_38;
  TNode<IntPtrT> phi_bb139_39;
  TNode<IntPtrT> tmp297;
  TNode<BoolT> tmp298;
  if (block139.is_used()) {
    ca_.Bind(&block139, &phi_bb139_19, &phi_bb139_25, &phi_bb139_26, &phi_bb139_27, &phi_bb139_28, &phi_bb139_31, &phi_bb139_32, &phi_bb139_36, &phi_bb139_38, &phi_bb139_39);
    tmp297 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp298 = CodeStubAssembler(state_).WordNotEqual(TNode<IntPtrT>{phi_bb139_31}, TNode<IntPtrT>{tmp297});
    ca_.Branch(tmp298, &block141, std::vector<compiler::Node*>{phi_bb139_19, phi_bb139_25, phi_bb139_26, phi_bb139_27, phi_bb139_28, phi_bb139_31, phi_bb139_32, phi_bb139_36, phi_bb139_38, phi_bb139_39}, &block142, std::vector<compiler::Node*>{phi_bb139_19, phi_bb139_25, phi_bb139_26, phi_bb139_27, phi_bb139_28, phi_bb139_31, phi_bb139_32, phi_bb139_36, phi_bb139_38, phi_bb139_39});
  }

  TNode<IntPtrT> phi_bb141_19;
  TNode<IntPtrT> phi_bb141_25;
  TNode<IntPtrT> phi_bb141_26;
  TNode<IntPtrT> phi_bb141_27;
  TNode<IntPtrT> phi_bb141_28;
  TNode<IntPtrT> phi_bb141_31;
  TNode<BoolT> phi_bb141_32;
  TNode<BoolT> phi_bb141_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb141_38;
  TNode<IntPtrT> phi_bb141_39;
  TNode<Union<HeapObject, TaggedIndex>> tmp299;
  TNode<IntPtrT> tmp300;
  TNode<IntPtrT> tmp301;
  TNode<BoolT> tmp302;
  if (block141.is_used()) {
    ca_.Bind(&block141, &phi_bb141_19, &phi_bb141_25, &phi_bb141_26, &phi_bb141_27, &phi_bb141_28, &phi_bb141_31, &phi_bb141_32, &phi_bb141_36, &phi_bb141_38, &phi_bb141_39);
    std::tie(tmp299, tmp300) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb141_31}).Flatten();
    tmp301 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp302 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block137, phi_bb141_19, phi_bb141_25, phi_bb141_26, phi_bb141_27, phi_bb141_28, tmp301, tmp302, phi_bb141_36, phi_bb141_38, phi_bb141_39, tmp299, tmp300);
  }

  TNode<IntPtrT> phi_bb142_19;
  TNode<IntPtrT> phi_bb142_25;
  TNode<IntPtrT> phi_bb142_26;
  TNode<IntPtrT> phi_bb142_27;
  TNode<IntPtrT> phi_bb142_28;
  TNode<IntPtrT> phi_bb142_31;
  TNode<BoolT> phi_bb142_32;
  TNode<BoolT> phi_bb142_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb142_38;
  TNode<IntPtrT> phi_bb142_39;
  TNode<Union<HeapObject, TaggedIndex>> tmp303;
  TNode<IntPtrT> tmp304;
  TNode<IntPtrT> tmp305;
  TNode<IntPtrT> tmp306;
  TNode<IntPtrT> tmp307;
  TNode<IntPtrT> tmp308;
  TNode<BoolT> tmp309;
  if (block142.is_used()) {
    ca_.Bind(&block142, &phi_bb142_19, &phi_bb142_25, &phi_bb142_26, &phi_bb142_27, &phi_bb142_28, &phi_bb142_31, &phi_bb142_32, &phi_bb142_36, &phi_bb142_38, &phi_bb142_39);
    std::tie(tmp303, tmp304) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb142_28}).Flatten();
    tmp305 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp306 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb142_28}, TNode<IntPtrT>{tmp305});
    tmp307 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp308 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp306}, TNode<IntPtrT>{tmp307});
    tmp309 = FromConstexpr_bool_constexpr_bool_0(state_, true);
    ca_.Goto(&block137, phi_bb142_19, phi_bb142_25, phi_bb142_26, phi_bb142_27, tmp308, tmp306, tmp309, phi_bb142_36, phi_bb142_38, phi_bb142_39, tmp303, tmp304);
  }

  TNode<IntPtrT> phi_bb137_19;
  TNode<IntPtrT> phi_bb137_25;
  TNode<IntPtrT> phi_bb137_26;
  TNode<IntPtrT> phi_bb137_27;
  TNode<IntPtrT> phi_bb137_28;
  TNode<IntPtrT> phi_bb137_31;
  TNode<BoolT> phi_bb137_32;
  TNode<BoolT> phi_bb137_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb137_38;
  TNode<IntPtrT> phi_bb137_39;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb137_40;
  TNode<IntPtrT> phi_bb137_41;
  if (block137.is_used()) {
    ca_.Bind(&block137, &phi_bb137_19, &phi_bb137_25, &phi_bb137_26, &phi_bb137_27, &phi_bb137_28, &phi_bb137_31, &phi_bb137_32, &phi_bb137_36, &phi_bb137_38, &phi_bb137_39, &phi_bb137_40, &phi_bb137_41);
    ca_.Goto(&block134, phi_bb137_19, phi_bb137_25, phi_bb137_26, phi_bb137_27, phi_bb137_28, phi_bb137_31, phi_bb137_32, phi_bb137_36, phi_bb137_38, phi_bb137_39, phi_bb137_40, phi_bb137_41);
  }

  TNode<IntPtrT> phi_bb134_19;
  TNode<IntPtrT> phi_bb134_25;
  TNode<IntPtrT> phi_bb134_26;
  TNode<IntPtrT> phi_bb134_27;
  TNode<IntPtrT> phi_bb134_28;
  TNode<IntPtrT> phi_bb134_31;
  TNode<BoolT> phi_bb134_32;
  TNode<BoolT> phi_bb134_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb134_38;
  TNode<IntPtrT> phi_bb134_39;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb134_40;
  TNode<IntPtrT> phi_bb134_41;
  TNode<IntPtrT> tmp310;
  TNode<IntPtrT> tmp311;
  TNode<Union<HeapObject, TaggedIndex>> tmp312;
  TNode<IntPtrT> tmp313;
  TNode<IntPtrT> tmp314;
  TNode<IntPtrT> tmp315;
  TNode<IntPtrT> tmp316;
  TNode<UintPtrT> tmp317;
  TNode<UintPtrT> tmp318;
  TNode<BoolT> tmp319;
  if (block134.is_used()) {
    ca_.Bind(&block134, &phi_bb134_19, &phi_bb134_25, &phi_bb134_26, &phi_bb134_27, &phi_bb134_28, &phi_bb134_31, &phi_bb134_32, &phi_bb134_36, &phi_bb134_38, &phi_bb134_39, &phi_bb134_40, &phi_bb134_41);
    tmp310 = CodeStubAssembler(state_).LoadReference<IntPtrT>(CodeStubAssembler::Reference{phi_bb134_38, phi_bb134_39});
    tmp311 = CodeStubAssembler(state_).LoadReference<IntPtrT>(CodeStubAssembler::Reference{phi_bb134_40, phi_bb134_41});
    std::tie(tmp312, tmp313, tmp314) = FieldSliceFixedArrayObjects_0(state_, TNode<FixedArray>{tmp63}).Flatten();
    tmp315 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp316 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb134_19}, TNode<IntPtrT>{tmp315});
    tmp317 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{phi_bb134_19});
    tmp318 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{tmp314});
    tmp319 = CodeStubAssembler(state_).UintPtrLessThan(TNode<UintPtrT>{tmp317}, TNode<UintPtrT>{tmp318});
    ca_.Branch(tmp319, &block147, std::vector<compiler::Node*>{phi_bb134_25, phi_bb134_26, phi_bb134_27, phi_bb134_28, phi_bb134_31, phi_bb134_32, phi_bb134_36, phi_bb134_38, phi_bb134_39, phi_bb134_40, phi_bb134_41, phi_bb134_19, phi_bb134_19, phi_bb134_19, phi_bb134_19}, &block148, std::vector<compiler::Node*>{phi_bb134_25, phi_bb134_26, phi_bb134_27, phi_bb134_28, phi_bb134_31, phi_bb134_32, phi_bb134_36, phi_bb134_38, phi_bb134_39, phi_bb134_40, phi_bb134_41, phi_bb134_19, phi_bb134_19, phi_bb134_19, phi_bb134_19});
  }

  TNode<IntPtrT> phi_bb147_25;
  TNode<IntPtrT> phi_bb147_26;
  TNode<IntPtrT> phi_bb147_27;
  TNode<IntPtrT> phi_bb147_28;
  TNode<IntPtrT> phi_bb147_31;
  TNode<BoolT> phi_bb147_32;
  TNode<BoolT> phi_bb147_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb147_38;
  TNode<IntPtrT> phi_bb147_39;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb147_40;
  TNode<IntPtrT> phi_bb147_41;
  TNode<IntPtrT> phi_bb147_48;
  TNode<IntPtrT> phi_bb147_49;
  TNode<IntPtrT> phi_bb147_53;
  TNode<IntPtrT> phi_bb147_54;
  TNode<IntPtrT> tmp320;
  TNode<IntPtrT> tmp321;
  TNode<Union<HeapObject, TaggedIndex>> tmp322;
  TNode<IntPtrT> tmp323;
  TNode<BigInt> tmp324;
  if (block147.is_used()) {
    ca_.Bind(&block147, &phi_bb147_25, &phi_bb147_26, &phi_bb147_27, &phi_bb147_28, &phi_bb147_31, &phi_bb147_32, &phi_bb147_36, &phi_bb147_38, &phi_bb147_39, &phi_bb147_40, &phi_bb147_41, &phi_bb147_48, &phi_bb147_49, &phi_bb147_53, &phi_bb147_54);
    tmp320 = TimesSizeOf_Object_0(state_, TNode<IntPtrT>{phi_bb147_54});
    tmp321 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp313}, TNode<IntPtrT>{tmp320});
    std::tie(tmp322, tmp323) = NewReference_Object_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp312}, TNode<IntPtrT>{tmp321}).Flatten();
    tmp324 = ca_.CallBuiltin<BigInt>(Builtin::kI32PairToBigInt, TNode<Object>(), tmp310, tmp311);
    CodeStubAssembler(state_).StoreReference<Object>(CodeStubAssembler::Reference{tmp322, tmp323}, tmp324);
    ca_.Goto(&block107, tmp316, tmp286, phi_bb147_25, phi_bb147_26, phi_bb147_27, phi_bb147_28, phi_bb147_31, phi_bb147_32, phi_bb147_36);
  }

  TNode<IntPtrT> phi_bb148_25;
  TNode<IntPtrT> phi_bb148_26;
  TNode<IntPtrT> phi_bb148_27;
  TNode<IntPtrT> phi_bb148_28;
  TNode<IntPtrT> phi_bb148_31;
  TNode<BoolT> phi_bb148_32;
  TNode<BoolT> phi_bb148_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb148_38;
  TNode<IntPtrT> phi_bb148_39;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb148_40;
  TNode<IntPtrT> phi_bb148_41;
  TNode<IntPtrT> phi_bb148_48;
  TNode<IntPtrT> phi_bb148_49;
  TNode<IntPtrT> phi_bb148_53;
  TNode<IntPtrT> phi_bb148_54;
  if (block148.is_used()) {
    ca_.Bind(&block148, &phi_bb148_25, &phi_bb148_26, &phi_bb148_27, &phi_bb148_28, &phi_bb148_31, &phi_bb148_32, &phi_bb148_36, &phi_bb148_38, &phi_bb148_39, &phi_bb148_40, &phi_bb148_41, &phi_bb148_48, &phi_bb148_49, &phi_bb148_53, &phi_bb148_54);
    CodeStubAssembler(state_).Unreachable();
  }

  TNode<IntPtrT> phi_bb107_19;
  TNode<IntPtrT> phi_bb107_24;
  TNode<IntPtrT> phi_bb107_25;
  TNode<IntPtrT> phi_bb107_26;
  TNode<IntPtrT> phi_bb107_27;
  TNode<IntPtrT> phi_bb107_28;
  TNode<IntPtrT> phi_bb107_31;
  TNode<BoolT> phi_bb107_32;
  TNode<BoolT> phi_bb107_36;
  if (block107.is_used()) {
    ca_.Bind(&block107, &phi_bb107_19, &phi_bb107_24, &phi_bb107_25, &phi_bb107_26, &phi_bb107_27, &phi_bb107_28, &phi_bb107_31, &phi_bb107_32, &phi_bb107_36);
    ca_.Goto(&block104, phi_bb107_19, phi_bb107_24, phi_bb107_25, phi_bb107_26, phi_bb107_27, phi_bb107_28, phi_bb107_31, phi_bb107_32, phi_bb107_36);
  }

  TNode<IntPtrT> phi_bb103_19;
  TNode<IntPtrT> phi_bb103_24;
  TNode<IntPtrT> phi_bb103_25;
  TNode<IntPtrT> phi_bb103_26;
  TNode<IntPtrT> phi_bb103_27;
  TNode<IntPtrT> phi_bb103_28;
  TNode<IntPtrT> phi_bb103_31;
  TNode<BoolT> phi_bb103_32;
  TNode<BoolT> phi_bb103_36;
  TNode<Uint32T> tmp325;
  TNode<BoolT> tmp326;
  if (block103.is_used()) {
    ca_.Bind(&block103, &phi_bb103_19, &phi_bb103_24, &phi_bb103_25, &phi_bb103_26, &phi_bb103_27, &phi_bb103_28, &phi_bb103_31, &phi_bb103_32, &phi_bb103_36);
    tmp325 = FromConstexpr_WasmCodePointer_constexpr_WasmCodePointer_0(state_, wasm::kWasmF64.raw_bit_field());
    tmp326 = CodeStubAssembler(state_).Word32Equal(TNode<Uint32T>{tmp107}, TNode<Uint32T>{tmp325});
    ca_.Branch(tmp326, &block151, std::vector<compiler::Node*>{phi_bb103_19, phi_bb103_24, phi_bb103_25, phi_bb103_26, phi_bb103_27, phi_bb103_28, phi_bb103_31, phi_bb103_32, phi_bb103_36}, &block152, std::vector<compiler::Node*>{phi_bb103_19, phi_bb103_24, phi_bb103_25, phi_bb103_26, phi_bb103_27, phi_bb103_28, phi_bb103_31, phi_bb103_32, phi_bb103_36});
  }

  TNode<IntPtrT> phi_bb151_19;
  TNode<IntPtrT> phi_bb151_24;
  TNode<IntPtrT> phi_bb151_25;
  TNode<IntPtrT> phi_bb151_26;
  TNode<IntPtrT> phi_bb151_27;
  TNode<IntPtrT> phi_bb151_28;
  TNode<IntPtrT> phi_bb151_31;
  TNode<BoolT> phi_bb151_32;
  TNode<BoolT> phi_bb151_36;
  TNode<IntPtrT> tmp327;
  TNode<IntPtrT> tmp328;
  TNode<IntPtrT> tmp329;
  TNode<BoolT> tmp330;
  if (block151.is_used()) {
    ca_.Bind(&block151, &phi_bb151_19, &phi_bb151_24, &phi_bb151_25, &phi_bb151_26, &phi_bb151_27, &phi_bb151_28, &phi_bb151_31, &phi_bb151_32, &phi_bb151_36);
    tmp327 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp328 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{phi_bb151_25}, TNode<IntPtrT>{tmp327});
    tmp329 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp330 = CodeStubAssembler(state_).IntPtrGreaterThan(TNode<IntPtrT>{phi_bb151_25}, TNode<IntPtrT>{tmp329});
    ca_.Branch(tmp330, &block155, std::vector<compiler::Node*>{phi_bb151_19, phi_bb151_24, phi_bb151_26, phi_bb151_27, phi_bb151_28, phi_bb151_31, phi_bb151_32, phi_bb151_36}, &block156, std::vector<compiler::Node*>{phi_bb151_19, phi_bb151_24, phi_bb151_26, phi_bb151_27, phi_bb151_28, phi_bb151_31, phi_bb151_32, phi_bb151_36});
  }

  TNode<IntPtrT> phi_bb155_19;
  TNode<IntPtrT> phi_bb155_24;
  TNode<IntPtrT> phi_bb155_26;
  TNode<IntPtrT> phi_bb155_27;
  TNode<IntPtrT> phi_bb155_28;
  TNode<IntPtrT> phi_bb155_31;
  TNode<BoolT> phi_bb155_32;
  TNode<BoolT> phi_bb155_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp331;
  TNode<IntPtrT> tmp332;
  TNode<IntPtrT> tmp333;
  TNode<IntPtrT> tmp334;
  if (block155.is_used()) {
    ca_.Bind(&block155, &phi_bb155_19, &phi_bb155_24, &phi_bb155_26, &phi_bb155_27, &phi_bb155_28, &phi_bb155_31, &phi_bb155_32, &phi_bb155_36);
    std::tie(tmp331, tmp332) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb155_27}).Flatten();
    tmp333 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_float64_0(state_)));
    tmp334 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb155_27}, TNode<IntPtrT>{tmp333});
    ca_.Goto(&block154, phi_bb155_19, phi_bb155_24, phi_bb155_26, tmp334, phi_bb155_28, phi_bb155_31, phi_bb155_32, phi_bb155_36, tmp331, tmp332);
  }

  TNode<IntPtrT> phi_bb156_19;
  TNode<IntPtrT> phi_bb156_24;
  TNode<IntPtrT> phi_bb156_26;
  TNode<IntPtrT> phi_bb156_27;
  TNode<IntPtrT> phi_bb156_28;
  TNode<IntPtrT> phi_bb156_31;
  TNode<BoolT> phi_bb156_32;
  TNode<BoolT> phi_bb156_36;
  if (block156.is_used()) {
    ca_.Bind(&block156, &phi_bb156_19, &phi_bb156_24, &phi_bb156_26, &phi_bb156_27, &phi_bb156_28, &phi_bb156_31, &phi_bb156_32, &phi_bb156_36);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block157, phi_bb156_19, phi_bb156_24, phi_bb156_26, phi_bb156_27, phi_bb156_28, phi_bb156_31, phi_bb156_32, phi_bb156_36);
    } else {
      ca_.Goto(&block158, phi_bb156_19, phi_bb156_24, phi_bb156_26, phi_bb156_27, phi_bb156_28, phi_bb156_31, phi_bb156_32, phi_bb156_36);
    }
  }

  TNode<IntPtrT> phi_bb157_19;
  TNode<IntPtrT> phi_bb157_24;
  TNode<IntPtrT> phi_bb157_26;
  TNode<IntPtrT> phi_bb157_27;
  TNode<IntPtrT> phi_bb157_28;
  TNode<IntPtrT> phi_bb157_31;
  TNode<BoolT> phi_bb157_32;
  TNode<BoolT> phi_bb157_36;
  if (block157.is_used()) {
    ca_.Bind(&block157, &phi_bb157_19, &phi_bb157_24, &phi_bb157_26, &phi_bb157_27, &phi_bb157_28, &phi_bb157_31, &phi_bb157_32, &phi_bb157_36);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block161, phi_bb157_19, phi_bb157_24, phi_bb157_26, phi_bb157_27, phi_bb157_28, phi_bb157_31, phi_bb157_32, phi_bb157_36);
    } else {
      ca_.Goto(&block162, phi_bb157_19, phi_bb157_24, phi_bb157_26, phi_bb157_27, phi_bb157_28, phi_bb157_31, phi_bb157_32, phi_bb157_36);
    }
  }

  TNode<IntPtrT> phi_bb161_19;
  TNode<IntPtrT> phi_bb161_24;
  TNode<IntPtrT> phi_bb161_26;
  TNode<IntPtrT> phi_bb161_27;
  TNode<IntPtrT> phi_bb161_28;
  TNode<IntPtrT> phi_bb161_31;
  TNode<BoolT> phi_bb161_32;
  TNode<BoolT> phi_bb161_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp335;
  TNode<IntPtrT> tmp336;
  TNode<IntPtrT> tmp337;
  TNode<IntPtrT> tmp338;
  if (block161.is_used()) {
    ca_.Bind(&block161, &phi_bb161_19, &phi_bb161_24, &phi_bb161_26, &phi_bb161_27, &phi_bb161_28, &phi_bb161_31, &phi_bb161_32, &phi_bb161_36);
    std::tie(tmp335, tmp336) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb161_28}).Flatten();
    tmp337 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp338 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb161_28}, TNode<IntPtrT>{tmp337});
    ca_.Goto(&block160, phi_bb161_19, phi_bb161_24, phi_bb161_26, phi_bb161_27, tmp338, phi_bb161_31, phi_bb161_32, phi_bb161_36, tmp335, tmp336);
  }

  TNode<IntPtrT> phi_bb162_19;
  TNode<IntPtrT> phi_bb162_24;
  TNode<IntPtrT> phi_bb162_26;
  TNode<IntPtrT> phi_bb162_27;
  TNode<IntPtrT> phi_bb162_28;
  TNode<IntPtrT> phi_bb162_31;
  TNode<BoolT> phi_bb162_32;
  TNode<BoolT> phi_bb162_36;
  TNode<IntPtrT> tmp339;
  TNode<BoolT> tmp340;
  if (block162.is_used()) {
    ca_.Bind(&block162, &phi_bb162_19, &phi_bb162_24, &phi_bb162_26, &phi_bb162_27, &phi_bb162_28, &phi_bb162_31, &phi_bb162_32, &phi_bb162_36);
    tmp339 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp340 = CodeStubAssembler(state_).WordNotEqual(TNode<IntPtrT>{phi_bb162_31}, TNode<IntPtrT>{tmp339});
    ca_.Branch(tmp340, &block164, std::vector<compiler::Node*>{phi_bb162_19, phi_bb162_24, phi_bb162_26, phi_bb162_27, phi_bb162_28, phi_bb162_31, phi_bb162_32, phi_bb162_36}, &block165, std::vector<compiler::Node*>{phi_bb162_19, phi_bb162_24, phi_bb162_26, phi_bb162_27, phi_bb162_28, phi_bb162_31, phi_bb162_32, phi_bb162_36});
  }

  TNode<IntPtrT> phi_bb164_19;
  TNode<IntPtrT> phi_bb164_24;
  TNode<IntPtrT> phi_bb164_26;
  TNode<IntPtrT> phi_bb164_27;
  TNode<IntPtrT> phi_bb164_28;
  TNode<IntPtrT> phi_bb164_31;
  TNode<BoolT> phi_bb164_32;
  TNode<BoolT> phi_bb164_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp341;
  TNode<IntPtrT> tmp342;
  TNode<IntPtrT> tmp343;
  TNode<BoolT> tmp344;
  if (block164.is_used()) {
    ca_.Bind(&block164, &phi_bb164_19, &phi_bb164_24, &phi_bb164_26, &phi_bb164_27, &phi_bb164_28, &phi_bb164_31, &phi_bb164_32, &phi_bb164_36);
    std::tie(tmp341, tmp342) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb164_31}).Flatten();
    tmp343 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp344 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block160, phi_bb164_19, phi_bb164_24, phi_bb164_26, phi_bb164_27, phi_bb164_28, tmp343, tmp344, phi_bb164_36, tmp341, tmp342);
  }

  TNode<IntPtrT> phi_bb165_19;
  TNode<IntPtrT> phi_bb165_24;
  TNode<IntPtrT> phi_bb165_26;
  TNode<IntPtrT> phi_bb165_27;
  TNode<IntPtrT> phi_bb165_28;
  TNode<IntPtrT> phi_bb165_31;
  TNode<BoolT> phi_bb165_32;
  TNode<BoolT> phi_bb165_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp345;
  TNode<IntPtrT> tmp346;
  TNode<IntPtrT> tmp347;
  TNode<IntPtrT> tmp348;
  TNode<IntPtrT> tmp349;
  TNode<IntPtrT> tmp350;
  TNode<BoolT> tmp351;
  if (block165.is_used()) {
    ca_.Bind(&block165, &phi_bb165_19, &phi_bb165_24, &phi_bb165_26, &phi_bb165_27, &phi_bb165_28, &phi_bb165_31, &phi_bb165_32, &phi_bb165_36);
    std::tie(tmp345, tmp346) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb165_28}).Flatten();
    tmp347 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp348 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb165_28}, TNode<IntPtrT>{tmp347});
    tmp349 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp350 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp348}, TNode<IntPtrT>{tmp349});
    tmp351 = FromConstexpr_bool_constexpr_bool_0(state_, true);
    ca_.Goto(&block160, phi_bb165_19, phi_bb165_24, phi_bb165_26, phi_bb165_27, tmp350, tmp348, tmp351, phi_bb165_36, tmp345, tmp346);
  }

  TNode<IntPtrT> phi_bb160_19;
  TNode<IntPtrT> phi_bb160_24;
  TNode<IntPtrT> phi_bb160_26;
  TNode<IntPtrT> phi_bb160_27;
  TNode<IntPtrT> phi_bb160_28;
  TNode<IntPtrT> phi_bb160_31;
  TNode<BoolT> phi_bb160_32;
  TNode<BoolT> phi_bb160_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb160_38;
  TNode<IntPtrT> phi_bb160_39;
  if (block160.is_used()) {
    ca_.Bind(&block160, &phi_bb160_19, &phi_bb160_24, &phi_bb160_26, &phi_bb160_27, &phi_bb160_28, &phi_bb160_31, &phi_bb160_32, &phi_bb160_36, &phi_bb160_38, &phi_bb160_39);
    ca_.Goto(&block154, phi_bb160_19, phi_bb160_24, phi_bb160_26, phi_bb160_27, phi_bb160_28, phi_bb160_31, phi_bb160_32, phi_bb160_36, phi_bb160_38, phi_bb160_39);
  }

  TNode<IntPtrT> phi_bb158_19;
  TNode<IntPtrT> phi_bb158_24;
  TNode<IntPtrT> phi_bb158_26;
  TNode<IntPtrT> phi_bb158_27;
  TNode<IntPtrT> phi_bb158_28;
  TNode<IntPtrT> phi_bb158_31;
  TNode<BoolT> phi_bb158_32;
  TNode<BoolT> phi_bb158_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp352;
  TNode<IntPtrT> tmp353;
  TNode<IntPtrT> tmp354;
  TNode<IntPtrT> tmp355;
  TNode<BoolT> tmp356;
  if (block158.is_used()) {
    ca_.Bind(&block158, &phi_bb158_19, &phi_bb158_24, &phi_bb158_26, &phi_bb158_27, &phi_bb158_28, &phi_bb158_31, &phi_bb158_32, &phi_bb158_36);
    std::tie(tmp352, tmp353) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb158_28}).Flatten();
    tmp354 = FromConstexpr_intptr_constexpr_int31_0(state_, (CodeStubAssembler(state_).ConstexprInt31Mul((FromConstexpr_constexpr_int31_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x2ull))), (SizeOf_intptr_0(state_)))));
    tmp355 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb158_28}, TNode<IntPtrT>{tmp354});
    tmp356 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block154, phi_bb158_19, phi_bb158_24, phi_bb158_26, phi_bb158_27, tmp355, phi_bb158_31, tmp356, phi_bb158_36, tmp352, tmp353);
  }

  TNode<IntPtrT> phi_bb154_19;
  TNode<IntPtrT> phi_bb154_24;
  TNode<IntPtrT> phi_bb154_26;
  TNode<IntPtrT> phi_bb154_27;
  TNode<IntPtrT> phi_bb154_28;
  TNode<IntPtrT> phi_bb154_31;
  TNode<BoolT> phi_bb154_32;
  TNode<BoolT> phi_bb154_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb154_38;
  TNode<IntPtrT> phi_bb154_39;
  TNode<Union<HeapObject, TaggedIndex>> tmp357;
  TNode<IntPtrT> tmp358;
  TNode<Float64T> tmp359;
  TNode<Union<HeapObject, TaggedIndex>> tmp360;
  TNode<IntPtrT> tmp361;
  TNode<IntPtrT> tmp362;
  TNode<IntPtrT> tmp363;
  TNode<IntPtrT> tmp364;
  TNode<UintPtrT> tmp365;
  TNode<UintPtrT> tmp366;
  TNode<BoolT> tmp367;
  if (block154.is_used()) {
    ca_.Bind(&block154, &phi_bb154_19, &phi_bb154_24, &phi_bb154_26, &phi_bb154_27, &phi_bb154_28, &phi_bb154_31, &phi_bb154_32, &phi_bb154_36, &phi_bb154_38, &phi_bb154_39);
    std::tie(tmp357, tmp358) = RefCast_float64_0(state_, TorqueStructReference_intptr_0{TNode<Union<HeapObject, TaggedIndex>>{phi_bb154_38}, TNode<IntPtrT>{phi_bb154_39}, TorqueStructUnsafe_0{}}).Flatten();
    tmp359 = CodeStubAssembler(state_).LoadReference<Float64T>(CodeStubAssembler::Reference{tmp357, tmp358});
    std::tie(tmp360, tmp361, tmp362) = FieldSliceFixedArrayObjects_0(state_, TNode<FixedArray>{tmp63}).Flatten();
    tmp363 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp364 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb154_19}, TNode<IntPtrT>{tmp363});
    tmp365 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{phi_bb154_19});
    tmp366 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{tmp362});
    tmp367 = CodeStubAssembler(state_).UintPtrLessThan(TNode<UintPtrT>{tmp365}, TNode<UintPtrT>{tmp366});
    ca_.Branch(tmp367, &block170, std::vector<compiler::Node*>{phi_bb154_24, phi_bb154_26, phi_bb154_27, phi_bb154_28, phi_bb154_31, phi_bb154_32, phi_bb154_36, phi_bb154_38, phi_bb154_39, phi_bb154_19, phi_bb154_19, phi_bb154_19, phi_bb154_19}, &block171, std::vector<compiler::Node*>{phi_bb154_24, phi_bb154_26, phi_bb154_27, phi_bb154_28, phi_bb154_31, phi_bb154_32, phi_bb154_36, phi_bb154_38, phi_bb154_39, phi_bb154_19, phi_bb154_19, phi_bb154_19, phi_bb154_19});
  }

  TNode<IntPtrT> phi_bb170_24;
  TNode<IntPtrT> phi_bb170_26;
  TNode<IntPtrT> phi_bb170_27;
  TNode<IntPtrT> phi_bb170_28;
  TNode<IntPtrT> phi_bb170_31;
  TNode<BoolT> phi_bb170_32;
  TNode<BoolT> phi_bb170_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb170_38;
  TNode<IntPtrT> phi_bb170_39;
  TNode<IntPtrT> phi_bb170_45;
  TNode<IntPtrT> phi_bb170_46;
  TNode<IntPtrT> phi_bb170_50;
  TNode<IntPtrT> phi_bb170_51;
  TNode<IntPtrT> tmp368;
  TNode<IntPtrT> tmp369;
  TNode<Union<HeapObject, TaggedIndex>> tmp370;
  TNode<IntPtrT> tmp371;
  TNode<Number> tmp372;
  if (block170.is_used()) {
    ca_.Bind(&block170, &phi_bb170_24, &phi_bb170_26, &phi_bb170_27, &phi_bb170_28, &phi_bb170_31, &phi_bb170_32, &phi_bb170_36, &phi_bb170_38, &phi_bb170_39, &phi_bb170_45, &phi_bb170_46, &phi_bb170_50, &phi_bb170_51);
    tmp368 = TimesSizeOf_Object_0(state_, TNode<IntPtrT>{phi_bb170_51});
    tmp369 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp361}, TNode<IntPtrT>{tmp368});
    std::tie(tmp370, tmp371) = NewReference_Object_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp360}, TNode<IntPtrT>{tmp369}).Flatten();
    tmp372 = Convert_Number_float64_0(state_, TNode<Float64T>{tmp359});
    CodeStubAssembler(state_).StoreReference<Object>(CodeStubAssembler::Reference{tmp370, tmp371}, tmp372);
    ca_.Goto(&block153, tmp364, phi_bb170_24, tmp328, phi_bb170_26, phi_bb170_27, phi_bb170_28, phi_bb170_31, phi_bb170_32, phi_bb170_36);
  }

  TNode<IntPtrT> phi_bb171_24;
  TNode<IntPtrT> phi_bb171_26;
  TNode<IntPtrT> phi_bb171_27;
  TNode<IntPtrT> phi_bb171_28;
  TNode<IntPtrT> phi_bb171_31;
  TNode<BoolT> phi_bb171_32;
  TNode<BoolT> phi_bb171_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb171_38;
  TNode<IntPtrT> phi_bb171_39;
  TNode<IntPtrT> phi_bb171_45;
  TNode<IntPtrT> phi_bb171_46;
  TNode<IntPtrT> phi_bb171_50;
  TNode<IntPtrT> phi_bb171_51;
  if (block171.is_used()) {
    ca_.Bind(&block171, &phi_bb171_24, &phi_bb171_26, &phi_bb171_27, &phi_bb171_28, &phi_bb171_31, &phi_bb171_32, &phi_bb171_36, &phi_bb171_38, &phi_bb171_39, &phi_bb171_45, &phi_bb171_46, &phi_bb171_50, &phi_bb171_51);
    CodeStubAssembler(state_).Unreachable();
  }

  TNode<IntPtrT> phi_bb152_19;
  TNode<IntPtrT> phi_bb152_24;
  TNode<IntPtrT> phi_bb152_25;
  TNode<IntPtrT> phi_bb152_26;
  TNode<IntPtrT> phi_bb152_27;
  TNode<IntPtrT> phi_bb152_28;
  TNode<IntPtrT> phi_bb152_31;
  TNode<BoolT> phi_bb152_32;
  TNode<BoolT> phi_bb152_36;
  TNode<Uint32T> tmp373;
  TNode<Uint32T> tmp374;
  TNode<Uint32T> tmp375;
  TNode<BoolT> tmp376;
  if (block152.is_used()) {
    ca_.Bind(&block152, &phi_bb152_19, &phi_bb152_24, &phi_bb152_25, &phi_bb152_26, &phi_bb152_27, &phi_bb152_28, &phi_bb152_31, &phi_bb152_32, &phi_bb152_36);
    tmp373 = FromConstexpr_WasmCodePointer_constexpr_WasmCodePointer_0(state_, wasm::ValueType::kIsRefBit);
    tmp374 = CodeStubAssembler(state_).Word32And(TNode<Uint32T>{tmp107}, TNode<Uint32T>{tmp373});
    tmp375 = FromConstexpr_WasmCodePointer_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp376 = CodeStubAssembler(state_).Word32NotEqual(TNode<Uint32T>{tmp374}, TNode<Uint32T>{tmp375});
    ca_.Branch(tmp376, &block174, std::vector<compiler::Node*>{phi_bb152_19, phi_bb152_24, phi_bb152_25, phi_bb152_26, phi_bb152_27, phi_bb152_28, phi_bb152_31, phi_bb152_32, phi_bb152_36}, &block175, std::vector<compiler::Node*>{phi_bb152_19, phi_bb152_24, phi_bb152_25, phi_bb152_26, phi_bb152_27, phi_bb152_28, phi_bb152_31, phi_bb152_32, phi_bb152_36});
  }

  TNode<IntPtrT> phi_bb175_19;
  TNode<IntPtrT> phi_bb175_24;
  TNode<IntPtrT> phi_bb175_25;
  TNode<IntPtrT> phi_bb175_26;
  TNode<IntPtrT> phi_bb175_27;
  TNode<IntPtrT> phi_bb175_28;
  TNode<IntPtrT> phi_bb175_31;
  TNode<BoolT> phi_bb175_32;
  TNode<BoolT> phi_bb175_36;
  if (block175.is_used()) {
    ca_.Bind(&block175, &phi_bb175_19, &phi_bb175_24, &phi_bb175_25, &phi_bb175_26, &phi_bb175_27, &phi_bb175_28, &phi_bb175_31, &phi_bb175_32, &phi_bb175_36);
    {
      auto pos_stack = ca_.GetMacroSourcePositionStack();
      pos_stack.push_back({"src/builtins/wasm-to-js.tq", 157});
      CodeStubAssembler(state_).FailAssert("Torque assert '(paramType & kValueTypeIsRefBit) != 0' failed", pos_stack);
    }
  }

  TNode<IntPtrT> phi_bb174_19;
  TNode<IntPtrT> phi_bb174_24;
  TNode<IntPtrT> phi_bb174_25;
  TNode<IntPtrT> phi_bb174_26;
  TNode<IntPtrT> phi_bb174_27;
  TNode<IntPtrT> phi_bb174_28;
  TNode<IntPtrT> phi_bb174_31;
  TNode<BoolT> phi_bb174_32;
  TNode<BoolT> phi_bb174_36;
  TNode<IntPtrT> tmp377;
  TNode<IntPtrT> tmp378;
  TNode<BoolT> tmp379;
  if (block174.is_used()) {
    ca_.Bind(&block174, &phi_bb174_19, &phi_bb174_24, &phi_bb174_25, &phi_bb174_26, &phi_bb174_27, &phi_bb174_28, &phi_bb174_31, &phi_bb174_32, &phi_bb174_36);
    tmp377 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp378 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb174_19}, TNode<IntPtrT>{tmp377});
    tmp379 = FromConstexpr_bool_constexpr_bool_0(state_, true);
    ca_.Goto(&block153, tmp378, phi_bb174_24, phi_bb174_25, phi_bb174_26, phi_bb174_27, phi_bb174_28, phi_bb174_31, phi_bb174_32, tmp379);
  }

  TNode<IntPtrT> phi_bb153_19;
  TNode<IntPtrT> phi_bb153_24;
  TNode<IntPtrT> phi_bb153_25;
  TNode<IntPtrT> phi_bb153_26;
  TNode<IntPtrT> phi_bb153_27;
  TNode<IntPtrT> phi_bb153_28;
  TNode<IntPtrT> phi_bb153_31;
  TNode<BoolT> phi_bb153_32;
  TNode<BoolT> phi_bb153_36;
  if (block153.is_used()) {
    ca_.Bind(&block153, &phi_bb153_19, &phi_bb153_24, &phi_bb153_25, &phi_bb153_26, &phi_bb153_27, &phi_bb153_28, &phi_bb153_31, &phi_bb153_32, &phi_bb153_36);
    ca_.Goto(&block104, phi_bb153_19, phi_bb153_24, phi_bb153_25, phi_bb153_26, phi_bb153_27, phi_bb153_28, phi_bb153_31, phi_bb153_32, phi_bb153_36);
  }

  TNode<IntPtrT> phi_bb104_19;
  TNode<IntPtrT> phi_bb104_24;
  TNode<IntPtrT> phi_bb104_25;
  TNode<IntPtrT> phi_bb104_26;
  TNode<IntPtrT> phi_bb104_27;
  TNode<IntPtrT> phi_bb104_28;
  TNode<IntPtrT> phi_bb104_31;
  TNode<BoolT> phi_bb104_32;
  TNode<BoolT> phi_bb104_36;
  if (block104.is_used()) {
    ca_.Bind(&block104, &phi_bb104_19, &phi_bb104_24, &phi_bb104_25, &phi_bb104_26, &phi_bb104_27, &phi_bb104_28, &phi_bb104_31, &phi_bb104_32, &phi_bb104_36);
    ca_.Goto(&block70, phi_bb104_19, phi_bb104_24, phi_bb104_25, phi_bb104_26, phi_bb104_27, phi_bb104_28, phi_bb104_31, phi_bb104_32, phi_bb104_36);
  }

  TNode<IntPtrT> phi_bb70_19;
  TNode<IntPtrT> phi_bb70_24;
  TNode<IntPtrT> phi_bb70_25;
  TNode<IntPtrT> phi_bb70_26;
  TNode<IntPtrT> phi_bb70_27;
  TNode<IntPtrT> phi_bb70_28;
  TNode<IntPtrT> phi_bb70_31;
  TNode<BoolT> phi_bb70_32;
  TNode<BoolT> phi_bb70_36;
  if (block70.is_used()) {
    ca_.Bind(&block70, &phi_bb70_19, &phi_bb70_24, &phi_bb70_25, &phi_bb70_26, &phi_bb70_27, &phi_bb70_28, &phi_bb70_31, &phi_bb70_32, &phi_bb70_36);
    ca_.Goto(&block47, phi_bb70_19, phi_bb70_24, phi_bb70_25, phi_bb70_26, phi_bb70_27, phi_bb70_28, phi_bb70_31, phi_bb70_32, phi_bb70_36);
  }

  TNode<IntPtrT> phi_bb47_19;
  TNode<IntPtrT> phi_bb47_24;
  TNode<IntPtrT> phi_bb47_25;
  TNode<IntPtrT> phi_bb47_26;
  TNode<IntPtrT> phi_bb47_27;
  TNode<IntPtrT> phi_bb47_28;
  TNode<IntPtrT> phi_bb47_31;
  TNode<BoolT> phi_bb47_32;
  TNode<BoolT> phi_bb47_36;
  if (block47.is_used()) {
    ca_.Bind(&block47, &phi_bb47_19, &phi_bb47_24, &phi_bb47_25, &phi_bb47_26, &phi_bb47_27, &phi_bb47_28, &phi_bb47_31, &phi_bb47_32, &phi_bb47_36);
    ca_.Goto(&block36, phi_bb47_19, phi_bb47_24, phi_bb47_25, phi_bb47_26, phi_bb47_27, phi_bb47_28, phi_bb47_31, phi_bb47_32, tmp106, phi_bb47_36);
  }

  TNode<IntPtrT> phi_bb35_19;
  TNode<IntPtrT> phi_bb35_24;
  TNode<IntPtrT> phi_bb35_25;
  TNode<IntPtrT> phi_bb35_26;
  TNode<IntPtrT> phi_bb35_27;
  TNode<IntPtrT> phi_bb35_28;
  TNode<IntPtrT> phi_bb35_31;
  TNode<BoolT> phi_bb35_32;
  TNode<IntPtrT> phi_bb35_34;
  TNode<BoolT> phi_bb35_36;
  if (block35.is_used()) {
    ca_.Bind(&block35, &phi_bb35_19, &phi_bb35_24, &phi_bb35_25, &phi_bb35_26, &phi_bb35_27, &phi_bb35_28, &phi_bb35_31, &phi_bb35_32, &phi_bb35_34, &phi_bb35_36);
    ca_.Branch(phi_bb35_36, &block176, std::vector<compiler::Node*>{phi_bb35_19, phi_bb35_24, phi_bb35_25, phi_bb35_26, phi_bb35_27, phi_bb35_28, phi_bb35_31, phi_bb35_32, phi_bb35_34, phi_bb35_36}, &block177, std::vector<compiler::Node*>{phi_bb35_19, phi_bb35_24, phi_bb35_25, phi_bb35_26, phi_bb35_27, phi_bb35_28, phi_bb35_31, phi_bb35_32, phi_bb35_34, tmp99, phi_bb35_36});
  }

  TNode<IntPtrT> phi_bb176_19;
  TNode<IntPtrT> phi_bb176_24;
  TNode<IntPtrT> phi_bb176_25;
  TNode<IntPtrT> phi_bb176_26;
  TNode<IntPtrT> phi_bb176_27;
  TNode<IntPtrT> phi_bb176_28;
  TNode<IntPtrT> phi_bb176_31;
  TNode<BoolT> phi_bb176_32;
  TNode<IntPtrT> phi_bb176_34;
  TNode<BoolT> phi_bb176_36;
  TNode<BoolT> tmp380;
  if (block176.is_used()) {
    ca_.Bind(&block176, &phi_bb176_19, &phi_bb176_24, &phi_bb176_25, &phi_bb176_26, &phi_bb176_27, &phi_bb176_28, &phi_bb176_31, &phi_bb176_32, &phi_bb176_34, &phi_bb176_36);
    tmp380 = CodeStubAssembler(state_).Word32BinaryNot(TNode<BoolT>{phi_bb176_32});
    ca_.Branch(tmp380, &block179, std::vector<compiler::Node*>{phi_bb176_19, phi_bb176_24, phi_bb176_25, phi_bb176_26, phi_bb176_27, phi_bb176_28, phi_bb176_31, phi_bb176_32, phi_bb176_34, phi_bb176_36}, &block180, std::vector<compiler::Node*>{phi_bb176_19, phi_bb176_24, phi_bb176_25, phi_bb176_26, phi_bb176_27, phi_bb176_28, phi_bb176_31, phi_bb176_32, phi_bb176_34, phi_bb176_36});
  }

  TNode<IntPtrT> phi_bb179_19;
  TNode<IntPtrT> phi_bb179_24;
  TNode<IntPtrT> phi_bb179_25;
  TNode<IntPtrT> phi_bb179_26;
  TNode<IntPtrT> phi_bb179_27;
  TNode<IntPtrT> phi_bb179_28;
  TNode<IntPtrT> phi_bb179_31;
  TNode<BoolT> phi_bb179_32;
  TNode<IntPtrT> phi_bb179_34;
  TNode<BoolT> phi_bb179_36;
  TNode<IntPtrT> tmp381;
  if (block179.is_used()) {
    ca_.Bind(&block179, &phi_bb179_19, &phi_bb179_24, &phi_bb179_25, &phi_bb179_26, &phi_bb179_27, &phi_bb179_28, &phi_bb179_31, &phi_bb179_32, &phi_bb179_34, &phi_bb179_36);
    tmp381 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    ca_.Goto(&block180, phi_bb179_19, phi_bb179_24, phi_bb179_25, phi_bb179_26, phi_bb179_27, phi_bb179_28, tmp381, phi_bb179_32, phi_bb179_34, phi_bb179_36);
  }

  TNode<IntPtrT> phi_bb180_19;
  TNode<IntPtrT> phi_bb180_24;
  TNode<IntPtrT> phi_bb180_25;
  TNode<IntPtrT> phi_bb180_26;
  TNode<IntPtrT> phi_bb180_27;
  TNode<IntPtrT> phi_bb180_28;
  TNode<IntPtrT> phi_bb180_31;
  TNode<BoolT> phi_bb180_32;
  TNode<IntPtrT> phi_bb180_34;
  TNode<BoolT> phi_bb180_36;
  TNode<IntPtrT> tmp382;
  TNode<IntPtrT> tmp383;
  TNode<IntPtrT> tmp384;
  if (block180.is_used()) {
    ca_.Bind(&block180, &phi_bb180_19, &phi_bb180_24, &phi_bb180_25, &phi_bb180_26, &phi_bb180_27, &phi_bb180_28, &phi_bb180_31, &phi_bb180_32, &phi_bb180_34, &phi_bb180_36);
    tmp382 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x1ull));
    tmp383 = TimesSizeOf_WasmCodePointer_0(state_, TNode<IntPtrT>{tmp59});
    tmp384 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp58}, TNode<IntPtrT>{tmp383});
    ca_.Goto(&block184, tmp382, phi_bb180_24, phi_bb180_25, phi_bb180_26, phi_bb180_27, phi_bb180_28, phi_bb180_31, phi_bb180_32, tmp58, phi_bb180_36);
  }

  TNode<IntPtrT> phi_bb184_19;
  TNode<IntPtrT> phi_bb184_24;
  TNode<IntPtrT> phi_bb184_25;
  TNode<IntPtrT> phi_bb184_26;
  TNode<IntPtrT> phi_bb184_27;
  TNode<IntPtrT> phi_bb184_28;
  TNode<IntPtrT> phi_bb184_31;
  TNode<BoolT> phi_bb184_32;
  TNode<IntPtrT> phi_bb184_34;
  TNode<BoolT> phi_bb184_36;
  TNode<BoolT> tmp385;
  TNode<BoolT> tmp386;
  if (block184.is_used()) {
    ca_.Bind(&block184, &phi_bb184_19, &phi_bb184_24, &phi_bb184_25, &phi_bb184_26, &phi_bb184_27, &phi_bb184_28, &phi_bb184_31, &phi_bb184_32, &phi_bb184_34, &phi_bb184_36);
    tmp385 = CodeStubAssembler(state_).WordEqual(TNode<IntPtrT>{phi_bb184_34}, TNode<IntPtrT>{tmp384});
    tmp386 = CodeStubAssembler(state_).Word32BinaryNot(TNode<BoolT>{tmp385});
    ca_.Branch(tmp386, &block182, std::vector<compiler::Node*>{phi_bb184_19, phi_bb184_24, phi_bb184_25, phi_bb184_26, phi_bb184_27, phi_bb184_28, phi_bb184_31, phi_bb184_32, phi_bb184_34, phi_bb184_36}, &block183, std::vector<compiler::Node*>{phi_bb184_19, phi_bb184_24, phi_bb184_25, phi_bb184_26, phi_bb184_27, phi_bb184_28, phi_bb184_31, phi_bb184_32, phi_bb184_34, phi_bb184_36});
  }

  TNode<IntPtrT> phi_bb182_19;
  TNode<IntPtrT> phi_bb182_24;
  TNode<IntPtrT> phi_bb182_25;
  TNode<IntPtrT> phi_bb182_26;
  TNode<IntPtrT> phi_bb182_27;
  TNode<IntPtrT> phi_bb182_28;
  TNode<IntPtrT> phi_bb182_31;
  TNode<BoolT> phi_bb182_32;
  TNode<IntPtrT> phi_bb182_34;
  TNode<BoolT> phi_bb182_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp387;
  TNode<IntPtrT> tmp388;
  TNode<IntPtrT> tmp389;
  TNode<IntPtrT> tmp390;
  TNode<Uint32T> tmp391;
  TNode<Uint32T> tmp392;
  TNode<Uint32T> tmp393;
  TNode<Uint32T> tmp394;
  TNode<BoolT> tmp395;
  if (block182.is_used()) {
    ca_.Bind(&block182, &phi_bb182_19, &phi_bb182_24, &phi_bb182_25, &phi_bb182_26, &phi_bb182_27, &phi_bb182_28, &phi_bb182_31, &phi_bb182_32, &phi_bb182_34, &phi_bb182_36);
    std::tie(tmp387, tmp388) = NewReference_WasmCodePointer_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp57}, TNode<IntPtrT>{phi_bb182_34}).Flatten();
    tmp389 = FromConstexpr_intptr_constexpr_int31_0(state_, kInt32Size);
    tmp390 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb182_34}, TNode<IntPtrT>{tmp389});
    tmp391 = CodeStubAssembler(state_).LoadReference<Uint32T>(CodeStubAssembler::Reference{tmp387, tmp388});
    tmp392 = FromConstexpr_WasmCodePointer_constexpr_WasmCodePointer_0(state_, wasm::ValueType::kIsRefBit);
    tmp393 = CodeStubAssembler(state_).Word32And(TNode<Uint32T>{tmp391}, TNode<Uint32T>{tmp392});
    tmp394 = FromConstexpr_WasmCodePointer_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp395 = CodeStubAssembler(state_).Word32NotEqual(TNode<Uint32T>{tmp393}, TNode<Uint32T>{tmp394});
    ca_.Branch(tmp395, &block193, std::vector<compiler::Node*>{phi_bb182_19, phi_bb182_24, phi_bb182_25, phi_bb182_26, phi_bb182_27, phi_bb182_28, phi_bb182_31, phi_bb182_32, phi_bb182_36}, &block194, std::vector<compiler::Node*>{phi_bb182_19, phi_bb182_24, phi_bb182_25, phi_bb182_26, phi_bb182_27, phi_bb182_28, phi_bb182_31, phi_bb182_32, phi_bb182_36});
  }

  TNode<IntPtrT> phi_bb193_19;
  TNode<IntPtrT> phi_bb193_24;
  TNode<IntPtrT> phi_bb193_25;
  TNode<IntPtrT> phi_bb193_26;
  TNode<IntPtrT> phi_bb193_27;
  TNode<IntPtrT> phi_bb193_28;
  TNode<IntPtrT> phi_bb193_31;
  TNode<BoolT> phi_bb193_32;
  TNode<BoolT> phi_bb193_36;
  TNode<IntPtrT> tmp396;
  TNode<IntPtrT> tmp397;
  TNode<IntPtrT> tmp398;
  TNode<BoolT> tmp399;
  if (block193.is_used()) {
    ca_.Bind(&block193, &phi_bb193_19, &phi_bb193_24, &phi_bb193_25, &phi_bb193_26, &phi_bb193_27, &phi_bb193_28, &phi_bb193_31, &phi_bb193_32, &phi_bb193_36);
    tmp396 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp397 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{phi_bb193_24}, TNode<IntPtrT>{tmp396});
    tmp398 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp399 = CodeStubAssembler(state_).IntPtrGreaterThan(TNode<IntPtrT>{phi_bb193_24}, TNode<IntPtrT>{tmp398});
    ca_.Branch(tmp399, &block196, std::vector<compiler::Node*>{phi_bb193_19, phi_bb193_25, phi_bb193_26, phi_bb193_27, phi_bb193_28, phi_bb193_31, phi_bb193_32, phi_bb193_36}, &block197, std::vector<compiler::Node*>{phi_bb193_19, phi_bb193_25, phi_bb193_26, phi_bb193_27, phi_bb193_28, phi_bb193_31, phi_bb193_32, phi_bb193_36});
  }

  TNode<IntPtrT> phi_bb196_19;
  TNode<IntPtrT> phi_bb196_25;
  TNode<IntPtrT> phi_bb196_26;
  TNode<IntPtrT> phi_bb196_27;
  TNode<IntPtrT> phi_bb196_28;
  TNode<IntPtrT> phi_bb196_31;
  TNode<BoolT> phi_bb196_32;
  TNode<BoolT> phi_bb196_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp400;
  TNode<IntPtrT> tmp401;
  TNode<IntPtrT> tmp402;
  TNode<IntPtrT> tmp403;
  if (block196.is_used()) {
    ca_.Bind(&block196, &phi_bb196_19, &phi_bb196_25, &phi_bb196_26, &phi_bb196_27, &phi_bb196_28, &phi_bb196_31, &phi_bb196_32, &phi_bb196_36);
    std::tie(tmp400, tmp401) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb196_26}).Flatten();
    tmp402 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp403 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb196_26}, TNode<IntPtrT>{tmp402});
    ca_.Goto(&block195, phi_bb196_19, phi_bb196_25, tmp403, phi_bb196_27, phi_bb196_28, phi_bb196_31, phi_bb196_32, phi_bb196_36, tmp400, tmp401);
  }

  TNode<IntPtrT> phi_bb197_19;
  TNode<IntPtrT> phi_bb197_25;
  TNode<IntPtrT> phi_bb197_26;
  TNode<IntPtrT> phi_bb197_27;
  TNode<IntPtrT> phi_bb197_28;
  TNode<IntPtrT> phi_bb197_31;
  TNode<BoolT> phi_bb197_32;
  TNode<BoolT> phi_bb197_36;
  if (block197.is_used()) {
    ca_.Bind(&block197, &phi_bb197_19, &phi_bb197_25, &phi_bb197_26, &phi_bb197_27, &phi_bb197_28, &phi_bb197_31, &phi_bb197_32, &phi_bb197_36);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block199, phi_bb197_19, phi_bb197_25, phi_bb197_26, phi_bb197_27, phi_bb197_28, phi_bb197_31, phi_bb197_32, phi_bb197_36);
    } else {
      ca_.Goto(&block200, phi_bb197_19, phi_bb197_25, phi_bb197_26, phi_bb197_27, phi_bb197_28, phi_bb197_31, phi_bb197_32, phi_bb197_36);
    }
  }

  TNode<IntPtrT> phi_bb199_19;
  TNode<IntPtrT> phi_bb199_25;
  TNode<IntPtrT> phi_bb199_26;
  TNode<IntPtrT> phi_bb199_27;
  TNode<IntPtrT> phi_bb199_28;
  TNode<IntPtrT> phi_bb199_31;
  TNode<BoolT> phi_bb199_32;
  TNode<BoolT> phi_bb199_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp404;
  TNode<IntPtrT> tmp405;
  TNode<IntPtrT> tmp406;
  TNode<IntPtrT> tmp407;
  if (block199.is_used()) {
    ca_.Bind(&block199, &phi_bb199_19, &phi_bb199_25, &phi_bb199_26, &phi_bb199_27, &phi_bb199_28, &phi_bb199_31, &phi_bb199_32, &phi_bb199_36);
    std::tie(tmp404, tmp405) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb199_28}).Flatten();
    tmp406 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp407 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb199_28}, TNode<IntPtrT>{tmp406});
    ca_.Goto(&block198, phi_bb199_19, phi_bb199_25, phi_bb199_26, phi_bb199_27, tmp407, phi_bb199_31, phi_bb199_32, phi_bb199_36, tmp404, tmp405);
  }

  TNode<IntPtrT> phi_bb200_19;
  TNode<IntPtrT> phi_bb200_25;
  TNode<IntPtrT> phi_bb200_26;
  TNode<IntPtrT> phi_bb200_27;
  TNode<IntPtrT> phi_bb200_28;
  TNode<IntPtrT> phi_bb200_31;
  TNode<BoolT> phi_bb200_32;
  TNode<BoolT> phi_bb200_36;
  TNode<IntPtrT> tmp408;
  TNode<BoolT> tmp409;
  if (block200.is_used()) {
    ca_.Bind(&block200, &phi_bb200_19, &phi_bb200_25, &phi_bb200_26, &phi_bb200_27, &phi_bb200_28, &phi_bb200_31, &phi_bb200_32, &phi_bb200_36);
    tmp408 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp409 = CodeStubAssembler(state_).WordNotEqual(TNode<IntPtrT>{phi_bb200_31}, TNode<IntPtrT>{tmp408});
    ca_.Branch(tmp409, &block202, std::vector<compiler::Node*>{phi_bb200_19, phi_bb200_25, phi_bb200_26, phi_bb200_27, phi_bb200_28, phi_bb200_31, phi_bb200_32, phi_bb200_36}, &block203, std::vector<compiler::Node*>{phi_bb200_19, phi_bb200_25, phi_bb200_26, phi_bb200_27, phi_bb200_28, phi_bb200_31, phi_bb200_32, phi_bb200_36});
  }

  TNode<IntPtrT> phi_bb202_19;
  TNode<IntPtrT> phi_bb202_25;
  TNode<IntPtrT> phi_bb202_26;
  TNode<IntPtrT> phi_bb202_27;
  TNode<IntPtrT> phi_bb202_28;
  TNode<IntPtrT> phi_bb202_31;
  TNode<BoolT> phi_bb202_32;
  TNode<BoolT> phi_bb202_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp410;
  TNode<IntPtrT> tmp411;
  TNode<IntPtrT> tmp412;
  TNode<BoolT> tmp413;
  if (block202.is_used()) {
    ca_.Bind(&block202, &phi_bb202_19, &phi_bb202_25, &phi_bb202_26, &phi_bb202_27, &phi_bb202_28, &phi_bb202_31, &phi_bb202_32, &phi_bb202_36);
    std::tie(tmp410, tmp411) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb202_31}).Flatten();
    tmp412 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp413 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block198, phi_bb202_19, phi_bb202_25, phi_bb202_26, phi_bb202_27, phi_bb202_28, tmp412, tmp413, phi_bb202_36, tmp410, tmp411);
  }

  TNode<IntPtrT> phi_bb203_19;
  TNode<IntPtrT> phi_bb203_25;
  TNode<IntPtrT> phi_bb203_26;
  TNode<IntPtrT> phi_bb203_27;
  TNode<IntPtrT> phi_bb203_28;
  TNode<IntPtrT> phi_bb203_31;
  TNode<BoolT> phi_bb203_32;
  TNode<BoolT> phi_bb203_36;
  TNode<Union<HeapObject, TaggedIndex>> tmp414;
  TNode<IntPtrT> tmp415;
  TNode<IntPtrT> tmp416;
  TNode<IntPtrT> tmp417;
  TNode<IntPtrT> tmp418;
  TNode<IntPtrT> tmp419;
  TNode<BoolT> tmp420;
  if (block203.is_used()) {
    ca_.Bind(&block203, &phi_bb203_19, &phi_bb203_25, &phi_bb203_26, &phi_bb203_27, &phi_bb203_28, &phi_bb203_31, &phi_bb203_32, &phi_bb203_36);
    std::tie(tmp414, tmp415) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb203_28}).Flatten();
    tmp416 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp417 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb203_28}, TNode<IntPtrT>{tmp416});
    tmp418 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp419 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp417}, TNode<IntPtrT>{tmp418});
    tmp420 = FromConstexpr_bool_constexpr_bool_0(state_, true);
    ca_.Goto(&block198, phi_bb203_19, phi_bb203_25, phi_bb203_26, phi_bb203_27, tmp419, tmp417, tmp420, phi_bb203_36, tmp414, tmp415);
  }

  TNode<IntPtrT> phi_bb198_19;
  TNode<IntPtrT> phi_bb198_25;
  TNode<IntPtrT> phi_bb198_26;
  TNode<IntPtrT> phi_bb198_27;
  TNode<IntPtrT> phi_bb198_28;
  TNode<IntPtrT> phi_bb198_31;
  TNode<BoolT> phi_bb198_32;
  TNode<BoolT> phi_bb198_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb198_38;
  TNode<IntPtrT> phi_bb198_39;
  if (block198.is_used()) {
    ca_.Bind(&block198, &phi_bb198_19, &phi_bb198_25, &phi_bb198_26, &phi_bb198_27, &phi_bb198_28, &phi_bb198_31, &phi_bb198_32, &phi_bb198_36, &phi_bb198_38, &phi_bb198_39);
    ca_.Goto(&block195, phi_bb198_19, phi_bb198_25, phi_bb198_26, phi_bb198_27, phi_bb198_28, phi_bb198_31, phi_bb198_32, phi_bb198_36, phi_bb198_38, phi_bb198_39);
  }

  TNode<IntPtrT> phi_bb195_19;
  TNode<IntPtrT> phi_bb195_25;
  TNode<IntPtrT> phi_bb195_26;
  TNode<IntPtrT> phi_bb195_27;
  TNode<IntPtrT> phi_bb195_28;
  TNode<IntPtrT> phi_bb195_31;
  TNode<BoolT> phi_bb195_32;
  TNode<BoolT> phi_bb195_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb195_38;
  TNode<IntPtrT> phi_bb195_39;
  TNode<IntPtrT> tmp421;
  TNode<Object> tmp422;
  TNode<Union<HeapObject, TaggedIndex>> tmp423;
  TNode<IntPtrT> tmp424;
  TNode<IntPtrT> tmp425;
  TNode<UintPtrT> tmp426;
  TNode<UintPtrT> tmp427;
  TNode<BoolT> tmp428;
  if (block195.is_used()) {
    ca_.Bind(&block195, &phi_bb195_19, &phi_bb195_25, &phi_bb195_26, &phi_bb195_27, &phi_bb195_28, &phi_bb195_31, &phi_bb195_32, &phi_bb195_36, &phi_bb195_38, &phi_bb195_39);
    tmp421 = CodeStubAssembler(state_).LoadReference<IntPtrT>(CodeStubAssembler::Reference{phi_bb195_38, phi_bb195_39});
    tmp422 = CodeStubAssembler(state_).BitcastWordToTagged(TNode<IntPtrT>{tmp421});
    std::tie(tmp423, tmp424, tmp425) = FieldSliceFixedArrayObjects_0(state_, TNode<FixedArray>{tmp63}).Flatten();
    tmp426 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{phi_bb195_19});
    tmp427 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{tmp425});
    tmp428 = CodeStubAssembler(state_).UintPtrLessThan(TNode<UintPtrT>{tmp426}, TNode<UintPtrT>{tmp427});
    ca_.Branch(tmp428, &block208, std::vector<compiler::Node*>{phi_bb195_19, phi_bb195_25, phi_bb195_26, phi_bb195_27, phi_bb195_28, phi_bb195_31, phi_bb195_32, phi_bb195_36, phi_bb195_38, phi_bb195_39, phi_bb195_19, phi_bb195_19, phi_bb195_19, phi_bb195_19}, &block209, std::vector<compiler::Node*>{phi_bb195_19, phi_bb195_25, phi_bb195_26, phi_bb195_27, phi_bb195_28, phi_bb195_31, phi_bb195_32, phi_bb195_36, phi_bb195_38, phi_bb195_39, phi_bb195_19, phi_bb195_19, phi_bb195_19, phi_bb195_19});
  }

  TNode<IntPtrT> phi_bb208_19;
  TNode<IntPtrT> phi_bb208_25;
  TNode<IntPtrT> phi_bb208_26;
  TNode<IntPtrT> phi_bb208_27;
  TNode<IntPtrT> phi_bb208_28;
  TNode<IntPtrT> phi_bb208_31;
  TNode<BoolT> phi_bb208_32;
  TNode<BoolT> phi_bb208_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb208_38;
  TNode<IntPtrT> phi_bb208_39;
  TNode<IntPtrT> phi_bb208_46;
  TNode<IntPtrT> phi_bb208_47;
  TNode<IntPtrT> phi_bb208_51;
  TNode<IntPtrT> phi_bb208_52;
  TNode<IntPtrT> tmp429;
  TNode<IntPtrT> tmp430;
  TNode<Union<HeapObject, TaggedIndex>> tmp431;
  TNode<IntPtrT> tmp432;
  TNode<IntPtrT> tmp433;
  TNode<NativeContext> tmp434;
  TNode<JSAny> tmp435;
  if (block208.is_used()) {
    ca_.Bind(&block208, &phi_bb208_19, &phi_bb208_25, &phi_bb208_26, &phi_bb208_27, &phi_bb208_28, &phi_bb208_31, &phi_bb208_32, &phi_bb208_36, &phi_bb208_38, &phi_bb208_39, &phi_bb208_46, &phi_bb208_47, &phi_bb208_51, &phi_bb208_52);
    tmp429 = TimesSizeOf_Object_0(state_, TNode<IntPtrT>{phi_bb208_52});
    tmp430 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp424}, TNode<IntPtrT>{tmp429});
    std::tie(tmp431, tmp432) = NewReference_Object_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp423}, TNode<IntPtrT>{tmp430}).Flatten();
    tmp433 = FromConstexpr_intptr_constexpr_int31_0(state_, 24);
    tmp434 = CodeStubAssembler(state_).LoadReference<NativeContext>(CodeStubAssembler::Reference{p_data, tmp433});
    tmp435 = WasmToJSObject_0(state_, TNode<NativeContext>{tmp434}, TNode<Object>{tmp422}, TNode<Uint32T>{tmp391});
    CodeStubAssembler(state_).StoreReference<Object>(CodeStubAssembler::Reference{tmp431, tmp432}, tmp435);
    ca_.Goto(&block194, phi_bb208_19, tmp397, phi_bb208_25, phi_bb208_26, phi_bb208_27, phi_bb208_28, phi_bb208_31, phi_bb208_32, phi_bb208_36);
  }

  TNode<IntPtrT> phi_bb209_19;
  TNode<IntPtrT> phi_bb209_25;
  TNode<IntPtrT> phi_bb209_26;
  TNode<IntPtrT> phi_bb209_27;
  TNode<IntPtrT> phi_bb209_28;
  TNode<IntPtrT> phi_bb209_31;
  TNode<BoolT> phi_bb209_32;
  TNode<BoolT> phi_bb209_36;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb209_38;
  TNode<IntPtrT> phi_bb209_39;
  TNode<IntPtrT> phi_bb209_46;
  TNode<IntPtrT> phi_bb209_47;
  TNode<IntPtrT> phi_bb209_51;
  TNode<IntPtrT> phi_bb209_52;
  if (block209.is_used()) {
    ca_.Bind(&block209, &phi_bb209_19, &phi_bb209_25, &phi_bb209_26, &phi_bb209_27, &phi_bb209_28, &phi_bb209_31, &phi_bb209_32, &phi_bb209_36, &phi_bb209_38, &phi_bb209_39, &phi_bb209_46, &phi_bb209_47, &phi_bb209_51, &phi_bb209_52);
    CodeStubAssembler(state_).Unreachable();
  }

  TNode<IntPtrT> phi_bb194_19;
  TNode<IntPtrT> phi_bb194_24;
  TNode<IntPtrT> phi_bb194_25;
  TNode<IntPtrT> phi_bb194_26;
  TNode<IntPtrT> phi_bb194_27;
  TNode<IntPtrT> phi_bb194_28;
  TNode<IntPtrT> phi_bb194_31;
  TNode<BoolT> phi_bb194_32;
  TNode<BoolT> phi_bb194_36;
  TNode<IntPtrT> tmp436;
  TNode<IntPtrT> tmp437;
  if (block194.is_used()) {
    ca_.Bind(&block194, &phi_bb194_19, &phi_bb194_24, &phi_bb194_25, &phi_bb194_26, &phi_bb194_27, &phi_bb194_28, &phi_bb194_31, &phi_bb194_32, &phi_bb194_36);
    tmp436 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp437 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb194_19}, TNode<IntPtrT>{tmp436});
    ca_.Goto(&block184, tmp437, phi_bb194_24, phi_bb194_25, phi_bb194_26, phi_bb194_27, phi_bb194_28, phi_bb194_31, phi_bb194_32, tmp390, phi_bb194_36);
  }

  TNode<IntPtrT> phi_bb183_19;
  TNode<IntPtrT> phi_bb183_24;
  TNode<IntPtrT> phi_bb183_25;
  TNode<IntPtrT> phi_bb183_26;
  TNode<IntPtrT> phi_bb183_27;
  TNode<IntPtrT> phi_bb183_28;
  TNode<IntPtrT> phi_bb183_31;
  TNode<BoolT> phi_bb183_32;
  TNode<IntPtrT> phi_bb183_34;
  TNode<BoolT> phi_bb183_36;
  if (block183.is_used()) {
    ca_.Bind(&block183, &phi_bb183_19, &phi_bb183_24, &phi_bb183_25, &phi_bb183_26, &phi_bb183_27, &phi_bb183_28, &phi_bb183_31, &phi_bb183_32, &phi_bb183_34, &phi_bb183_36);
    ca_.Goto(&block177, phi_bb183_19, phi_bb183_24, phi_bb183_25, phi_bb183_26, phi_bb183_27, phi_bb183_28, phi_bb183_31, phi_bb183_32, phi_bb183_34, tmp384, phi_bb183_36);
  }

  TNode<IntPtrT> phi_bb177_19;
  TNode<IntPtrT> phi_bb177_24;
  TNode<IntPtrT> phi_bb177_25;
  TNode<IntPtrT> phi_bb177_26;
  TNode<IntPtrT> phi_bb177_27;
  TNode<IntPtrT> phi_bb177_28;
  TNode<IntPtrT> phi_bb177_31;
  TNode<BoolT> phi_bb177_32;
  TNode<IntPtrT> phi_bb177_34;
  TNode<IntPtrT> phi_bb177_35;
  TNode<BoolT> phi_bb177_36;
  TNode<IntPtrT> tmp438;
  TNode<Union<JSReceiver, Undefined>> tmp439;
  TNode<IntPtrT> tmp440;
  TNode<NativeContext> tmp441;
  TNode<IntPtrT> tmp442;
  TNode<Union<HeapObject, TaggedIndex>> tmp443;
  TNode<IntPtrT> tmp444;
  TNode<IntPtrT> tmp445;
  TNode<Int32T> tmp446;
  TNode<Int32T> tmp447;
  TNode<JSAny> tmp448;
  TNode<IntPtrT> tmp449;
  TNode<Union<HeapObject, TaggedIndex>> tmp450;
  TNode<IntPtrT> tmp451;
  TNode<IntPtrT> tmp452;
  TNode<IntPtrT> tmp453;
  TNode<BoolT> tmp454;
  if (block177.is_used()) {
    ca_.Bind(&block177, &phi_bb177_19, &phi_bb177_24, &phi_bb177_25, &phi_bb177_26, &phi_bb177_27, &phi_bb177_28, &phi_bb177_31, &phi_bb177_32, &phi_bb177_34, &phi_bb177_35, &phi_bb177_36);
    tmp438 = FromConstexpr_intptr_constexpr_int31_0(state_, 32);
    tmp439 = CodeStubAssembler(state_).LoadReference<Union<JSReceiver, Undefined>>(CodeStubAssembler::Reference{p_data, tmp438});
    tmp440 = FromConstexpr_intptr_constexpr_int31_0(state_, 24);
    tmp441 = CodeStubAssembler(state_).LoadReference<NativeContext>(CodeStubAssembler::Reference{p_data, tmp440});
    tmp442 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    std::tie(tmp443, tmp444) = GetRefAt_intptr_RawPtr_0(state_, TNode<RawPtrT>{tmp3}, TNode<IntPtrT>{tmp442}).Flatten();
    tmp445 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    CodeStubAssembler(state_).StoreReference<IntPtrT>(CodeStubAssembler::Reference{tmp443, tmp444}, tmp445);
    tmp446 = Convert_int32_intptr_0(state_, TNode<IntPtrT>{tmp62});
    tmp447 = FromConstexpr_int32_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp448 = ca_.CallBuiltin<JSAny>(Builtin::kCallVarargs, tmp441, tmp439, tmp447, tmp446, tmp63);
    tmp449 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    std::tie(tmp450, tmp451) = GetRefAt_intptr_RawPtr_0(state_, TNode<RawPtrT>{tmp3}, TNode<IntPtrT>{tmp449}).Flatten();
    tmp452 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(true, 0x1ull));
    CodeStubAssembler(state_).StoreReference<IntPtrT>(CodeStubAssembler::Reference{tmp450, tmp451}, tmp452);
    tmp453 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x1ull));
    tmp454 = CodeStubAssembler(state_).IntPtrGreaterThan(TNode<IntPtrT>{tmp31}, TNode<IntPtrT>{tmp453});
    ca_.Branch(tmp454, &block212, std::vector<compiler::Node*>{phi_bb177_19, phi_bb177_24, phi_bb177_25, phi_bb177_26, phi_bb177_27, phi_bb177_28, phi_bb177_31, phi_bb177_32, phi_bb177_34, phi_bb177_35, phi_bb177_36}, &block213, std::vector<compiler::Node*>{phi_bb177_19, phi_bb177_24, phi_bb177_25, phi_bb177_26, phi_bb177_27, phi_bb177_28, phi_bb177_31, phi_bb177_32, phi_bb177_34, phi_bb177_35, phi_bb177_36});
  }

  TNode<IntPtrT> phi_bb212_19;
  TNode<IntPtrT> phi_bb212_24;
  TNode<IntPtrT> phi_bb212_25;
  TNode<IntPtrT> phi_bb212_26;
  TNode<IntPtrT> phi_bb212_27;
  TNode<IntPtrT> phi_bb212_28;
  TNode<IntPtrT> phi_bb212_31;
  TNode<BoolT> phi_bb212_32;
  TNode<IntPtrT> phi_bb212_34;
  TNode<IntPtrT> phi_bb212_35;
  TNode<BoolT> phi_bb212_36;
  TNode<Smi> tmp455;
  TNode<FixedArray> tmp456;
  if (block212.is_used()) {
    ca_.Bind(&block212, &phi_bb212_19, &phi_bb212_24, &phi_bb212_25, &phi_bb212_26, &phi_bb212_27, &phi_bb212_28, &phi_bb212_31, &phi_bb212_32, &phi_bb212_34, &phi_bb212_35, &phi_bb212_36);
    tmp455 = Convert_Smi_intptr_0(state_, TNode<IntPtrT>{tmp31});
    tmp456 = ca_.CallBuiltin<FixedArray>(Builtin::kIterableToFixedArrayForWasm, tmp441, tmp448, tmp455);
    ca_.Goto(&block214, phi_bb212_19, phi_bb212_24, phi_bb212_25, phi_bb212_26, phi_bb212_27, phi_bb212_28, phi_bb212_31, phi_bb212_32, phi_bb212_34, phi_bb212_35, phi_bb212_36, tmp456);
  }

  TNode<IntPtrT> phi_bb213_19;
  TNode<IntPtrT> phi_bb213_24;
  TNode<IntPtrT> phi_bb213_25;
  TNode<IntPtrT> phi_bb213_26;
  TNode<IntPtrT> phi_bb213_27;
  TNode<IntPtrT> phi_bb213_28;
  TNode<IntPtrT> phi_bb213_31;
  TNode<BoolT> phi_bb213_32;
  TNode<IntPtrT> phi_bb213_34;
  TNode<IntPtrT> phi_bb213_35;
  TNode<BoolT> phi_bb213_36;
  TNode<FixedArray> tmp457;
  if (block213.is_used()) {
    ca_.Bind(&block213, &phi_bb213_19, &phi_bb213_24, &phi_bb213_25, &phi_bb213_26, &phi_bb213_27, &phi_bb213_28, &phi_bb213_31, &phi_bb213_32, &phi_bb213_34, &phi_bb213_35, &phi_bb213_36);
    tmp457 = kEmptyFixedArray_0(state_);
    ca_.Goto(&block214, phi_bb213_19, phi_bb213_24, phi_bb213_25, phi_bb213_26, phi_bb213_27, phi_bb213_28, phi_bb213_31, phi_bb213_32, phi_bb213_34, phi_bb213_35, phi_bb213_36, tmp457);
  }

  TNode<IntPtrT> phi_bb214_19;
  TNode<IntPtrT> phi_bb214_24;
  TNode<IntPtrT> phi_bb214_25;
  TNode<IntPtrT> phi_bb214_26;
  TNode<IntPtrT> phi_bb214_27;
  TNode<IntPtrT> phi_bb214_28;
  TNode<IntPtrT> phi_bb214_31;
  TNode<BoolT> phi_bb214_32;
  TNode<IntPtrT> phi_bb214_34;
  TNode<IntPtrT> phi_bb214_35;
  TNode<BoolT> phi_bb214_36;
  TNode<FixedArray> phi_bb214_40;
  TNode<RawPtrT> tmp458;
  TNode<RawPtrT> tmp459;
  TNode<RawPtrT> tmp460;
  TNode<RawPtrT> tmp461;
  TNode<IntPtrT> tmp462;
  if (block214.is_used()) {
    ca_.Bind(&block214, &phi_bb214_19, &phi_bb214_24, &phi_bb214_25, &phi_bb214_26, &phi_bb214_27, &phi_bb214_28, &phi_bb214_31, &phi_bb214_32, &phi_bb214_34, &phi_bb214_35, &phi_bb214_36, &phi_bb214_40);
    tmp458 = CodeStubAssembler(state_).StackSlotPtr((CodeStubAssembler(state_).ConstexprInt31Mul((FromConstexpr_constexpr_int31_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x2ull))), (SizeOf_intptr_0(state_)))), (SizeOf_intptr_0(state_)));
    tmp459 = (TNode<RawPtrT>{tmp458});
    tmp460 = CodeStubAssembler(state_).StackSlotPtr((CodeStubAssembler(state_).ConstexprInt31Mul((FromConstexpr_constexpr_int31_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x2ull))), (SizeOf_float64_0(state_)))), (SizeOf_float64_0(state_)));
    tmp461 = (TNode<RawPtrT>{tmp460});
    tmp462 = CodeStubAssembler(state_).StackAlignmentInBytes();
    ca_.Branch(phi_bb214_32, &block216, std::vector<compiler::Node*>{phi_bb214_19, phi_bb214_24, phi_bb214_25, phi_bb214_26, phi_bb214_27, phi_bb214_28, phi_bb214_31, phi_bb214_32, phi_bb214_34, phi_bb214_35, phi_bb214_36, phi_bb214_28}, &block217, std::vector<compiler::Node*>{phi_bb214_19, phi_bb214_24, phi_bb214_25, phi_bb214_26, phi_bb214_27, phi_bb214_28, phi_bb214_31, phi_bb214_32, phi_bb214_34, phi_bb214_35, phi_bb214_36, phi_bb214_28});
  }

  TNode<IntPtrT> phi_bb216_19;
  TNode<IntPtrT> phi_bb216_24;
  TNode<IntPtrT> phi_bb216_25;
  TNode<IntPtrT> phi_bb216_26;
  TNode<IntPtrT> phi_bb216_27;
  TNode<IntPtrT> phi_bb216_28;
  TNode<IntPtrT> phi_bb216_31;
  TNode<BoolT> phi_bb216_32;
  TNode<IntPtrT> phi_bb216_34;
  TNode<IntPtrT> phi_bb216_35;
  TNode<BoolT> phi_bb216_36;
  TNode<IntPtrT> phi_bb216_45;
  TNode<IntPtrT> tmp463;
  TNode<IntPtrT> tmp464;
  if (block216.is_used()) {
    ca_.Bind(&block216, &phi_bb216_19, &phi_bb216_24, &phi_bb216_25, &phi_bb216_26, &phi_bb216_27, &phi_bb216_28, &phi_bb216_31, &phi_bb216_32, &phi_bb216_34, &phi_bb216_35, &phi_bb216_36, &phi_bb216_45);
    tmp463 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp464 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{phi_bb216_45}, TNode<IntPtrT>{tmp463});
    ca_.Goto(&block217, phi_bb216_19, phi_bb216_24, phi_bb216_25, phi_bb216_26, phi_bb216_27, phi_bb216_28, phi_bb216_31, phi_bb216_32, phi_bb216_34, phi_bb216_35, phi_bb216_36, tmp464);
  }

  TNode<IntPtrT> phi_bb217_19;
  TNode<IntPtrT> phi_bb217_24;
  TNode<IntPtrT> phi_bb217_25;
  TNode<IntPtrT> phi_bb217_26;
  TNode<IntPtrT> phi_bb217_27;
  TNode<IntPtrT> phi_bb217_28;
  TNode<IntPtrT> phi_bb217_31;
  TNode<BoolT> phi_bb217_32;
  TNode<IntPtrT> phi_bb217_34;
  TNode<IntPtrT> phi_bb217_35;
  TNode<BoolT> phi_bb217_36;
  TNode<IntPtrT> phi_bb217_45;
  TNode<IntPtrT> tmp465;
  TNode<IntPtrT> tmp466;
  TNode<IntPtrT> tmp467;
  TNode<BoolT> tmp468;
  if (block217.is_used()) {
    ca_.Bind(&block217, &phi_bb217_19, &phi_bb217_24, &phi_bb217_25, &phi_bb217_26, &phi_bb217_27, &phi_bb217_28, &phi_bb217_31, &phi_bb217_32, &phi_bb217_34, &phi_bb217_35, &phi_bb217_36, &phi_bb217_45);
    tmp465 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{phi_bb217_45}, TNode<IntPtrT>{tmp94});
    tmp466 = CodeStubAssembler(state_).IntPtrMod(TNode<IntPtrT>{tmp465}, TNode<IntPtrT>{tmp462});
    tmp467 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp468 = CodeStubAssembler(state_).WordNotEqual(TNode<IntPtrT>{tmp466}, TNode<IntPtrT>{tmp467});
    ca_.Branch(tmp468, &block218, std::vector<compiler::Node*>{phi_bb217_19, phi_bb217_24, phi_bb217_25, phi_bb217_26, phi_bb217_27, phi_bb217_28, phi_bb217_31, phi_bb217_32, phi_bb217_34, phi_bb217_35, phi_bb217_36}, &block219, std::vector<compiler::Node*>{phi_bb217_19, phi_bb217_24, phi_bb217_25, phi_bb217_26, phi_bb217_27, phi_bb217_28, phi_bb217_31, phi_bb217_32, phi_bb217_34, phi_bb217_35, phi_bb217_36, phi_bb217_45});
  }

  TNode<IntPtrT> phi_bb218_19;
  TNode<IntPtrT> phi_bb218_24;
  TNode<IntPtrT> phi_bb218_25;
  TNode<IntPtrT> phi_bb218_26;
  TNode<IntPtrT> phi_bb218_27;
  TNode<IntPtrT> phi_bb218_28;
  TNode<IntPtrT> phi_bb218_31;
  TNode<BoolT> phi_bb218_32;
  TNode<IntPtrT> phi_bb218_34;
  TNode<IntPtrT> phi_bb218_35;
  TNode<BoolT> phi_bb218_36;
  TNode<IntPtrT> tmp469;
  TNode<IntPtrT> tmp470;
  TNode<IntPtrT> tmp471;
  if (block218.is_used()) {
    ca_.Bind(&block218, &phi_bb218_19, &phi_bb218_24, &phi_bb218_25, &phi_bb218_26, &phi_bb218_27, &phi_bb218_28, &phi_bb218_31, &phi_bb218_32, &phi_bb218_34, &phi_bb218_35, &phi_bb218_36);
    tmp469 = CodeStubAssembler(state_).IntPtrMod(TNode<IntPtrT>{tmp465}, TNode<IntPtrT>{tmp462});
    tmp470 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{tmp462}, TNode<IntPtrT>{tmp469});
    tmp471 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb217_45}, TNode<IntPtrT>{tmp470});
    ca_.Goto(&block219, phi_bb218_19, phi_bb218_24, phi_bb218_25, phi_bb218_26, phi_bb218_27, phi_bb218_28, phi_bb218_31, phi_bb218_32, phi_bb218_34, phi_bb218_35, phi_bb218_36, tmp471);
  }

  TNode<IntPtrT> phi_bb219_19;
  TNode<IntPtrT> phi_bb219_24;
  TNode<IntPtrT> phi_bb219_25;
  TNode<IntPtrT> phi_bb219_26;
  TNode<IntPtrT> phi_bb219_27;
  TNode<IntPtrT> phi_bb219_28;
  TNode<IntPtrT> phi_bb219_31;
  TNode<BoolT> phi_bb219_32;
  TNode<IntPtrT> phi_bb219_34;
  TNode<IntPtrT> phi_bb219_35;
  TNode<BoolT> phi_bb219_36;
  TNode<IntPtrT> phi_bb219_45;
  TNode<RawPtrT> tmp472;
  TNode<Union<HeapObject, TaggedIndex>> tmp473;
  TNode<IntPtrT> tmp474;
  TNode<IntPtrT> tmp475;
  TNode<IntPtrT> tmp476;
  TNode<IntPtrT> tmp477;
  TNode<IntPtrT> tmp478;
  TNode<IntPtrT> tmp479;
  TNode<IntPtrT> tmp480;
  TNode<IntPtrT> tmp481;
  TNode<BoolT> tmp482;
  TNode<IntPtrT> tmp483;
  TNode<IntPtrT> tmp484;
  TNode<IntPtrT> tmp485;
  TNode<BoolT> tmp486;
  if (block219.is_used()) {
    ca_.Bind(&block219, &phi_bb219_19, &phi_bb219_24, &phi_bb219_25, &phi_bb219_26, &phi_bb219_27, &phi_bb219_28, &phi_bb219_31, &phi_bb219_32, &phi_bb219_34, &phi_bb219_35, &phi_bb219_36, &phi_bb219_45);
    tmp472 = CodeStubAssembler(state_).GCUnsafeReferenceToRawPtr(TNode<Union<HeapObject, TaggedIndex>>{tmp88}, TNode<IntPtrT>{phi_bb219_45});
    std::tie(tmp473, tmp474, tmp475, tmp476, tmp477, tmp478, tmp479, tmp480, tmp481, tmp482) = LocationAllocatorForReturns_0(state_, TNode<RawPtrT>{tmp459}, TNode<RawPtrT>{tmp461}, TNode<RawPtrT>{tmp472}).Flatten();
    tmp483 = TimesSizeOf_WasmCodePointer_0(state_, TNode<IntPtrT>{tmp55});
    tmp484 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp54}, TNode<IntPtrT>{tmp483});
    tmp485 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp486 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block223, tmp485, tmp474, tmp475, tmp476, tmp477, tmp478, tmp481, tmp482, phi_bb219_34, phi_bb219_35, phi_bb219_36, tmp54, tmp486);
  }

  TNode<IntPtrT> phi_bb223_19;
  TNode<IntPtrT> phi_bb223_24;
  TNode<IntPtrT> phi_bb223_25;
  TNode<IntPtrT> phi_bb223_26;
  TNode<IntPtrT> phi_bb223_27;
  TNode<IntPtrT> phi_bb223_28;
  TNode<IntPtrT> phi_bb223_31;
  TNode<BoolT> phi_bb223_32;
  TNode<IntPtrT> phi_bb223_34;
  TNode<IntPtrT> phi_bb223_35;
  TNode<BoolT> phi_bb223_36;
  TNode<IntPtrT> phi_bb223_45;
  TNode<BoolT> phi_bb223_47;
  TNode<BoolT> tmp487;
  TNode<BoolT> tmp488;
  if (block223.is_used()) {
    ca_.Bind(&block223, &phi_bb223_19, &phi_bb223_24, &phi_bb223_25, &phi_bb223_26, &phi_bb223_27, &phi_bb223_28, &phi_bb223_31, &phi_bb223_32, &phi_bb223_34, &phi_bb223_35, &phi_bb223_36, &phi_bb223_45, &phi_bb223_47);
    tmp487 = CodeStubAssembler(state_).WordEqual(TNode<IntPtrT>{phi_bb223_45}, TNode<IntPtrT>{tmp484});
    tmp488 = CodeStubAssembler(state_).Word32BinaryNot(TNode<BoolT>{tmp487});
    ca_.Branch(tmp488, &block221, std::vector<compiler::Node*>{phi_bb223_19, phi_bb223_24, phi_bb223_25, phi_bb223_26, phi_bb223_27, phi_bb223_28, phi_bb223_31, phi_bb223_32, phi_bb223_34, phi_bb223_35, phi_bb223_36, phi_bb223_45, phi_bb223_47}, &block222, std::vector<compiler::Node*>{phi_bb223_19, phi_bb223_24, phi_bb223_25, phi_bb223_26, phi_bb223_27, phi_bb223_28, phi_bb223_31, phi_bb223_32, phi_bb223_34, phi_bb223_35, phi_bb223_36, phi_bb223_45, phi_bb223_47});
  }

  TNode<IntPtrT> phi_bb221_19;
  TNode<IntPtrT> phi_bb221_24;
  TNode<IntPtrT> phi_bb221_25;
  TNode<IntPtrT> phi_bb221_26;
  TNode<IntPtrT> phi_bb221_27;
  TNode<IntPtrT> phi_bb221_28;
  TNode<IntPtrT> phi_bb221_31;
  TNode<BoolT> phi_bb221_32;
  TNode<IntPtrT> phi_bb221_34;
  TNode<IntPtrT> phi_bb221_35;
  TNode<BoolT> phi_bb221_36;
  TNode<IntPtrT> phi_bb221_45;
  TNode<BoolT> phi_bb221_47;
  TNode<IntPtrT> tmp489;
  TNode<BoolT> tmp490;
  if (block221.is_used()) {
    ca_.Bind(&block221, &phi_bb221_19, &phi_bb221_24, &phi_bb221_25, &phi_bb221_26, &phi_bb221_27, &phi_bb221_28, &phi_bb221_31, &phi_bb221_32, &phi_bb221_34, &phi_bb221_35, &phi_bb221_36, &phi_bb221_45, &phi_bb221_47);
    tmp489 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x1ull));
    tmp490 = CodeStubAssembler(state_).WordEqual(TNode<IntPtrT>{tmp31}, TNode<IntPtrT>{tmp489});
    ca_.Branch(tmp490, &block225, std::vector<compiler::Node*>{phi_bb221_19, phi_bb221_24, phi_bb221_25, phi_bb221_26, phi_bb221_27, phi_bb221_28, phi_bb221_31, phi_bb221_32, phi_bb221_34, phi_bb221_35, phi_bb221_36, phi_bb221_45, phi_bb221_47}, &block226, std::vector<compiler::Node*>{phi_bb221_19, phi_bb221_24, phi_bb221_25, phi_bb221_26, phi_bb221_27, phi_bb221_28, phi_bb221_31, phi_bb221_32, phi_bb221_34, phi_bb221_35, phi_bb221_36, phi_bb221_45, phi_bb221_47});
  }

  TNode<IntPtrT> phi_bb225_19;
  TNode<IntPtrT> phi_bb225_24;
  TNode<IntPtrT> phi_bb225_25;
  TNode<IntPtrT> phi_bb225_26;
  TNode<IntPtrT> phi_bb225_27;
  TNode<IntPtrT> phi_bb225_28;
  TNode<IntPtrT> phi_bb225_31;
  TNode<BoolT> phi_bb225_32;
  TNode<IntPtrT> phi_bb225_34;
  TNode<IntPtrT> phi_bb225_35;
  TNode<BoolT> phi_bb225_36;
  TNode<IntPtrT> phi_bb225_45;
  TNode<BoolT> phi_bb225_47;
  if (block225.is_used()) {
    ca_.Bind(&block225, &phi_bb225_19, &phi_bb225_24, &phi_bb225_25, &phi_bb225_26, &phi_bb225_27, &phi_bb225_28, &phi_bb225_31, &phi_bb225_32, &phi_bb225_34, &phi_bb225_35, &phi_bb225_36, &phi_bb225_45, &phi_bb225_47);
    ca_.Goto(&block227, phi_bb225_19, phi_bb225_24, phi_bb225_25, phi_bb225_26, phi_bb225_27, phi_bb225_28, phi_bb225_31, phi_bb225_32, phi_bb225_34, phi_bb225_35, phi_bb225_36, phi_bb225_45, phi_bb225_47, tmp448);
  }

  TNode<IntPtrT> phi_bb226_19;
  TNode<IntPtrT> phi_bb226_24;
  TNode<IntPtrT> phi_bb226_25;
  TNode<IntPtrT> phi_bb226_26;
  TNode<IntPtrT> phi_bb226_27;
  TNode<IntPtrT> phi_bb226_28;
  TNode<IntPtrT> phi_bb226_31;
  TNode<BoolT> phi_bb226_32;
  TNode<IntPtrT> phi_bb226_34;
  TNode<IntPtrT> phi_bb226_35;
  TNode<BoolT> phi_bb226_36;
  TNode<IntPtrT> phi_bb226_45;
  TNode<BoolT> phi_bb226_47;
  TNode<Union<HeapObject, TaggedIndex>> tmp491;
  TNode<IntPtrT> tmp492;
  TNode<IntPtrT> tmp493;
  TNode<UintPtrT> tmp494;
  TNode<UintPtrT> tmp495;
  TNode<BoolT> tmp496;
  if (block226.is_used()) {
    ca_.Bind(&block226, &phi_bb226_19, &phi_bb226_24, &phi_bb226_25, &phi_bb226_26, &phi_bb226_27, &phi_bb226_28, &phi_bb226_31, &phi_bb226_32, &phi_bb226_34, &phi_bb226_35, &phi_bb226_36, &phi_bb226_45, &phi_bb226_47);
    std::tie(tmp491, tmp492, tmp493) = FieldSliceFixedArrayObjects_0(state_, TNode<FixedArray>{phi_bb214_40}).Flatten();
    tmp494 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{phi_bb226_19});
    tmp495 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{tmp493});
    tmp496 = CodeStubAssembler(state_).UintPtrLessThan(TNode<UintPtrT>{tmp494}, TNode<UintPtrT>{tmp495});
    ca_.Branch(tmp496, &block232, std::vector<compiler::Node*>{phi_bb226_19, phi_bb226_24, phi_bb226_25, phi_bb226_26, phi_bb226_27, phi_bb226_28, phi_bb226_31, phi_bb226_32, phi_bb226_34, phi_bb226_35, phi_bb226_36, phi_bb226_45, phi_bb226_47, phi_bb226_19, phi_bb226_19, phi_bb226_19, phi_bb226_19}, &block233, std::vector<compiler::Node*>{phi_bb226_19, phi_bb226_24, phi_bb226_25, phi_bb226_26, phi_bb226_27, phi_bb226_28, phi_bb226_31, phi_bb226_32, phi_bb226_34, phi_bb226_35, phi_bb226_36, phi_bb226_45, phi_bb226_47, phi_bb226_19, phi_bb226_19, phi_bb226_19, phi_bb226_19});
  }

  TNode<IntPtrT> phi_bb232_19;
  TNode<IntPtrT> phi_bb232_24;
  TNode<IntPtrT> phi_bb232_25;
  TNode<IntPtrT> phi_bb232_26;
  TNode<IntPtrT> phi_bb232_27;
  TNode<IntPtrT> phi_bb232_28;
  TNode<IntPtrT> phi_bb232_31;
  TNode<BoolT> phi_bb232_32;
  TNode<IntPtrT> phi_bb232_34;
  TNode<IntPtrT> phi_bb232_35;
  TNode<BoolT> phi_bb232_36;
  TNode<IntPtrT> phi_bb232_45;
  TNode<BoolT> phi_bb232_47;
  TNode<IntPtrT> phi_bb232_53;
  TNode<IntPtrT> phi_bb232_54;
  TNode<IntPtrT> phi_bb232_58;
  TNode<IntPtrT> phi_bb232_59;
  TNode<IntPtrT> tmp497;
  TNode<IntPtrT> tmp498;
  TNode<Union<HeapObject, TaggedIndex>> tmp499;
  TNode<IntPtrT> tmp500;
  TNode<Object> tmp501;
  TNode<JSAny> tmp502;
  if (block232.is_used()) {
    ca_.Bind(&block232, &phi_bb232_19, &phi_bb232_24, &phi_bb232_25, &phi_bb232_26, &phi_bb232_27, &phi_bb232_28, &phi_bb232_31, &phi_bb232_32, &phi_bb232_34, &phi_bb232_35, &phi_bb232_36, &phi_bb232_45, &phi_bb232_47, &phi_bb232_53, &phi_bb232_54, &phi_bb232_58, &phi_bb232_59);
    tmp497 = TimesSizeOf_Object_0(state_, TNode<IntPtrT>{phi_bb232_59});
    tmp498 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp492}, TNode<IntPtrT>{tmp497});
    std::tie(tmp499, tmp500) = NewReference_Object_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp491}, TNode<IntPtrT>{tmp498}).Flatten();
    tmp501 = CodeStubAssembler(state_).LoadReference<Object>(CodeStubAssembler::Reference{tmp499, tmp500});
    tmp502 = UnsafeCast_JSAny_0(state_, TNode<Context>{tmp441}, TNode<Object>{tmp501});
    ca_.Goto(&block227, phi_bb232_19, phi_bb232_24, phi_bb232_25, phi_bb232_26, phi_bb232_27, phi_bb232_28, phi_bb232_31, phi_bb232_32, phi_bb232_34, phi_bb232_35, phi_bb232_36, phi_bb232_45, phi_bb232_47, tmp502);
  }

  TNode<IntPtrT> phi_bb233_19;
  TNode<IntPtrT> phi_bb233_24;
  TNode<IntPtrT> phi_bb233_25;
  TNode<IntPtrT> phi_bb233_26;
  TNode<IntPtrT> phi_bb233_27;
  TNode<IntPtrT> phi_bb233_28;
  TNode<IntPtrT> phi_bb233_31;
  TNode<BoolT> phi_bb233_32;
  TNode<IntPtrT> phi_bb233_34;
  TNode<IntPtrT> phi_bb233_35;
  TNode<BoolT> phi_bb233_36;
  TNode<IntPtrT> phi_bb233_45;
  TNode<BoolT> phi_bb233_47;
  TNode<IntPtrT> phi_bb233_53;
  TNode<IntPtrT> phi_bb233_54;
  TNode<IntPtrT> phi_bb233_58;
  TNode<IntPtrT> phi_bb233_59;
  if (block233.is_used()) {
    ca_.Bind(&block233, &phi_bb233_19, &phi_bb233_24, &phi_bb233_25, &phi_bb233_26, &phi_bb233_27, &phi_bb233_28, &phi_bb233_31, &phi_bb233_32, &phi_bb233_34, &phi_bb233_35, &phi_bb233_36, &phi_bb233_45, &phi_bb233_47, &phi_bb233_53, &phi_bb233_54, &phi_bb233_58, &phi_bb233_59);
    CodeStubAssembler(state_).Unreachable();
  }

  TNode<IntPtrT> phi_bb227_19;
  TNode<IntPtrT> phi_bb227_24;
  TNode<IntPtrT> phi_bb227_25;
  TNode<IntPtrT> phi_bb227_26;
  TNode<IntPtrT> phi_bb227_27;
  TNode<IntPtrT> phi_bb227_28;
  TNode<IntPtrT> phi_bb227_31;
  TNode<BoolT> phi_bb227_32;
  TNode<IntPtrT> phi_bb227_34;
  TNode<IntPtrT> phi_bb227_35;
  TNode<BoolT> phi_bb227_36;
  TNode<IntPtrT> phi_bb227_45;
  TNode<BoolT> phi_bb227_47;
  TNode<JSAny> phi_bb227_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp503;
  TNode<IntPtrT> tmp504;
  TNode<IntPtrT> tmp505;
  TNode<IntPtrT> tmp506;
  TNode<Uint32T> tmp507;
  TNode<Uint32T> tmp508;
  TNode<BoolT> tmp509;
  if (block227.is_used()) {
    ca_.Bind(&block227, &phi_bb227_19, &phi_bb227_24, &phi_bb227_25, &phi_bb227_26, &phi_bb227_27, &phi_bb227_28, &phi_bb227_31, &phi_bb227_32, &phi_bb227_34, &phi_bb227_35, &phi_bb227_36, &phi_bb227_45, &phi_bb227_47, &phi_bb227_48);
    std::tie(tmp503, tmp504) = NewReference_WasmCodePointer_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp53}, TNode<IntPtrT>{phi_bb227_45}).Flatten();
    tmp505 = FromConstexpr_intptr_constexpr_int31_0(state_, kInt32Size);
    tmp506 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb227_45}, TNode<IntPtrT>{tmp505});
    tmp507 = CodeStubAssembler(state_).LoadReference<Uint32T>(CodeStubAssembler::Reference{tmp503, tmp504});
    tmp508 = FromConstexpr_WasmCodePointer_constexpr_WasmCodePointer_0(state_, wasm::kWasmI32.raw_bit_field());
    tmp509 = CodeStubAssembler(state_).Word32Equal(TNode<Uint32T>{tmp507}, TNode<Uint32T>{tmp508});
    ca_.Branch(tmp509, &block243, std::vector<compiler::Node*>{phi_bb227_19, phi_bb227_24, phi_bb227_25, phi_bb227_26, phi_bb227_27, phi_bb227_28, phi_bb227_31, phi_bb227_32, phi_bb227_34, phi_bb227_35, phi_bb227_36, phi_bb227_47, phi_bb227_48}, &block244, std::vector<compiler::Node*>{phi_bb227_19, phi_bb227_24, phi_bb227_25, phi_bb227_26, phi_bb227_27, phi_bb227_28, phi_bb227_31, phi_bb227_32, phi_bb227_34, phi_bb227_35, phi_bb227_36, phi_bb227_47, phi_bb227_48});
  }

  TNode<IntPtrT> phi_bb243_19;
  TNode<IntPtrT> phi_bb243_24;
  TNode<IntPtrT> phi_bb243_25;
  TNode<IntPtrT> phi_bb243_26;
  TNode<IntPtrT> phi_bb243_27;
  TNode<IntPtrT> phi_bb243_28;
  TNode<IntPtrT> phi_bb243_31;
  TNode<BoolT> phi_bb243_32;
  TNode<IntPtrT> phi_bb243_34;
  TNode<IntPtrT> phi_bb243_35;
  TNode<BoolT> phi_bb243_36;
  TNode<BoolT> phi_bb243_47;
  TNode<JSAny> phi_bb243_48;
  TNode<IntPtrT> tmp510;
  TNode<IntPtrT> tmp511;
  TNode<IntPtrT> tmp512;
  TNode<BoolT> tmp513;
  if (block243.is_used()) {
    ca_.Bind(&block243, &phi_bb243_19, &phi_bb243_24, &phi_bb243_25, &phi_bb243_26, &phi_bb243_27, &phi_bb243_28, &phi_bb243_31, &phi_bb243_32, &phi_bb243_34, &phi_bb243_35, &phi_bb243_36, &phi_bb243_47, &phi_bb243_48);
    tmp510 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp511 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{phi_bb243_24}, TNode<IntPtrT>{tmp510});
    tmp512 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp513 = CodeStubAssembler(state_).IntPtrGreaterThan(TNode<IntPtrT>{phi_bb243_24}, TNode<IntPtrT>{tmp512});
    ca_.Branch(tmp513, &block247, std::vector<compiler::Node*>{phi_bb243_19, phi_bb243_25, phi_bb243_26, phi_bb243_27, phi_bb243_28, phi_bb243_31, phi_bb243_32, phi_bb243_34, phi_bb243_35, phi_bb243_36, phi_bb243_47, phi_bb243_48}, &block248, std::vector<compiler::Node*>{phi_bb243_19, phi_bb243_25, phi_bb243_26, phi_bb243_27, phi_bb243_28, phi_bb243_31, phi_bb243_32, phi_bb243_34, phi_bb243_35, phi_bb243_36, phi_bb243_47, phi_bb243_48});
  }

  TNode<IntPtrT> phi_bb247_19;
  TNode<IntPtrT> phi_bb247_25;
  TNode<IntPtrT> phi_bb247_26;
  TNode<IntPtrT> phi_bb247_27;
  TNode<IntPtrT> phi_bb247_28;
  TNode<IntPtrT> phi_bb247_31;
  TNode<BoolT> phi_bb247_32;
  TNode<IntPtrT> phi_bb247_34;
  TNode<IntPtrT> phi_bb247_35;
  TNode<BoolT> phi_bb247_36;
  TNode<BoolT> phi_bb247_47;
  TNode<JSAny> phi_bb247_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp514;
  TNode<IntPtrT> tmp515;
  TNode<IntPtrT> tmp516;
  TNode<IntPtrT> tmp517;
  if (block247.is_used()) {
    ca_.Bind(&block247, &phi_bb247_19, &phi_bb247_25, &phi_bb247_26, &phi_bb247_27, &phi_bb247_28, &phi_bb247_31, &phi_bb247_32, &phi_bb247_34, &phi_bb247_35, &phi_bb247_36, &phi_bb247_47, &phi_bb247_48);
    std::tie(tmp514, tmp515) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb247_26}).Flatten();
    tmp516 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp517 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb247_26}, TNode<IntPtrT>{tmp516});
    ca_.Goto(&block246, phi_bb247_19, phi_bb247_25, tmp517, phi_bb247_27, phi_bb247_28, phi_bb247_31, phi_bb247_32, phi_bb247_34, phi_bb247_35, phi_bb247_36, phi_bb247_47, phi_bb247_48, tmp514, tmp515);
  }

  TNode<IntPtrT> phi_bb248_19;
  TNode<IntPtrT> phi_bb248_25;
  TNode<IntPtrT> phi_bb248_26;
  TNode<IntPtrT> phi_bb248_27;
  TNode<IntPtrT> phi_bb248_28;
  TNode<IntPtrT> phi_bb248_31;
  TNode<BoolT> phi_bb248_32;
  TNode<IntPtrT> phi_bb248_34;
  TNode<IntPtrT> phi_bb248_35;
  TNode<BoolT> phi_bb248_36;
  TNode<BoolT> phi_bb248_47;
  TNode<JSAny> phi_bb248_48;
  if (block248.is_used()) {
    ca_.Bind(&block248, &phi_bb248_19, &phi_bb248_25, &phi_bb248_26, &phi_bb248_27, &phi_bb248_28, &phi_bb248_31, &phi_bb248_32, &phi_bb248_34, &phi_bb248_35, &phi_bb248_36, &phi_bb248_47, &phi_bb248_48);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block250, phi_bb248_19, phi_bb248_25, phi_bb248_26, phi_bb248_27, phi_bb248_28, phi_bb248_31, phi_bb248_32, phi_bb248_34, phi_bb248_35, phi_bb248_36, phi_bb248_47, phi_bb248_48);
    } else {
      ca_.Goto(&block251, phi_bb248_19, phi_bb248_25, phi_bb248_26, phi_bb248_27, phi_bb248_28, phi_bb248_31, phi_bb248_32, phi_bb248_34, phi_bb248_35, phi_bb248_36, phi_bb248_47, phi_bb248_48);
    }
  }

  TNode<IntPtrT> phi_bb250_19;
  TNode<IntPtrT> phi_bb250_25;
  TNode<IntPtrT> phi_bb250_26;
  TNode<IntPtrT> phi_bb250_27;
  TNode<IntPtrT> phi_bb250_28;
  TNode<IntPtrT> phi_bb250_31;
  TNode<BoolT> phi_bb250_32;
  TNode<IntPtrT> phi_bb250_34;
  TNode<IntPtrT> phi_bb250_35;
  TNode<BoolT> phi_bb250_36;
  TNode<BoolT> phi_bb250_47;
  TNode<JSAny> phi_bb250_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp518;
  TNode<IntPtrT> tmp519;
  TNode<IntPtrT> tmp520;
  TNode<IntPtrT> tmp521;
  if (block250.is_used()) {
    ca_.Bind(&block250, &phi_bb250_19, &phi_bb250_25, &phi_bb250_26, &phi_bb250_27, &phi_bb250_28, &phi_bb250_31, &phi_bb250_32, &phi_bb250_34, &phi_bb250_35, &phi_bb250_36, &phi_bb250_47, &phi_bb250_48);
    std::tie(tmp518, tmp519) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb250_28}).Flatten();
    tmp520 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp521 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb250_28}, TNode<IntPtrT>{tmp520});
    ca_.Goto(&block249, phi_bb250_19, phi_bb250_25, phi_bb250_26, phi_bb250_27, tmp521, phi_bb250_31, phi_bb250_32, phi_bb250_34, phi_bb250_35, phi_bb250_36, phi_bb250_47, phi_bb250_48, tmp518, tmp519);
  }

  TNode<IntPtrT> phi_bb251_19;
  TNode<IntPtrT> phi_bb251_25;
  TNode<IntPtrT> phi_bb251_26;
  TNode<IntPtrT> phi_bb251_27;
  TNode<IntPtrT> phi_bb251_28;
  TNode<IntPtrT> phi_bb251_31;
  TNode<BoolT> phi_bb251_32;
  TNode<IntPtrT> phi_bb251_34;
  TNode<IntPtrT> phi_bb251_35;
  TNode<BoolT> phi_bb251_36;
  TNode<BoolT> phi_bb251_47;
  TNode<JSAny> phi_bb251_48;
  TNode<IntPtrT> tmp522;
  TNode<BoolT> tmp523;
  if (block251.is_used()) {
    ca_.Bind(&block251, &phi_bb251_19, &phi_bb251_25, &phi_bb251_26, &phi_bb251_27, &phi_bb251_28, &phi_bb251_31, &phi_bb251_32, &phi_bb251_34, &phi_bb251_35, &phi_bb251_36, &phi_bb251_47, &phi_bb251_48);
    tmp522 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp523 = CodeStubAssembler(state_).WordNotEqual(TNode<IntPtrT>{phi_bb251_31}, TNode<IntPtrT>{tmp522});
    ca_.Branch(tmp523, &block253, std::vector<compiler::Node*>{phi_bb251_19, phi_bb251_25, phi_bb251_26, phi_bb251_27, phi_bb251_28, phi_bb251_31, phi_bb251_32, phi_bb251_34, phi_bb251_35, phi_bb251_36, phi_bb251_47, phi_bb251_48}, &block254, std::vector<compiler::Node*>{phi_bb251_19, phi_bb251_25, phi_bb251_26, phi_bb251_27, phi_bb251_28, phi_bb251_31, phi_bb251_32, phi_bb251_34, phi_bb251_35, phi_bb251_36, phi_bb251_47, phi_bb251_48});
  }

  TNode<IntPtrT> phi_bb253_19;
  TNode<IntPtrT> phi_bb253_25;
  TNode<IntPtrT> phi_bb253_26;
  TNode<IntPtrT> phi_bb253_27;
  TNode<IntPtrT> phi_bb253_28;
  TNode<IntPtrT> phi_bb253_31;
  TNode<BoolT> phi_bb253_32;
  TNode<IntPtrT> phi_bb253_34;
  TNode<IntPtrT> phi_bb253_35;
  TNode<BoolT> phi_bb253_36;
  TNode<BoolT> phi_bb253_47;
  TNode<JSAny> phi_bb253_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp524;
  TNode<IntPtrT> tmp525;
  TNode<IntPtrT> tmp526;
  TNode<BoolT> tmp527;
  if (block253.is_used()) {
    ca_.Bind(&block253, &phi_bb253_19, &phi_bb253_25, &phi_bb253_26, &phi_bb253_27, &phi_bb253_28, &phi_bb253_31, &phi_bb253_32, &phi_bb253_34, &phi_bb253_35, &phi_bb253_36, &phi_bb253_47, &phi_bb253_48);
    std::tie(tmp524, tmp525) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb253_31}).Flatten();
    tmp526 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp527 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block249, phi_bb253_19, phi_bb253_25, phi_bb253_26, phi_bb253_27, phi_bb253_28, tmp526, tmp527, phi_bb253_34, phi_bb253_35, phi_bb253_36, phi_bb253_47, phi_bb253_48, tmp524, tmp525);
  }

  TNode<IntPtrT> phi_bb254_19;
  TNode<IntPtrT> phi_bb254_25;
  TNode<IntPtrT> phi_bb254_26;
  TNode<IntPtrT> phi_bb254_27;
  TNode<IntPtrT> phi_bb254_28;
  TNode<IntPtrT> phi_bb254_31;
  TNode<BoolT> phi_bb254_32;
  TNode<IntPtrT> phi_bb254_34;
  TNode<IntPtrT> phi_bb254_35;
  TNode<BoolT> phi_bb254_36;
  TNode<BoolT> phi_bb254_47;
  TNode<JSAny> phi_bb254_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp528;
  TNode<IntPtrT> tmp529;
  TNode<IntPtrT> tmp530;
  TNode<IntPtrT> tmp531;
  TNode<IntPtrT> tmp532;
  TNode<IntPtrT> tmp533;
  TNode<BoolT> tmp534;
  if (block254.is_used()) {
    ca_.Bind(&block254, &phi_bb254_19, &phi_bb254_25, &phi_bb254_26, &phi_bb254_27, &phi_bb254_28, &phi_bb254_31, &phi_bb254_32, &phi_bb254_34, &phi_bb254_35, &phi_bb254_36, &phi_bb254_47, &phi_bb254_48);
    std::tie(tmp528, tmp529) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb254_28}).Flatten();
    tmp530 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp531 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb254_28}, TNode<IntPtrT>{tmp530});
    tmp532 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp533 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp531}, TNode<IntPtrT>{tmp532});
    tmp534 = FromConstexpr_bool_constexpr_bool_0(state_, true);
    ca_.Goto(&block249, phi_bb254_19, phi_bb254_25, phi_bb254_26, phi_bb254_27, tmp533, tmp531, tmp534, phi_bb254_34, phi_bb254_35, phi_bb254_36, phi_bb254_47, phi_bb254_48, tmp528, tmp529);
  }

  TNode<IntPtrT> phi_bb249_19;
  TNode<IntPtrT> phi_bb249_25;
  TNode<IntPtrT> phi_bb249_26;
  TNode<IntPtrT> phi_bb249_27;
  TNode<IntPtrT> phi_bb249_28;
  TNode<IntPtrT> phi_bb249_31;
  TNode<BoolT> phi_bb249_32;
  TNode<IntPtrT> phi_bb249_34;
  TNode<IntPtrT> phi_bb249_35;
  TNode<BoolT> phi_bb249_36;
  TNode<BoolT> phi_bb249_47;
  TNode<JSAny> phi_bb249_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb249_50;
  TNode<IntPtrT> phi_bb249_51;
  if (block249.is_used()) {
    ca_.Bind(&block249, &phi_bb249_19, &phi_bb249_25, &phi_bb249_26, &phi_bb249_27, &phi_bb249_28, &phi_bb249_31, &phi_bb249_32, &phi_bb249_34, &phi_bb249_35, &phi_bb249_36, &phi_bb249_47, &phi_bb249_48, &phi_bb249_50, &phi_bb249_51);
    ca_.Goto(&block246, phi_bb249_19, phi_bb249_25, phi_bb249_26, phi_bb249_27, phi_bb249_28, phi_bb249_31, phi_bb249_32, phi_bb249_34, phi_bb249_35, phi_bb249_36, phi_bb249_47, phi_bb249_48, phi_bb249_50, phi_bb249_51);
  }

  TNode<IntPtrT> phi_bb246_19;
  TNode<IntPtrT> phi_bb246_25;
  TNode<IntPtrT> phi_bb246_26;
  TNode<IntPtrT> phi_bb246_27;
  TNode<IntPtrT> phi_bb246_28;
  TNode<IntPtrT> phi_bb246_31;
  TNode<BoolT> phi_bb246_32;
  TNode<IntPtrT> phi_bb246_34;
  TNode<IntPtrT> phi_bb246_35;
  TNode<BoolT> phi_bb246_36;
  TNode<BoolT> phi_bb246_47;
  TNode<JSAny> phi_bb246_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb246_50;
  TNode<IntPtrT> phi_bb246_51;
  TNode<Smi> tmp535;
  if (block246.is_used()) {
    ca_.Bind(&block246, &phi_bb246_19, &phi_bb246_25, &phi_bb246_26, &phi_bb246_27, &phi_bb246_28, &phi_bb246_31, &phi_bb246_32, &phi_bb246_34, &phi_bb246_35, &phi_bb246_36, &phi_bb246_47, &phi_bb246_48, &phi_bb246_50, &phi_bb246_51);
    compiler::CodeAssemblerLabel label536(&ca_);
    tmp535 = Cast_Smi_0(state_, TNode<Object>{phi_bb246_48}, &label536);
    ca_.Goto(&block257, phi_bb246_19, phi_bb246_25, phi_bb246_26, phi_bb246_27, phi_bb246_28, phi_bb246_31, phi_bb246_32, phi_bb246_34, phi_bb246_35, phi_bb246_36, phi_bb246_47, phi_bb246_48, phi_bb246_50, phi_bb246_51, phi_bb246_48, phi_bb246_48);
    if (label536.is_used()) {
      ca_.Bind(&label536);
      ca_.Goto(&block258, phi_bb246_19, phi_bb246_25, phi_bb246_26, phi_bb246_27, phi_bb246_28, phi_bb246_31, phi_bb246_32, phi_bb246_34, phi_bb246_35, phi_bb246_36, phi_bb246_47, phi_bb246_48, phi_bb246_50, phi_bb246_51, phi_bb246_48, phi_bb246_48);
    }
  }

  TNode<IntPtrT> phi_bb258_19;
  TNode<IntPtrT> phi_bb258_25;
  TNode<IntPtrT> phi_bb258_26;
  TNode<IntPtrT> phi_bb258_27;
  TNode<IntPtrT> phi_bb258_28;
  TNode<IntPtrT> phi_bb258_31;
  TNode<BoolT> phi_bb258_32;
  TNode<IntPtrT> phi_bb258_34;
  TNode<IntPtrT> phi_bb258_35;
  TNode<BoolT> phi_bb258_36;
  TNode<BoolT> phi_bb258_47;
  TNode<JSAny> phi_bb258_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb258_50;
  TNode<IntPtrT> phi_bb258_51;
  TNode<JSAny> phi_bb258_52;
  TNode<JSAny> phi_bb258_53;
  TNode<Int32T> tmp537;
  TNode<Uint32T> tmp538;
  TNode<IntPtrT> tmp539;
  if (block258.is_used()) {
    ca_.Bind(&block258, &phi_bb258_19, &phi_bb258_25, &phi_bb258_26, &phi_bb258_27, &phi_bb258_28, &phi_bb258_31, &phi_bb258_32, &phi_bb258_34, &phi_bb258_35, &phi_bb258_36, &phi_bb258_47, &phi_bb258_48, &phi_bb258_50, &phi_bb258_51, &phi_bb258_52, &phi_bb258_53);
    tmp537 = ca_.CallBuiltin<Int32T>(Builtin::kWasmTaggedNonSmiToInt32, tmp441, ca_.UncheckedCast<Union<BigInt, Boolean, HeapNumber, JSReceiver, Null, String, Symbol, Undefined>>(phi_bb258_52));
    tmp538 = CodeStubAssembler(state_).Unsigned(TNode<Int32T>{tmp537});
    tmp539 = Convert_intptr_WasmCodePointer_0(state_, TNode<Uint32T>{tmp538});
    CodeStubAssembler(state_).StoreReference<IntPtrT>(CodeStubAssembler::Reference{phi_bb258_50, phi_bb258_51}, tmp539);
    ca_.Goto(&block255, phi_bb258_19, phi_bb258_25, phi_bb258_26, phi_bb258_27, phi_bb258_28, phi_bb258_31, phi_bb258_32, phi_bb258_34, phi_bb258_35, phi_bb258_36, phi_bb258_47, phi_bb258_48, phi_bb258_50, phi_bb258_51, phi_bb258_52);
  }

  TNode<IntPtrT> phi_bb257_19;
  TNode<IntPtrT> phi_bb257_25;
  TNode<IntPtrT> phi_bb257_26;
  TNode<IntPtrT> phi_bb257_27;
  TNode<IntPtrT> phi_bb257_28;
  TNode<IntPtrT> phi_bb257_31;
  TNode<BoolT> phi_bb257_32;
  TNode<IntPtrT> phi_bb257_34;
  TNode<IntPtrT> phi_bb257_35;
  TNode<BoolT> phi_bb257_36;
  TNode<BoolT> phi_bb257_47;
  TNode<JSAny> phi_bb257_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb257_50;
  TNode<IntPtrT> phi_bb257_51;
  TNode<JSAny> phi_bb257_52;
  TNode<JSAny> phi_bb257_53;
  TNode<Int32T> tmp540;
  TNode<Uint32T> tmp541;
  TNode<IntPtrT> tmp542;
  if (block257.is_used()) {
    ca_.Bind(&block257, &phi_bb257_19, &phi_bb257_25, &phi_bb257_26, &phi_bb257_27, &phi_bb257_28, &phi_bb257_31, &phi_bb257_32, &phi_bb257_34, &phi_bb257_35, &phi_bb257_36, &phi_bb257_47, &phi_bb257_48, &phi_bb257_50, &phi_bb257_51, &phi_bb257_52, &phi_bb257_53);
    tmp540 = CodeStubAssembler(state_).SmiToInt32(TNode<Smi>{tmp535});
    tmp541 = CodeStubAssembler(state_).Unsigned(TNode<Int32T>{tmp540});
    tmp542 = Convert_intptr_WasmCodePointer_0(state_, TNode<Uint32T>{tmp541});
    CodeStubAssembler(state_).StoreReference<IntPtrT>(CodeStubAssembler::Reference{phi_bb257_50, phi_bb257_51}, tmp542);
    ca_.Goto(&block255, phi_bb257_19, phi_bb257_25, phi_bb257_26, phi_bb257_27, phi_bb257_28, phi_bb257_31, phi_bb257_32, phi_bb257_34, phi_bb257_35, phi_bb257_36, phi_bb257_47, phi_bb257_48, phi_bb257_50, phi_bb257_51, phi_bb257_52);
  }

  TNode<IntPtrT> phi_bb255_19;
  TNode<IntPtrT> phi_bb255_25;
  TNode<IntPtrT> phi_bb255_26;
  TNode<IntPtrT> phi_bb255_27;
  TNode<IntPtrT> phi_bb255_28;
  TNode<IntPtrT> phi_bb255_31;
  TNode<BoolT> phi_bb255_32;
  TNode<IntPtrT> phi_bb255_34;
  TNode<IntPtrT> phi_bb255_35;
  TNode<BoolT> phi_bb255_36;
  TNode<BoolT> phi_bb255_47;
  TNode<JSAny> phi_bb255_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb255_50;
  TNode<IntPtrT> phi_bb255_51;
  TNode<JSAny> phi_bb255_52;
  if (block255.is_used()) {
    ca_.Bind(&block255, &phi_bb255_19, &phi_bb255_25, &phi_bb255_26, &phi_bb255_27, &phi_bb255_28, &phi_bb255_31, &phi_bb255_32, &phi_bb255_34, &phi_bb255_35, &phi_bb255_36, &phi_bb255_47, &phi_bb255_48, &phi_bb255_50, &phi_bb255_51, &phi_bb255_52);
    ca_.Goto(&block245, phi_bb255_19, tmp511, phi_bb255_25, phi_bb255_26, phi_bb255_27, phi_bb255_28, phi_bb255_31, phi_bb255_32, phi_bb255_34, phi_bb255_35, phi_bb255_36, phi_bb255_47, phi_bb255_48);
  }

  TNode<IntPtrT> phi_bb244_19;
  TNode<IntPtrT> phi_bb244_24;
  TNode<IntPtrT> phi_bb244_25;
  TNode<IntPtrT> phi_bb244_26;
  TNode<IntPtrT> phi_bb244_27;
  TNode<IntPtrT> phi_bb244_28;
  TNode<IntPtrT> phi_bb244_31;
  TNode<BoolT> phi_bb244_32;
  TNode<IntPtrT> phi_bb244_34;
  TNode<IntPtrT> phi_bb244_35;
  TNode<BoolT> phi_bb244_36;
  TNode<BoolT> phi_bb244_47;
  TNode<JSAny> phi_bb244_48;
  TNode<Uint32T> tmp543;
  TNode<BoolT> tmp544;
  if (block244.is_used()) {
    ca_.Bind(&block244, &phi_bb244_19, &phi_bb244_24, &phi_bb244_25, &phi_bb244_26, &phi_bb244_27, &phi_bb244_28, &phi_bb244_31, &phi_bb244_32, &phi_bb244_34, &phi_bb244_35, &phi_bb244_36, &phi_bb244_47, &phi_bb244_48);
    tmp543 = FromConstexpr_WasmCodePointer_constexpr_WasmCodePointer_0(state_, wasm::kWasmF32.raw_bit_field());
    tmp544 = CodeStubAssembler(state_).Word32Equal(TNode<Uint32T>{tmp507}, TNode<Uint32T>{tmp543});
    ca_.Branch(tmp544, &block259, std::vector<compiler::Node*>{phi_bb244_19, phi_bb244_24, phi_bb244_25, phi_bb244_26, phi_bb244_27, phi_bb244_28, phi_bb244_31, phi_bb244_32, phi_bb244_34, phi_bb244_35, phi_bb244_36, phi_bb244_47, phi_bb244_48}, &block260, std::vector<compiler::Node*>{phi_bb244_19, phi_bb244_24, phi_bb244_25, phi_bb244_26, phi_bb244_27, phi_bb244_28, phi_bb244_31, phi_bb244_32, phi_bb244_34, phi_bb244_35, phi_bb244_36, phi_bb244_47, phi_bb244_48});
  }

  TNode<IntPtrT> phi_bb259_19;
  TNode<IntPtrT> phi_bb259_24;
  TNode<IntPtrT> phi_bb259_25;
  TNode<IntPtrT> phi_bb259_26;
  TNode<IntPtrT> phi_bb259_27;
  TNode<IntPtrT> phi_bb259_28;
  TNode<IntPtrT> phi_bb259_31;
  TNode<BoolT> phi_bb259_32;
  TNode<IntPtrT> phi_bb259_34;
  TNode<IntPtrT> phi_bb259_35;
  TNode<BoolT> phi_bb259_36;
  TNode<BoolT> phi_bb259_47;
  TNode<JSAny> phi_bb259_48;
  TNode<IntPtrT> tmp545;
  TNode<IntPtrT> tmp546;
  TNode<IntPtrT> tmp547;
  TNode<BoolT> tmp548;
  if (block259.is_used()) {
    ca_.Bind(&block259, &phi_bb259_19, &phi_bb259_24, &phi_bb259_25, &phi_bb259_26, &phi_bb259_27, &phi_bb259_28, &phi_bb259_31, &phi_bb259_32, &phi_bb259_34, &phi_bb259_35, &phi_bb259_36, &phi_bb259_47, &phi_bb259_48);
    tmp545 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp546 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{phi_bb259_25}, TNode<IntPtrT>{tmp545});
    tmp547 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp548 = CodeStubAssembler(state_).IntPtrGreaterThan(TNode<IntPtrT>{phi_bb259_25}, TNode<IntPtrT>{tmp547});
    ca_.Branch(tmp548, &block263, std::vector<compiler::Node*>{phi_bb259_19, phi_bb259_24, phi_bb259_26, phi_bb259_27, phi_bb259_28, phi_bb259_31, phi_bb259_32, phi_bb259_34, phi_bb259_35, phi_bb259_36, phi_bb259_47, phi_bb259_48}, &block264, std::vector<compiler::Node*>{phi_bb259_19, phi_bb259_24, phi_bb259_26, phi_bb259_27, phi_bb259_28, phi_bb259_31, phi_bb259_32, phi_bb259_34, phi_bb259_35, phi_bb259_36, phi_bb259_47, phi_bb259_48});
  }

  TNode<IntPtrT> phi_bb263_19;
  TNode<IntPtrT> phi_bb263_24;
  TNode<IntPtrT> phi_bb263_26;
  TNode<IntPtrT> phi_bb263_27;
  TNode<IntPtrT> phi_bb263_28;
  TNode<IntPtrT> phi_bb263_31;
  TNode<BoolT> phi_bb263_32;
  TNode<IntPtrT> phi_bb263_34;
  TNode<IntPtrT> phi_bb263_35;
  TNode<BoolT> phi_bb263_36;
  TNode<BoolT> phi_bb263_47;
  TNode<JSAny> phi_bb263_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp549;
  TNode<IntPtrT> tmp550;
  TNode<IntPtrT> tmp551;
  TNode<IntPtrT> tmp552;
  if (block263.is_used()) {
    ca_.Bind(&block263, &phi_bb263_19, &phi_bb263_24, &phi_bb263_26, &phi_bb263_27, &phi_bb263_28, &phi_bb263_31, &phi_bb263_32, &phi_bb263_34, &phi_bb263_35, &phi_bb263_36, &phi_bb263_47, &phi_bb263_48);
    std::tie(tmp549, tmp550) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb263_27}).Flatten();
    tmp551 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_float64_0(state_)));
    tmp552 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb263_27}, TNode<IntPtrT>{tmp551});
    ca_.Goto(&block262, phi_bb263_19, phi_bb263_24, phi_bb263_26, tmp552, phi_bb263_28, phi_bb263_31, phi_bb263_32, phi_bb263_34, phi_bb263_35, phi_bb263_36, phi_bb263_47, phi_bb263_48, tmp549, tmp550);
  }

  TNode<IntPtrT> phi_bb264_19;
  TNode<IntPtrT> phi_bb264_24;
  TNode<IntPtrT> phi_bb264_26;
  TNode<IntPtrT> phi_bb264_27;
  TNode<IntPtrT> phi_bb264_28;
  TNode<IntPtrT> phi_bb264_31;
  TNode<BoolT> phi_bb264_32;
  TNode<IntPtrT> phi_bb264_34;
  TNode<IntPtrT> phi_bb264_35;
  TNode<BoolT> phi_bb264_36;
  TNode<BoolT> phi_bb264_47;
  TNode<JSAny> phi_bb264_48;
  if (block264.is_used()) {
    ca_.Bind(&block264, &phi_bb264_19, &phi_bb264_24, &phi_bb264_26, &phi_bb264_27, &phi_bb264_28, &phi_bb264_31, &phi_bb264_32, &phi_bb264_34, &phi_bb264_35, &phi_bb264_36, &phi_bb264_47, &phi_bb264_48);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block266, phi_bb264_19, phi_bb264_24, phi_bb264_26, phi_bb264_27, phi_bb264_28, phi_bb264_31, phi_bb264_32, phi_bb264_34, phi_bb264_35, phi_bb264_36, phi_bb264_47, phi_bb264_48);
    } else {
      ca_.Goto(&block267, phi_bb264_19, phi_bb264_24, phi_bb264_26, phi_bb264_27, phi_bb264_28, phi_bb264_31, phi_bb264_32, phi_bb264_34, phi_bb264_35, phi_bb264_36, phi_bb264_47, phi_bb264_48);
    }
  }

  TNode<IntPtrT> phi_bb266_19;
  TNode<IntPtrT> phi_bb266_24;
  TNode<IntPtrT> phi_bb266_26;
  TNode<IntPtrT> phi_bb266_27;
  TNode<IntPtrT> phi_bb266_28;
  TNode<IntPtrT> phi_bb266_31;
  TNode<BoolT> phi_bb266_32;
  TNode<IntPtrT> phi_bb266_34;
  TNode<IntPtrT> phi_bb266_35;
  TNode<BoolT> phi_bb266_36;
  TNode<BoolT> phi_bb266_47;
  TNode<JSAny> phi_bb266_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp553;
  TNode<IntPtrT> tmp554;
  TNode<IntPtrT> tmp555;
  TNode<IntPtrT> tmp556;
  if (block266.is_used()) {
    ca_.Bind(&block266, &phi_bb266_19, &phi_bb266_24, &phi_bb266_26, &phi_bb266_27, &phi_bb266_28, &phi_bb266_31, &phi_bb266_32, &phi_bb266_34, &phi_bb266_35, &phi_bb266_36, &phi_bb266_47, &phi_bb266_48);
    std::tie(tmp553, tmp554) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb266_28}).Flatten();
    tmp555 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp556 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb266_28}, TNode<IntPtrT>{tmp555});
    ca_.Goto(&block265, phi_bb266_19, phi_bb266_24, phi_bb266_26, phi_bb266_27, tmp556, phi_bb266_31, phi_bb266_32, phi_bb266_34, phi_bb266_35, phi_bb266_36, phi_bb266_47, phi_bb266_48, tmp553, tmp554);
  }

  TNode<IntPtrT> phi_bb267_19;
  TNode<IntPtrT> phi_bb267_24;
  TNode<IntPtrT> phi_bb267_26;
  TNode<IntPtrT> phi_bb267_27;
  TNode<IntPtrT> phi_bb267_28;
  TNode<IntPtrT> phi_bb267_31;
  TNode<BoolT> phi_bb267_32;
  TNode<IntPtrT> phi_bb267_34;
  TNode<IntPtrT> phi_bb267_35;
  TNode<BoolT> phi_bb267_36;
  TNode<BoolT> phi_bb267_47;
  TNode<JSAny> phi_bb267_48;
  TNode<IntPtrT> tmp557;
  TNode<BoolT> tmp558;
  if (block267.is_used()) {
    ca_.Bind(&block267, &phi_bb267_19, &phi_bb267_24, &phi_bb267_26, &phi_bb267_27, &phi_bb267_28, &phi_bb267_31, &phi_bb267_32, &phi_bb267_34, &phi_bb267_35, &phi_bb267_36, &phi_bb267_47, &phi_bb267_48);
    tmp557 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp558 = CodeStubAssembler(state_).WordNotEqual(TNode<IntPtrT>{phi_bb267_31}, TNode<IntPtrT>{tmp557});
    ca_.Branch(tmp558, &block269, std::vector<compiler::Node*>{phi_bb267_19, phi_bb267_24, phi_bb267_26, phi_bb267_27, phi_bb267_28, phi_bb267_31, phi_bb267_32, phi_bb267_34, phi_bb267_35, phi_bb267_36, phi_bb267_47, phi_bb267_48}, &block270, std::vector<compiler::Node*>{phi_bb267_19, phi_bb267_24, phi_bb267_26, phi_bb267_27, phi_bb267_28, phi_bb267_31, phi_bb267_32, phi_bb267_34, phi_bb267_35, phi_bb267_36, phi_bb267_47, phi_bb267_48});
  }

  TNode<IntPtrT> phi_bb269_19;
  TNode<IntPtrT> phi_bb269_24;
  TNode<IntPtrT> phi_bb269_26;
  TNode<IntPtrT> phi_bb269_27;
  TNode<IntPtrT> phi_bb269_28;
  TNode<IntPtrT> phi_bb269_31;
  TNode<BoolT> phi_bb269_32;
  TNode<IntPtrT> phi_bb269_34;
  TNode<IntPtrT> phi_bb269_35;
  TNode<BoolT> phi_bb269_36;
  TNode<BoolT> phi_bb269_47;
  TNode<JSAny> phi_bb269_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp559;
  TNode<IntPtrT> tmp560;
  TNode<IntPtrT> tmp561;
  TNode<BoolT> tmp562;
  if (block269.is_used()) {
    ca_.Bind(&block269, &phi_bb269_19, &phi_bb269_24, &phi_bb269_26, &phi_bb269_27, &phi_bb269_28, &phi_bb269_31, &phi_bb269_32, &phi_bb269_34, &phi_bb269_35, &phi_bb269_36, &phi_bb269_47, &phi_bb269_48);
    std::tie(tmp559, tmp560) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb269_31}).Flatten();
    tmp561 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp562 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block265, phi_bb269_19, phi_bb269_24, phi_bb269_26, phi_bb269_27, phi_bb269_28, tmp561, tmp562, phi_bb269_34, phi_bb269_35, phi_bb269_36, phi_bb269_47, phi_bb269_48, tmp559, tmp560);
  }

  TNode<IntPtrT> phi_bb270_19;
  TNode<IntPtrT> phi_bb270_24;
  TNode<IntPtrT> phi_bb270_26;
  TNode<IntPtrT> phi_bb270_27;
  TNode<IntPtrT> phi_bb270_28;
  TNode<IntPtrT> phi_bb270_31;
  TNode<BoolT> phi_bb270_32;
  TNode<IntPtrT> phi_bb270_34;
  TNode<IntPtrT> phi_bb270_35;
  TNode<BoolT> phi_bb270_36;
  TNode<BoolT> phi_bb270_47;
  TNode<JSAny> phi_bb270_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp563;
  TNode<IntPtrT> tmp564;
  TNode<IntPtrT> tmp565;
  TNode<IntPtrT> tmp566;
  TNode<IntPtrT> tmp567;
  TNode<IntPtrT> tmp568;
  TNode<BoolT> tmp569;
  if (block270.is_used()) {
    ca_.Bind(&block270, &phi_bb270_19, &phi_bb270_24, &phi_bb270_26, &phi_bb270_27, &phi_bb270_28, &phi_bb270_31, &phi_bb270_32, &phi_bb270_34, &phi_bb270_35, &phi_bb270_36, &phi_bb270_47, &phi_bb270_48);
    std::tie(tmp563, tmp564) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb270_28}).Flatten();
    tmp565 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp566 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb270_28}, TNode<IntPtrT>{tmp565});
    tmp567 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp568 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp566}, TNode<IntPtrT>{tmp567});
    tmp569 = FromConstexpr_bool_constexpr_bool_0(state_, true);
    ca_.Goto(&block265, phi_bb270_19, phi_bb270_24, phi_bb270_26, phi_bb270_27, tmp568, tmp566, tmp569, phi_bb270_34, phi_bb270_35, phi_bb270_36, phi_bb270_47, phi_bb270_48, tmp563, tmp564);
  }

  TNode<IntPtrT> phi_bb265_19;
  TNode<IntPtrT> phi_bb265_24;
  TNode<IntPtrT> phi_bb265_26;
  TNode<IntPtrT> phi_bb265_27;
  TNode<IntPtrT> phi_bb265_28;
  TNode<IntPtrT> phi_bb265_31;
  TNode<BoolT> phi_bb265_32;
  TNode<IntPtrT> phi_bb265_34;
  TNode<IntPtrT> phi_bb265_35;
  TNode<BoolT> phi_bb265_36;
  TNode<BoolT> phi_bb265_47;
  TNode<JSAny> phi_bb265_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb265_50;
  TNode<IntPtrT> phi_bb265_51;
  if (block265.is_used()) {
    ca_.Bind(&block265, &phi_bb265_19, &phi_bb265_24, &phi_bb265_26, &phi_bb265_27, &phi_bb265_28, &phi_bb265_31, &phi_bb265_32, &phi_bb265_34, &phi_bb265_35, &phi_bb265_36, &phi_bb265_47, &phi_bb265_48, &phi_bb265_50, &phi_bb265_51);
    ca_.Goto(&block262, phi_bb265_19, phi_bb265_24, phi_bb265_26, phi_bb265_27, phi_bb265_28, phi_bb265_31, phi_bb265_32, phi_bb265_34, phi_bb265_35, phi_bb265_36, phi_bb265_47, phi_bb265_48, phi_bb265_50, phi_bb265_51);
  }

  TNode<IntPtrT> phi_bb262_19;
  TNode<IntPtrT> phi_bb262_24;
  TNode<IntPtrT> phi_bb262_26;
  TNode<IntPtrT> phi_bb262_27;
  TNode<IntPtrT> phi_bb262_28;
  TNode<IntPtrT> phi_bb262_31;
  TNode<BoolT> phi_bb262_32;
  TNode<IntPtrT> phi_bb262_34;
  TNode<IntPtrT> phi_bb262_35;
  TNode<BoolT> phi_bb262_36;
  TNode<BoolT> phi_bb262_47;
  TNode<JSAny> phi_bb262_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb262_50;
  TNode<IntPtrT> phi_bb262_51;
  if (block262.is_used()) {
    ca_.Bind(&block262, &phi_bb262_19, &phi_bb262_24, &phi_bb262_26, &phi_bb262_27, &phi_bb262_28, &phi_bb262_31, &phi_bb262_32, &phi_bb262_34, &phi_bb262_35, &phi_bb262_36, &phi_bb262_47, &phi_bb262_48, &phi_bb262_50, &phi_bb262_51);
    if ((((wasm::kIsFpAlwaysDouble || wasm::kIsBigEndian) || wasm::kIsBigEndianOnSim))) {
      ca_.Goto(&block271, phi_bb262_19, phi_bb262_24, phi_bb262_26, phi_bb262_27, phi_bb262_28, phi_bb262_31, phi_bb262_32, phi_bb262_34, phi_bb262_35, phi_bb262_36, phi_bb262_47, phi_bb262_48, phi_bb262_50, phi_bb262_51);
    } else {
      ca_.Goto(&block272, phi_bb262_19, phi_bb262_24, phi_bb262_26, phi_bb262_27, phi_bb262_28, phi_bb262_31, phi_bb262_32, phi_bb262_34, phi_bb262_35, phi_bb262_36, phi_bb262_47, phi_bb262_48, phi_bb262_50, phi_bb262_51);
    }
  }

  TNode<IntPtrT> phi_bb271_19;
  TNode<IntPtrT> phi_bb271_24;
  TNode<IntPtrT> phi_bb271_26;
  TNode<IntPtrT> phi_bb271_27;
  TNode<IntPtrT> phi_bb271_28;
  TNode<IntPtrT> phi_bb271_31;
  TNode<BoolT> phi_bb271_32;
  TNode<IntPtrT> phi_bb271_34;
  TNode<IntPtrT> phi_bb271_35;
  TNode<BoolT> phi_bb271_36;
  TNode<BoolT> phi_bb271_47;
  TNode<JSAny> phi_bb271_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb271_50;
  TNode<IntPtrT> phi_bb271_51;
  if (block271.is_used()) {
    ca_.Bind(&block271, &phi_bb271_19, &phi_bb271_24, &phi_bb271_26, &phi_bb271_27, &phi_bb271_28, &phi_bb271_31, &phi_bb271_32, &phi_bb271_34, &phi_bb271_35, &phi_bb271_36, &phi_bb271_47, &phi_bb271_48, &phi_bb271_50, &phi_bb271_51);
    HandleF32Returns_0(state_, TNode<NativeContext>{tmp441}, TorqueStructLocationAllocator_0{TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb271_24}, TNode<IntPtrT>{tmp546}, TNode<IntPtrT>{phi_bb271_26}, TNode<IntPtrT>{phi_bb271_27}, TNode<IntPtrT>{phi_bb271_28}, TNode<IntPtrT>{tmp479}, TNode<IntPtrT>{tmp480}, TNode<IntPtrT>{phi_bb271_31}, TNode<BoolT>{phi_bb271_32}}, TorqueStructReference_intptr_0{TNode<Union<HeapObject, TaggedIndex>>{phi_bb271_50}, TNode<IntPtrT>{phi_bb271_51}, TorqueStructUnsafe_0{}}, TNode<JSAny>{phi_bb271_48});
    ca_.Goto(&block273, phi_bb271_19, phi_bb271_24, phi_bb271_26, phi_bb271_27, phi_bb271_28, phi_bb271_31, phi_bb271_32, phi_bb271_34, phi_bb271_35, phi_bb271_36, phi_bb271_47, phi_bb271_48, phi_bb271_50, phi_bb271_51);
  }

  TNode<IntPtrT> phi_bb272_19;
  TNode<IntPtrT> phi_bb272_24;
  TNode<IntPtrT> phi_bb272_26;
  TNode<IntPtrT> phi_bb272_27;
  TNode<IntPtrT> phi_bb272_28;
  TNode<IntPtrT> phi_bb272_31;
  TNode<BoolT> phi_bb272_32;
  TNode<IntPtrT> phi_bb272_34;
  TNode<IntPtrT> phi_bb272_35;
  TNode<BoolT> phi_bb272_36;
  TNode<BoolT> phi_bb272_47;
  TNode<JSAny> phi_bb272_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb272_50;
  TNode<IntPtrT> phi_bb272_51;
  TNode<Float32T> tmp570;
  TNode<Uint32T> tmp571;
  TNode<IntPtrT> tmp572;
  if (block272.is_used()) {
    ca_.Bind(&block272, &phi_bb272_19, &phi_bb272_24, &phi_bb272_26, &phi_bb272_27, &phi_bb272_28, &phi_bb272_31, &phi_bb272_32, &phi_bb272_34, &phi_bb272_35, &phi_bb272_36, &phi_bb272_47, &phi_bb272_48, &phi_bb272_50, &phi_bb272_51);
    tmp570 = ca_.CallBuiltin<Float32T>(Builtin::kWasmTaggedToFloat32, tmp441, phi_bb272_48);
    tmp571 = Bitcast_WasmCodePointer_float32_0(state_, TNode<Float32T>{tmp570});
    tmp572 = Convert_intptr_WasmCodePointer_0(state_, TNode<Uint32T>{tmp571});
    CodeStubAssembler(state_).StoreReference<IntPtrT>(CodeStubAssembler::Reference{phi_bb272_50, phi_bb272_51}, tmp572);
    ca_.Goto(&block273, phi_bb272_19, phi_bb272_24, phi_bb272_26, phi_bb272_27, phi_bb272_28, phi_bb272_31, phi_bb272_32, phi_bb272_34, phi_bb272_35, phi_bb272_36, phi_bb272_47, phi_bb272_48, phi_bb272_50, phi_bb272_51);
  }

  TNode<IntPtrT> phi_bb273_19;
  TNode<IntPtrT> phi_bb273_24;
  TNode<IntPtrT> phi_bb273_26;
  TNode<IntPtrT> phi_bb273_27;
  TNode<IntPtrT> phi_bb273_28;
  TNode<IntPtrT> phi_bb273_31;
  TNode<BoolT> phi_bb273_32;
  TNode<IntPtrT> phi_bb273_34;
  TNode<IntPtrT> phi_bb273_35;
  TNode<BoolT> phi_bb273_36;
  TNode<BoolT> phi_bb273_47;
  TNode<JSAny> phi_bb273_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb273_50;
  TNode<IntPtrT> phi_bb273_51;
  if (block273.is_used()) {
    ca_.Bind(&block273, &phi_bb273_19, &phi_bb273_24, &phi_bb273_26, &phi_bb273_27, &phi_bb273_28, &phi_bb273_31, &phi_bb273_32, &phi_bb273_34, &phi_bb273_35, &phi_bb273_36, &phi_bb273_47, &phi_bb273_48, &phi_bb273_50, &phi_bb273_51);
    ca_.Goto(&block261, phi_bb273_19, phi_bb273_24, tmp546, phi_bb273_26, phi_bb273_27, phi_bb273_28, phi_bb273_31, phi_bb273_32, phi_bb273_34, phi_bb273_35, phi_bb273_36, phi_bb273_47, phi_bb273_48);
  }

  TNode<IntPtrT> phi_bb260_19;
  TNode<IntPtrT> phi_bb260_24;
  TNode<IntPtrT> phi_bb260_25;
  TNode<IntPtrT> phi_bb260_26;
  TNode<IntPtrT> phi_bb260_27;
  TNode<IntPtrT> phi_bb260_28;
  TNode<IntPtrT> phi_bb260_31;
  TNode<BoolT> phi_bb260_32;
  TNode<IntPtrT> phi_bb260_34;
  TNode<IntPtrT> phi_bb260_35;
  TNode<BoolT> phi_bb260_36;
  TNode<BoolT> phi_bb260_47;
  TNode<JSAny> phi_bb260_48;
  TNode<Uint32T> tmp573;
  TNode<BoolT> tmp574;
  if (block260.is_used()) {
    ca_.Bind(&block260, &phi_bb260_19, &phi_bb260_24, &phi_bb260_25, &phi_bb260_26, &phi_bb260_27, &phi_bb260_28, &phi_bb260_31, &phi_bb260_32, &phi_bb260_34, &phi_bb260_35, &phi_bb260_36, &phi_bb260_47, &phi_bb260_48);
    tmp573 = FromConstexpr_WasmCodePointer_constexpr_WasmCodePointer_0(state_, wasm::kWasmF64.raw_bit_field());
    tmp574 = CodeStubAssembler(state_).Word32Equal(TNode<Uint32T>{tmp507}, TNode<Uint32T>{tmp573});
    ca_.Branch(tmp574, &block274, std::vector<compiler::Node*>{phi_bb260_19, phi_bb260_24, phi_bb260_25, phi_bb260_26, phi_bb260_27, phi_bb260_28, phi_bb260_31, phi_bb260_32, phi_bb260_34, phi_bb260_35, phi_bb260_36, phi_bb260_47, phi_bb260_48}, &block275, std::vector<compiler::Node*>{phi_bb260_19, phi_bb260_24, phi_bb260_25, phi_bb260_26, phi_bb260_27, phi_bb260_28, phi_bb260_31, phi_bb260_32, phi_bb260_34, phi_bb260_35, phi_bb260_36, phi_bb260_47, phi_bb260_48});
  }

  TNode<IntPtrT> phi_bb274_19;
  TNode<IntPtrT> phi_bb274_24;
  TNode<IntPtrT> phi_bb274_25;
  TNode<IntPtrT> phi_bb274_26;
  TNode<IntPtrT> phi_bb274_27;
  TNode<IntPtrT> phi_bb274_28;
  TNode<IntPtrT> phi_bb274_31;
  TNode<BoolT> phi_bb274_32;
  TNode<IntPtrT> phi_bb274_34;
  TNode<IntPtrT> phi_bb274_35;
  TNode<BoolT> phi_bb274_36;
  TNode<BoolT> phi_bb274_47;
  TNode<JSAny> phi_bb274_48;
  TNode<IntPtrT> tmp575;
  TNode<IntPtrT> tmp576;
  TNode<IntPtrT> tmp577;
  TNode<BoolT> tmp578;
  if (block274.is_used()) {
    ca_.Bind(&block274, &phi_bb274_19, &phi_bb274_24, &phi_bb274_25, &phi_bb274_26, &phi_bb274_27, &phi_bb274_28, &phi_bb274_31, &phi_bb274_32, &phi_bb274_34, &phi_bb274_35, &phi_bb274_36, &phi_bb274_47, &phi_bb274_48);
    tmp575 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp576 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{phi_bb274_25}, TNode<IntPtrT>{tmp575});
    tmp577 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp578 = CodeStubAssembler(state_).IntPtrGreaterThan(TNode<IntPtrT>{phi_bb274_25}, TNode<IntPtrT>{tmp577});
    ca_.Branch(tmp578, &block278, std::vector<compiler::Node*>{phi_bb274_19, phi_bb274_24, phi_bb274_26, phi_bb274_27, phi_bb274_28, phi_bb274_31, phi_bb274_32, phi_bb274_34, phi_bb274_35, phi_bb274_36, phi_bb274_47, phi_bb274_48}, &block279, std::vector<compiler::Node*>{phi_bb274_19, phi_bb274_24, phi_bb274_26, phi_bb274_27, phi_bb274_28, phi_bb274_31, phi_bb274_32, phi_bb274_34, phi_bb274_35, phi_bb274_36, phi_bb274_47, phi_bb274_48});
  }

  TNode<IntPtrT> phi_bb278_19;
  TNode<IntPtrT> phi_bb278_24;
  TNode<IntPtrT> phi_bb278_26;
  TNode<IntPtrT> phi_bb278_27;
  TNode<IntPtrT> phi_bb278_28;
  TNode<IntPtrT> phi_bb278_31;
  TNode<BoolT> phi_bb278_32;
  TNode<IntPtrT> phi_bb278_34;
  TNode<IntPtrT> phi_bb278_35;
  TNode<BoolT> phi_bb278_36;
  TNode<BoolT> phi_bb278_47;
  TNode<JSAny> phi_bb278_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp579;
  TNode<IntPtrT> tmp580;
  TNode<IntPtrT> tmp581;
  TNode<IntPtrT> tmp582;
  if (block278.is_used()) {
    ca_.Bind(&block278, &phi_bb278_19, &phi_bb278_24, &phi_bb278_26, &phi_bb278_27, &phi_bb278_28, &phi_bb278_31, &phi_bb278_32, &phi_bb278_34, &phi_bb278_35, &phi_bb278_36, &phi_bb278_47, &phi_bb278_48);
    std::tie(tmp579, tmp580) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb278_27}).Flatten();
    tmp581 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_float64_0(state_)));
    tmp582 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb278_27}, TNode<IntPtrT>{tmp581});
    ca_.Goto(&block277, phi_bb278_19, phi_bb278_24, phi_bb278_26, tmp582, phi_bb278_28, phi_bb278_31, phi_bb278_32, phi_bb278_34, phi_bb278_35, phi_bb278_36, phi_bb278_47, phi_bb278_48, tmp579, tmp580);
  }

  TNode<IntPtrT> phi_bb279_19;
  TNode<IntPtrT> phi_bb279_24;
  TNode<IntPtrT> phi_bb279_26;
  TNode<IntPtrT> phi_bb279_27;
  TNode<IntPtrT> phi_bb279_28;
  TNode<IntPtrT> phi_bb279_31;
  TNode<BoolT> phi_bb279_32;
  TNode<IntPtrT> phi_bb279_34;
  TNode<IntPtrT> phi_bb279_35;
  TNode<BoolT> phi_bb279_36;
  TNode<BoolT> phi_bb279_47;
  TNode<JSAny> phi_bb279_48;
  if (block279.is_used()) {
    ca_.Bind(&block279, &phi_bb279_19, &phi_bb279_24, &phi_bb279_26, &phi_bb279_27, &phi_bb279_28, &phi_bb279_31, &phi_bb279_32, &phi_bb279_34, &phi_bb279_35, &phi_bb279_36, &phi_bb279_47, &phi_bb279_48);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block280, phi_bb279_19, phi_bb279_24, phi_bb279_26, phi_bb279_27, phi_bb279_28, phi_bb279_31, phi_bb279_32, phi_bb279_34, phi_bb279_35, phi_bb279_36, phi_bb279_47, phi_bb279_48);
    } else {
      ca_.Goto(&block281, phi_bb279_19, phi_bb279_24, phi_bb279_26, phi_bb279_27, phi_bb279_28, phi_bb279_31, phi_bb279_32, phi_bb279_34, phi_bb279_35, phi_bb279_36, phi_bb279_47, phi_bb279_48);
    }
  }

  TNode<IntPtrT> phi_bb280_19;
  TNode<IntPtrT> phi_bb280_24;
  TNode<IntPtrT> phi_bb280_26;
  TNode<IntPtrT> phi_bb280_27;
  TNode<IntPtrT> phi_bb280_28;
  TNode<IntPtrT> phi_bb280_31;
  TNode<BoolT> phi_bb280_32;
  TNode<IntPtrT> phi_bb280_34;
  TNode<IntPtrT> phi_bb280_35;
  TNode<BoolT> phi_bb280_36;
  TNode<BoolT> phi_bb280_47;
  TNode<JSAny> phi_bb280_48;
  if (block280.is_used()) {
    ca_.Bind(&block280, &phi_bb280_19, &phi_bb280_24, &phi_bb280_26, &phi_bb280_27, &phi_bb280_28, &phi_bb280_31, &phi_bb280_32, &phi_bb280_34, &phi_bb280_35, &phi_bb280_36, &phi_bb280_47, &phi_bb280_48);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block284, phi_bb280_19, phi_bb280_24, phi_bb280_26, phi_bb280_27, phi_bb280_28, phi_bb280_31, phi_bb280_32, phi_bb280_34, phi_bb280_35, phi_bb280_36, phi_bb280_47, phi_bb280_48);
    } else {
      ca_.Goto(&block285, phi_bb280_19, phi_bb280_24, phi_bb280_26, phi_bb280_27, phi_bb280_28, phi_bb280_31, phi_bb280_32, phi_bb280_34, phi_bb280_35, phi_bb280_36, phi_bb280_47, phi_bb280_48);
    }
  }

  TNode<IntPtrT> phi_bb284_19;
  TNode<IntPtrT> phi_bb284_24;
  TNode<IntPtrT> phi_bb284_26;
  TNode<IntPtrT> phi_bb284_27;
  TNode<IntPtrT> phi_bb284_28;
  TNode<IntPtrT> phi_bb284_31;
  TNode<BoolT> phi_bb284_32;
  TNode<IntPtrT> phi_bb284_34;
  TNode<IntPtrT> phi_bb284_35;
  TNode<BoolT> phi_bb284_36;
  TNode<BoolT> phi_bb284_47;
  TNode<JSAny> phi_bb284_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp583;
  TNode<IntPtrT> tmp584;
  TNode<IntPtrT> tmp585;
  TNode<IntPtrT> tmp586;
  if (block284.is_used()) {
    ca_.Bind(&block284, &phi_bb284_19, &phi_bb284_24, &phi_bb284_26, &phi_bb284_27, &phi_bb284_28, &phi_bb284_31, &phi_bb284_32, &phi_bb284_34, &phi_bb284_35, &phi_bb284_36, &phi_bb284_47, &phi_bb284_48);
    std::tie(tmp583, tmp584) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb284_28}).Flatten();
    tmp585 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp586 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb284_28}, TNode<IntPtrT>{tmp585});
    ca_.Goto(&block283, phi_bb284_19, phi_bb284_24, phi_bb284_26, phi_bb284_27, tmp586, phi_bb284_31, phi_bb284_32, phi_bb284_34, phi_bb284_35, phi_bb284_36, phi_bb284_47, phi_bb284_48, tmp583, tmp584);
  }

  TNode<IntPtrT> phi_bb285_19;
  TNode<IntPtrT> phi_bb285_24;
  TNode<IntPtrT> phi_bb285_26;
  TNode<IntPtrT> phi_bb285_27;
  TNode<IntPtrT> phi_bb285_28;
  TNode<IntPtrT> phi_bb285_31;
  TNode<BoolT> phi_bb285_32;
  TNode<IntPtrT> phi_bb285_34;
  TNode<IntPtrT> phi_bb285_35;
  TNode<BoolT> phi_bb285_36;
  TNode<BoolT> phi_bb285_47;
  TNode<JSAny> phi_bb285_48;
  TNode<IntPtrT> tmp587;
  TNode<BoolT> tmp588;
  if (block285.is_used()) {
    ca_.Bind(&block285, &phi_bb285_19, &phi_bb285_24, &phi_bb285_26, &phi_bb285_27, &phi_bb285_28, &phi_bb285_31, &phi_bb285_32, &phi_bb285_34, &phi_bb285_35, &phi_bb285_36, &phi_bb285_47, &phi_bb285_48);
    tmp587 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp588 = CodeStubAssembler(state_).WordNotEqual(TNode<IntPtrT>{phi_bb285_31}, TNode<IntPtrT>{tmp587});
    ca_.Branch(tmp588, &block287, std::vector<compiler::Node*>{phi_bb285_19, phi_bb285_24, phi_bb285_26, phi_bb285_27, phi_bb285_28, phi_bb285_31, phi_bb285_32, phi_bb285_34, phi_bb285_35, phi_bb285_36, phi_bb285_47, phi_bb285_48}, &block288, std::vector<compiler::Node*>{phi_bb285_19, phi_bb285_24, phi_bb285_26, phi_bb285_27, phi_bb285_28, phi_bb285_31, phi_bb285_32, phi_bb285_34, phi_bb285_35, phi_bb285_36, phi_bb285_47, phi_bb285_48});
  }

  TNode<IntPtrT> phi_bb287_19;
  TNode<IntPtrT> phi_bb287_24;
  TNode<IntPtrT> phi_bb287_26;
  TNode<IntPtrT> phi_bb287_27;
  TNode<IntPtrT> phi_bb287_28;
  TNode<IntPtrT> phi_bb287_31;
  TNode<BoolT> phi_bb287_32;
  TNode<IntPtrT> phi_bb287_34;
  TNode<IntPtrT> phi_bb287_35;
  TNode<BoolT> phi_bb287_36;
  TNode<BoolT> phi_bb287_47;
  TNode<JSAny> phi_bb287_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp589;
  TNode<IntPtrT> tmp590;
  TNode<IntPtrT> tmp591;
  TNode<BoolT> tmp592;
  if (block287.is_used()) {
    ca_.Bind(&block287, &phi_bb287_19, &phi_bb287_24, &phi_bb287_26, &phi_bb287_27, &phi_bb287_28, &phi_bb287_31, &phi_bb287_32, &phi_bb287_34, &phi_bb287_35, &phi_bb287_36, &phi_bb287_47, &phi_bb287_48);
    std::tie(tmp589, tmp590) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb287_31}).Flatten();
    tmp591 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp592 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block283, phi_bb287_19, phi_bb287_24, phi_bb287_26, phi_bb287_27, phi_bb287_28, tmp591, tmp592, phi_bb287_34, phi_bb287_35, phi_bb287_36, phi_bb287_47, phi_bb287_48, tmp589, tmp590);
  }

  TNode<IntPtrT> phi_bb288_19;
  TNode<IntPtrT> phi_bb288_24;
  TNode<IntPtrT> phi_bb288_26;
  TNode<IntPtrT> phi_bb288_27;
  TNode<IntPtrT> phi_bb288_28;
  TNode<IntPtrT> phi_bb288_31;
  TNode<BoolT> phi_bb288_32;
  TNode<IntPtrT> phi_bb288_34;
  TNode<IntPtrT> phi_bb288_35;
  TNode<BoolT> phi_bb288_36;
  TNode<BoolT> phi_bb288_47;
  TNode<JSAny> phi_bb288_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp593;
  TNode<IntPtrT> tmp594;
  TNode<IntPtrT> tmp595;
  TNode<IntPtrT> tmp596;
  TNode<IntPtrT> tmp597;
  TNode<IntPtrT> tmp598;
  TNode<BoolT> tmp599;
  if (block288.is_used()) {
    ca_.Bind(&block288, &phi_bb288_19, &phi_bb288_24, &phi_bb288_26, &phi_bb288_27, &phi_bb288_28, &phi_bb288_31, &phi_bb288_32, &phi_bb288_34, &phi_bb288_35, &phi_bb288_36, &phi_bb288_47, &phi_bb288_48);
    std::tie(tmp593, tmp594) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb288_28}).Flatten();
    tmp595 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp596 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb288_28}, TNode<IntPtrT>{tmp595});
    tmp597 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp598 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp596}, TNode<IntPtrT>{tmp597});
    tmp599 = FromConstexpr_bool_constexpr_bool_0(state_, true);
    ca_.Goto(&block283, phi_bb288_19, phi_bb288_24, phi_bb288_26, phi_bb288_27, tmp598, tmp596, tmp599, phi_bb288_34, phi_bb288_35, phi_bb288_36, phi_bb288_47, phi_bb288_48, tmp593, tmp594);
  }

  TNode<IntPtrT> phi_bb283_19;
  TNode<IntPtrT> phi_bb283_24;
  TNode<IntPtrT> phi_bb283_26;
  TNode<IntPtrT> phi_bb283_27;
  TNode<IntPtrT> phi_bb283_28;
  TNode<IntPtrT> phi_bb283_31;
  TNode<BoolT> phi_bb283_32;
  TNode<IntPtrT> phi_bb283_34;
  TNode<IntPtrT> phi_bb283_35;
  TNode<BoolT> phi_bb283_36;
  TNode<BoolT> phi_bb283_47;
  TNode<JSAny> phi_bb283_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb283_50;
  TNode<IntPtrT> phi_bb283_51;
  if (block283.is_used()) {
    ca_.Bind(&block283, &phi_bb283_19, &phi_bb283_24, &phi_bb283_26, &phi_bb283_27, &phi_bb283_28, &phi_bb283_31, &phi_bb283_32, &phi_bb283_34, &phi_bb283_35, &phi_bb283_36, &phi_bb283_47, &phi_bb283_48, &phi_bb283_50, &phi_bb283_51);
    ca_.Goto(&block277, phi_bb283_19, phi_bb283_24, phi_bb283_26, phi_bb283_27, phi_bb283_28, phi_bb283_31, phi_bb283_32, phi_bb283_34, phi_bb283_35, phi_bb283_36, phi_bb283_47, phi_bb283_48, phi_bb283_50, phi_bb283_51);
  }

  TNode<IntPtrT> phi_bb281_19;
  TNode<IntPtrT> phi_bb281_24;
  TNode<IntPtrT> phi_bb281_26;
  TNode<IntPtrT> phi_bb281_27;
  TNode<IntPtrT> phi_bb281_28;
  TNode<IntPtrT> phi_bb281_31;
  TNode<BoolT> phi_bb281_32;
  TNode<IntPtrT> phi_bb281_34;
  TNode<IntPtrT> phi_bb281_35;
  TNode<BoolT> phi_bb281_36;
  TNode<BoolT> phi_bb281_47;
  TNode<JSAny> phi_bb281_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp600;
  TNode<IntPtrT> tmp601;
  TNode<IntPtrT> tmp602;
  TNode<IntPtrT> tmp603;
  TNode<BoolT> tmp604;
  if (block281.is_used()) {
    ca_.Bind(&block281, &phi_bb281_19, &phi_bb281_24, &phi_bb281_26, &phi_bb281_27, &phi_bb281_28, &phi_bb281_31, &phi_bb281_32, &phi_bb281_34, &phi_bb281_35, &phi_bb281_36, &phi_bb281_47, &phi_bb281_48);
    std::tie(tmp600, tmp601) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb281_28}).Flatten();
    tmp602 = FromConstexpr_intptr_constexpr_int31_0(state_, (CodeStubAssembler(state_).ConstexprInt31Mul((FromConstexpr_constexpr_int31_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x2ull))), (SizeOf_intptr_0(state_)))));
    tmp603 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb281_28}, TNode<IntPtrT>{tmp602});
    tmp604 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block277, phi_bb281_19, phi_bb281_24, phi_bb281_26, phi_bb281_27, tmp603, phi_bb281_31, tmp604, phi_bb281_34, phi_bb281_35, phi_bb281_36, phi_bb281_47, phi_bb281_48, tmp600, tmp601);
  }

  TNode<IntPtrT> phi_bb277_19;
  TNode<IntPtrT> phi_bb277_24;
  TNode<IntPtrT> phi_bb277_26;
  TNode<IntPtrT> phi_bb277_27;
  TNode<IntPtrT> phi_bb277_28;
  TNode<IntPtrT> phi_bb277_31;
  TNode<BoolT> phi_bb277_32;
  TNode<IntPtrT> phi_bb277_34;
  TNode<IntPtrT> phi_bb277_35;
  TNode<BoolT> phi_bb277_36;
  TNode<BoolT> phi_bb277_47;
  TNode<JSAny> phi_bb277_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb277_50;
  TNode<IntPtrT> phi_bb277_51;
  TNode<Union<HeapObject, TaggedIndex>> tmp605;
  TNode<IntPtrT> tmp606;
  TNode<Float64T> tmp607;
  TNode<Float64T> tmp608;
  if (block277.is_used()) {
    ca_.Bind(&block277, &phi_bb277_19, &phi_bb277_24, &phi_bb277_26, &phi_bb277_27, &phi_bb277_28, &phi_bb277_31, &phi_bb277_32, &phi_bb277_34, &phi_bb277_35, &phi_bb277_36, &phi_bb277_47, &phi_bb277_48, &phi_bb277_50, &phi_bb277_51);
    std::tie(tmp605, tmp606) = RefCast_float64_0(state_, TorqueStructReference_intptr_0{TNode<Union<HeapObject, TaggedIndex>>{phi_bb277_50}, TNode<IntPtrT>{phi_bb277_51}, TorqueStructUnsafe_0{}}).Flatten();
    tmp607 = CodeStubAssembler(state_).ChangeTaggedToFloat64(TNode<Context>{tmp441}, TNode<JSAny>{phi_bb277_48});
    tmp608 = CodeStubAssembler(state_).Float64SilenceNaN(TNode<Float64T>{tmp607});
    CodeStubAssembler(state_).StoreReference<Float64T>(CodeStubAssembler::Reference{tmp605, tmp606}, tmp608);
    ca_.Goto(&block276, phi_bb277_19, phi_bb277_24, tmp576, phi_bb277_26, phi_bb277_27, phi_bb277_28, phi_bb277_31, phi_bb277_32, phi_bb277_34, phi_bb277_35, phi_bb277_36, phi_bb277_47, phi_bb277_48);
  }

  TNode<IntPtrT> phi_bb275_19;
  TNode<IntPtrT> phi_bb275_24;
  TNode<IntPtrT> phi_bb275_25;
  TNode<IntPtrT> phi_bb275_26;
  TNode<IntPtrT> phi_bb275_27;
  TNode<IntPtrT> phi_bb275_28;
  TNode<IntPtrT> phi_bb275_31;
  TNode<BoolT> phi_bb275_32;
  TNode<IntPtrT> phi_bb275_34;
  TNode<IntPtrT> phi_bb275_35;
  TNode<BoolT> phi_bb275_36;
  TNode<BoolT> phi_bb275_47;
  TNode<JSAny> phi_bb275_48;
  TNode<Uint32T> tmp609;
  TNode<BoolT> tmp610;
  if (block275.is_used()) {
    ca_.Bind(&block275, &phi_bb275_19, &phi_bb275_24, &phi_bb275_25, &phi_bb275_26, &phi_bb275_27, &phi_bb275_28, &phi_bb275_31, &phi_bb275_32, &phi_bb275_34, &phi_bb275_35, &phi_bb275_36, &phi_bb275_47, &phi_bb275_48);
    tmp609 = FromConstexpr_WasmCodePointer_constexpr_WasmCodePointer_0(state_, wasm::kWasmI64.raw_bit_field());
    tmp610 = CodeStubAssembler(state_).Word32Equal(TNode<Uint32T>{tmp507}, TNode<Uint32T>{tmp609});
    ca_.Branch(tmp610, &block289, std::vector<compiler::Node*>{phi_bb275_19, phi_bb275_24, phi_bb275_25, phi_bb275_26, phi_bb275_27, phi_bb275_28, phi_bb275_31, phi_bb275_32, phi_bb275_34, phi_bb275_35, phi_bb275_36, phi_bb275_47, phi_bb275_48}, &block290, std::vector<compiler::Node*>{phi_bb275_19, phi_bb275_24, phi_bb275_25, phi_bb275_26, phi_bb275_27, phi_bb275_28, phi_bb275_31, phi_bb275_32, phi_bb275_34, phi_bb275_35, phi_bb275_36, phi_bb275_47, phi_bb275_48});
  }

  TNode<IntPtrT> phi_bb289_19;
  TNode<IntPtrT> phi_bb289_24;
  TNode<IntPtrT> phi_bb289_25;
  TNode<IntPtrT> phi_bb289_26;
  TNode<IntPtrT> phi_bb289_27;
  TNode<IntPtrT> phi_bb289_28;
  TNode<IntPtrT> phi_bb289_31;
  TNode<BoolT> phi_bb289_32;
  TNode<IntPtrT> phi_bb289_34;
  TNode<IntPtrT> phi_bb289_35;
  TNode<BoolT> phi_bb289_36;
  TNode<BoolT> phi_bb289_47;
  TNode<JSAny> phi_bb289_48;
  if (block289.is_used()) {
    ca_.Bind(&block289, &phi_bb289_19, &phi_bb289_24, &phi_bb289_25, &phi_bb289_26, &phi_bb289_27, &phi_bb289_28, &phi_bb289_31, &phi_bb289_32, &phi_bb289_34, &phi_bb289_35, &phi_bb289_36, &phi_bb289_47, &phi_bb289_48);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block292, phi_bb289_19, phi_bb289_24, phi_bb289_25, phi_bb289_26, phi_bb289_27, phi_bb289_28, phi_bb289_31, phi_bb289_32, phi_bb289_34, phi_bb289_35, phi_bb289_36, phi_bb289_47, phi_bb289_48);
    } else {
      ca_.Goto(&block293, phi_bb289_19, phi_bb289_24, phi_bb289_25, phi_bb289_26, phi_bb289_27, phi_bb289_28, phi_bb289_31, phi_bb289_32, phi_bb289_34, phi_bb289_35, phi_bb289_36, phi_bb289_47, phi_bb289_48);
    }
  }

  TNode<IntPtrT> phi_bb292_19;
  TNode<IntPtrT> phi_bb292_24;
  TNode<IntPtrT> phi_bb292_25;
  TNode<IntPtrT> phi_bb292_26;
  TNode<IntPtrT> phi_bb292_27;
  TNode<IntPtrT> phi_bb292_28;
  TNode<IntPtrT> phi_bb292_31;
  TNode<BoolT> phi_bb292_32;
  TNode<IntPtrT> phi_bb292_34;
  TNode<IntPtrT> phi_bb292_35;
  TNode<BoolT> phi_bb292_36;
  TNode<BoolT> phi_bb292_47;
  TNode<JSAny> phi_bb292_48;
  TNode<IntPtrT> tmp611;
  TNode<IntPtrT> tmp612;
  TNode<IntPtrT> tmp613;
  TNode<BoolT> tmp614;
  if (block292.is_used()) {
    ca_.Bind(&block292, &phi_bb292_19, &phi_bb292_24, &phi_bb292_25, &phi_bb292_26, &phi_bb292_27, &phi_bb292_28, &phi_bb292_31, &phi_bb292_32, &phi_bb292_34, &phi_bb292_35, &phi_bb292_36, &phi_bb292_47, &phi_bb292_48);
    tmp611 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp612 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{phi_bb292_24}, TNode<IntPtrT>{tmp611});
    tmp613 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp614 = CodeStubAssembler(state_).IntPtrGreaterThan(TNode<IntPtrT>{phi_bb292_24}, TNode<IntPtrT>{tmp613});
    ca_.Branch(tmp614, &block296, std::vector<compiler::Node*>{phi_bb292_19, phi_bb292_25, phi_bb292_26, phi_bb292_27, phi_bb292_28, phi_bb292_31, phi_bb292_32, phi_bb292_34, phi_bb292_35, phi_bb292_36, phi_bb292_47, phi_bb292_48}, &block297, std::vector<compiler::Node*>{phi_bb292_19, phi_bb292_25, phi_bb292_26, phi_bb292_27, phi_bb292_28, phi_bb292_31, phi_bb292_32, phi_bb292_34, phi_bb292_35, phi_bb292_36, phi_bb292_47, phi_bb292_48});
  }

  TNode<IntPtrT> phi_bb296_19;
  TNode<IntPtrT> phi_bb296_25;
  TNode<IntPtrT> phi_bb296_26;
  TNode<IntPtrT> phi_bb296_27;
  TNode<IntPtrT> phi_bb296_28;
  TNode<IntPtrT> phi_bb296_31;
  TNode<BoolT> phi_bb296_32;
  TNode<IntPtrT> phi_bb296_34;
  TNode<IntPtrT> phi_bb296_35;
  TNode<BoolT> phi_bb296_36;
  TNode<BoolT> phi_bb296_47;
  TNode<JSAny> phi_bb296_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp615;
  TNode<IntPtrT> tmp616;
  TNode<IntPtrT> tmp617;
  TNode<IntPtrT> tmp618;
  if (block296.is_used()) {
    ca_.Bind(&block296, &phi_bb296_19, &phi_bb296_25, &phi_bb296_26, &phi_bb296_27, &phi_bb296_28, &phi_bb296_31, &phi_bb296_32, &phi_bb296_34, &phi_bb296_35, &phi_bb296_36, &phi_bb296_47, &phi_bb296_48);
    std::tie(tmp615, tmp616) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb296_26}).Flatten();
    tmp617 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp618 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb296_26}, TNode<IntPtrT>{tmp617});
    ca_.Goto(&block295, phi_bb296_19, phi_bb296_25, tmp618, phi_bb296_27, phi_bb296_28, phi_bb296_31, phi_bb296_32, phi_bb296_34, phi_bb296_35, phi_bb296_36, phi_bb296_47, phi_bb296_48, tmp615, tmp616);
  }

  TNode<IntPtrT> phi_bb297_19;
  TNode<IntPtrT> phi_bb297_25;
  TNode<IntPtrT> phi_bb297_26;
  TNode<IntPtrT> phi_bb297_27;
  TNode<IntPtrT> phi_bb297_28;
  TNode<IntPtrT> phi_bb297_31;
  TNode<BoolT> phi_bb297_32;
  TNode<IntPtrT> phi_bb297_34;
  TNode<IntPtrT> phi_bb297_35;
  TNode<BoolT> phi_bb297_36;
  TNode<BoolT> phi_bb297_47;
  TNode<JSAny> phi_bb297_48;
  if (block297.is_used()) {
    ca_.Bind(&block297, &phi_bb297_19, &phi_bb297_25, &phi_bb297_26, &phi_bb297_27, &phi_bb297_28, &phi_bb297_31, &phi_bb297_32, &phi_bb297_34, &phi_bb297_35, &phi_bb297_36, &phi_bb297_47, &phi_bb297_48);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block299, phi_bb297_19, phi_bb297_25, phi_bb297_26, phi_bb297_27, phi_bb297_28, phi_bb297_31, phi_bb297_32, phi_bb297_34, phi_bb297_35, phi_bb297_36, phi_bb297_47, phi_bb297_48);
    } else {
      ca_.Goto(&block300, phi_bb297_19, phi_bb297_25, phi_bb297_26, phi_bb297_27, phi_bb297_28, phi_bb297_31, phi_bb297_32, phi_bb297_34, phi_bb297_35, phi_bb297_36, phi_bb297_47, phi_bb297_48);
    }
  }

  TNode<IntPtrT> phi_bb299_19;
  TNode<IntPtrT> phi_bb299_25;
  TNode<IntPtrT> phi_bb299_26;
  TNode<IntPtrT> phi_bb299_27;
  TNode<IntPtrT> phi_bb299_28;
  TNode<IntPtrT> phi_bb299_31;
  TNode<BoolT> phi_bb299_32;
  TNode<IntPtrT> phi_bb299_34;
  TNode<IntPtrT> phi_bb299_35;
  TNode<BoolT> phi_bb299_36;
  TNode<BoolT> phi_bb299_47;
  TNode<JSAny> phi_bb299_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp619;
  TNode<IntPtrT> tmp620;
  TNode<IntPtrT> tmp621;
  TNode<IntPtrT> tmp622;
  if (block299.is_used()) {
    ca_.Bind(&block299, &phi_bb299_19, &phi_bb299_25, &phi_bb299_26, &phi_bb299_27, &phi_bb299_28, &phi_bb299_31, &phi_bb299_32, &phi_bb299_34, &phi_bb299_35, &phi_bb299_36, &phi_bb299_47, &phi_bb299_48);
    std::tie(tmp619, tmp620) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb299_28}).Flatten();
    tmp621 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp622 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb299_28}, TNode<IntPtrT>{tmp621});
    ca_.Goto(&block298, phi_bb299_19, phi_bb299_25, phi_bb299_26, phi_bb299_27, tmp622, phi_bb299_31, phi_bb299_32, phi_bb299_34, phi_bb299_35, phi_bb299_36, phi_bb299_47, phi_bb299_48, tmp619, tmp620);
  }

  TNode<IntPtrT> phi_bb300_19;
  TNode<IntPtrT> phi_bb300_25;
  TNode<IntPtrT> phi_bb300_26;
  TNode<IntPtrT> phi_bb300_27;
  TNode<IntPtrT> phi_bb300_28;
  TNode<IntPtrT> phi_bb300_31;
  TNode<BoolT> phi_bb300_32;
  TNode<IntPtrT> phi_bb300_34;
  TNode<IntPtrT> phi_bb300_35;
  TNode<BoolT> phi_bb300_36;
  TNode<BoolT> phi_bb300_47;
  TNode<JSAny> phi_bb300_48;
  TNode<IntPtrT> tmp623;
  TNode<BoolT> tmp624;
  if (block300.is_used()) {
    ca_.Bind(&block300, &phi_bb300_19, &phi_bb300_25, &phi_bb300_26, &phi_bb300_27, &phi_bb300_28, &phi_bb300_31, &phi_bb300_32, &phi_bb300_34, &phi_bb300_35, &phi_bb300_36, &phi_bb300_47, &phi_bb300_48);
    tmp623 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp624 = CodeStubAssembler(state_).WordNotEqual(TNode<IntPtrT>{phi_bb300_31}, TNode<IntPtrT>{tmp623});
    ca_.Branch(tmp624, &block302, std::vector<compiler::Node*>{phi_bb300_19, phi_bb300_25, phi_bb300_26, phi_bb300_27, phi_bb300_28, phi_bb300_31, phi_bb300_32, phi_bb300_34, phi_bb300_35, phi_bb300_36, phi_bb300_47, phi_bb300_48}, &block303, std::vector<compiler::Node*>{phi_bb300_19, phi_bb300_25, phi_bb300_26, phi_bb300_27, phi_bb300_28, phi_bb300_31, phi_bb300_32, phi_bb300_34, phi_bb300_35, phi_bb300_36, phi_bb300_47, phi_bb300_48});
  }

  TNode<IntPtrT> phi_bb302_19;
  TNode<IntPtrT> phi_bb302_25;
  TNode<IntPtrT> phi_bb302_26;
  TNode<IntPtrT> phi_bb302_27;
  TNode<IntPtrT> phi_bb302_28;
  TNode<IntPtrT> phi_bb302_31;
  TNode<BoolT> phi_bb302_32;
  TNode<IntPtrT> phi_bb302_34;
  TNode<IntPtrT> phi_bb302_35;
  TNode<BoolT> phi_bb302_36;
  TNode<BoolT> phi_bb302_47;
  TNode<JSAny> phi_bb302_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp625;
  TNode<IntPtrT> tmp626;
  TNode<IntPtrT> tmp627;
  TNode<BoolT> tmp628;
  if (block302.is_used()) {
    ca_.Bind(&block302, &phi_bb302_19, &phi_bb302_25, &phi_bb302_26, &phi_bb302_27, &phi_bb302_28, &phi_bb302_31, &phi_bb302_32, &phi_bb302_34, &phi_bb302_35, &phi_bb302_36, &phi_bb302_47, &phi_bb302_48);
    std::tie(tmp625, tmp626) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb302_31}).Flatten();
    tmp627 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp628 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block298, phi_bb302_19, phi_bb302_25, phi_bb302_26, phi_bb302_27, phi_bb302_28, tmp627, tmp628, phi_bb302_34, phi_bb302_35, phi_bb302_36, phi_bb302_47, phi_bb302_48, tmp625, tmp626);
  }

  TNode<IntPtrT> phi_bb303_19;
  TNode<IntPtrT> phi_bb303_25;
  TNode<IntPtrT> phi_bb303_26;
  TNode<IntPtrT> phi_bb303_27;
  TNode<IntPtrT> phi_bb303_28;
  TNode<IntPtrT> phi_bb303_31;
  TNode<BoolT> phi_bb303_32;
  TNode<IntPtrT> phi_bb303_34;
  TNode<IntPtrT> phi_bb303_35;
  TNode<BoolT> phi_bb303_36;
  TNode<BoolT> phi_bb303_47;
  TNode<JSAny> phi_bb303_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp629;
  TNode<IntPtrT> tmp630;
  TNode<IntPtrT> tmp631;
  TNode<IntPtrT> tmp632;
  TNode<IntPtrT> tmp633;
  TNode<IntPtrT> tmp634;
  TNode<BoolT> tmp635;
  if (block303.is_used()) {
    ca_.Bind(&block303, &phi_bb303_19, &phi_bb303_25, &phi_bb303_26, &phi_bb303_27, &phi_bb303_28, &phi_bb303_31, &phi_bb303_32, &phi_bb303_34, &phi_bb303_35, &phi_bb303_36, &phi_bb303_47, &phi_bb303_48);
    std::tie(tmp629, tmp630) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb303_28}).Flatten();
    tmp631 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp632 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb303_28}, TNode<IntPtrT>{tmp631});
    tmp633 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp634 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp632}, TNode<IntPtrT>{tmp633});
    tmp635 = FromConstexpr_bool_constexpr_bool_0(state_, true);
    ca_.Goto(&block298, phi_bb303_19, phi_bb303_25, phi_bb303_26, phi_bb303_27, tmp634, tmp632, tmp635, phi_bb303_34, phi_bb303_35, phi_bb303_36, phi_bb303_47, phi_bb303_48, tmp629, tmp630);
  }

  TNode<IntPtrT> phi_bb298_19;
  TNode<IntPtrT> phi_bb298_25;
  TNode<IntPtrT> phi_bb298_26;
  TNode<IntPtrT> phi_bb298_27;
  TNode<IntPtrT> phi_bb298_28;
  TNode<IntPtrT> phi_bb298_31;
  TNode<BoolT> phi_bb298_32;
  TNode<IntPtrT> phi_bb298_34;
  TNode<IntPtrT> phi_bb298_35;
  TNode<BoolT> phi_bb298_36;
  TNode<BoolT> phi_bb298_47;
  TNode<JSAny> phi_bb298_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb298_50;
  TNode<IntPtrT> phi_bb298_51;
  if (block298.is_used()) {
    ca_.Bind(&block298, &phi_bb298_19, &phi_bb298_25, &phi_bb298_26, &phi_bb298_27, &phi_bb298_28, &phi_bb298_31, &phi_bb298_32, &phi_bb298_34, &phi_bb298_35, &phi_bb298_36, &phi_bb298_47, &phi_bb298_48, &phi_bb298_50, &phi_bb298_51);
    ca_.Goto(&block295, phi_bb298_19, phi_bb298_25, phi_bb298_26, phi_bb298_27, phi_bb298_28, phi_bb298_31, phi_bb298_32, phi_bb298_34, phi_bb298_35, phi_bb298_36, phi_bb298_47, phi_bb298_48, phi_bb298_50, phi_bb298_51);
  }

  TNode<IntPtrT> phi_bb295_19;
  TNode<IntPtrT> phi_bb295_25;
  TNode<IntPtrT> phi_bb295_26;
  TNode<IntPtrT> phi_bb295_27;
  TNode<IntPtrT> phi_bb295_28;
  TNode<IntPtrT> phi_bb295_31;
  TNode<BoolT> phi_bb295_32;
  TNode<IntPtrT> phi_bb295_34;
  TNode<IntPtrT> phi_bb295_35;
  TNode<BoolT> phi_bb295_36;
  TNode<BoolT> phi_bb295_47;
  TNode<JSAny> phi_bb295_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb295_50;
  TNode<IntPtrT> phi_bb295_51;
  TNode<IntPtrT> tmp636;
  if (block295.is_used()) {
    ca_.Bind(&block295, &phi_bb295_19, &phi_bb295_25, &phi_bb295_26, &phi_bb295_27, &phi_bb295_28, &phi_bb295_31, &phi_bb295_32, &phi_bb295_34, &phi_bb295_35, &phi_bb295_36, &phi_bb295_47, &phi_bb295_48, &phi_bb295_50, &phi_bb295_51);
    tmp636 = TruncateBigIntToI64_0(state_, TNode<Context>{tmp441}, TNode<JSAny>{phi_bb295_48});
    CodeStubAssembler(state_).StoreReference<IntPtrT>(CodeStubAssembler::Reference{phi_bb295_50, phi_bb295_51}, tmp636);
    ca_.Goto(&block294, phi_bb295_19, tmp612, phi_bb295_25, phi_bb295_26, phi_bb295_27, phi_bb295_28, phi_bb295_31, phi_bb295_32, phi_bb295_34, phi_bb295_35, phi_bb295_36, phi_bb295_47, phi_bb295_48);
  }

  TNode<IntPtrT> phi_bb293_19;
  TNode<IntPtrT> phi_bb293_24;
  TNode<IntPtrT> phi_bb293_25;
  TNode<IntPtrT> phi_bb293_26;
  TNode<IntPtrT> phi_bb293_27;
  TNode<IntPtrT> phi_bb293_28;
  TNode<IntPtrT> phi_bb293_31;
  TNode<BoolT> phi_bb293_32;
  TNode<IntPtrT> phi_bb293_34;
  TNode<IntPtrT> phi_bb293_35;
  TNode<BoolT> phi_bb293_36;
  TNode<BoolT> phi_bb293_47;
  TNode<JSAny> phi_bb293_48;
  TNode<IntPtrT> tmp637;
  TNode<IntPtrT> tmp638;
  TNode<IntPtrT> tmp639;
  TNode<BoolT> tmp640;
  if (block293.is_used()) {
    ca_.Bind(&block293, &phi_bb293_19, &phi_bb293_24, &phi_bb293_25, &phi_bb293_26, &phi_bb293_27, &phi_bb293_28, &phi_bb293_31, &phi_bb293_32, &phi_bb293_34, &phi_bb293_35, &phi_bb293_36, &phi_bb293_47, &phi_bb293_48);
    tmp637 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp638 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{phi_bb293_24}, TNode<IntPtrT>{tmp637});
    tmp639 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp640 = CodeStubAssembler(state_).IntPtrGreaterThan(TNode<IntPtrT>{phi_bb293_24}, TNode<IntPtrT>{tmp639});
    ca_.Branch(tmp640, &block305, std::vector<compiler::Node*>{phi_bb293_19, phi_bb293_25, phi_bb293_26, phi_bb293_27, phi_bb293_28, phi_bb293_31, phi_bb293_32, phi_bb293_34, phi_bb293_35, phi_bb293_36, phi_bb293_47, phi_bb293_48}, &block306, std::vector<compiler::Node*>{phi_bb293_19, phi_bb293_25, phi_bb293_26, phi_bb293_27, phi_bb293_28, phi_bb293_31, phi_bb293_32, phi_bb293_34, phi_bb293_35, phi_bb293_36, phi_bb293_47, phi_bb293_48});
  }

  TNode<IntPtrT> phi_bb305_19;
  TNode<IntPtrT> phi_bb305_25;
  TNode<IntPtrT> phi_bb305_26;
  TNode<IntPtrT> phi_bb305_27;
  TNode<IntPtrT> phi_bb305_28;
  TNode<IntPtrT> phi_bb305_31;
  TNode<BoolT> phi_bb305_32;
  TNode<IntPtrT> phi_bb305_34;
  TNode<IntPtrT> phi_bb305_35;
  TNode<BoolT> phi_bb305_36;
  TNode<BoolT> phi_bb305_47;
  TNode<JSAny> phi_bb305_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp641;
  TNode<IntPtrT> tmp642;
  TNode<IntPtrT> tmp643;
  TNode<IntPtrT> tmp644;
  if (block305.is_used()) {
    ca_.Bind(&block305, &phi_bb305_19, &phi_bb305_25, &phi_bb305_26, &phi_bb305_27, &phi_bb305_28, &phi_bb305_31, &phi_bb305_32, &phi_bb305_34, &phi_bb305_35, &phi_bb305_36, &phi_bb305_47, &phi_bb305_48);
    std::tie(tmp641, tmp642) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb305_26}).Flatten();
    tmp643 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp644 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb305_26}, TNode<IntPtrT>{tmp643});
    ca_.Goto(&block304, phi_bb305_19, phi_bb305_25, tmp644, phi_bb305_27, phi_bb305_28, phi_bb305_31, phi_bb305_32, phi_bb305_34, phi_bb305_35, phi_bb305_36, phi_bb305_47, phi_bb305_48, tmp641, tmp642);
  }

  TNode<IntPtrT> phi_bb306_19;
  TNode<IntPtrT> phi_bb306_25;
  TNode<IntPtrT> phi_bb306_26;
  TNode<IntPtrT> phi_bb306_27;
  TNode<IntPtrT> phi_bb306_28;
  TNode<IntPtrT> phi_bb306_31;
  TNode<BoolT> phi_bb306_32;
  TNode<IntPtrT> phi_bb306_34;
  TNode<IntPtrT> phi_bb306_35;
  TNode<BoolT> phi_bb306_36;
  TNode<BoolT> phi_bb306_47;
  TNode<JSAny> phi_bb306_48;
  if (block306.is_used()) {
    ca_.Bind(&block306, &phi_bb306_19, &phi_bb306_25, &phi_bb306_26, &phi_bb306_27, &phi_bb306_28, &phi_bb306_31, &phi_bb306_32, &phi_bb306_34, &phi_bb306_35, &phi_bb306_36, &phi_bb306_47, &phi_bb306_48);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block308, phi_bb306_19, phi_bb306_25, phi_bb306_26, phi_bb306_27, phi_bb306_28, phi_bb306_31, phi_bb306_32, phi_bb306_34, phi_bb306_35, phi_bb306_36, phi_bb306_47, phi_bb306_48);
    } else {
      ca_.Goto(&block309, phi_bb306_19, phi_bb306_25, phi_bb306_26, phi_bb306_27, phi_bb306_28, phi_bb306_31, phi_bb306_32, phi_bb306_34, phi_bb306_35, phi_bb306_36, phi_bb306_47, phi_bb306_48);
    }
  }

  TNode<IntPtrT> phi_bb308_19;
  TNode<IntPtrT> phi_bb308_25;
  TNode<IntPtrT> phi_bb308_26;
  TNode<IntPtrT> phi_bb308_27;
  TNode<IntPtrT> phi_bb308_28;
  TNode<IntPtrT> phi_bb308_31;
  TNode<BoolT> phi_bb308_32;
  TNode<IntPtrT> phi_bb308_34;
  TNode<IntPtrT> phi_bb308_35;
  TNode<BoolT> phi_bb308_36;
  TNode<BoolT> phi_bb308_47;
  TNode<JSAny> phi_bb308_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp645;
  TNode<IntPtrT> tmp646;
  TNode<IntPtrT> tmp647;
  TNode<IntPtrT> tmp648;
  if (block308.is_used()) {
    ca_.Bind(&block308, &phi_bb308_19, &phi_bb308_25, &phi_bb308_26, &phi_bb308_27, &phi_bb308_28, &phi_bb308_31, &phi_bb308_32, &phi_bb308_34, &phi_bb308_35, &phi_bb308_36, &phi_bb308_47, &phi_bb308_48);
    std::tie(tmp645, tmp646) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb308_28}).Flatten();
    tmp647 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp648 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb308_28}, TNode<IntPtrT>{tmp647});
    ca_.Goto(&block307, phi_bb308_19, phi_bb308_25, phi_bb308_26, phi_bb308_27, tmp648, phi_bb308_31, phi_bb308_32, phi_bb308_34, phi_bb308_35, phi_bb308_36, phi_bb308_47, phi_bb308_48, tmp645, tmp646);
  }

  TNode<IntPtrT> phi_bb309_19;
  TNode<IntPtrT> phi_bb309_25;
  TNode<IntPtrT> phi_bb309_26;
  TNode<IntPtrT> phi_bb309_27;
  TNode<IntPtrT> phi_bb309_28;
  TNode<IntPtrT> phi_bb309_31;
  TNode<BoolT> phi_bb309_32;
  TNode<IntPtrT> phi_bb309_34;
  TNode<IntPtrT> phi_bb309_35;
  TNode<BoolT> phi_bb309_36;
  TNode<BoolT> phi_bb309_47;
  TNode<JSAny> phi_bb309_48;
  TNode<IntPtrT> tmp649;
  TNode<BoolT> tmp650;
  if (block309.is_used()) {
    ca_.Bind(&block309, &phi_bb309_19, &phi_bb309_25, &phi_bb309_26, &phi_bb309_27, &phi_bb309_28, &phi_bb309_31, &phi_bb309_32, &phi_bb309_34, &phi_bb309_35, &phi_bb309_36, &phi_bb309_47, &phi_bb309_48);
    tmp649 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp650 = CodeStubAssembler(state_).WordNotEqual(TNode<IntPtrT>{phi_bb309_31}, TNode<IntPtrT>{tmp649});
    ca_.Branch(tmp650, &block311, std::vector<compiler::Node*>{phi_bb309_19, phi_bb309_25, phi_bb309_26, phi_bb309_27, phi_bb309_28, phi_bb309_31, phi_bb309_32, phi_bb309_34, phi_bb309_35, phi_bb309_36, phi_bb309_47, phi_bb309_48}, &block312, std::vector<compiler::Node*>{phi_bb309_19, phi_bb309_25, phi_bb309_26, phi_bb309_27, phi_bb309_28, phi_bb309_31, phi_bb309_32, phi_bb309_34, phi_bb309_35, phi_bb309_36, phi_bb309_47, phi_bb309_48});
  }

  TNode<IntPtrT> phi_bb311_19;
  TNode<IntPtrT> phi_bb311_25;
  TNode<IntPtrT> phi_bb311_26;
  TNode<IntPtrT> phi_bb311_27;
  TNode<IntPtrT> phi_bb311_28;
  TNode<IntPtrT> phi_bb311_31;
  TNode<BoolT> phi_bb311_32;
  TNode<IntPtrT> phi_bb311_34;
  TNode<IntPtrT> phi_bb311_35;
  TNode<BoolT> phi_bb311_36;
  TNode<BoolT> phi_bb311_47;
  TNode<JSAny> phi_bb311_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp651;
  TNode<IntPtrT> tmp652;
  TNode<IntPtrT> tmp653;
  TNode<BoolT> tmp654;
  if (block311.is_used()) {
    ca_.Bind(&block311, &phi_bb311_19, &phi_bb311_25, &phi_bb311_26, &phi_bb311_27, &phi_bb311_28, &phi_bb311_31, &phi_bb311_32, &phi_bb311_34, &phi_bb311_35, &phi_bb311_36, &phi_bb311_47, &phi_bb311_48);
    std::tie(tmp651, tmp652) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb311_31}).Flatten();
    tmp653 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp654 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block307, phi_bb311_19, phi_bb311_25, phi_bb311_26, phi_bb311_27, phi_bb311_28, tmp653, tmp654, phi_bb311_34, phi_bb311_35, phi_bb311_36, phi_bb311_47, phi_bb311_48, tmp651, tmp652);
  }

  TNode<IntPtrT> phi_bb312_19;
  TNode<IntPtrT> phi_bb312_25;
  TNode<IntPtrT> phi_bb312_26;
  TNode<IntPtrT> phi_bb312_27;
  TNode<IntPtrT> phi_bb312_28;
  TNode<IntPtrT> phi_bb312_31;
  TNode<BoolT> phi_bb312_32;
  TNode<IntPtrT> phi_bb312_34;
  TNode<IntPtrT> phi_bb312_35;
  TNode<BoolT> phi_bb312_36;
  TNode<BoolT> phi_bb312_47;
  TNode<JSAny> phi_bb312_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp655;
  TNode<IntPtrT> tmp656;
  TNode<IntPtrT> tmp657;
  TNode<IntPtrT> tmp658;
  TNode<IntPtrT> tmp659;
  TNode<IntPtrT> tmp660;
  TNode<BoolT> tmp661;
  if (block312.is_used()) {
    ca_.Bind(&block312, &phi_bb312_19, &phi_bb312_25, &phi_bb312_26, &phi_bb312_27, &phi_bb312_28, &phi_bb312_31, &phi_bb312_32, &phi_bb312_34, &phi_bb312_35, &phi_bb312_36, &phi_bb312_47, &phi_bb312_48);
    std::tie(tmp655, tmp656) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb312_28}).Flatten();
    tmp657 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp658 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb312_28}, TNode<IntPtrT>{tmp657});
    tmp659 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp660 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp658}, TNode<IntPtrT>{tmp659});
    tmp661 = FromConstexpr_bool_constexpr_bool_0(state_, true);
    ca_.Goto(&block307, phi_bb312_19, phi_bb312_25, phi_bb312_26, phi_bb312_27, tmp660, tmp658, tmp661, phi_bb312_34, phi_bb312_35, phi_bb312_36, phi_bb312_47, phi_bb312_48, tmp655, tmp656);
  }

  TNode<IntPtrT> phi_bb307_19;
  TNode<IntPtrT> phi_bb307_25;
  TNode<IntPtrT> phi_bb307_26;
  TNode<IntPtrT> phi_bb307_27;
  TNode<IntPtrT> phi_bb307_28;
  TNode<IntPtrT> phi_bb307_31;
  TNode<BoolT> phi_bb307_32;
  TNode<IntPtrT> phi_bb307_34;
  TNode<IntPtrT> phi_bb307_35;
  TNode<BoolT> phi_bb307_36;
  TNode<BoolT> phi_bb307_47;
  TNode<JSAny> phi_bb307_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb307_50;
  TNode<IntPtrT> phi_bb307_51;
  if (block307.is_used()) {
    ca_.Bind(&block307, &phi_bb307_19, &phi_bb307_25, &phi_bb307_26, &phi_bb307_27, &phi_bb307_28, &phi_bb307_31, &phi_bb307_32, &phi_bb307_34, &phi_bb307_35, &phi_bb307_36, &phi_bb307_47, &phi_bb307_48, &phi_bb307_50, &phi_bb307_51);
    ca_.Goto(&block304, phi_bb307_19, phi_bb307_25, phi_bb307_26, phi_bb307_27, phi_bb307_28, phi_bb307_31, phi_bb307_32, phi_bb307_34, phi_bb307_35, phi_bb307_36, phi_bb307_47, phi_bb307_48, phi_bb307_50, phi_bb307_51);
  }

  TNode<IntPtrT> phi_bb304_19;
  TNode<IntPtrT> phi_bb304_25;
  TNode<IntPtrT> phi_bb304_26;
  TNode<IntPtrT> phi_bb304_27;
  TNode<IntPtrT> phi_bb304_28;
  TNode<IntPtrT> phi_bb304_31;
  TNode<BoolT> phi_bb304_32;
  TNode<IntPtrT> phi_bb304_34;
  TNode<IntPtrT> phi_bb304_35;
  TNode<BoolT> phi_bb304_36;
  TNode<BoolT> phi_bb304_47;
  TNode<JSAny> phi_bb304_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb304_50;
  TNode<IntPtrT> phi_bb304_51;
  TNode<IntPtrT> tmp662;
  TNode<IntPtrT> tmp663;
  TNode<IntPtrT> tmp664;
  TNode<BoolT> tmp665;
  if (block304.is_used()) {
    ca_.Bind(&block304, &phi_bb304_19, &phi_bb304_25, &phi_bb304_26, &phi_bb304_27, &phi_bb304_28, &phi_bb304_31, &phi_bb304_32, &phi_bb304_34, &phi_bb304_35, &phi_bb304_36, &phi_bb304_47, &phi_bb304_48, &phi_bb304_50, &phi_bb304_51);
    tmp662 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp663 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{tmp638}, TNode<IntPtrT>{tmp662});
    tmp664 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp665 = CodeStubAssembler(state_).IntPtrGreaterThan(TNode<IntPtrT>{tmp638}, TNode<IntPtrT>{tmp664});
    ca_.Branch(tmp665, &block314, std::vector<compiler::Node*>{phi_bb304_19, phi_bb304_25, phi_bb304_26, phi_bb304_27, phi_bb304_28, phi_bb304_31, phi_bb304_32, phi_bb304_34, phi_bb304_35, phi_bb304_36, phi_bb304_47, phi_bb304_48, phi_bb304_50, phi_bb304_51}, &block315, std::vector<compiler::Node*>{phi_bb304_19, phi_bb304_25, phi_bb304_26, phi_bb304_27, phi_bb304_28, phi_bb304_31, phi_bb304_32, phi_bb304_34, phi_bb304_35, phi_bb304_36, phi_bb304_47, phi_bb304_48, phi_bb304_50, phi_bb304_51});
  }

  TNode<IntPtrT> phi_bb314_19;
  TNode<IntPtrT> phi_bb314_25;
  TNode<IntPtrT> phi_bb314_26;
  TNode<IntPtrT> phi_bb314_27;
  TNode<IntPtrT> phi_bb314_28;
  TNode<IntPtrT> phi_bb314_31;
  TNode<BoolT> phi_bb314_32;
  TNode<IntPtrT> phi_bb314_34;
  TNode<IntPtrT> phi_bb314_35;
  TNode<BoolT> phi_bb314_36;
  TNode<BoolT> phi_bb314_47;
  TNode<JSAny> phi_bb314_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb314_50;
  TNode<IntPtrT> phi_bb314_51;
  TNode<Union<HeapObject, TaggedIndex>> tmp666;
  TNode<IntPtrT> tmp667;
  TNode<IntPtrT> tmp668;
  TNode<IntPtrT> tmp669;
  if (block314.is_used()) {
    ca_.Bind(&block314, &phi_bb314_19, &phi_bb314_25, &phi_bb314_26, &phi_bb314_27, &phi_bb314_28, &phi_bb314_31, &phi_bb314_32, &phi_bb314_34, &phi_bb314_35, &phi_bb314_36, &phi_bb314_47, &phi_bb314_48, &phi_bb314_50, &phi_bb314_51);
    std::tie(tmp666, tmp667) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb314_26}).Flatten();
    tmp668 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp669 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb314_26}, TNode<IntPtrT>{tmp668});
    ca_.Goto(&block313, phi_bb314_19, phi_bb314_25, tmp669, phi_bb314_27, phi_bb314_28, phi_bb314_31, phi_bb314_32, phi_bb314_34, phi_bb314_35, phi_bb314_36, phi_bb314_47, phi_bb314_48, phi_bb314_50, phi_bb314_51, tmp666, tmp667);
  }

  TNode<IntPtrT> phi_bb315_19;
  TNode<IntPtrT> phi_bb315_25;
  TNode<IntPtrT> phi_bb315_26;
  TNode<IntPtrT> phi_bb315_27;
  TNode<IntPtrT> phi_bb315_28;
  TNode<IntPtrT> phi_bb315_31;
  TNode<BoolT> phi_bb315_32;
  TNode<IntPtrT> phi_bb315_34;
  TNode<IntPtrT> phi_bb315_35;
  TNode<BoolT> phi_bb315_36;
  TNode<BoolT> phi_bb315_47;
  TNode<JSAny> phi_bb315_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb315_50;
  TNode<IntPtrT> phi_bb315_51;
  if (block315.is_used()) {
    ca_.Bind(&block315, &phi_bb315_19, &phi_bb315_25, &phi_bb315_26, &phi_bb315_27, &phi_bb315_28, &phi_bb315_31, &phi_bb315_32, &phi_bb315_34, &phi_bb315_35, &phi_bb315_36, &phi_bb315_47, &phi_bb315_48, &phi_bb315_50, &phi_bb315_51);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block317, phi_bb315_19, phi_bb315_25, phi_bb315_26, phi_bb315_27, phi_bb315_28, phi_bb315_31, phi_bb315_32, phi_bb315_34, phi_bb315_35, phi_bb315_36, phi_bb315_47, phi_bb315_48, phi_bb315_50, phi_bb315_51);
    } else {
      ca_.Goto(&block318, phi_bb315_19, phi_bb315_25, phi_bb315_26, phi_bb315_27, phi_bb315_28, phi_bb315_31, phi_bb315_32, phi_bb315_34, phi_bb315_35, phi_bb315_36, phi_bb315_47, phi_bb315_48, phi_bb315_50, phi_bb315_51);
    }
  }

  TNode<IntPtrT> phi_bb317_19;
  TNode<IntPtrT> phi_bb317_25;
  TNode<IntPtrT> phi_bb317_26;
  TNode<IntPtrT> phi_bb317_27;
  TNode<IntPtrT> phi_bb317_28;
  TNode<IntPtrT> phi_bb317_31;
  TNode<BoolT> phi_bb317_32;
  TNode<IntPtrT> phi_bb317_34;
  TNode<IntPtrT> phi_bb317_35;
  TNode<BoolT> phi_bb317_36;
  TNode<BoolT> phi_bb317_47;
  TNode<JSAny> phi_bb317_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb317_50;
  TNode<IntPtrT> phi_bb317_51;
  TNode<Union<HeapObject, TaggedIndex>> tmp670;
  TNode<IntPtrT> tmp671;
  TNode<IntPtrT> tmp672;
  TNode<IntPtrT> tmp673;
  if (block317.is_used()) {
    ca_.Bind(&block317, &phi_bb317_19, &phi_bb317_25, &phi_bb317_26, &phi_bb317_27, &phi_bb317_28, &phi_bb317_31, &phi_bb317_32, &phi_bb317_34, &phi_bb317_35, &phi_bb317_36, &phi_bb317_47, &phi_bb317_48, &phi_bb317_50, &phi_bb317_51);
    std::tie(tmp670, tmp671) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb317_28}).Flatten();
    tmp672 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp673 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb317_28}, TNode<IntPtrT>{tmp672});
    ca_.Goto(&block316, phi_bb317_19, phi_bb317_25, phi_bb317_26, phi_bb317_27, tmp673, phi_bb317_31, phi_bb317_32, phi_bb317_34, phi_bb317_35, phi_bb317_36, phi_bb317_47, phi_bb317_48, phi_bb317_50, phi_bb317_51, tmp670, tmp671);
  }

  TNode<IntPtrT> phi_bb318_19;
  TNode<IntPtrT> phi_bb318_25;
  TNode<IntPtrT> phi_bb318_26;
  TNode<IntPtrT> phi_bb318_27;
  TNode<IntPtrT> phi_bb318_28;
  TNode<IntPtrT> phi_bb318_31;
  TNode<BoolT> phi_bb318_32;
  TNode<IntPtrT> phi_bb318_34;
  TNode<IntPtrT> phi_bb318_35;
  TNode<BoolT> phi_bb318_36;
  TNode<BoolT> phi_bb318_47;
  TNode<JSAny> phi_bb318_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb318_50;
  TNode<IntPtrT> phi_bb318_51;
  TNode<IntPtrT> tmp674;
  TNode<BoolT> tmp675;
  if (block318.is_used()) {
    ca_.Bind(&block318, &phi_bb318_19, &phi_bb318_25, &phi_bb318_26, &phi_bb318_27, &phi_bb318_28, &phi_bb318_31, &phi_bb318_32, &phi_bb318_34, &phi_bb318_35, &phi_bb318_36, &phi_bb318_47, &phi_bb318_48, &phi_bb318_50, &phi_bb318_51);
    tmp674 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp675 = CodeStubAssembler(state_).WordNotEqual(TNode<IntPtrT>{phi_bb318_31}, TNode<IntPtrT>{tmp674});
    ca_.Branch(tmp675, &block320, std::vector<compiler::Node*>{phi_bb318_19, phi_bb318_25, phi_bb318_26, phi_bb318_27, phi_bb318_28, phi_bb318_31, phi_bb318_32, phi_bb318_34, phi_bb318_35, phi_bb318_36, phi_bb318_47, phi_bb318_48, phi_bb318_50, phi_bb318_51}, &block321, std::vector<compiler::Node*>{phi_bb318_19, phi_bb318_25, phi_bb318_26, phi_bb318_27, phi_bb318_28, phi_bb318_31, phi_bb318_32, phi_bb318_34, phi_bb318_35, phi_bb318_36, phi_bb318_47, phi_bb318_48, phi_bb318_50, phi_bb318_51});
  }

  TNode<IntPtrT> phi_bb320_19;
  TNode<IntPtrT> phi_bb320_25;
  TNode<IntPtrT> phi_bb320_26;
  TNode<IntPtrT> phi_bb320_27;
  TNode<IntPtrT> phi_bb320_28;
  TNode<IntPtrT> phi_bb320_31;
  TNode<BoolT> phi_bb320_32;
  TNode<IntPtrT> phi_bb320_34;
  TNode<IntPtrT> phi_bb320_35;
  TNode<BoolT> phi_bb320_36;
  TNode<BoolT> phi_bb320_47;
  TNode<JSAny> phi_bb320_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb320_50;
  TNode<IntPtrT> phi_bb320_51;
  TNode<Union<HeapObject, TaggedIndex>> tmp676;
  TNode<IntPtrT> tmp677;
  TNode<IntPtrT> tmp678;
  TNode<BoolT> tmp679;
  if (block320.is_used()) {
    ca_.Bind(&block320, &phi_bb320_19, &phi_bb320_25, &phi_bb320_26, &phi_bb320_27, &phi_bb320_28, &phi_bb320_31, &phi_bb320_32, &phi_bb320_34, &phi_bb320_35, &phi_bb320_36, &phi_bb320_47, &phi_bb320_48, &phi_bb320_50, &phi_bb320_51);
    std::tie(tmp676, tmp677) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb320_31}).Flatten();
    tmp678 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp679 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block316, phi_bb320_19, phi_bb320_25, phi_bb320_26, phi_bb320_27, phi_bb320_28, tmp678, tmp679, phi_bb320_34, phi_bb320_35, phi_bb320_36, phi_bb320_47, phi_bb320_48, phi_bb320_50, phi_bb320_51, tmp676, tmp677);
  }

  TNode<IntPtrT> phi_bb321_19;
  TNode<IntPtrT> phi_bb321_25;
  TNode<IntPtrT> phi_bb321_26;
  TNode<IntPtrT> phi_bb321_27;
  TNode<IntPtrT> phi_bb321_28;
  TNode<IntPtrT> phi_bb321_31;
  TNode<BoolT> phi_bb321_32;
  TNode<IntPtrT> phi_bb321_34;
  TNode<IntPtrT> phi_bb321_35;
  TNode<BoolT> phi_bb321_36;
  TNode<BoolT> phi_bb321_47;
  TNode<JSAny> phi_bb321_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb321_50;
  TNode<IntPtrT> phi_bb321_51;
  TNode<Union<HeapObject, TaggedIndex>> tmp680;
  TNode<IntPtrT> tmp681;
  TNode<IntPtrT> tmp682;
  TNode<IntPtrT> tmp683;
  TNode<IntPtrT> tmp684;
  TNode<IntPtrT> tmp685;
  TNode<BoolT> tmp686;
  if (block321.is_used()) {
    ca_.Bind(&block321, &phi_bb321_19, &phi_bb321_25, &phi_bb321_26, &phi_bb321_27, &phi_bb321_28, &phi_bb321_31, &phi_bb321_32, &phi_bb321_34, &phi_bb321_35, &phi_bb321_36, &phi_bb321_47, &phi_bb321_48, &phi_bb321_50, &phi_bb321_51);
    std::tie(tmp680, tmp681) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb321_28}).Flatten();
    tmp682 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp683 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb321_28}, TNode<IntPtrT>{tmp682});
    tmp684 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp685 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp683}, TNode<IntPtrT>{tmp684});
    tmp686 = FromConstexpr_bool_constexpr_bool_0(state_, true);
    ca_.Goto(&block316, phi_bb321_19, phi_bb321_25, phi_bb321_26, phi_bb321_27, tmp685, tmp683, tmp686, phi_bb321_34, phi_bb321_35, phi_bb321_36, phi_bb321_47, phi_bb321_48, phi_bb321_50, phi_bb321_51, tmp680, tmp681);
  }

  TNode<IntPtrT> phi_bb316_19;
  TNode<IntPtrT> phi_bb316_25;
  TNode<IntPtrT> phi_bb316_26;
  TNode<IntPtrT> phi_bb316_27;
  TNode<IntPtrT> phi_bb316_28;
  TNode<IntPtrT> phi_bb316_31;
  TNode<BoolT> phi_bb316_32;
  TNode<IntPtrT> phi_bb316_34;
  TNode<IntPtrT> phi_bb316_35;
  TNode<BoolT> phi_bb316_36;
  TNode<BoolT> phi_bb316_47;
  TNode<JSAny> phi_bb316_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb316_50;
  TNode<IntPtrT> phi_bb316_51;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb316_52;
  TNode<IntPtrT> phi_bb316_53;
  if (block316.is_used()) {
    ca_.Bind(&block316, &phi_bb316_19, &phi_bb316_25, &phi_bb316_26, &phi_bb316_27, &phi_bb316_28, &phi_bb316_31, &phi_bb316_32, &phi_bb316_34, &phi_bb316_35, &phi_bb316_36, &phi_bb316_47, &phi_bb316_48, &phi_bb316_50, &phi_bb316_51, &phi_bb316_52, &phi_bb316_53);
    ca_.Goto(&block313, phi_bb316_19, phi_bb316_25, phi_bb316_26, phi_bb316_27, phi_bb316_28, phi_bb316_31, phi_bb316_32, phi_bb316_34, phi_bb316_35, phi_bb316_36, phi_bb316_47, phi_bb316_48, phi_bb316_50, phi_bb316_51, phi_bb316_52, phi_bb316_53);
  }

  TNode<IntPtrT> phi_bb313_19;
  TNode<IntPtrT> phi_bb313_25;
  TNode<IntPtrT> phi_bb313_26;
  TNode<IntPtrT> phi_bb313_27;
  TNode<IntPtrT> phi_bb313_28;
  TNode<IntPtrT> phi_bb313_31;
  TNode<BoolT> phi_bb313_32;
  TNode<IntPtrT> phi_bb313_34;
  TNode<IntPtrT> phi_bb313_35;
  TNode<BoolT> phi_bb313_36;
  TNode<BoolT> phi_bb313_47;
  TNode<JSAny> phi_bb313_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb313_50;
  TNode<IntPtrT> phi_bb313_51;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb313_52;
  TNode<IntPtrT> phi_bb313_53;
  TNode<BigInt> tmp687;
  TNode<UintPtrT> tmp688;
  TNode<UintPtrT> tmp689;
  TNode<IntPtrT> tmp690;
  TNode<IntPtrT> tmp691;
  if (block313.is_used()) {
    ca_.Bind(&block313, &phi_bb313_19, &phi_bb313_25, &phi_bb313_26, &phi_bb313_27, &phi_bb313_28, &phi_bb313_31, &phi_bb313_32, &phi_bb313_34, &phi_bb313_35, &phi_bb313_36, &phi_bb313_47, &phi_bb313_48, &phi_bb313_50, &phi_bb313_51, &phi_bb313_52, &phi_bb313_53);
    tmp687 = CodeStubAssembler(state_).ToBigInt(TNode<Context>{tmp441}, TNode<JSAny>{phi_bb313_48});
    std::tie(tmp688, tmp689) = CodeStubAssembler(state_).BigIntToRawBytes(TNode<BigInt>{tmp687}).Flatten();
    tmp690 = CodeStubAssembler(state_).Signed(TNode<UintPtrT>{tmp688});
    CodeStubAssembler(state_).StoreReference<IntPtrT>(CodeStubAssembler::Reference{phi_bb313_50, phi_bb313_51}, tmp690);
    tmp691 = CodeStubAssembler(state_).Signed(TNode<UintPtrT>{tmp689});
    CodeStubAssembler(state_).StoreReference<IntPtrT>(CodeStubAssembler::Reference{phi_bb313_52, phi_bb313_53}, tmp691);
    ca_.Goto(&block294, phi_bb313_19, tmp663, phi_bb313_25, phi_bb313_26, phi_bb313_27, phi_bb313_28, phi_bb313_31, phi_bb313_32, phi_bb313_34, phi_bb313_35, phi_bb313_36, phi_bb313_47, phi_bb313_48);
  }

  TNode<IntPtrT> phi_bb294_19;
  TNode<IntPtrT> phi_bb294_24;
  TNode<IntPtrT> phi_bb294_25;
  TNode<IntPtrT> phi_bb294_26;
  TNode<IntPtrT> phi_bb294_27;
  TNode<IntPtrT> phi_bb294_28;
  TNode<IntPtrT> phi_bb294_31;
  TNode<BoolT> phi_bb294_32;
  TNode<IntPtrT> phi_bb294_34;
  TNode<IntPtrT> phi_bb294_35;
  TNode<BoolT> phi_bb294_36;
  TNode<BoolT> phi_bb294_47;
  TNode<JSAny> phi_bb294_48;
  if (block294.is_used()) {
    ca_.Bind(&block294, &phi_bb294_19, &phi_bb294_24, &phi_bb294_25, &phi_bb294_26, &phi_bb294_27, &phi_bb294_28, &phi_bb294_31, &phi_bb294_32, &phi_bb294_34, &phi_bb294_35, &phi_bb294_36, &phi_bb294_47, &phi_bb294_48);
    ca_.Goto(&block291, phi_bb294_19, phi_bb294_24, phi_bb294_25, phi_bb294_26, phi_bb294_27, phi_bb294_28, phi_bb294_31, phi_bb294_32, phi_bb294_34, phi_bb294_35, phi_bb294_36, phi_bb294_47, phi_bb294_48);
  }

  TNode<IntPtrT> phi_bb290_19;
  TNode<IntPtrT> phi_bb290_24;
  TNode<IntPtrT> phi_bb290_25;
  TNode<IntPtrT> phi_bb290_26;
  TNode<IntPtrT> phi_bb290_27;
  TNode<IntPtrT> phi_bb290_28;
  TNode<IntPtrT> phi_bb290_31;
  TNode<BoolT> phi_bb290_32;
  TNode<IntPtrT> phi_bb290_34;
  TNode<IntPtrT> phi_bb290_35;
  TNode<BoolT> phi_bb290_36;
  TNode<BoolT> phi_bb290_47;
  TNode<JSAny> phi_bb290_48;
  TNode<Uint32T> tmp692;
  TNode<Uint32T> tmp693;
  TNode<Uint32T> tmp694;
  TNode<BoolT> tmp695;
  if (block290.is_used()) {
    ca_.Bind(&block290, &phi_bb290_19, &phi_bb290_24, &phi_bb290_25, &phi_bb290_26, &phi_bb290_27, &phi_bb290_28, &phi_bb290_31, &phi_bb290_32, &phi_bb290_34, &phi_bb290_35, &phi_bb290_36, &phi_bb290_47, &phi_bb290_48);
    tmp692 = FromConstexpr_WasmCodePointer_constexpr_WasmCodePointer_0(state_, wasm::ValueType::kIsRefBit);
    tmp693 = CodeStubAssembler(state_).Word32And(TNode<Uint32T>{tmp507}, TNode<Uint32T>{tmp692});
    tmp694 = FromConstexpr_WasmCodePointer_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp695 = CodeStubAssembler(state_).Word32NotEqual(TNode<Uint32T>{tmp693}, TNode<Uint32T>{tmp694});
    ca_.Branch(tmp695, &block322, std::vector<compiler::Node*>{phi_bb290_19, phi_bb290_24, phi_bb290_25, phi_bb290_26, phi_bb290_27, phi_bb290_28, phi_bb290_31, phi_bb290_32, phi_bb290_34, phi_bb290_35, phi_bb290_36, phi_bb290_47, phi_bb290_48}, &block323, std::vector<compiler::Node*>{phi_bb290_19, phi_bb290_24, phi_bb290_25, phi_bb290_26, phi_bb290_27, phi_bb290_28, phi_bb290_31, phi_bb290_32, phi_bb290_34, phi_bb290_35, phi_bb290_36, phi_bb290_47, phi_bb290_48});
  }

  TNode<IntPtrT> phi_bb323_19;
  TNode<IntPtrT> phi_bb323_24;
  TNode<IntPtrT> phi_bb323_25;
  TNode<IntPtrT> phi_bb323_26;
  TNode<IntPtrT> phi_bb323_27;
  TNode<IntPtrT> phi_bb323_28;
  TNode<IntPtrT> phi_bb323_31;
  TNode<BoolT> phi_bb323_32;
  TNode<IntPtrT> phi_bb323_34;
  TNode<IntPtrT> phi_bb323_35;
  TNode<BoolT> phi_bb323_36;
  TNode<BoolT> phi_bb323_47;
  TNode<JSAny> phi_bb323_48;
  if (block323.is_used()) {
    ca_.Bind(&block323, &phi_bb323_19, &phi_bb323_24, &phi_bb323_25, &phi_bb323_26, &phi_bb323_27, &phi_bb323_28, &phi_bb323_31, &phi_bb323_32, &phi_bb323_34, &phi_bb323_35, &phi_bb323_36, &phi_bb323_47, &phi_bb323_48);
    {
      auto pos_stack = ca_.GetMacroSourcePositionStack();
      pos_stack.push_back({"src/builtins/wasm-to-js.tq", 260});
      CodeStubAssembler(state_).FailAssert("Torque assert '(retType & kValueTypeIsRefBit) != 0' failed", pos_stack);
    }
  }

  TNode<IntPtrT> phi_bb322_19;
  TNode<IntPtrT> phi_bb322_24;
  TNode<IntPtrT> phi_bb322_25;
  TNode<IntPtrT> phi_bb322_26;
  TNode<IntPtrT> phi_bb322_27;
  TNode<IntPtrT> phi_bb322_28;
  TNode<IntPtrT> phi_bb322_31;
  TNode<BoolT> phi_bb322_32;
  TNode<IntPtrT> phi_bb322_34;
  TNode<IntPtrT> phi_bb322_35;
  TNode<BoolT> phi_bb322_36;
  TNode<BoolT> phi_bb322_47;
  TNode<JSAny> phi_bb322_48;
  TNode<Object> tmp696;
  TNode<IntPtrT> tmp697;
  TNode<BoolT> tmp698;
  if (block322.is_used()) {
    ca_.Bind(&block322, &phi_bb322_19, &phi_bb322_24, &phi_bb322_25, &phi_bb322_26, &phi_bb322_27, &phi_bb322_28, &phi_bb322_31, &phi_bb322_32, &phi_bb322_34, &phi_bb322_35, &phi_bb322_36, &phi_bb322_47, &phi_bb322_48);
    tmp696 = JSToWasmObject_0(state_, TNode<NativeContext>{tmp441}, TNode<Uint32T>{tmp507}, TNode<JSAny>{phi_bb322_48});
    tmp697 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x1ull));
    tmp698 = CodeStubAssembler(state_).WordEqual(TNode<IntPtrT>{tmp31}, TNode<IntPtrT>{tmp697});
    ca_.Branch(tmp698, &block324, std::vector<compiler::Node*>{phi_bb322_19, phi_bb322_24, phi_bb322_25, phi_bb322_26, phi_bb322_27, phi_bb322_28, phi_bb322_31, phi_bb322_32, phi_bb322_34, phi_bb322_35, phi_bb322_36, phi_bb322_47, phi_bb322_48}, &block325, std::vector<compiler::Node*>{phi_bb322_19, phi_bb322_24, phi_bb322_25, phi_bb322_26, phi_bb322_27, phi_bb322_28, phi_bb322_31, phi_bb322_32, phi_bb322_34, phi_bb322_35, phi_bb322_36, phi_bb322_47, phi_bb322_48});
  }

  TNode<IntPtrT> phi_bb324_19;
  TNode<IntPtrT> phi_bb324_24;
  TNode<IntPtrT> phi_bb324_25;
  TNode<IntPtrT> phi_bb324_26;
  TNode<IntPtrT> phi_bb324_27;
  TNode<IntPtrT> phi_bb324_28;
  TNode<IntPtrT> phi_bb324_31;
  TNode<BoolT> phi_bb324_32;
  TNode<IntPtrT> phi_bb324_34;
  TNode<IntPtrT> phi_bb324_35;
  TNode<BoolT> phi_bb324_36;
  TNode<BoolT> phi_bb324_47;
  TNode<JSAny> phi_bb324_48;
  TNode<IntPtrT> tmp699;
  TNode<IntPtrT> tmp700;
  TNode<IntPtrT> tmp701;
  TNode<BoolT> tmp702;
  if (block324.is_used()) {
    ca_.Bind(&block324, &phi_bb324_19, &phi_bb324_24, &phi_bb324_25, &phi_bb324_26, &phi_bb324_27, &phi_bb324_28, &phi_bb324_31, &phi_bb324_32, &phi_bb324_34, &phi_bb324_35, &phi_bb324_36, &phi_bb324_47, &phi_bb324_48);
    tmp699 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp700 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{phi_bb324_24}, TNode<IntPtrT>{tmp699});
    tmp701 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp702 = CodeStubAssembler(state_).IntPtrGreaterThan(TNode<IntPtrT>{phi_bb324_24}, TNode<IntPtrT>{tmp701});
    ca_.Branch(tmp702, &block328, std::vector<compiler::Node*>{phi_bb324_19, phi_bb324_25, phi_bb324_26, phi_bb324_27, phi_bb324_28, phi_bb324_31, phi_bb324_32, phi_bb324_34, phi_bb324_35, phi_bb324_36, phi_bb324_47, phi_bb324_48}, &block329, std::vector<compiler::Node*>{phi_bb324_19, phi_bb324_25, phi_bb324_26, phi_bb324_27, phi_bb324_28, phi_bb324_31, phi_bb324_32, phi_bb324_34, phi_bb324_35, phi_bb324_36, phi_bb324_47, phi_bb324_48});
  }

  TNode<IntPtrT> phi_bb328_19;
  TNode<IntPtrT> phi_bb328_25;
  TNode<IntPtrT> phi_bb328_26;
  TNode<IntPtrT> phi_bb328_27;
  TNode<IntPtrT> phi_bb328_28;
  TNode<IntPtrT> phi_bb328_31;
  TNode<BoolT> phi_bb328_32;
  TNode<IntPtrT> phi_bb328_34;
  TNode<IntPtrT> phi_bb328_35;
  TNode<BoolT> phi_bb328_36;
  TNode<BoolT> phi_bb328_47;
  TNode<JSAny> phi_bb328_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp703;
  TNode<IntPtrT> tmp704;
  TNode<IntPtrT> tmp705;
  TNode<IntPtrT> tmp706;
  if (block328.is_used()) {
    ca_.Bind(&block328, &phi_bb328_19, &phi_bb328_25, &phi_bb328_26, &phi_bb328_27, &phi_bb328_28, &phi_bb328_31, &phi_bb328_32, &phi_bb328_34, &phi_bb328_35, &phi_bb328_36, &phi_bb328_47, &phi_bb328_48);
    std::tie(tmp703, tmp704) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb328_26}).Flatten();
    tmp705 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp706 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb328_26}, TNode<IntPtrT>{tmp705});
    ca_.Goto(&block327, phi_bb328_19, phi_bb328_25, tmp706, phi_bb328_27, phi_bb328_28, phi_bb328_31, phi_bb328_32, phi_bb328_34, phi_bb328_35, phi_bb328_36, phi_bb328_47, phi_bb328_48, tmp703, tmp704);
  }

  TNode<IntPtrT> phi_bb329_19;
  TNode<IntPtrT> phi_bb329_25;
  TNode<IntPtrT> phi_bb329_26;
  TNode<IntPtrT> phi_bb329_27;
  TNode<IntPtrT> phi_bb329_28;
  TNode<IntPtrT> phi_bb329_31;
  TNode<BoolT> phi_bb329_32;
  TNode<IntPtrT> phi_bb329_34;
  TNode<IntPtrT> phi_bb329_35;
  TNode<BoolT> phi_bb329_36;
  TNode<BoolT> phi_bb329_47;
  TNode<JSAny> phi_bb329_48;
  if (block329.is_used()) {
    ca_.Bind(&block329, &phi_bb329_19, &phi_bb329_25, &phi_bb329_26, &phi_bb329_27, &phi_bb329_28, &phi_bb329_31, &phi_bb329_32, &phi_bb329_34, &phi_bb329_35, &phi_bb329_36, &phi_bb329_47, &phi_bb329_48);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block331, phi_bb329_19, phi_bb329_25, phi_bb329_26, phi_bb329_27, phi_bb329_28, phi_bb329_31, phi_bb329_32, phi_bb329_34, phi_bb329_35, phi_bb329_36, phi_bb329_47, phi_bb329_48);
    } else {
      ca_.Goto(&block332, phi_bb329_19, phi_bb329_25, phi_bb329_26, phi_bb329_27, phi_bb329_28, phi_bb329_31, phi_bb329_32, phi_bb329_34, phi_bb329_35, phi_bb329_36, phi_bb329_47, phi_bb329_48);
    }
  }

  TNode<IntPtrT> phi_bb331_19;
  TNode<IntPtrT> phi_bb331_25;
  TNode<IntPtrT> phi_bb331_26;
  TNode<IntPtrT> phi_bb331_27;
  TNode<IntPtrT> phi_bb331_28;
  TNode<IntPtrT> phi_bb331_31;
  TNode<BoolT> phi_bb331_32;
  TNode<IntPtrT> phi_bb331_34;
  TNode<IntPtrT> phi_bb331_35;
  TNode<BoolT> phi_bb331_36;
  TNode<BoolT> phi_bb331_47;
  TNode<JSAny> phi_bb331_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp707;
  TNode<IntPtrT> tmp708;
  TNode<IntPtrT> tmp709;
  TNode<IntPtrT> tmp710;
  if (block331.is_used()) {
    ca_.Bind(&block331, &phi_bb331_19, &phi_bb331_25, &phi_bb331_26, &phi_bb331_27, &phi_bb331_28, &phi_bb331_31, &phi_bb331_32, &phi_bb331_34, &phi_bb331_35, &phi_bb331_36, &phi_bb331_47, &phi_bb331_48);
    std::tie(tmp707, tmp708) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb331_28}).Flatten();
    tmp709 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp710 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb331_28}, TNode<IntPtrT>{tmp709});
    ca_.Goto(&block330, phi_bb331_19, phi_bb331_25, phi_bb331_26, phi_bb331_27, tmp710, phi_bb331_31, phi_bb331_32, phi_bb331_34, phi_bb331_35, phi_bb331_36, phi_bb331_47, phi_bb331_48, tmp707, tmp708);
  }

  TNode<IntPtrT> phi_bb332_19;
  TNode<IntPtrT> phi_bb332_25;
  TNode<IntPtrT> phi_bb332_26;
  TNode<IntPtrT> phi_bb332_27;
  TNode<IntPtrT> phi_bb332_28;
  TNode<IntPtrT> phi_bb332_31;
  TNode<BoolT> phi_bb332_32;
  TNode<IntPtrT> phi_bb332_34;
  TNode<IntPtrT> phi_bb332_35;
  TNode<BoolT> phi_bb332_36;
  TNode<BoolT> phi_bb332_47;
  TNode<JSAny> phi_bb332_48;
  TNode<IntPtrT> tmp711;
  TNode<BoolT> tmp712;
  if (block332.is_used()) {
    ca_.Bind(&block332, &phi_bb332_19, &phi_bb332_25, &phi_bb332_26, &phi_bb332_27, &phi_bb332_28, &phi_bb332_31, &phi_bb332_32, &phi_bb332_34, &phi_bb332_35, &phi_bb332_36, &phi_bb332_47, &phi_bb332_48);
    tmp711 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp712 = CodeStubAssembler(state_).WordNotEqual(TNode<IntPtrT>{phi_bb332_31}, TNode<IntPtrT>{tmp711});
    ca_.Branch(tmp712, &block334, std::vector<compiler::Node*>{phi_bb332_19, phi_bb332_25, phi_bb332_26, phi_bb332_27, phi_bb332_28, phi_bb332_31, phi_bb332_32, phi_bb332_34, phi_bb332_35, phi_bb332_36, phi_bb332_47, phi_bb332_48}, &block335, std::vector<compiler::Node*>{phi_bb332_19, phi_bb332_25, phi_bb332_26, phi_bb332_27, phi_bb332_28, phi_bb332_31, phi_bb332_32, phi_bb332_34, phi_bb332_35, phi_bb332_36, phi_bb332_47, phi_bb332_48});
  }

  TNode<IntPtrT> phi_bb334_19;
  TNode<IntPtrT> phi_bb334_25;
  TNode<IntPtrT> phi_bb334_26;
  TNode<IntPtrT> phi_bb334_27;
  TNode<IntPtrT> phi_bb334_28;
  TNode<IntPtrT> phi_bb334_31;
  TNode<BoolT> phi_bb334_32;
  TNode<IntPtrT> phi_bb334_34;
  TNode<IntPtrT> phi_bb334_35;
  TNode<BoolT> phi_bb334_36;
  TNode<BoolT> phi_bb334_47;
  TNode<JSAny> phi_bb334_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp713;
  TNode<IntPtrT> tmp714;
  TNode<IntPtrT> tmp715;
  TNode<BoolT> tmp716;
  if (block334.is_used()) {
    ca_.Bind(&block334, &phi_bb334_19, &phi_bb334_25, &phi_bb334_26, &phi_bb334_27, &phi_bb334_28, &phi_bb334_31, &phi_bb334_32, &phi_bb334_34, &phi_bb334_35, &phi_bb334_36, &phi_bb334_47, &phi_bb334_48);
    std::tie(tmp713, tmp714) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb334_31}).Flatten();
    tmp715 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp716 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block330, phi_bb334_19, phi_bb334_25, phi_bb334_26, phi_bb334_27, phi_bb334_28, tmp715, tmp716, phi_bb334_34, phi_bb334_35, phi_bb334_36, phi_bb334_47, phi_bb334_48, tmp713, tmp714);
  }

  TNode<IntPtrT> phi_bb335_19;
  TNode<IntPtrT> phi_bb335_25;
  TNode<IntPtrT> phi_bb335_26;
  TNode<IntPtrT> phi_bb335_27;
  TNode<IntPtrT> phi_bb335_28;
  TNode<IntPtrT> phi_bb335_31;
  TNode<BoolT> phi_bb335_32;
  TNode<IntPtrT> phi_bb335_34;
  TNode<IntPtrT> phi_bb335_35;
  TNode<BoolT> phi_bb335_36;
  TNode<BoolT> phi_bb335_47;
  TNode<JSAny> phi_bb335_48;
  TNode<Union<HeapObject, TaggedIndex>> tmp717;
  TNode<IntPtrT> tmp718;
  TNode<IntPtrT> tmp719;
  TNode<IntPtrT> tmp720;
  TNode<IntPtrT> tmp721;
  TNode<IntPtrT> tmp722;
  TNode<BoolT> tmp723;
  if (block335.is_used()) {
    ca_.Bind(&block335, &phi_bb335_19, &phi_bb335_25, &phi_bb335_26, &phi_bb335_27, &phi_bb335_28, &phi_bb335_31, &phi_bb335_32, &phi_bb335_34, &phi_bb335_35, &phi_bb335_36, &phi_bb335_47, &phi_bb335_48);
    std::tie(tmp717, tmp718) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb335_28}).Flatten();
    tmp719 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp720 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb335_28}, TNode<IntPtrT>{tmp719});
    tmp721 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp722 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp720}, TNode<IntPtrT>{tmp721});
    tmp723 = FromConstexpr_bool_constexpr_bool_0(state_, true);
    ca_.Goto(&block330, phi_bb335_19, phi_bb335_25, phi_bb335_26, phi_bb335_27, tmp722, tmp720, tmp723, phi_bb335_34, phi_bb335_35, phi_bb335_36, phi_bb335_47, phi_bb335_48, tmp717, tmp718);
  }

  TNode<IntPtrT> phi_bb330_19;
  TNode<IntPtrT> phi_bb330_25;
  TNode<IntPtrT> phi_bb330_26;
  TNode<IntPtrT> phi_bb330_27;
  TNode<IntPtrT> phi_bb330_28;
  TNode<IntPtrT> phi_bb330_31;
  TNode<BoolT> phi_bb330_32;
  TNode<IntPtrT> phi_bb330_34;
  TNode<IntPtrT> phi_bb330_35;
  TNode<BoolT> phi_bb330_36;
  TNode<BoolT> phi_bb330_47;
  TNode<JSAny> phi_bb330_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb330_51;
  TNode<IntPtrT> phi_bb330_52;
  if (block330.is_used()) {
    ca_.Bind(&block330, &phi_bb330_19, &phi_bb330_25, &phi_bb330_26, &phi_bb330_27, &phi_bb330_28, &phi_bb330_31, &phi_bb330_32, &phi_bb330_34, &phi_bb330_35, &phi_bb330_36, &phi_bb330_47, &phi_bb330_48, &phi_bb330_51, &phi_bb330_52);
    ca_.Goto(&block327, phi_bb330_19, phi_bb330_25, phi_bb330_26, phi_bb330_27, phi_bb330_28, phi_bb330_31, phi_bb330_32, phi_bb330_34, phi_bb330_35, phi_bb330_36, phi_bb330_47, phi_bb330_48, phi_bb330_51, phi_bb330_52);
  }

  TNode<IntPtrT> phi_bb327_19;
  TNode<IntPtrT> phi_bb327_25;
  TNode<IntPtrT> phi_bb327_26;
  TNode<IntPtrT> phi_bb327_27;
  TNode<IntPtrT> phi_bb327_28;
  TNode<IntPtrT> phi_bb327_31;
  TNode<BoolT> phi_bb327_32;
  TNode<IntPtrT> phi_bb327_34;
  TNode<IntPtrT> phi_bb327_35;
  TNode<BoolT> phi_bb327_36;
  TNode<BoolT> phi_bb327_47;
  TNode<JSAny> phi_bb327_48;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb327_51;
  TNode<IntPtrT> phi_bb327_52;
  TNode<IntPtrT> tmp724;
  if (block327.is_used()) {
    ca_.Bind(&block327, &phi_bb327_19, &phi_bb327_25, &phi_bb327_26, &phi_bb327_27, &phi_bb327_28, &phi_bb327_31, &phi_bb327_32, &phi_bb327_34, &phi_bb327_35, &phi_bb327_36, &phi_bb327_47, &phi_bb327_48, &phi_bb327_51, &phi_bb327_52);
    tmp724 = CodeStubAssembler(state_).BitcastTaggedToWord(TNode<Object>{tmp696});
    CodeStubAssembler(state_).StoreReference<IntPtrT>(CodeStubAssembler::Reference{phi_bb327_51, phi_bb327_52}, tmp724);
    ca_.Goto(&block326, phi_bb327_19, tmp700, phi_bb327_25, phi_bb327_26, phi_bb327_27, phi_bb327_28, phi_bb327_31, phi_bb327_32, phi_bb327_34, phi_bb327_35, phi_bb327_36, phi_bb327_47, phi_bb327_48);
  }

  TNode<IntPtrT> phi_bb325_19;
  TNode<IntPtrT> phi_bb325_24;
  TNode<IntPtrT> phi_bb325_25;
  TNode<IntPtrT> phi_bb325_26;
  TNode<IntPtrT> phi_bb325_27;
  TNode<IntPtrT> phi_bb325_28;
  TNode<IntPtrT> phi_bb325_31;
  TNode<BoolT> phi_bb325_32;
  TNode<IntPtrT> phi_bb325_34;
  TNode<IntPtrT> phi_bb325_35;
  TNode<BoolT> phi_bb325_36;
  TNode<BoolT> phi_bb325_47;
  TNode<JSAny> phi_bb325_48;
  TNode<BoolT> tmp725;
  TNode<Union<HeapObject, TaggedIndex>> tmp726;
  TNode<IntPtrT> tmp727;
  TNode<IntPtrT> tmp728;
  TNode<UintPtrT> tmp729;
  TNode<UintPtrT> tmp730;
  TNode<BoolT> tmp731;
  if (block325.is_used()) {
    ca_.Bind(&block325, &phi_bb325_19, &phi_bb325_24, &phi_bb325_25, &phi_bb325_26, &phi_bb325_27, &phi_bb325_28, &phi_bb325_31, &phi_bb325_32, &phi_bb325_34, &phi_bb325_35, &phi_bb325_36, &phi_bb325_47, &phi_bb325_48);
    tmp725 = FromConstexpr_bool_constexpr_bool_0(state_, true);
    std::tie(tmp726, tmp727, tmp728) = FieldSliceFixedArrayObjects_0(state_, TNode<FixedArray>{phi_bb214_40}).Flatten();
    tmp729 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{phi_bb325_19});
    tmp730 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{tmp728});
    tmp731 = CodeStubAssembler(state_).UintPtrLessThan(TNode<UintPtrT>{tmp729}, TNode<UintPtrT>{tmp730});
    ca_.Branch(tmp731, &block340, std::vector<compiler::Node*>{phi_bb325_19, phi_bb325_24, phi_bb325_25, phi_bb325_26, phi_bb325_27, phi_bb325_28, phi_bb325_31, phi_bb325_32, phi_bb325_34, phi_bb325_35, phi_bb325_36, phi_bb325_48, phi_bb325_19, phi_bb325_19, phi_bb325_19, phi_bb325_19}, &block341, std::vector<compiler::Node*>{phi_bb325_19, phi_bb325_24, phi_bb325_25, phi_bb325_26, phi_bb325_27, phi_bb325_28, phi_bb325_31, phi_bb325_32, phi_bb325_34, phi_bb325_35, phi_bb325_36, phi_bb325_48, phi_bb325_19, phi_bb325_19, phi_bb325_19, phi_bb325_19});
  }

  TNode<IntPtrT> phi_bb340_19;
  TNode<IntPtrT> phi_bb340_24;
  TNode<IntPtrT> phi_bb340_25;
  TNode<IntPtrT> phi_bb340_26;
  TNode<IntPtrT> phi_bb340_27;
  TNode<IntPtrT> phi_bb340_28;
  TNode<IntPtrT> phi_bb340_31;
  TNode<BoolT> phi_bb340_32;
  TNode<IntPtrT> phi_bb340_34;
  TNode<IntPtrT> phi_bb340_35;
  TNode<BoolT> phi_bb340_36;
  TNode<JSAny> phi_bb340_48;
  TNode<IntPtrT> phi_bb340_55;
  TNode<IntPtrT> phi_bb340_56;
  TNode<IntPtrT> phi_bb340_60;
  TNode<IntPtrT> phi_bb340_61;
  TNode<IntPtrT> tmp732;
  TNode<IntPtrT> tmp733;
  TNode<Union<HeapObject, TaggedIndex>> tmp734;
  TNode<IntPtrT> tmp735;
  if (block340.is_used()) {
    ca_.Bind(&block340, &phi_bb340_19, &phi_bb340_24, &phi_bb340_25, &phi_bb340_26, &phi_bb340_27, &phi_bb340_28, &phi_bb340_31, &phi_bb340_32, &phi_bb340_34, &phi_bb340_35, &phi_bb340_36, &phi_bb340_48, &phi_bb340_55, &phi_bb340_56, &phi_bb340_60, &phi_bb340_61);
    tmp732 = TimesSizeOf_Object_0(state_, TNode<IntPtrT>{phi_bb340_61});
    tmp733 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp727}, TNode<IntPtrT>{tmp732});
    std::tie(tmp734, tmp735) = NewReference_Object_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp726}, TNode<IntPtrT>{tmp733}).Flatten();
    CodeStubAssembler(state_).StoreReference<Object>(CodeStubAssembler::Reference{tmp734, tmp735}, tmp696);
    ca_.Goto(&block326, phi_bb340_19, phi_bb340_24, phi_bb340_25, phi_bb340_26, phi_bb340_27, phi_bb340_28, phi_bb340_31, phi_bb340_32, phi_bb340_34, phi_bb340_35, phi_bb340_36, tmp725, phi_bb340_48);
  }

  TNode<IntPtrT> phi_bb341_19;
  TNode<IntPtrT> phi_bb341_24;
  TNode<IntPtrT> phi_bb341_25;
  TNode<IntPtrT> phi_bb341_26;
  TNode<IntPtrT> phi_bb341_27;
  TNode<IntPtrT> phi_bb341_28;
  TNode<IntPtrT> phi_bb341_31;
  TNode<BoolT> phi_bb341_32;
  TNode<IntPtrT> phi_bb341_34;
  TNode<IntPtrT> phi_bb341_35;
  TNode<BoolT> phi_bb341_36;
  TNode<JSAny> phi_bb341_48;
  TNode<IntPtrT> phi_bb341_55;
  TNode<IntPtrT> phi_bb341_56;
  TNode<IntPtrT> phi_bb341_60;
  TNode<IntPtrT> phi_bb341_61;
  if (block341.is_used()) {
    ca_.Bind(&block341, &phi_bb341_19, &phi_bb341_24, &phi_bb341_25, &phi_bb341_26, &phi_bb341_27, &phi_bb341_28, &phi_bb341_31, &phi_bb341_32, &phi_bb341_34, &phi_bb341_35, &phi_bb341_36, &phi_bb341_48, &phi_bb341_55, &phi_bb341_56, &phi_bb341_60, &phi_bb341_61);
    CodeStubAssembler(state_).Unreachable();
  }

  TNode<IntPtrT> phi_bb326_19;
  TNode<IntPtrT> phi_bb326_24;
  TNode<IntPtrT> phi_bb326_25;
  TNode<IntPtrT> phi_bb326_26;
  TNode<IntPtrT> phi_bb326_27;
  TNode<IntPtrT> phi_bb326_28;
  TNode<IntPtrT> phi_bb326_31;
  TNode<BoolT> phi_bb326_32;
  TNode<IntPtrT> phi_bb326_34;
  TNode<IntPtrT> phi_bb326_35;
  TNode<BoolT> phi_bb326_36;
  TNode<BoolT> phi_bb326_47;
  TNode<JSAny> phi_bb326_48;
  if (block326.is_used()) {
    ca_.Bind(&block326, &phi_bb326_19, &phi_bb326_24, &phi_bb326_25, &phi_bb326_26, &phi_bb326_27, &phi_bb326_28, &phi_bb326_31, &phi_bb326_32, &phi_bb326_34, &phi_bb326_35, &phi_bb326_36, &phi_bb326_47, &phi_bb326_48);
    ca_.Goto(&block291, phi_bb326_19, phi_bb326_24, phi_bb326_25, phi_bb326_26, phi_bb326_27, phi_bb326_28, phi_bb326_31, phi_bb326_32, phi_bb326_34, phi_bb326_35, phi_bb326_36, phi_bb326_47, phi_bb326_48);
  }

  TNode<IntPtrT> phi_bb291_19;
  TNode<IntPtrT> phi_bb291_24;
  TNode<IntPtrT> phi_bb291_25;
  TNode<IntPtrT> phi_bb291_26;
  TNode<IntPtrT> phi_bb291_27;
  TNode<IntPtrT> phi_bb291_28;
  TNode<IntPtrT> phi_bb291_31;
  TNode<BoolT> phi_bb291_32;
  TNode<IntPtrT> phi_bb291_34;
  TNode<IntPtrT> phi_bb291_35;
  TNode<BoolT> phi_bb291_36;
  TNode<BoolT> phi_bb291_47;
  TNode<JSAny> phi_bb291_48;
  if (block291.is_used()) {
    ca_.Bind(&block291, &phi_bb291_19, &phi_bb291_24, &phi_bb291_25, &phi_bb291_26, &phi_bb291_27, &phi_bb291_28, &phi_bb291_31, &phi_bb291_32, &phi_bb291_34, &phi_bb291_35, &phi_bb291_36, &phi_bb291_47, &phi_bb291_48);
    ca_.Goto(&block276, phi_bb291_19, phi_bb291_24, phi_bb291_25, phi_bb291_26, phi_bb291_27, phi_bb291_28, phi_bb291_31, phi_bb291_32, phi_bb291_34, phi_bb291_35, phi_bb291_36, phi_bb291_47, phi_bb291_48);
  }

  TNode<IntPtrT> phi_bb276_19;
  TNode<IntPtrT> phi_bb276_24;
  TNode<IntPtrT> phi_bb276_25;
  TNode<IntPtrT> phi_bb276_26;
  TNode<IntPtrT> phi_bb276_27;
  TNode<IntPtrT> phi_bb276_28;
  TNode<IntPtrT> phi_bb276_31;
  TNode<BoolT> phi_bb276_32;
  TNode<IntPtrT> phi_bb276_34;
  TNode<IntPtrT> phi_bb276_35;
  TNode<BoolT> phi_bb276_36;
  TNode<BoolT> phi_bb276_47;
  TNode<JSAny> phi_bb276_48;
  if (block276.is_used()) {
    ca_.Bind(&block276, &phi_bb276_19, &phi_bb276_24, &phi_bb276_25, &phi_bb276_26, &phi_bb276_27, &phi_bb276_28, &phi_bb276_31, &phi_bb276_32, &phi_bb276_34, &phi_bb276_35, &phi_bb276_36, &phi_bb276_47, &phi_bb276_48);
    ca_.Goto(&block261, phi_bb276_19, phi_bb276_24, phi_bb276_25, phi_bb276_26, phi_bb276_27, phi_bb276_28, phi_bb276_31, phi_bb276_32, phi_bb276_34, phi_bb276_35, phi_bb276_36, phi_bb276_47, phi_bb276_48);
  }

  TNode<IntPtrT> phi_bb261_19;
  TNode<IntPtrT> phi_bb261_24;
  TNode<IntPtrT> phi_bb261_25;
  TNode<IntPtrT> phi_bb261_26;
  TNode<IntPtrT> phi_bb261_27;
  TNode<IntPtrT> phi_bb261_28;
  TNode<IntPtrT> phi_bb261_31;
  TNode<BoolT> phi_bb261_32;
  TNode<IntPtrT> phi_bb261_34;
  TNode<IntPtrT> phi_bb261_35;
  TNode<BoolT> phi_bb261_36;
  TNode<BoolT> phi_bb261_47;
  TNode<JSAny> phi_bb261_48;
  if (block261.is_used()) {
    ca_.Bind(&block261, &phi_bb261_19, &phi_bb261_24, &phi_bb261_25, &phi_bb261_26, &phi_bb261_27, &phi_bb261_28, &phi_bb261_31, &phi_bb261_32, &phi_bb261_34, &phi_bb261_35, &phi_bb261_36, &phi_bb261_47, &phi_bb261_48);
    ca_.Goto(&block245, phi_bb261_19, phi_bb261_24, phi_bb261_25, phi_bb261_26, phi_bb261_27, phi_bb261_28, phi_bb261_31, phi_bb261_32, phi_bb261_34, phi_bb261_35, phi_bb261_36, phi_bb261_47, phi_bb261_48);
  }

  TNode<IntPtrT> phi_bb245_19;
  TNode<IntPtrT> phi_bb245_24;
  TNode<IntPtrT> phi_bb245_25;
  TNode<IntPtrT> phi_bb245_26;
  TNode<IntPtrT> phi_bb245_27;
  TNode<IntPtrT> phi_bb245_28;
  TNode<IntPtrT> phi_bb245_31;
  TNode<BoolT> phi_bb245_32;
  TNode<IntPtrT> phi_bb245_34;
  TNode<IntPtrT> phi_bb245_35;
  TNode<BoolT> phi_bb245_36;
  TNode<BoolT> phi_bb245_47;
  TNode<JSAny> phi_bb245_48;
  TNode<IntPtrT> tmp736;
  TNode<IntPtrT> tmp737;
  if (block245.is_used()) {
    ca_.Bind(&block245, &phi_bb245_19, &phi_bb245_24, &phi_bb245_25, &phi_bb245_26, &phi_bb245_27, &phi_bb245_28, &phi_bb245_31, &phi_bb245_32, &phi_bb245_34, &phi_bb245_35, &phi_bb245_36, &phi_bb245_47, &phi_bb245_48);
    tmp736 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp737 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb245_19}, TNode<IntPtrT>{tmp736});
    ca_.Goto(&block223, tmp737, phi_bb245_24, phi_bb245_25, phi_bb245_26, phi_bb245_27, phi_bb245_28, phi_bb245_31, phi_bb245_32, phi_bb245_34, phi_bb245_35, phi_bb245_36, tmp506, phi_bb245_47);
  }

  TNode<IntPtrT> phi_bb222_19;
  TNode<IntPtrT> phi_bb222_24;
  TNode<IntPtrT> phi_bb222_25;
  TNode<IntPtrT> phi_bb222_26;
  TNode<IntPtrT> phi_bb222_27;
  TNode<IntPtrT> phi_bb222_28;
  TNode<IntPtrT> phi_bb222_31;
  TNode<BoolT> phi_bb222_32;
  TNode<IntPtrT> phi_bb222_34;
  TNode<IntPtrT> phi_bb222_35;
  TNode<BoolT> phi_bb222_36;
  TNode<IntPtrT> phi_bb222_45;
  TNode<BoolT> phi_bb222_47;
  if (block222.is_used()) {
    ca_.Bind(&block222, &phi_bb222_19, &phi_bb222_24, &phi_bb222_25, &phi_bb222_26, &phi_bb222_27, &phi_bb222_28, &phi_bb222_31, &phi_bb222_32, &phi_bb222_34, &phi_bb222_35, &phi_bb222_36, &phi_bb222_45, &phi_bb222_47);
    ca_.Branch(phi_bb222_47, &block344, std::vector<compiler::Node*>{phi_bb222_19, phi_bb222_24, phi_bb222_25, phi_bb222_26, phi_bb222_27, phi_bb222_28, phi_bb222_31, phi_bb222_32, phi_bb222_34, phi_bb222_35, phi_bb222_36, phi_bb222_45, phi_bb222_47}, &block345, std::vector<compiler::Node*>{phi_bb222_19, phi_bb222_24, phi_bb222_25, phi_bb222_26, phi_bb222_27, phi_bb222_28, phi_bb222_31, phi_bb222_32, phi_bb222_34, phi_bb222_35, phi_bb222_36, phi_bb222_45, tmp484, phi_bb222_47});
  }

  TNode<IntPtrT> phi_bb344_19;
  TNode<IntPtrT> phi_bb344_24;
  TNode<IntPtrT> phi_bb344_25;
  TNode<IntPtrT> phi_bb344_26;
  TNode<IntPtrT> phi_bb344_27;
  TNode<IntPtrT> phi_bb344_28;
  TNode<IntPtrT> phi_bb344_31;
  TNode<BoolT> phi_bb344_32;
  TNode<IntPtrT> phi_bb344_34;
  TNode<IntPtrT> phi_bb344_35;
  TNode<BoolT> phi_bb344_36;
  TNode<IntPtrT> phi_bb344_45;
  TNode<BoolT> phi_bb344_47;
  TNode<BoolT> tmp738;
  if (block344.is_used()) {
    ca_.Bind(&block344, &phi_bb344_19, &phi_bb344_24, &phi_bb344_25, &phi_bb344_26, &phi_bb344_27, &phi_bb344_28, &phi_bb344_31, &phi_bb344_32, &phi_bb344_34, &phi_bb344_35, &phi_bb344_36, &phi_bb344_45, &phi_bb344_47);
    tmp738 = CodeStubAssembler(state_).Word32BinaryNot(TNode<BoolT>{phi_bb344_32});
    ca_.Branch(tmp738, &block347, std::vector<compiler::Node*>{phi_bb344_19, phi_bb344_24, phi_bb344_25, phi_bb344_26, phi_bb344_27, phi_bb344_28, phi_bb344_31, phi_bb344_32, phi_bb344_34, phi_bb344_35, phi_bb344_36, phi_bb344_45, phi_bb344_47}, &block348, std::vector<compiler::Node*>{phi_bb344_19, phi_bb344_24, phi_bb344_25, phi_bb344_26, phi_bb344_27, phi_bb344_28, phi_bb344_31, phi_bb344_32, phi_bb344_34, phi_bb344_35, phi_bb344_36, phi_bb344_45, phi_bb344_47});
  }

  TNode<IntPtrT> phi_bb347_19;
  TNode<IntPtrT> phi_bb347_24;
  TNode<IntPtrT> phi_bb347_25;
  TNode<IntPtrT> phi_bb347_26;
  TNode<IntPtrT> phi_bb347_27;
  TNode<IntPtrT> phi_bb347_28;
  TNode<IntPtrT> phi_bb347_31;
  TNode<BoolT> phi_bb347_32;
  TNode<IntPtrT> phi_bb347_34;
  TNode<IntPtrT> phi_bb347_35;
  TNode<BoolT> phi_bb347_36;
  TNode<IntPtrT> phi_bb347_45;
  TNode<BoolT> phi_bb347_47;
  TNode<IntPtrT> tmp739;
  if (block347.is_used()) {
    ca_.Bind(&block347, &phi_bb347_19, &phi_bb347_24, &phi_bb347_25, &phi_bb347_26, &phi_bb347_27, &phi_bb347_28, &phi_bb347_31, &phi_bb347_32, &phi_bb347_34, &phi_bb347_35, &phi_bb347_36, &phi_bb347_45, &phi_bb347_47);
    tmp739 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    ca_.Goto(&block348, phi_bb347_19, phi_bb347_24, phi_bb347_25, phi_bb347_26, phi_bb347_27, phi_bb347_28, tmp739, phi_bb347_32, phi_bb347_34, phi_bb347_35, phi_bb347_36, phi_bb347_45, phi_bb347_47);
  }

  TNode<IntPtrT> phi_bb348_19;
  TNode<IntPtrT> phi_bb348_24;
  TNode<IntPtrT> phi_bb348_25;
  TNode<IntPtrT> phi_bb348_26;
  TNode<IntPtrT> phi_bb348_27;
  TNode<IntPtrT> phi_bb348_28;
  TNode<IntPtrT> phi_bb348_31;
  TNode<BoolT> phi_bb348_32;
  TNode<IntPtrT> phi_bb348_34;
  TNode<IntPtrT> phi_bb348_35;
  TNode<BoolT> phi_bb348_36;
  TNode<IntPtrT> phi_bb348_45;
  TNode<BoolT> phi_bb348_47;
  TNode<IntPtrT> tmp740;
  TNode<IntPtrT> tmp741;
  TNode<IntPtrT> tmp742;
  if (block348.is_used()) {
    ca_.Bind(&block348, &phi_bb348_19, &phi_bb348_24, &phi_bb348_25, &phi_bb348_26, &phi_bb348_27, &phi_bb348_28, &phi_bb348_31, &phi_bb348_32, &phi_bb348_34, &phi_bb348_35, &phi_bb348_36, &phi_bb348_45, &phi_bb348_47);
    tmp740 = TimesSizeOf_WasmCodePointer_0(state_, TNode<IntPtrT>{tmp55});
    tmp741 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp54}, TNode<IntPtrT>{tmp740});
    tmp742 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    ca_.Goto(&block352, tmp742, phi_bb348_24, phi_bb348_25, phi_bb348_26, phi_bb348_27, phi_bb348_28, phi_bb348_31, phi_bb348_32, phi_bb348_34, phi_bb348_35, phi_bb348_36, tmp54, phi_bb348_47);
  }

  TNode<IntPtrT> phi_bb352_19;
  TNode<IntPtrT> phi_bb352_24;
  TNode<IntPtrT> phi_bb352_25;
  TNode<IntPtrT> phi_bb352_26;
  TNode<IntPtrT> phi_bb352_27;
  TNode<IntPtrT> phi_bb352_28;
  TNode<IntPtrT> phi_bb352_31;
  TNode<BoolT> phi_bb352_32;
  TNode<IntPtrT> phi_bb352_34;
  TNode<IntPtrT> phi_bb352_35;
  TNode<BoolT> phi_bb352_36;
  TNode<IntPtrT> phi_bb352_45;
  TNode<BoolT> phi_bb352_47;
  TNode<BoolT> tmp743;
  TNode<BoolT> tmp744;
  if (block352.is_used()) {
    ca_.Bind(&block352, &phi_bb352_19, &phi_bb352_24, &phi_bb352_25, &phi_bb352_26, &phi_bb352_27, &phi_bb352_28, &phi_bb352_31, &phi_bb352_32, &phi_bb352_34, &phi_bb352_35, &phi_bb352_36, &phi_bb352_45, &phi_bb352_47);
    tmp743 = CodeStubAssembler(state_).WordEqual(TNode<IntPtrT>{phi_bb352_45}, TNode<IntPtrT>{tmp741});
    tmp744 = CodeStubAssembler(state_).Word32BinaryNot(TNode<BoolT>{tmp743});
    ca_.Branch(tmp744, &block350, std::vector<compiler::Node*>{phi_bb352_19, phi_bb352_24, phi_bb352_25, phi_bb352_26, phi_bb352_27, phi_bb352_28, phi_bb352_31, phi_bb352_32, phi_bb352_34, phi_bb352_35, phi_bb352_36, phi_bb352_45, phi_bb352_47}, &block351, std::vector<compiler::Node*>{phi_bb352_19, phi_bb352_24, phi_bb352_25, phi_bb352_26, phi_bb352_27, phi_bb352_28, phi_bb352_31, phi_bb352_32, phi_bb352_34, phi_bb352_35, phi_bb352_36, phi_bb352_45, phi_bb352_47});
  }

  TNode<IntPtrT> phi_bb350_19;
  TNode<IntPtrT> phi_bb350_24;
  TNode<IntPtrT> phi_bb350_25;
  TNode<IntPtrT> phi_bb350_26;
  TNode<IntPtrT> phi_bb350_27;
  TNode<IntPtrT> phi_bb350_28;
  TNode<IntPtrT> phi_bb350_31;
  TNode<BoolT> phi_bb350_32;
  TNode<IntPtrT> phi_bb350_34;
  TNode<IntPtrT> phi_bb350_35;
  TNode<BoolT> phi_bb350_36;
  TNode<IntPtrT> phi_bb350_45;
  TNode<BoolT> phi_bb350_47;
  TNode<Union<HeapObject, TaggedIndex>> tmp745;
  TNode<IntPtrT> tmp746;
  TNode<IntPtrT> tmp747;
  TNode<IntPtrT> tmp748;
  TNode<Uint32T> tmp749;
  TNode<Uint32T> tmp750;
  TNode<Uint32T> tmp751;
  TNode<Uint32T> tmp752;
  TNode<BoolT> tmp753;
  if (block350.is_used()) {
    ca_.Bind(&block350, &phi_bb350_19, &phi_bb350_24, &phi_bb350_25, &phi_bb350_26, &phi_bb350_27, &phi_bb350_28, &phi_bb350_31, &phi_bb350_32, &phi_bb350_34, &phi_bb350_35, &phi_bb350_36, &phi_bb350_45, &phi_bb350_47);
    std::tie(tmp745, tmp746) = NewReference_WasmCodePointer_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp53}, TNode<IntPtrT>{phi_bb350_45}).Flatten();
    tmp747 = FromConstexpr_intptr_constexpr_int31_0(state_, kInt32Size);
    tmp748 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb350_45}, TNode<IntPtrT>{tmp747});
    tmp749 = CodeStubAssembler(state_).LoadReference<Uint32T>(CodeStubAssembler::Reference{tmp745, tmp746});
    tmp750 = FromConstexpr_WasmCodePointer_constexpr_WasmCodePointer_0(state_, wasm::ValueType::kIsRefBit);
    tmp751 = CodeStubAssembler(state_).Word32And(TNode<Uint32T>{tmp749}, TNode<Uint32T>{tmp750});
    tmp752 = FromConstexpr_WasmCodePointer_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp753 = CodeStubAssembler(state_).Word32NotEqual(TNode<Uint32T>{tmp751}, TNode<Uint32T>{tmp752});
    ca_.Branch(tmp753, &block361, std::vector<compiler::Node*>{phi_bb350_19, phi_bb350_24, phi_bb350_25, phi_bb350_26, phi_bb350_27, phi_bb350_28, phi_bb350_31, phi_bb350_32, phi_bb350_34, phi_bb350_35, phi_bb350_36, phi_bb350_47}, &block362, std::vector<compiler::Node*>{phi_bb350_19, phi_bb350_24, phi_bb350_25, phi_bb350_26, phi_bb350_27, phi_bb350_28, phi_bb350_31, phi_bb350_32, phi_bb350_34, phi_bb350_35, phi_bb350_36, phi_bb350_47});
  }

  TNode<IntPtrT> phi_bb361_19;
  TNode<IntPtrT> phi_bb361_24;
  TNode<IntPtrT> phi_bb361_25;
  TNode<IntPtrT> phi_bb361_26;
  TNode<IntPtrT> phi_bb361_27;
  TNode<IntPtrT> phi_bb361_28;
  TNode<IntPtrT> phi_bb361_31;
  TNode<BoolT> phi_bb361_32;
  TNode<IntPtrT> phi_bb361_34;
  TNode<IntPtrT> phi_bb361_35;
  TNode<BoolT> phi_bb361_36;
  TNode<BoolT> phi_bb361_47;
  TNode<IntPtrT> tmp754;
  TNode<IntPtrT> tmp755;
  TNode<IntPtrT> tmp756;
  TNode<BoolT> tmp757;
  if (block361.is_used()) {
    ca_.Bind(&block361, &phi_bb361_19, &phi_bb361_24, &phi_bb361_25, &phi_bb361_26, &phi_bb361_27, &phi_bb361_28, &phi_bb361_31, &phi_bb361_32, &phi_bb361_34, &phi_bb361_35, &phi_bb361_36, &phi_bb361_47);
    tmp754 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp755 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{phi_bb361_24}, TNode<IntPtrT>{tmp754});
    tmp756 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp757 = CodeStubAssembler(state_).IntPtrGreaterThan(TNode<IntPtrT>{phi_bb361_24}, TNode<IntPtrT>{tmp756});
    ca_.Branch(tmp757, &block364, std::vector<compiler::Node*>{phi_bb361_19, phi_bb361_25, phi_bb361_26, phi_bb361_27, phi_bb361_28, phi_bb361_31, phi_bb361_32, phi_bb361_34, phi_bb361_35, phi_bb361_36, phi_bb361_47}, &block365, std::vector<compiler::Node*>{phi_bb361_19, phi_bb361_25, phi_bb361_26, phi_bb361_27, phi_bb361_28, phi_bb361_31, phi_bb361_32, phi_bb361_34, phi_bb361_35, phi_bb361_36, phi_bb361_47});
  }

  TNode<IntPtrT> phi_bb364_19;
  TNode<IntPtrT> phi_bb364_25;
  TNode<IntPtrT> phi_bb364_26;
  TNode<IntPtrT> phi_bb364_27;
  TNode<IntPtrT> phi_bb364_28;
  TNode<IntPtrT> phi_bb364_31;
  TNode<BoolT> phi_bb364_32;
  TNode<IntPtrT> phi_bb364_34;
  TNode<IntPtrT> phi_bb364_35;
  TNode<BoolT> phi_bb364_36;
  TNode<BoolT> phi_bb364_47;
  TNode<Union<HeapObject, TaggedIndex>> tmp758;
  TNode<IntPtrT> tmp759;
  TNode<IntPtrT> tmp760;
  TNode<IntPtrT> tmp761;
  if (block364.is_used()) {
    ca_.Bind(&block364, &phi_bb364_19, &phi_bb364_25, &phi_bb364_26, &phi_bb364_27, &phi_bb364_28, &phi_bb364_31, &phi_bb364_32, &phi_bb364_34, &phi_bb364_35, &phi_bb364_36, &phi_bb364_47);
    std::tie(tmp758, tmp759) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb364_26}).Flatten();
    tmp760 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp761 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb364_26}, TNode<IntPtrT>{tmp760});
    ca_.Goto(&block363, phi_bb364_19, phi_bb364_25, tmp761, phi_bb364_27, phi_bb364_28, phi_bb364_31, phi_bb364_32, phi_bb364_34, phi_bb364_35, phi_bb364_36, phi_bb364_47, tmp758, tmp759);
  }

  TNode<IntPtrT> phi_bb365_19;
  TNode<IntPtrT> phi_bb365_25;
  TNode<IntPtrT> phi_bb365_26;
  TNode<IntPtrT> phi_bb365_27;
  TNode<IntPtrT> phi_bb365_28;
  TNode<IntPtrT> phi_bb365_31;
  TNode<BoolT> phi_bb365_32;
  TNode<IntPtrT> phi_bb365_34;
  TNode<IntPtrT> phi_bb365_35;
  TNode<BoolT> phi_bb365_36;
  TNode<BoolT> phi_bb365_47;
  if (block365.is_used()) {
    ca_.Bind(&block365, &phi_bb365_19, &phi_bb365_25, &phi_bb365_26, &phi_bb365_27, &phi_bb365_28, &phi_bb365_31, &phi_bb365_32, &phi_bb365_34, &phi_bb365_35, &phi_bb365_36, &phi_bb365_47);
    if (((CodeStubAssembler(state_).Is64()))) {
      ca_.Goto(&block367, phi_bb365_19, phi_bb365_25, phi_bb365_26, phi_bb365_27, phi_bb365_28, phi_bb365_31, phi_bb365_32, phi_bb365_34, phi_bb365_35, phi_bb365_36, phi_bb365_47);
    } else {
      ca_.Goto(&block368, phi_bb365_19, phi_bb365_25, phi_bb365_26, phi_bb365_27, phi_bb365_28, phi_bb365_31, phi_bb365_32, phi_bb365_34, phi_bb365_35, phi_bb365_36, phi_bb365_47);
    }
  }

  TNode<IntPtrT> phi_bb367_19;
  TNode<IntPtrT> phi_bb367_25;
  TNode<IntPtrT> phi_bb367_26;
  TNode<IntPtrT> phi_bb367_27;
  TNode<IntPtrT> phi_bb367_28;
  TNode<IntPtrT> phi_bb367_31;
  TNode<BoolT> phi_bb367_32;
  TNode<IntPtrT> phi_bb367_34;
  TNode<IntPtrT> phi_bb367_35;
  TNode<BoolT> phi_bb367_36;
  TNode<BoolT> phi_bb367_47;
  TNode<Union<HeapObject, TaggedIndex>> tmp762;
  TNode<IntPtrT> tmp763;
  TNode<IntPtrT> tmp764;
  TNode<IntPtrT> tmp765;
  if (block367.is_used()) {
    ca_.Bind(&block367, &phi_bb367_19, &phi_bb367_25, &phi_bb367_26, &phi_bb367_27, &phi_bb367_28, &phi_bb367_31, &phi_bb367_32, &phi_bb367_34, &phi_bb367_35, &phi_bb367_36, &phi_bb367_47);
    std::tie(tmp762, tmp763) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb367_28}).Flatten();
    tmp764 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp765 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb367_28}, TNode<IntPtrT>{tmp764});
    ca_.Goto(&block366, phi_bb367_19, phi_bb367_25, phi_bb367_26, phi_bb367_27, tmp765, phi_bb367_31, phi_bb367_32, phi_bb367_34, phi_bb367_35, phi_bb367_36, phi_bb367_47, tmp762, tmp763);
  }

  TNode<IntPtrT> phi_bb368_19;
  TNode<IntPtrT> phi_bb368_25;
  TNode<IntPtrT> phi_bb368_26;
  TNode<IntPtrT> phi_bb368_27;
  TNode<IntPtrT> phi_bb368_28;
  TNode<IntPtrT> phi_bb368_31;
  TNode<BoolT> phi_bb368_32;
  TNode<IntPtrT> phi_bb368_34;
  TNode<IntPtrT> phi_bb368_35;
  TNode<BoolT> phi_bb368_36;
  TNode<BoolT> phi_bb368_47;
  TNode<IntPtrT> tmp766;
  TNode<BoolT> tmp767;
  if (block368.is_used()) {
    ca_.Bind(&block368, &phi_bb368_19, &phi_bb368_25, &phi_bb368_26, &phi_bb368_27, &phi_bb368_28, &phi_bb368_31, &phi_bb368_32, &phi_bb368_34, &phi_bb368_35, &phi_bb368_36, &phi_bb368_47);
    tmp766 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp767 = CodeStubAssembler(state_).WordNotEqual(TNode<IntPtrT>{phi_bb368_31}, TNode<IntPtrT>{tmp766});
    ca_.Branch(tmp767, &block370, std::vector<compiler::Node*>{phi_bb368_19, phi_bb368_25, phi_bb368_26, phi_bb368_27, phi_bb368_28, phi_bb368_31, phi_bb368_32, phi_bb368_34, phi_bb368_35, phi_bb368_36, phi_bb368_47}, &block371, std::vector<compiler::Node*>{phi_bb368_19, phi_bb368_25, phi_bb368_26, phi_bb368_27, phi_bb368_28, phi_bb368_31, phi_bb368_32, phi_bb368_34, phi_bb368_35, phi_bb368_36, phi_bb368_47});
  }

  TNode<IntPtrT> phi_bb370_19;
  TNode<IntPtrT> phi_bb370_25;
  TNode<IntPtrT> phi_bb370_26;
  TNode<IntPtrT> phi_bb370_27;
  TNode<IntPtrT> phi_bb370_28;
  TNode<IntPtrT> phi_bb370_31;
  TNode<BoolT> phi_bb370_32;
  TNode<IntPtrT> phi_bb370_34;
  TNode<IntPtrT> phi_bb370_35;
  TNode<BoolT> phi_bb370_36;
  TNode<BoolT> phi_bb370_47;
  TNode<Union<HeapObject, TaggedIndex>> tmp768;
  TNode<IntPtrT> tmp769;
  TNode<IntPtrT> tmp770;
  TNode<BoolT> tmp771;
  if (block370.is_used()) {
    ca_.Bind(&block370, &phi_bb370_19, &phi_bb370_25, &phi_bb370_26, &phi_bb370_27, &phi_bb370_28, &phi_bb370_31, &phi_bb370_32, &phi_bb370_34, &phi_bb370_35, &phi_bb370_36, &phi_bb370_47);
    std::tie(tmp768, tmp769) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb370_31}).Flatten();
    tmp770 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    tmp771 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block366, phi_bb370_19, phi_bb370_25, phi_bb370_26, phi_bb370_27, phi_bb370_28, tmp770, tmp771, phi_bb370_34, phi_bb370_35, phi_bb370_36, phi_bb370_47, tmp768, tmp769);
  }

  TNode<IntPtrT> phi_bb371_19;
  TNode<IntPtrT> phi_bb371_25;
  TNode<IntPtrT> phi_bb371_26;
  TNode<IntPtrT> phi_bb371_27;
  TNode<IntPtrT> phi_bb371_28;
  TNode<IntPtrT> phi_bb371_31;
  TNode<BoolT> phi_bb371_32;
  TNode<IntPtrT> phi_bb371_34;
  TNode<IntPtrT> phi_bb371_35;
  TNode<BoolT> phi_bb371_36;
  TNode<BoolT> phi_bb371_47;
  TNode<Union<HeapObject, TaggedIndex>> tmp772;
  TNode<IntPtrT> tmp773;
  TNode<IntPtrT> tmp774;
  TNode<IntPtrT> tmp775;
  TNode<IntPtrT> tmp776;
  TNode<IntPtrT> tmp777;
  TNode<BoolT> tmp778;
  if (block371.is_used()) {
    ca_.Bind(&block371, &phi_bb371_19, &phi_bb371_25, &phi_bb371_26, &phi_bb371_27, &phi_bb371_28, &phi_bb371_31, &phi_bb371_32, &phi_bb371_34, &phi_bb371_35, &phi_bb371_36, &phi_bb371_47);
    std::tie(tmp772, tmp773) = NewReference_intptr_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp473}, TNode<IntPtrT>{phi_bb371_28}).Flatten();
    tmp774 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp775 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb371_28}, TNode<IntPtrT>{tmp774});
    tmp776 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp777 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp775}, TNode<IntPtrT>{tmp776});
    tmp778 = FromConstexpr_bool_constexpr_bool_0(state_, true);
    ca_.Goto(&block366, phi_bb371_19, phi_bb371_25, phi_bb371_26, phi_bb371_27, tmp777, tmp775, tmp778, phi_bb371_34, phi_bb371_35, phi_bb371_36, phi_bb371_47, tmp772, tmp773);
  }

  TNode<IntPtrT> phi_bb366_19;
  TNode<IntPtrT> phi_bb366_25;
  TNode<IntPtrT> phi_bb366_26;
  TNode<IntPtrT> phi_bb366_27;
  TNode<IntPtrT> phi_bb366_28;
  TNode<IntPtrT> phi_bb366_31;
  TNode<BoolT> phi_bb366_32;
  TNode<IntPtrT> phi_bb366_34;
  TNode<IntPtrT> phi_bb366_35;
  TNode<BoolT> phi_bb366_36;
  TNode<BoolT> phi_bb366_47;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb366_49;
  TNode<IntPtrT> phi_bb366_50;
  if (block366.is_used()) {
    ca_.Bind(&block366, &phi_bb366_19, &phi_bb366_25, &phi_bb366_26, &phi_bb366_27, &phi_bb366_28, &phi_bb366_31, &phi_bb366_32, &phi_bb366_34, &phi_bb366_35, &phi_bb366_36, &phi_bb366_47, &phi_bb366_49, &phi_bb366_50);
    ca_.Goto(&block363, phi_bb366_19, phi_bb366_25, phi_bb366_26, phi_bb366_27, phi_bb366_28, phi_bb366_31, phi_bb366_32, phi_bb366_34, phi_bb366_35, phi_bb366_36, phi_bb366_47, phi_bb366_49, phi_bb366_50);
  }

  TNode<IntPtrT> phi_bb363_19;
  TNode<IntPtrT> phi_bb363_25;
  TNode<IntPtrT> phi_bb363_26;
  TNode<IntPtrT> phi_bb363_27;
  TNode<IntPtrT> phi_bb363_28;
  TNode<IntPtrT> phi_bb363_31;
  TNode<BoolT> phi_bb363_32;
  TNode<IntPtrT> phi_bb363_34;
  TNode<IntPtrT> phi_bb363_35;
  TNode<BoolT> phi_bb363_36;
  TNode<BoolT> phi_bb363_47;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb363_49;
  TNode<IntPtrT> phi_bb363_50;
  TNode<Union<HeapObject, TaggedIndex>> tmp779;
  TNode<IntPtrT> tmp780;
  TNode<IntPtrT> tmp781;
  TNode<UintPtrT> tmp782;
  TNode<UintPtrT> tmp783;
  TNode<BoolT> tmp784;
  if (block363.is_used()) {
    ca_.Bind(&block363, &phi_bb363_19, &phi_bb363_25, &phi_bb363_26, &phi_bb363_27, &phi_bb363_28, &phi_bb363_31, &phi_bb363_32, &phi_bb363_34, &phi_bb363_35, &phi_bb363_36, &phi_bb363_47, &phi_bb363_49, &phi_bb363_50);
    std::tie(tmp779, tmp780, tmp781) = FieldSliceFixedArrayObjects_0(state_, TNode<FixedArray>{phi_bb214_40}).Flatten();
    tmp782 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{phi_bb363_19});
    tmp783 = Convert_uintptr_intptr_0(state_, TNode<IntPtrT>{tmp781});
    tmp784 = CodeStubAssembler(state_).UintPtrLessThan(TNode<UintPtrT>{tmp782}, TNode<UintPtrT>{tmp783});
    ca_.Branch(tmp784, &block376, std::vector<compiler::Node*>{phi_bb363_19, phi_bb363_25, phi_bb363_26, phi_bb363_27, phi_bb363_28, phi_bb363_31, phi_bb363_32, phi_bb363_34, phi_bb363_35, phi_bb363_36, phi_bb363_47, phi_bb363_49, phi_bb363_50, phi_bb363_19, phi_bb363_19, phi_bb363_19, phi_bb363_19}, &block377, std::vector<compiler::Node*>{phi_bb363_19, phi_bb363_25, phi_bb363_26, phi_bb363_27, phi_bb363_28, phi_bb363_31, phi_bb363_32, phi_bb363_34, phi_bb363_35, phi_bb363_36, phi_bb363_47, phi_bb363_49, phi_bb363_50, phi_bb363_19, phi_bb363_19, phi_bb363_19, phi_bb363_19});
  }

  TNode<IntPtrT> phi_bb376_19;
  TNode<IntPtrT> phi_bb376_25;
  TNode<IntPtrT> phi_bb376_26;
  TNode<IntPtrT> phi_bb376_27;
  TNode<IntPtrT> phi_bb376_28;
  TNode<IntPtrT> phi_bb376_31;
  TNode<BoolT> phi_bb376_32;
  TNode<IntPtrT> phi_bb376_34;
  TNode<IntPtrT> phi_bb376_35;
  TNode<BoolT> phi_bb376_36;
  TNode<BoolT> phi_bb376_47;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb376_49;
  TNode<IntPtrT> phi_bb376_50;
  TNode<IntPtrT> phi_bb376_55;
  TNode<IntPtrT> phi_bb376_56;
  TNode<IntPtrT> phi_bb376_60;
  TNode<IntPtrT> phi_bb376_61;
  TNode<IntPtrT> tmp785;
  TNode<IntPtrT> tmp786;
  TNode<Union<HeapObject, TaggedIndex>> tmp787;
  TNode<IntPtrT> tmp788;
  TNode<Object> tmp789;
  TNode<IntPtrT> tmp790;
  if (block376.is_used()) {
    ca_.Bind(&block376, &phi_bb376_19, &phi_bb376_25, &phi_bb376_26, &phi_bb376_27, &phi_bb376_28, &phi_bb376_31, &phi_bb376_32, &phi_bb376_34, &phi_bb376_35, &phi_bb376_36, &phi_bb376_47, &phi_bb376_49, &phi_bb376_50, &phi_bb376_55, &phi_bb376_56, &phi_bb376_60, &phi_bb376_61);
    tmp785 = TimesSizeOf_Object_0(state_, TNode<IntPtrT>{phi_bb376_61});
    tmp786 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp780}, TNode<IntPtrT>{tmp785});
    std::tie(tmp787, tmp788) = NewReference_Object_0(state_, TNode<Union<HeapObject, TaggedIndex>>{tmp779}, TNode<IntPtrT>{tmp786}).Flatten();
    tmp789 = CodeStubAssembler(state_).LoadReference<Object>(CodeStubAssembler::Reference{tmp787, tmp788});
    tmp790 = CodeStubAssembler(state_).BitcastTaggedToWord(TNode<Object>{tmp789});
    CodeStubAssembler(state_).StoreReference<IntPtrT>(CodeStubAssembler::Reference{phi_bb376_49, phi_bb376_50}, tmp790);
    ca_.Goto(&block362, phi_bb376_19, tmp755, phi_bb376_25, phi_bb376_26, phi_bb376_27, phi_bb376_28, phi_bb376_31, phi_bb376_32, phi_bb376_34, phi_bb376_35, phi_bb376_36, phi_bb376_47);
  }

  TNode<IntPtrT> phi_bb377_19;
  TNode<IntPtrT> phi_bb377_25;
  TNode<IntPtrT> phi_bb377_26;
  TNode<IntPtrT> phi_bb377_27;
  TNode<IntPtrT> phi_bb377_28;
  TNode<IntPtrT> phi_bb377_31;
  TNode<BoolT> phi_bb377_32;
  TNode<IntPtrT> phi_bb377_34;
  TNode<IntPtrT> phi_bb377_35;
  TNode<BoolT> phi_bb377_36;
  TNode<BoolT> phi_bb377_47;
  TNode<Union<HeapObject, TaggedIndex>> phi_bb377_49;
  TNode<IntPtrT> phi_bb377_50;
  TNode<IntPtrT> phi_bb377_55;
  TNode<IntPtrT> phi_bb377_56;
  TNode<IntPtrT> phi_bb377_60;
  TNode<IntPtrT> phi_bb377_61;
  if (block377.is_used()) {
    ca_.Bind(&block377, &phi_bb377_19, &phi_bb377_25, &phi_bb377_26, &phi_bb377_27, &phi_bb377_28, &phi_bb377_31, &phi_bb377_32, &phi_bb377_34, &phi_bb377_35, &phi_bb377_36, &phi_bb377_47, &phi_bb377_49, &phi_bb377_50, &phi_bb377_55, &phi_bb377_56, &phi_bb377_60, &phi_bb377_61);
    CodeStubAssembler(state_).Unreachable();
  }

  TNode<IntPtrT> phi_bb362_19;
  TNode<IntPtrT> phi_bb362_24;
  TNode<IntPtrT> phi_bb362_25;
  TNode<IntPtrT> phi_bb362_26;
  TNode<IntPtrT> phi_bb362_27;
  TNode<IntPtrT> phi_bb362_28;
  TNode<IntPtrT> phi_bb362_31;
  TNode<BoolT> phi_bb362_32;
  TNode<IntPtrT> phi_bb362_34;
  TNode<IntPtrT> phi_bb362_35;
  TNode<BoolT> phi_bb362_36;
  TNode<BoolT> phi_bb362_47;
  TNode<IntPtrT> tmp791;
  TNode<IntPtrT> tmp792;
  if (block362.is_used()) {
    ca_.Bind(&block362, &phi_bb362_19, &phi_bb362_24, &phi_bb362_25, &phi_bb362_26, &phi_bb362_27, &phi_bb362_28, &phi_bb362_31, &phi_bb362_32, &phi_bb362_34, &phi_bb362_35, &phi_bb362_36, &phi_bb362_47);
    tmp791 = FromConstexpr_intptr_constexpr_int31_0(state_, 1);
    tmp792 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{phi_bb362_19}, TNode<IntPtrT>{tmp791});
    ca_.Goto(&block352, tmp792, phi_bb362_24, phi_bb362_25, phi_bb362_26, phi_bb362_27, phi_bb362_28, phi_bb362_31, phi_bb362_32, phi_bb362_34, phi_bb362_35, phi_bb362_36, tmp748, phi_bb362_47);
  }

  TNode<IntPtrT> phi_bb351_19;
  TNode<IntPtrT> phi_bb351_24;
  TNode<IntPtrT> phi_bb351_25;
  TNode<IntPtrT> phi_bb351_26;
  TNode<IntPtrT> phi_bb351_27;
  TNode<IntPtrT> phi_bb351_28;
  TNode<IntPtrT> phi_bb351_31;
  TNode<BoolT> phi_bb351_32;
  TNode<IntPtrT> phi_bb351_34;
  TNode<IntPtrT> phi_bb351_35;
  TNode<BoolT> phi_bb351_36;
  TNode<IntPtrT> phi_bb351_45;
  TNode<BoolT> phi_bb351_47;
  if (block351.is_used()) {
    ca_.Bind(&block351, &phi_bb351_19, &phi_bb351_24, &phi_bb351_25, &phi_bb351_26, &phi_bb351_27, &phi_bb351_28, &phi_bb351_31, &phi_bb351_32, &phi_bb351_34, &phi_bb351_35, &phi_bb351_36, &phi_bb351_45, &phi_bb351_47);
    ca_.Goto(&block345, phi_bb351_19, phi_bb351_24, phi_bb351_25, phi_bb351_26, phi_bb351_27, phi_bb351_28, phi_bb351_31, phi_bb351_32, phi_bb351_34, phi_bb351_35, phi_bb351_36, phi_bb351_45, tmp741, phi_bb351_47);
  }

  TNode<IntPtrT> phi_bb345_19;
  TNode<IntPtrT> phi_bb345_24;
  TNode<IntPtrT> phi_bb345_25;
  TNode<IntPtrT> phi_bb345_26;
  TNode<IntPtrT> phi_bb345_27;
  TNode<IntPtrT> phi_bb345_28;
  TNode<IntPtrT> phi_bb345_31;
  TNode<BoolT> phi_bb345_32;
  TNode<IntPtrT> phi_bb345_34;
  TNode<IntPtrT> phi_bb345_35;
  TNode<BoolT> phi_bb345_36;
  TNode<IntPtrT> phi_bb345_45;
  TNode<IntPtrT> phi_bb345_46;
  TNode<BoolT> phi_bb345_47;
  TNode<IntPtrT> tmp793;
  TNode<IntPtrT> tmp794;
  TNode<IntPtrT> tmp795;
  TNode<IntPtrT> tmp796;
  TNode<IntPtrT> tmp797;
  TNode<IntPtrT> tmp798;
  TNode<Int32T> tmp799;
  TNode<IntPtrT> tmp800;
  TNode<Union<HeapObject, TaggedIndex>> tmp801;
  TNode<IntPtrT> tmp802;
  TNode<IntPtrT> tmp803;
  TNode<IntPtrT> tmp804;
  TNode<Union<HeapObject, TaggedIndex>> tmp805;
  TNode<IntPtrT> tmp806;
  TNode<IntPtrT> tmp807;
  TNode<IntPtrT> tmp808;
  TNode<Union<HeapObject, TaggedIndex>> tmp809;
  TNode<IntPtrT> tmp810;
  TNode<Float64T> tmp811;
  TNode<IntPtrT> tmp812;
  TNode<Union<HeapObject, TaggedIndex>> tmp813;
  TNode<IntPtrT> tmp814;
  TNode<Float64T> tmp815;
  if (block345.is_used()) {
    ca_.Bind(&block345, &phi_bb345_19, &phi_bb345_24, &phi_bb345_25, &phi_bb345_26, &phi_bb345_27, &phi_bb345_28, &phi_bb345_31, &phi_bb345_32, &phi_bb345_34, &phi_bb345_35, &phi_bb345_36, &phi_bb345_45, &phi_bb345_46, &phi_bb345_47);
    tmp793 = Convert_intptr_RawPtr_0(state_, TNode<RawPtrT>{tmp472});
    tmp794 = Convert_intptr_RawPtr_0(state_, TNode<RawPtrT>{tmp83});
    tmp795 = CodeStubAssembler(state_).IntPtrSub(TNode<IntPtrT>{tmp793}, TNode<IntPtrT>{tmp794});
    tmp796 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    tmp797 = CodeStubAssembler(state_).IntPtrDiv(TNode<IntPtrT>{tmp795}, TNode<IntPtrT>{tmp796});
    tmp798 = CodeStubAssembler(state_).IntPtrAdd(TNode<IntPtrT>{tmp797}, TNode<IntPtrT>{tmp11});
    tmp799 = FromConstexpr_int32_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x1ull));
    ModifyThreadInWasmFlag_0(state_, TNode<Int32T>{tmp799});
    tmp800 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    std::tie(tmp801, tmp802) = GetRefAt_intptr_RawPtr_intptr_0(state_, TNode<RawPtrT>{tmp459}, TNode<IntPtrT>{tmp800}).Flatten();
    tmp803 = CodeStubAssembler(state_).LoadReference<IntPtrT>(CodeStubAssembler::Reference{tmp801, tmp802});
    tmp804 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_intptr_0(state_)));
    std::tie(tmp805, tmp806) = GetRefAt_intptr_RawPtr_intptr_0(state_, TNode<RawPtrT>{tmp459}, TNode<IntPtrT>{tmp804}).Flatten();
    tmp807 = CodeStubAssembler(state_).LoadReference<IntPtrT>(CodeStubAssembler::Reference{tmp805, tmp806});
    tmp808 = FromConstexpr_intptr_constexpr_IntegerLiteral_0(state_, IntegerLiteral(false, 0x0ull));
    std::tie(tmp809, tmp810) = GetRefAt_float64_RawPtr_float64_0(state_, TNode<RawPtrT>{tmp461}, TNode<IntPtrT>{tmp808}).Flatten();
    tmp811 = CodeStubAssembler(state_).LoadReference<Float64T>(CodeStubAssembler::Reference{tmp809, tmp810});
    tmp812 = FromConstexpr_intptr_constexpr_int31_0(state_, (SizeOf_float64_0(state_)));
    std::tie(tmp813, tmp814) = GetRefAt_float64_RawPtr_float64_0(state_, TNode<RawPtrT>{tmp461}, TNode<IntPtrT>{tmp812}).Flatten();
    tmp815 = CodeStubAssembler(state_).LoadReference<Float64T>(CodeStubAssembler::Reference{tmp813, tmp814});
    CodeStubAssembler(state_).SwitchFromTheCentralStack(TNode<RawPtrT>{tmp0});
    ca_.Goto(&block380);
  }

    ca_.Bind(&block380);
  return TorqueStructWasmToJSResult{TNode<IntPtrT>{tmp798}, TNode<IntPtrT>{tmp803}, TNode<IntPtrT>{tmp807}, TNode<Float64T>{tmp811}, TNode<Float64T>{tmp815}};
}

// https://source.chromium.org/chromium/chromium/src/+/main:v8/src/builtins/wasm-to-js.tq?l=53&c=10
TNode<BoolT> Is_WasmImportData_WasmImportData_0(compiler::CodeAssemblerState* state_, TNode<Context> p_context, TNode<WasmImportData> p_o) {
  compiler::CodeAssembler ca_(state_);
  compiler::CodeAssembler::SourcePositionScope pos_scope(&ca_);
  compiler::CodeAssemblerParameterizedLabel<> block0(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block5(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block4(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<BoolT> block1(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block6(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
    ca_.Goto(&block0);

  TNode<WasmImportData> tmp0;
  if (block0.is_used()) {
    ca_.Bind(&block0);
    compiler::CodeAssemblerLabel label1(&ca_);
    tmp0 = Cast_WasmImportData_0(state_, TNode<HeapObject>{p_o}, &label1);
    ca_.Goto(&block4);
    if (label1.is_used()) {
      ca_.Bind(&label1);
      ca_.Goto(&block5);
    }
  }

  TNode<BoolT> tmp2;
  if (block5.is_used()) {
    ca_.Bind(&block5);
    tmp2 = FromConstexpr_bool_constexpr_bool_0(state_, false);
    ca_.Goto(&block1, tmp2);
  }

  TNode<BoolT> tmp3;
  if (block4.is_used()) {
    ca_.Bind(&block4);
    tmp3 = FromConstexpr_bool_constexpr_bool_0(state_, true);
    ca_.Goto(&block1, tmp3);
  }

  TNode<BoolT> phi_bb1_2;
  if (block1.is_used()) {
    ca_.Bind(&block1, &phi_bb1_2);
    ca_.Goto(&block6);
  }

    ca_.Bind(&block6);
  return TNode<BoolT>{phi_bb1_2};
}

// https://source.chromium.org/chromium/chromium/src/+/main:v8/src/builtins/wasm-to-js.tq?l=58&c=4
TorqueStructReference_RawPtr_0 GetRefAt_RawPtr_RawPtr_0(compiler::CodeAssemblerState* state_, TNode<RawPtrT> p_base, TNode<IntPtrT> p_offset) {
  compiler::CodeAssembler ca_(state_);
  compiler::CodeAssembler::SourcePositionScope pos_scope(&ca_);
  compiler::CodeAssemblerParameterizedLabel<> block0(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block2(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
    ca_.Goto(&block0);

  TNode<RawPtrT> tmp0;
  TNode<RawPtrT> tmp1;
  TNode<Union<HeapObject, TaggedIndex>> tmp2;
  TNode<IntPtrT> tmp3;
  if (block0.is_used()) {
    ca_.Bind(&block0);
    tmp0 = CodeStubAssembler(state_).RawPtrAdd(TNode<RawPtrT>{p_base}, TNode<IntPtrT>{p_offset});
    tmp1 = (TNode<RawPtrT>{tmp0});
    std::tie(tmp2, tmp3) = NewOffHeapReference_RawPtr_0(state_, TNode<RawPtrT>{tmp1}).Flatten();
    ca_.Goto(&block2);
  }

    ca_.Bind(&block2);
  return TorqueStructReference_RawPtr_0{TNode<Union<HeapObject, TaggedIndex>>{tmp2}, TNode<IntPtrT>{tmp3}, TorqueStructUnsafe_0{}};
}

// https://source.chromium.org/chromium/chromium/src/+/main:v8/src/builtins/wasm-to-js.tq?l=185&c=4
TorqueStructReference_intptr_0 GetRefAt_intptr_RawPtr_0(compiler::CodeAssemblerState* state_, TNode<RawPtrT> p_base, TNode<IntPtrT> p_offset) {
  compiler::CodeAssembler ca_(state_);
  compiler::CodeAssembler::SourcePositionScope pos_scope(&ca_);
  compiler::CodeAssemblerParameterizedLabel<> block0(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block2(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
    ca_.Goto(&block0);

  TNode<RawPtrT> tmp0;
  TNode<RawPtrT> tmp1;
  TNode<Union<HeapObject, TaggedIndex>> tmp2;
  TNode<IntPtrT> tmp3;
  if (block0.is_used()) {
    ca_.Bind(&block0);
    tmp0 = CodeStubAssembler(state_).RawPtrAdd(TNode<RawPtrT>{p_base}, TNode<IntPtrT>{p_offset});
    tmp1 = (TNode<RawPtrT>{tmp0});
    std::tie(tmp2, tmp3) = NewOffHeapReference_intptr_0(state_, TNode<RawPtrT>{tmp1}).Flatten();
    ca_.Goto(&block2);
  }

    ca_.Bind(&block2);
  return TorqueStructReference_intptr_0{TNode<Union<HeapObject, TaggedIndex>>{tmp2}, TNode<IntPtrT>{tmp3}, TorqueStructUnsafe_0{}};
}

// https://source.chromium.org/chromium/chromium/src/+/main:v8/src/builtins/wasm-to-js.tq?l=305&c=15
TorqueStructReference_float64_0 GetRefAt_float64_RawPtr_float64_0(compiler::CodeAssemblerState* state_, TNode<RawPtrT> p_base, TNode<IntPtrT> p_offset) {
  compiler::CodeAssembler ca_(state_);
  compiler::CodeAssembler::SourcePositionScope pos_scope(&ca_);
  compiler::CodeAssemblerParameterizedLabel<> block0(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
  compiler::CodeAssemblerParameterizedLabel<> block2(&ca_, compiler::CodeAssemblerLabel::kNonDeferred);
    ca_.Goto(&block0);

  TNode<RawPtrT> tmp0;
  TNode<RawPtrT> tmp1;
  TNode<Union<HeapObject, TaggedIndex>> tmp2;
  TNode<IntPtrT> tmp3;
  if (block0.is_used()) {
    ca_.Bind(&block0);
    tmp0 = CodeStubAssembler(state_).RawPtrAdd(TNode<RawPtrT>{p_base}, TNode<IntPtrT>{p_offset});
    tmp1 = (TNode<RawPtrT>{tmp0});
    std::tie(tmp2, tmp3) = NewOffHeapReference_float64_0(state_, TNode<RawPtrT>{tmp1}).Flatten();
    ca_.Goto(&block2);
  }

    ca_.Bind(&block2);
  return TorqueStructReference_float64_0{TNode<Union<HeapObject, TaggedIndex>>{tmp2}, TNode<IntPtrT>{tmp3}, TorqueStructUnsafe_0{}};
}

} // namespace internal
} // namespace v8
